"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.SpinAnimation = exports.Playground = exports.ComposedAnimations = exports.AnimatedListings = void 0;
var _jest = require("@storybook/jest");
var _testingLibrary = require("@storybook/testing-library");
var _react = _interopRequireWildcard(require("react"));
var _Box = require("../Box/Box");
var _Button = require("../Button/Button");
var _ChoiceChip = require("../Chip/ChoiceChip/ChoiceChip");
var _Flex = require("../Flex/Flex");
var _Image = require("../Image/Image");
var _Text = require("../Text/Text");
var _Animate = require("./Animate");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/* eslint-disable jsx-a11y/accessible-emoji */

const meta = {
  component: _Animate.Animate
};
var _default = exports.default = meta;
const Playground = () => {
  const [motion, setMotion] = (0, _react.useState)('expandDown');
  const [transition, setTransition] = (0, _react.useState)('default');
  const [isRendered, setIsRendered] = (0, _react.useState)(true);
  const rerender = () => {
    setIsRendered(false);
    setTimeout(() => setIsRendered(true));
  };
  const handleMotionChange = variant => {
    setMotion(variant);
    rerender();
  };
  const handleTransitionChange = variant => {
    setTransition(variant);
    rerender();
  };
  return _react.default.createElement(_Flex.Flex, {
    flexDirection: 'column',
    maxWidth: 600
  }, _react.default.createElement(_Text.Text, {
    fontSize: 5,
    bold: true
  }, "Motion Variants"), _react.default.createElement(_Flex.Flex, {
    flexWrap: 'wrap'
  }, Object.keys(_Animate.MotionVariants).map(variant => _react.default.createElement(_ChoiceChip.ChoiceChip, {
    "data-testid": variant,
    selected: motion === variant,
    m: 2,
    key: variant,
    onClick: () => handleMotionChange(variant)
  }, variant))), _react.default.createElement(_Text.Text, {
    fontSize: 5,
    bold: true
  }, "Transition Variants"), _react.default.createElement(_Flex.Flex, {
    flexWrap: 'wrap'
  }, Object.keys(_Animate.TransitionVariants).map(variant => _react.default.createElement(_ChoiceChip.ChoiceChip, {
    "data-testid": variant,
    selected: transition === variant,
    m: 2,
    key: variant,
    onClick: () => handleTransitionChange(variant)
  }, variant))), isRendered && _react.default.createElement(_Animate.Animate, {
    variant: motion,
    transition: transition
  }, _react.default.createElement(_Flex.Flex, {
    "data-testid": 'playground-content',
    p: 5,
    bg: 'background.darkest',
    flexDirection: 'column',
    justifyContent: 'center',
    alignItems: 'center'
  }, _react.default.createElement(_Text.Text, {
    fontSize: 5,
    bold: true,
    color: 'text.lightest'
  }, "Hello \uD83D\uDC4B"), _react.default.createElement(_Text.Text, {
    fontSize: 5,
    bold: true,
    color: 'text.lightest'
  }, "World \uD83C\uDF0E"))));
};
exports.Playground = Playground;
const delay = time => new Promise(resolve => setTimeout(resolve, time));
Playground.play = async ({
  canvasElement
}) => {
  const canvas = (0, _testingLibrary.within)(canvasElement);
  await _testingLibrary.userEvent.click(canvas.getByText('fadeIn'));
  await delay(1000);
  const playgroundContent = await canvas.getByTestId('playground-content');
  await (0, _jest.expect)(playgroundContent).toBeTruthy();
};
const AnimatedListings = () => {
  const [isRendered, setIsRendered] = (0, _react.useState)(true);
  const rerender = () => {
    setIsRendered(false);
    setTimeout(() => setIsRendered(true));
  };
  return _react.default.createElement(_Box.Box, null, _react.default.createElement(_Button.Button, {
    onClick: rerender
  }, "Reset"), isRendered && Array.from(Array(10).keys()).map(i => _react.default.createElement(_Animate.Animate, {
    key: i,
    variant: 'scaleFromTopLeft',
    override: {
      transition: {
        ..._Animate.TransitionVariants.default,
        delay: 0.05 * i
      }
    }
  }, _react.default.createElement(_Flex.Flex, {
    m: 2
  }, _react.default.createElement(_Image.Image, {
    src: `https://picsum.photos/id/${i + 50}/160/90`,
    alt: 'random'
  }), _react.default.createElement(_Flex.Flex, {
    p: 2,
    bg: 'background.darkest',
    alignItems: 'center'
  }, _react.default.createElement(_Text.Text, {
    color: 'text.lightest',
    fontSize: 3
  }, "\uD83D\uDC48 Travel Here \uD83C\uDFE8 \u2708\uFE0F \uD83D\uDE99"))))));
};
exports.AnimatedListings = AnimatedListings;
const ComposedAnimations = () => {
  const [isRendered, setIsRendered] = (0, _react.useState)(true);
  const rerender = () => {
    setIsRendered(false);
    setTimeout(() => setIsRendered(true));
  };
  return _react.default.createElement(_Box.Box, null, _react.default.createElement(_Flex.Flex, {
    width: 'fit-content'
  }, _react.default.createElement(_Button.Button, {
    m: 2,
    onClick: rerender
  }, "Reset")), isRendered && _react.default.createElement(_Animate.Animate, {
    variant: 'scaleFromTopLeft'
  }, _react.default.createElement(_Flex.Flex, {
    width: 'fit-content'
  }, _react.default.createElement(_Animate.Animate, {
    variant: 'scaleOnHover'
  }, _react.default.createElement(_Button.Button, {
    m: 2
  }, "Hover Me")), _react.default.createElement(_Animate.Animate, {
    variant: 'scaleOnTap',
    transition: 'spring'
  }, _react.default.createElement(_Button.Button, {
    m: 2
  }, "Click Me")), _react.default.createElement(_Animate.Animate, {
    variant: 'scaleOnTap'
  }, _react.default.createElement(_Animate.Animate, {
    variant: 'scaleOnHover'
  }, _react.default.createElement(_Button.Button, {
    m: 2
  }, "I Do Both!"))))));
};
exports.ComposedAnimations = ComposedAnimations;
const SpinAnimation = () => {
  return _react.default.createElement(_Flex.Flex, {
    width: 'fit-content'
  }, _react.default.createElement(_Animate.Animate, {
    variant: 'spin'
  }, _react.default.createElement(_Button.Button, {
    m: 2
  }, "Spin!")));
};
exports.SpinAnimation = SpinAnimation;