"use strict";

var _react = _interopRequireDefault(require("react"));
var _theme = require("../theme/theme");
var _BackgroundImage = require("./BackgroundImage");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
describe('BackgroundImage', () => {
  test('renders', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_BackgroundImage.BackgroundImage, null)).toJSON();
    expect(json).toMatchSnapshot();
  });
  test('renders with image', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_BackgroundImage.BackgroundImage, {
      image: 'hello.png'
    })).toJSON();
    expect(json).toMatchSnapshot();
  });
  test('renders with height', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_BackgroundImage.BackgroundImage, {
      height: '320px'
    })).toJSON();
    expect(json).toMatchSnapshot();
  });
  test('renders with border radius', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_BackgroundImage.BackgroundImage, {
      height: '320px',
      borderRadius: 'full',
      rounded: 'top'
    })).toJSON();
    expect(json).toMatchSnapshot();
    const {
      borderRadii: {
        full
      }
    } = _theme.theme;
    expect(json).toHaveStyleRule('border-radius', `${full} ${full} 0 0`);
  });
  test('renders with background position', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_BackgroundImage.BackgroundImage, {
      height: '320px',
      borderRadius: 'full',
      rounded: 'top',
      backgroundPosition: 'top'
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('background-position', 'top');
  });
  test('renders with default background position', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_BackgroundImage.BackgroundImage, {
      height: '320px',
      borderRadius: 'full',
      rounded: 'top'
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('background-position', 'center');
  });
  describe('variations', () => {
    describe('parallax variation', () => {
      test('default render', () => {
        const json = rendererCreateWithTheme(_react.default.createElement(_BackgroundImage.BackgroundImage, {
          variation: 'parallax',
          image: 'hello.png'
        })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('background-attachment', 'fixed');
      });
    });
  });
});