"use strict";

var _react = _interopRequireDefault(require("react"));
var _testingLibrary = require("../__test__/testing-library");
var _theme = require("../theme");
var _Badge = require("./Badge");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
describe('Badge', () => {
  let consoleError;
  beforeEach(() => {
    consoleError = console.error;
    console.error = jest.fn();
  });
  afterEach(() => console.error = consoleError);
  test('renders', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Badge.Badge, null)).toJSON();
    expect(json).toMatchSnapshot();
  });
  test('renders small', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Badge.Badge, {
      size: 'small'
    })).toJSON();
    expect(json).toMatchSnapshot();
  });
  test('bg green sets background-color and color', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Badge.Badge, {
      bg: 'green'
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('background-color', _theme.theme.colors.green);
    expect(json).toHaveStyleRule('color', _theme.theme.colors.white);
  });
  test('bg lightGreen sets background-color and color', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Badge.Badge, {
      bg: 'lightGreen'
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('background-color', _theme.theme.colors.lightGreen);
    expect(json).toHaveStyleRule('color', _theme.theme.colors.darkGreen);
  });
  test('bg red sets background-color and color', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Badge.Badge, {
      bg: 'red'
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('background-color', _theme.theme.colors.red);
    expect(json).toHaveStyleRule('color', _theme.theme.colors.white);
  });
  test('bg lightRed sets background-color and color', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Badge.Badge, {
      bg: 'lightRed'
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('background-color', _theme.theme.colors.lightRed);
    expect(json).toHaveStyleRule('color', _theme.theme.colors.darkRed);
  });
  test('bg orange sets background-color and color', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Badge.Badge, {
      bg: 'orange'
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('background-color', _theme.theme.colors.orange);
    expect(json).toHaveStyleRule('color', _theme.theme.colors.text);
  });
  test('bg blue sets background-color and color', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Badge.Badge, {
      bg: 'blue'
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('background-color', _theme.theme.colors.blue);
    expect(json).toHaveStyleRule('color', _theme.theme.colors.white);
  });
  test('bg lightBlue sets background-color and color', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Badge.Badge, {
      bg: 'lightBlue'
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('background-color', _theme.theme.colors.lightBlue);
    expect(json).toHaveStyleRule('color', _theme.theme.colors.darkBlue);
  });
  test('non-preset: bg text sets background-color and color white sets color', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Badge.Badge, {
      bg: 'text',
      color: 'white'
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('background-color', _theme.theme.colors.text);
    expect(json).toHaveStyleRule('color', _theme.theme.colors.white);
  });
  test('can escape preset: bg lightBlue sets background-color and color text sets color', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Badge.Badge, {
      bg: 'lightBlue',
      color: 'text'
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('background-color', _theme.theme.colors.lightBlue);
    expect(json).toHaveStyleRule('color', _theme.theme.colors.text);
  });
  test('textTransform', () => {
    (0, _testingLibrary.render)(_react.default.createElement(_Badge.Badge, {
      textTransform: 'lowercase'
    }, "Lowercase Text"));
    expect(_testingLibrary.screen.getByText('Lowercase Text')).toHaveStyleRule('text-transform', 'lowercase');
    expect(_testingLibrary.screen.getByText('Lowercase Text')).toHaveStyleRule('letter-spacing', 'normal');
  });
  test('size', () => {
    (0, _testingLibrary.render)(_react.default.createElement(_Badge.Badge, {
      size: 'captionMedium'
    }, "Caption"));
    expect(_testingLibrary.screen.getByText('Caption')).toHaveStyleRule('padding-right', _theme.theme.space[2]);
  });
});