"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Banner = Banner;
var _pclnIcons = require("pcln-icons");
var _react = _interopRequireDefault(require("react"));
var _styledComponents = _interopRequireDefault(require("styled-components"));
var _Box = require("../Box/Box");
var _CloseButton = require("../CloseButton/CloseButton");
var _Flex = require("../Flex/Flex");
var _Text = require("../Text/Text");
var _utils = require("../utils/utils");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const bannerColors = {
  green: {
    backgroundColor: 'secondary.base',
    color: 'text.lightest',
    icon: _react.default.createElement(_pclnIcons.Success, null)
  },
  lightGreen: {
    backgroundColor: 'secondary.light',
    color: 'secondary.dark',
    icon: _react.default.createElement(_pclnIcons.Success, null)
  },
  red: {
    backgroundColor: 'error.base',
    color: 'text.lightest',
    icon: _react.default.createElement(_pclnIcons.Warning, null)
  },
  lightRed: {
    backgroundColor: 'error.light',
    color: 'error.dark',
    icon: _react.default.createElement(_pclnIcons.Warning, null)
  },
  orange: {
    backgroundColor: 'alert.base',
    color: 'text.lightest',
    icon: _react.default.createElement(_pclnIcons.Attention, null)
  },
  blue: {
    backgroundColor: 'primary.base',
    color: 'text.lightest',
    icon: _react.default.createElement(_pclnIcons.Information, null)
  },
  lightBlue: {
    backgroundColor: 'primary.light',
    color: 'primary.dark',
    icon: _react.default.createElement(_pclnIcons.Information, null)
  }
};
const StyledBox = /*#__PURE__*/(0, _styledComponents.default)(_Box.Box).withConfig({
  displayName: "Banner__StyledBox",
  componentId: "sc-1xoq14y-0"
})(["", ""], (0, _utils.applyVariations)('Banner'));
/**
 * @public
 */
function Banner(props) {
  const bannerColor = bannerColors[!props.bg && props.color === 'green' ? props.color : props.bg] || {};
  const Icon = props.icon || bannerColor.icon;
  const color = !bannerColor.color ? props.color : bannerColor.color;
  let header = null;
  if (props.header) {
    header = _react.default.isValidElement(props.header) ? props.header : _react.default.createElement(_Text.Text, {
      textStyle: 'display2'
    }, props.header);
  }
  return _react.default.createElement(StyledBox, {
    ...props,
    bg: bannerColor.backgroundColor || props.bg,
    color: color
  }, _react.default.createElement(_Flex.Flex, {
    justifyContent: 'space-between',
    alignItems: 'flex-start'
  }, !!Icon && !!props.showIcon && _react.default.cloneElement(Icon, {
    mr: 2,
    size: 24,
    mt: '-2px'
  }), _react.default.createElement(_Box.Box, {
    textAlign: props.textAlign,
    width: 1
  }, header, _react.default.createElement(_Text.Text.span, {
    fontSize: 1
  }, props.text), props.children), !!props.onClose && _react.default.createElement(_CloseButton.CloseButton, {
    onClick: props.onClose,
    ml: 2,
    size: 24,
    title: 'close',
    mt: '-2px'
  })));
}
Banner.displayName = 'Banner';
Banner.defaultProps = {
  textAlign: 'left',
  showIcon: true,
  color: 'green'
};