"use strict";

var _pclnIcons = require("pcln-icons");
var _react = _interopRequireDefault(require("react"));
var _Banner = require("../Banner/Banner");
var _Heading = require("../Heading/Heading");
var _Text = require("../Text/Text");
var _testingLibrary = require("../__test__/testing-library");
var _theme = require("../theme/theme");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
describe('Banner', () => {
  let consoleError;
  beforeEach(() => {
    consoleError = console.error;
    console.error = jest.fn();
  });
  afterEach(() => console.error = consoleError);
  test('renders with no props other than theme', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Banner.Banner, null)).toJSON();
    expect(json).toMatchSnapshot();
  });
  test('renders with an icon', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Banner.Banner, {
      icon: _react.default.createElement(_pclnIcons.Star, null)
    })).toJSON();
    expect(json).toMatchSnapshot();
  });
  test('renders with text string', () => {
    const {
      asFragment
    } = (0, _testingLibrary.render)(_react.default.createElement(_Banner.Banner, {
      header: 'Header',
      text: 'Text',
      icon: _react.default.createElement(_pclnIcons.Star, null)
    }));
    expect(asFragment()).toMatchSnapshot();
  });
  test('renders with text node', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Banner.Banner, {
      header: 'Header',
      text: _react.default.createElement(_Text.Text, null, "Text"),
      icon: _react.default.createElement(_pclnIcons.Star, null)
    })).toJSON();
    expect(json).toMatchSnapshot();
  });
  test('renders with blue bg', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Banner.Banner, {
      bg: 'blue'
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('background-color', _theme.theme.colors.blue);
    expect(json).toHaveStyleRule('color', _theme.theme.colors.white);
  });
  test('renders with green bg', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Banner.Banner, {
      bg: 'green'
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('background-color', _theme.theme.colors.green);
    expect(json).toHaveStyleRule('color', _theme.theme.colors.white);
  });
  test('renders with orange bg', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Banner.Banner, {
      bg: 'orange'
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('background-color', _theme.theme.colors.orange);
    expect(json).toHaveStyleRule('color', _theme.theme.colors.white);
  });
  test('renders with red bg', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Banner.Banner, {
      bg: 'red'
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('background-color', _theme.theme.colors.red);
    expect(json).toHaveStyleRule('color', _theme.theme.colors.white);
  });
  test('renders with lightBlue bg', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Banner.Banner, {
      bg: 'lightBlue'
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('background-color', _theme.theme.colors.lightBlue);
    expect(json).toHaveStyleRule('color', _theme.theme.colors.darkBlue);
  });
  test('renders with lightGreen bg', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Banner.Banner, {
      bg: 'lightGreen'
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('background-color', _theme.theme.colors.lightGreen);
    expect(json).toHaveStyleRule('color', _theme.theme.colors.darkGreen);
  });
  test('renders with lightRed bg', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Banner.Banner, {
      bg: 'lightRed'
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('background-color', _theme.theme.colors.lightRed);
    expect(json).toHaveStyleRule('color', _theme.theme.colors.darkRed);
  });
  test('renders close button if onClose func is provided', () => {
    function noop() {}
    const {
      container
    } = (0, _testingLibrary.render)(_react.default.createElement(_Banner.Banner, {
      onClose: noop
    }));
    const closeButton = container.querySelector('button');
    expect(closeButton).toBeTruthy();
  });
  test('does render blue left-hand icon by default', () => {
    const {
      container
    } = (0, _testingLibrary.render)(_react.default.createElement(_Banner.Banner, {
      bg: 'blue'
    }));
    const icon = container.querySelector('svg');
    // todo: check svg path/attrs for correct icon
    expect(icon).toBeTruthy();
  });
  test('does not render blue left-hand icon if showIcon is false', () => {
    const {
      container
    } = (0, _testingLibrary.render)(_react.default.createElement(_Banner.Banner, {
      bg: 'blue',
      showIcon: false
    }));
    const icon = container.querySelector('svg');
    expect(icon).toBeFalsy();
  });
  test('accepts non-preset colors', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Banner.Banner, {
      bg: 'gray'
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('background-color', _theme.theme.colors.gray);
  });
  test('renders content from children props', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Banner.Banner, null, _react.default.createElement("span", null, "123"))).toJSON();
    expect(json).toMatchSnapshot();
  });
  test('renders with header node', () => {
    const {
      asFragment,
      getByText
    } = (0, _testingLibrary.render)(_react.default.createElement(_Banner.Banner, {
      header: _react.default.createElement(_Heading.Heading, null, "Hello world"),
      text: _react.default.createElement(_Text.Text, null, "Text")
    }));
    getByText(/Hello world/);
    expect(asFragment()).toMatchSnapshot();
  });
});