"use strict";

var _react = _interopRequireDefault(require("react"));
var _testingLibrary = require("../__test__/testing-library");
var _theme = require("../theme/theme");
var _Box = require("./Box");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
describe('Box', () => {
  test('renders', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Box.Box, null)).toJSON();
    expect(json).toMatchSnapshot();
  });
  test('width and height props set width/height', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Box.Box, {
      width: 1 / 2,
      height: '50%'
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('height', '50%');
    expect(json).toHaveStyleRule('width', '50%');
  });
  test('m prop sets margin', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Box.Box, {
      m: 2
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('margin', _theme.theme.space[2]);
  });
  test('maxHeight, maxWidth, minHeight, minWidth', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Box.Box, {
      maxHeight: 250,
      maxWidth: 250,
      minHeight: 55,
      minWidth: 55
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('max-height', '250px');
    expect(json).toHaveStyleRule('max-width', '250px');
    expect(json).toHaveStyleRule('min-height', '55px');
    expect(json).toHaveStyleRule('min-width', '55px');
  });
  test('p prop sets padding', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Box.Box, {
      p: 2
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('padding', _theme.theme.space[2]);
  });
  test('color prop sets color', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Box.Box, {
      color: 'blue'
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('color', _theme.theme.colors.blue);
  });
  test('boxShadowSize prop sets box-shadow', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Box.Box, {
      boxShadowSize: 'sm'
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('box-shadow', _theme.theme.shadows.sm);
  });
  test('overflow prop sets overflow', () => {
    const {
      asFragment,
      getByTestId
    } = (0, _testingLibrary.render)(_react.default.createElement(_Box.Box, {
      overflow: 'scroll',
      "data-testid": 'Box'
    }));
    expect(asFragment()).toMatchSnapshot();
    expect(getByTestId('Box')).toHaveStyleRule('overflow', 'scroll');
  });
});