"use strict";

var _pclnIcons = require("pcln-icons");
var _react = _interopRequireDefault(require("react"));
var _styledComponents = _interopRequireDefault(require("styled-components"));
var _testingLibrary = require("../__test__/testing-library");
var _theme = require("../theme/theme");
var _boxShadowAttrs = require("../utils/attrs/boxShadowAttrs");
var _createTheme = require("../utils/createTheme");
var _Button = require("./Button");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const theme = (0, _createTheme.createTheme)();
const StyledButton = /*#__PURE__*/(0, _styledComponents.default)(_Button.Button).withConfig({
  displayName: "Buttonspec__StyledButton",
  componentId: "sc-a70l1w-0"
})(["padding:100px;"]);
const consoleError = console.error;
afterEach(() => {
  console.error = consoleError;
});
describe('Button', () => {
  it('should render correctly with no props', () => {
    const {
      getByRole
    } = (0, _testingLibrary.render)(_react.default.createElement(_Button.Button, null, "BUTTON"));
    const button = getByRole('button');
    expect(button).toHaveStyleRule('background-color', theme.palette.primary.base);
    expect(button).toHaveStyleRule('color', theme.palette.text.lightest);
    expect(button).toHaveStyleRule('background-color', theme.palette.primary.dark, {
      modifier: ':hover'
    });
    expect(button).toHaveStyleRule('color', theme.palette.text.lightest, {
      modifier: ':hover'
    });
  });
  it('should render correctly when disabled', () => {
    const {
      getByRole
    } = (0, _testingLibrary.render)(_react.default.createElement(_Button.Button, {
      disabled: true
    }, "BUTTON"));
    const button = getByRole('button');
    expect(button).toHaveStyleRule('background-color', theme.palette.primary.light);
    expect(button).toHaveStyleRule('color', theme.palette.text.base);
    expect(button).toHaveStyleRule('cursor', 'not-allowed', {
      modifier: ':disabled'
    });
    expect(button).toHaveStyleRule('background-color', theme.palette.primary.light, {
      modifier: ':hover'
    });
    expect(button).toHaveStyleRule('color', theme.palette.text.base);
  });
  it('should render correctly for "size" prop', () => {
    const {
      getByRole,
      rerender
    } = (0, _testingLibrary.render)(_react.default.createElement(_Button.Button, null, "BUTTON"));
    const button = getByRole('button');
    expect(button).toHaveStyleRule('font-size', '14px');
    expect(button).toHaveStyleRule('padding', '9.5px 18px');
    rerender(_react.default.createElement(_Button.Button, {
      size: 'small'
    }, "BUTTON"));
    expect(button).toHaveStyleRule('font-size', '12px');
    expect(button).toHaveStyleRule('padding', '7px 12px');
    rerender(_react.default.createElement(_Button.Button, {
      size: 'medium'
    }, "BUTTON"));
    expect(button).toHaveStyleRule('font-size', '14px');
    expect(button).toHaveStyleRule('padding', '9.5px 18px');
    rerender(_react.default.createElement(_Button.Button, {
      size: 'large'
    }, "BUTTON"));
    expect(button).toHaveStyleRule('font-size', '16px');
    expect(button).toHaveStyleRule('padding', '12px 22px');
    rerender(_react.default.createElement(_Button.Button, {
      size: 'extraLarge'
    }, "BUTTON"));
    expect(button).toHaveStyleRule('font-size', '16px');
    expect(button).toHaveStyleRule('padding', '16px 22px');
  });
  it('should render correctly for "IconLeft" and "IconRight"', () => {
    const {
      getByRole,
      rerender
    } = (0, _testingLibrary.render)(_react.default.createElement(_Button.Button, {
      IconLeft: _pclnIcons.User
    }, "BUTTON"));
    const button = getByRole('button');
    expect(button).toHaveStyleRule('font-size', '14px');
    expect(button).toHaveStyleRule('padding', '8px 20px 8px 16px');
    rerender(_react.default.createElement(_Button.Button, {
      size: 'small',
      IconRight: _pclnIcons.User
    }));
    expect(button).toHaveStyleRule('font-size', '12px');
    expect(button).toHaveStyleRule('padding', '7px 12px');
    rerender(_react.default.createElement(_Button.Button, {
      size: 'medium'
    }, "BUTTON"));
    expect(button).toHaveStyleRule('font-size', '14px');
    expect(button).toHaveStyleRule('padding', '9.5px 18px');
    rerender(_react.default.createElement(_Button.Button, {
      size: 'large'
    }, "BUTTON"));
    expect(button).toHaveStyleRule('font-size', '16px');
    expect(button).toHaveStyleRule('padding', '12px 22px');
    rerender(_react.default.createElement(_Button.Button, {
      size: 'extraLarge'
    }, "BUTTON"));
    expect(button).toHaveStyleRule('font-size', '16px');
    expect(button).toHaveStyleRule('padding', '16px 22px');
  });
  it('should render correctly for "width" prop', () => {
    const {
      getByRole,
      rerender
    } = (0, _testingLibrary.render)(_react.default.createElement(_Button.Button, null, "BUTTON"));
    const button = getByRole('button');
    expect(button).toHaveStyleRule('width', undefined);
    rerender(_react.default.createElement(_Button.Button, {
      width: 1
    }, "BUTTON"));
    expect(button).toHaveStyleRule('width', '100%');
    rerender(_react.default.createElement(_Button.Button, {
      width: 1 / 2
    }, "BUTTON"));
    expect(button).toHaveStyleRule('width', '50%');
    rerender(_react.default.createElement(_Button.Button, {
      width: 100
    }, "BUTTON"));
    expect(button).toHaveStyleRule('width', '100px');
    rerender(_react.default.createElement(_Button.Button, {
      width: '3em'
    }, "BUTTON"));
    expect(button).toHaveStyleRule('width', '3em');
  });
  it('should render correctly for "height" prop', () => {
    const {
      getByRole,
      rerender
    } = (0, _testingLibrary.render)(_react.default.createElement(_Button.Button, null, "BUTTON"));
    const button = getByRole('button');
    expect(button).toHaveStyleRule('height', undefined);
    rerender(_react.default.createElement(_Button.Button, {
      height: 60
    }, "BUTTON"));
    expect(button).toHaveStyleRule('height', '60px');
  });
  it('should render correctly for "title" prop', () => {
    const {
      getByTitle
    } = (0, _testingLibrary.render)(_react.default.createElement(_Button.Button, {
      title: 'button title'
    }, "BUTTON"));
    expect(getByTitle('button title')).toHaveAttribute('aria-label', 'button title');
  });
  it('should forward the "aria-label" prop', () => {
    const label = 'i am an aria label';
    const {
      getByLabelText
    } = (0, _testingLibrary.render)(_react.default.createElement(_Button.Button, {
      "aria-label": label
    }, "BUTTON"));
    expect(getByLabelText(label)).toHaveAttribute('aria-label', label);
  });
  it('should render correctly for "borderRadius" prop', () => {
    const {
      getByRole,
      rerender
    } = (0, _testingLibrary.render)(_react.default.createElement(_Button.Button, {
      size: 'medium'
    }, "BUTTON"));
    const button = getByRole('button');
    expect(button).toHaveStyleRule('border-radius', _theme.borderRadii['action-md']);
    rerender(_react.default.createElement(_Button.Button, {
      size: 'small',
      borderRadius: ''
    }, "BUTTON"));
    expect(button).toHaveStyleRule('border-radius', _theme.borderRadii['action-sm']);
    rerender(_react.default.createElement(_Button.Button, {
      size: 'small',
      borderRadius: 'none'
    }, "BUTTON"));
    expect(button).toHaveStyleRule('border-radius', _theme.borderRadii.none);
    rerender(_react.default.createElement(_Button.Button, {
      size: 'medium',
      borderRadius: 'sm'
    }, "BUTTON"));
    expect(button).toHaveStyleRule('border-radius', _theme.borderRadii.sm);
    rerender(_react.default.createElement(_Button.Button, {
      size: 'large',
      borderRadius: 'md'
    }, "BUTTON"));
    expect(button).toHaveStyleRule('border-radius', _theme.borderRadii.md);
    rerender(
    // @ts-ignore
    _react.default.createElement(_Button.Button, {
      size: 'large',
      borderRadius: 'NOT VALID'
    }, "BUTTON"));
    expect(button).toHaveStyleRule('border-radius', _theme.borderRadii['action-lg']);
    rerender(_react.default.createElement(_Button.Button, {
      size: 'large',
      borderRadius: 'xl'
    }, "BUTTON"));
    expect(button).toHaveStyleRule('border-radius', _theme.borderRadii.xl);
    rerender(
    // @ts-ignore
    _react.default.createElement(_Button.Button, {
      size: 'extraLarge',
      borderRadius: 'notValid'
    }, "BUTTON"));
    expect(button).toHaveStyleRule('border-radius', _theme.borderRadii['action-xl']);
  });
  it('should render correctly for "boxShadowSize" prop', () => {
    const {
      getByRole,
      rerender
    } = (0, _testingLibrary.render)(_react.default.createElement(_Button.Button, null, "BUTTON"));
    const button = getByRole('button');
    expect(button).toHaveStyleRule('box-shadow', undefined);
    Array.from(_boxShadowAttrs.boxShadowSizeValues).forEach(size => {
      // @ts-ignore
      rerender(_react.default.createElement(_Button.Button, {
        boxShadowSize: size
      }, "BUTTON"));
      expect(button).toHaveStyleRule('box-shadow', _theme.shadows[size]);
    });
  });
  it('should render correctly for extraLarge size', () => {
    const {
      getByRole
    } = (0, _testingLibrary.render)(_react.default.createElement(_Button.Button, {
      borderRadius: 'xl',
      size: 'extraLarge'
    }, "BUTTON"));
    const button = getByRole('button');
    expect(button).toHaveStyleRule('border-radius', '16px');
    expect(button).toHaveStyleRule('font-size', '16px');
    expect(button).toHaveStyleRule('padding', '16px 22px');
  });
  describe('variations', () => {
    describe('fill variation', () => {
      it('should render correctly', () => {
        const {
          getByRole
        } = (0, _testingLibrary.render)(_react.default.createElement(_Button.Button, {
          variation: 'fill'
        }, "BUTTON"));
        const button = getByRole('button');
        expect(button).toHaveStyleRule('color', theme.palette.text.lightest);
        expect(button).toHaveStyleRule('background-color', theme.palette.primary.base);
        expect(button).toHaveStyleRule('color', theme.palette.text.lightest, {
          modifier: ':hover'
        });
        expect(button).toHaveStyleRule('background-color', theme.palette.primary.dark, {
          modifier: ':hover'
        });
        expect(button).toHaveStyleRule('outline', `0px solid ${theme.palette.primary.dark}`, {
          modifier: ':focus-visible'
        });
        expect(button).toHaveStyleRule('box-shadow', `0 0 0 2px ${theme.palette.primary.dark}`, {
          modifier: ':focus-visible'
        });
      });
      it('should render correctly when disabled', () => {
        const {
          getByRole
        } = (0, _testingLibrary.render)(_react.default.createElement(_Button.Button, {
          variation: 'fill',
          disabled: true
        }, "BUTTON"));
        const button = getByRole('button');
        expect(button).toHaveStyleRule('color', theme.palette.text.base);
        expect(button).toHaveStyleRule('background-color', theme.palette.primary.light);
        expect(button).toHaveStyleRule('background-color', theme.palette.primary.light, {
          modifier: ':hover'
        });
      });
    });
    describe('outline variation', () => {
      it('should render correctly', () => {
        const {
          getByRole
        } = (0, _testingLibrary.render)(_react.default.createElement(_Button.Button, {
          variation: 'outline'
        }, "BUTTON"));
        const button = getByRole('button');
        expect(button).toHaveStyleRule('color', theme.palette.primary.base);
        expect(button).toHaveStyleRule('background-color', 'transparent');
        expect(button).toHaveStyleRule('background-color', 'transparent', {
          modifier: ':hover'
        });
        expect(button).toHaveStyleRule('color', theme.palette.primary.dark, {
          modifier: ':hover'
        });
        expect(button).toHaveStyleRule('box-shadow', `inset 0 0 0 2px ${theme.palette.primary.dark}`, {
          modifier: ':hover'
        });
      });
      it('should render correctly when disabled', () => {
        const {
          getByRole
        } = (0, _testingLibrary.render)(_react.default.createElement(_Button.Button, {
          variation: 'outline',
          disabled: true
        }, "BUTTON"));
        const button = getByRole('button');
        expect(button).toHaveStyleRule('color', theme.palette.primary.light);
        expect(button).toHaveStyleRule('background-color', 'transparent');
      });
    });
    describe('link variation', () => {
      it('should render correctly', () => {
        const {
          getByRole
        } = (0, _testingLibrary.render)(_react.default.createElement(_Button.Button, {
          variation: 'link'
        }, "BUTTON"));
        const button = getByRole('button');
        expect(button).toHaveStyleRule('color', theme.palette.primary.base);
        expect(button).toHaveStyleRule('vertical-align', 'inherit');
        expect(button).toHaveStyleRule('-webkit-font-smoothing', 'inherit');
        expect(button).toHaveStyleRule('font-weight', '500');
        expect(button).toHaveStyleRule('line-height', '1.4');
        expect(button).toHaveStyleRule('padding', '0px');
        expect(button).toHaveStyleRule('color', theme.palette.primary.dark, {
          modifier: ':hover'
        });
        expect(button).toHaveStyleRule('text-decoration', 'underline', {
          modifier: ':hover'
        });
      });
      it('should render correctly when disabled', () => {
        const {
          getByRole
        } = (0, _testingLibrary.render)(_react.default.createElement(_Button.Button, {
          variation: 'link',
          disabled: true
        }, "BUTTON"));
        const button = getByRole('button');
        expect(button).toHaveStyleRule('color', theme.palette.background.tone, {
          modifier: ':disabled'
        });
        expect(button).toHaveStyleRule('background-color', theme.palette.background.base, {
          modifier: ':disabled'
        });
        expect(button).toHaveStyleRule('background-color', 'transparent');
      });
    });
    describe('subtle variation', () => {
      it('should render correctly', () => {
        const {
          getByRole
        } = (0, _testingLibrary.render)(_react.default.createElement(_Button.Button, {
          variation: 'subtle'
        }, "BUTTON"));
        const button = getByRole('button');
        expect(button).toHaveStyleRule('color', theme.palette.primary.base);
        expect(button).toHaveStyleRule('background-color', theme.palette.background.base);
        expect(button).toHaveStyleRule('vertical-align', 'middle');
        expect(button).toHaveStyleRule('-webkit-font-smoothing', 'antialiased');
        expect(button).toHaveStyleRule('font-weight', '700');
        expect(button).toHaveStyleRule('line-height', '1.5');
        expect(button).toHaveStyleRule('color', theme.palette.primary.dark, {
          modifier: ':hover'
        });
        expect(button).toHaveStyleRule('background-color', theme.palette.background.tint, {
          modifier: ':hover'
        });
        expect(button).toHaveStyleRule('outline', `0px solid ${theme.palette.primary.dark}`, {
          modifier: ':focus-visible'
        });
        expect(button).toHaveStyleRule('box-shadow', `0 0 0 2px ${theme.palette.primary.dark}`, {
          modifier: ':focus-visible'
        });
      });
      it('should render correctly when disabled', () => {
        const {
          getByRole
        } = (0, _testingLibrary.render)(_react.default.createElement(_Button.Button, {
          variation: 'subtle',
          disabled: true
        }, "BUTTON"));
        const button = getByRole('button');
        expect(button).toHaveStyleRule('color', theme.palette.background.tone, {
          modifier: ':disabled'
        });
        expect(button).toHaveStyleRule('background-color', theme.palette.background.base, {
          modifier: ':disabled'
        });
      });
    });
    describe('white variation', () => {
      it('should render correctly', () => {
        const {
          getByRole
        } = (0, _testingLibrary.render)(_react.default.createElement(_Button.Button, {
          variation: 'white'
        }, "BUTTON"));
        const button = getByRole('button');
        expect(button).toHaveStyleRule('background-color', theme.palette.background.lightest);
      });
    });
    describe('plain variation', () => {
      it('should render correctly', () => {
        const {
          getByRole
        } = (0, _testingLibrary.render)(_react.default.createElement(_Button.Button, {
          variation: 'plain'
        }, "BUTTON"));
        const button = getByRole('button');
        expect(button).toHaveStyleRule('color', theme.palette.primary.base);
        expect(button).toHaveStyleRule('background-color', 'transparent');
        expect(button).toHaveStyleRule('vertical-align', 'middle');
        expect(button).toHaveStyleRule('-webkit-font-smoothing', 'antialiased');
        expect(button).toHaveStyleRule('font-weight', '700');
        expect(button).toHaveStyleRule('line-height', '1.5');
        expect(button).toHaveStyleRule('color', theme.palette.primary.dark, {
          modifier: ':hover'
        });
        expect(button).toHaveStyleRule('background-color', theme.palette.background.base, {
          modifier: ':hover'
        });
        expect(button).toHaveStyleRule('outline', `0px solid ${theme.palette.primary.dark}`, {
          modifier: ':focus-visible'
        });
        expect(button).toHaveStyleRule('box-shadow', `0 0 0 2px ${theme.palette.primary.dark}`, {
          modifier: ':focus-visible'
        });
      });
      it('should render correctly when disabled', () => {
        const {
          getByRole
        } = (0, _testingLibrary.render)(_react.default.createElement(_Button.Button, {
          variation: 'plain',
          disabled: true
        }, "BUTTON"));
        const button = getByRole('button');
        expect(button).toHaveStyleRule('color', theme.palette.background.tone, {
          modifier: ':disabled'
        });
        expect(button).toHaveStyleRule('background-color', theme.palette.background.base, {
          modifier: ':disabled'
        });
      });
    });
    describe('lightFill variation', () => {
      it('should render correctly', () => {
        const {
          getByRole
        } = (0, _testingLibrary.render)(_react.default.createElement(_Button.Button, {
          variation: 'lightFill',
          color: 'warning'
        }, "BUTTON"));
        const button = getByRole('button');
        expect(button).toHaveStyleRule('color', theme.palette.warning.base);
        expect(button).toHaveStyleRule('background-color', theme.palette.warning.light);
        expect(button).toHaveStyleRule('vertical-align', 'middle');
        expect(button).toHaveStyleRule('-webkit-font-smoothing', 'antialiased');
        expect(button).toHaveStyleRule('font-weight', '700');
        expect(button).toHaveStyleRule('line-height', '1.5');
        expect(button).toHaveStyleRule('color', theme.palette.warning.dark, {
          modifier: ':hover'
        });
        expect(button).toHaveStyleRule('background-color', theme.palette.warning.light, {
          modifier: ':hover'
        });
        expect(button).toHaveStyleRule('outline', `0px solid ${theme.palette.warning.dark}`, {
          modifier: ':focus-visible'
        });
        expect(button).toHaveStyleRule('box-shadow', `0 0 0 2px ${theme.palette.warning.dark}`, {
          modifier: ':focus-visible'
        });
      });
      it('should render correctly when disabled', () => {
        const {
          getByRole
        } = (0, _testingLibrary.render)(_react.default.createElement(_Button.Button, {
          variation: 'lightFill',
          disabled: true
        }, "BUTTON"));
        const button = getByRole('button');
        expect(button).toHaveStyleRule('color', theme.palette.background.tone, {
          modifier: ':disabled'
        });
        expect(button).toHaveStyleRule('background-color', theme.palette.background.base, {
          modifier: ':disabled'
        });
      });
    });
    describe('input variation', () => {
      it('should render correctly', () => {
        const {
          getByRole
        } = (0, _testingLibrary.render)(_react.default.createElement(_Button.Button, {
          variation: 'input'
        }, "BUTTON"));
        const button = getByRole('button');
        expect(button).toHaveStyleRule('color', theme.palette.text.base);
        expect(button).toHaveStyleRule('background-color', 'transparent');
        expect(button).toHaveStyleRule('border-color', theme.palette.border.base);
        expect(button).toHaveStyleRule('border-color', theme.palette.primary.base, {
          modifier: ':focus'
        });
        expect(button).toHaveStyleRule('box-shadow', `0 0 0 2px ${theme.palette.primary.base}`, {
          modifier: ':focus'
        });
      });
    });
  });
  // this test detects a current defect that will be fixed properly in DSv4
  it('should not lose base styles on "styled(Button)"', () => {
    const {
      getByRole
    } = (0, _testingLibrary.render)(_react.default.createElement(StyledButton, null, "BUTTON"));
    const button = getByRole('button');
    expect(button).toHaveStyleRule('background-color', theme.palette.primary.base);
    expect(button).toHaveStyleRule('color', theme.palette.text.lightest);
    expect(button).toHaveStyleRule('padding', '100px');
    expect(button).toHaveStyleRule('background-color', theme.palette.primary.dark, {
      modifier: ':hover'
    });
    expect(button).toHaveStyleRule('color', theme.palette.text.lightest, {
      modifier: ':hover'
    });
  });
});