"use strict";

var _react = require("@testing-library/react");
var _react2 = _interopRequireDefault(require("react"));
var _Dialog = require("./Dialog");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const triggerText = 'Open Dialog';
const contentText = 'Dialog Content';
describe('Dialog', () => {
  it('renders the trigger node', () => {
    (0, _react.render)(_react2.default.createElement(_Dialog.Dialog, {
      triggerNode: _react2.default.createElement("button", null, triggerText),
      ariaDescription: 'Description',
      ariaTitle: 'Title'
    }, contentText));
    const triggerNode = _react.screen.getByText(triggerText);
    expect(triggerNode).toBeInTheDocument();
  });
  it('renders the dialog content when trigger is clicked', async () => {
    (0, _react.render)(_react2.default.createElement(_Dialog.Dialog, {
      triggerNode: _react2.default.createElement("button", null, triggerText),
      ariaDescription: 'Description',
      ariaTitle: 'Title'
    }, contentText));
    const triggerNode = _react.screen.getByText(triggerText);
    triggerNode.click();
    await new Promise(resolve => setTimeout(resolve, 1000));
    const contentNode = _react.screen.getByText(contentText);
    expect(contentNode).toBeInTheDocument();
  });
  it('renders the dialog with footer content', async () => {
    (0, _react.render)(_react2.default.createElement(_Dialog.Dialog, {
      triggerNode: _react2.default.createElement("button", null, triggerText),
      ariaDescription: 'Description',
      ariaTitle: 'Title',
      footerContent: _react2.default.createElement("div", null, "Footer Content")
    }, contentText));
    const triggerNode = _react.screen.getByText(triggerText);
    triggerNode.click();
    await (0, _react.waitFor)(() => {
      expect(_react.screen.getByText('Footer Content')).toBeInTheDocument();
    });
  });
  it.skip('calls onOpenChange when trigger is clicked', () => {
    const onOpenChange = jest.fn();
    (0, _react.render)(_react2.default.createElement(_Dialog.Dialog, {
      triggerNode: _react2.default.createElement("button", null, triggerText),
      ariaDescription: 'Description',
      ariaTitle: 'Title',
      onOpenChange: onOpenChange
    }, contentText));
    const triggerNode = _react.screen.getByText(triggerText);
    triggerNode.click();
    expect(onOpenChange).toHaveBeenCalledWith(true);
  });
  it.skip('handles controlled state when open', () => {
    (0, _react.render)(_react2.default.createElement(_Dialog.Dialog, {
      triggerNode: _react2.default.createElement("button", null, triggerText),
      ariaDescription: 'Description',
      ariaTitle: 'Title',
      open: false
    }, contentText));
    const triggerNode = _react.screen.getByText(triggerText);
    triggerNode.click();
    const contentNode = _react.screen.queryByText(contentText);
    expect(contentNode).not.toBeVisible();
  });
});