"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.dialogSizes = exports.DialogOverlay = exports.DialogContent = void 0;
var Dialog = _interopRequireWildcard(require("@radix-ui/react-dialog"));
var _reactVisuallyHidden = require("@radix-ui/react-visually-hidden");
var _themeGet = _interopRequireDefault(require("@styled-system/theme-get"));
var _framerMotion = require("framer-motion");
var _react = _interopRequireDefault(require("react"));
var _styledComponents = _interopRequireDefault(require("styled-components"));
var _styledSystem = require("styled-system");
var _CloseButton = require("../CloseButton/CloseButton");
var _Grid = require("../Grid/Grid");
var _Text = require("../Text/Text");
var _ThemeProvider = require("../ThemeProvider/ThemeProvider");
var _useScrollWithShadow = require("../useScrollWithShadows/useScrollWithShadow");
var _Box = require("../Box/Box");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/** @public */
const dialogSizes = exports.dialogSizes = ['sm', 'md', 'lg', 'xl', 'full'];
const sizeStyles = {
  sm: {
    width: 'calc(min(400px, 100vw) - 2 * 16px)'
  },
  md: {
    width: 'calc(min(640px, 100vw) - 2 * 16px)'
  },
  lg: {
    width: 'calc(min(960px, 100vw) - 2 * 16px)'
  },
  xl: {
    width: 'calc(min(1280px, 100vw) - 2 * 16px)',
    height: 'calc(100% - 2 * 48px)'
  },
  full: {
    width: '100%',
    height: '100%'
  }
};
const scrimStyles = {
  dark: 'rgba(0, 24, 51, 0.75)',
  medium: 'rgba(0, 24, 51, 0.5)',
  light: 'rgba(0, 24, 51, 0.25)'
};
const enterTransition = {
  duration: 0.25,
  ease: 'easeOut'
};
const exitTransition = {
  duration: 0.15,
  ease: 'easeIn'
};
const animationStyles = {
  default: {
    initial: {
      opacity: 0,
      scale: 0.9,
      translateY: 64
    },
    animate: {
      opacity: 1,
      scale: 1,
      translateY: 0,
      transition: enterTransition
    },
    exit: {
      opacity: 0,
      scale: 0.9,
      translateY: 32,
      transition: exitTransition
    }
  },
  sheet: {
    initial: {
      opacity: 0,
      translateY: '40%'
    },
    animate: {
      opacity: 1,
      translateY: 0,
      transition: enterTransition
    },
    exit: {
      opacity: 0,
      translateY: '60%',
      transition: exitTransition
    }
  },
  overlay: {
    initial: {
      opacity: 0,
      overflow: 'hidden'
    },
    animate: {
      opacity: 1,
      transitionEnd: {
        overflow: 'auto'
      },
      transition: enterTransition
    },
    exit: {
      opacity: 0,
      overflow: 'hidden',
      transition: exitTransition
    }
  }
};
const FloatingCloseButton = /*#__PURE__*/(0, _styledComponents.default)(_CloseButton.CloseButton).withConfig({
  displayName: "Dialogstyled__FloatingCloseButton",
  componentId: "sc-1seg3h7-0"
})(["position:absolute;top:", "px;right:", "px;z-index:", ";"], props => props.dialogSize === 'full' || props.fullWidth ? 8 : -12, props => props.dialogSize === 'full' || props.fullWidth ? 8 : -12, props => (0, _themeGet.default)('zIndices.absolute')(props));
const DialogOverlayWrapper = /*#__PURE__*/(0, _styledComponents.default)(_framerMotion.motion.div).withConfig({
  displayName: "Dialogstyled__DialogOverlayWrapper",
  componentId: "sc-1seg3h7-1"
})(["", " position:fixed;inset:0;display:grid;overflow-y:auto;place-items:", ";background-color:", ";"], _styledSystem.zIndex, props => props.sheet ? 'end center' : 'center', props => Object.keys(scrimStyles).includes(props.scrimColor) ? scrimStyles[props.scrimColor] : props.scrimColor);
const DialogContentWrapper = /*#__PURE__*/(0, _styledComponents.default)(_framerMotion.motion.div).withConfig({
  displayName: "Dialogstyled__DialogContentWrapper",
  componentId: "sc-1seg3h7-2"
})(["position:relative;cursor:initial;background-color:", ";width:", ";height:", ";margin:", ";border-radius:", ";box-shadow:", ";", ""], props => (0, _themeGet.default)('palette.background.lightest')(props), props => props.fullWidth ? '100%' : sizeStyles[props.size]?.width, props => props.sheet ? `calc(${sizeStyles[props.size]?.height} - 24px)` : sizeStyles[props.size]?.height, props => props.sheet ? `${(0, _themeGet.default)('space.3')(props)} 0 0 0` : props.size === 'full' ? '0' : `${(0, _themeGet.default)('space.4')(props)}
         ${(0, _themeGet.default)('space.3')(props)}
         ${(0, _themeGet.default)('space.5')(props)}
         ${(0, _themeGet.default)('space.3')(props)}`, props => props.sheet ? `${(0, _themeGet.default)(`borderRadii.${props.borderRadius}`)(props)} ${(0, _themeGet.default)(`borderRadii.${props.borderRadius}`)(props)} 0 0` : props.size === 'full' ? 'none' : (0, _themeGet.default)(`borderRadii.${props.borderRadius}`)(props), props => (0, _themeGet.default)('shadows.overlay-lg')(props), props => props.hasFooterContent && `
    overflow: ${props.sheet ? 'scroll' : 'visible'};
  `);
const DialogInnerContentWrapper = /*#__PURE__*/_styledComponents.default.div.withConfig({
  displayName: "Dialogstyled__DialogInnerContentWrapper",
  componentId: "sc-1seg3h7-3"
})(["position:relative;display:grid;grid-template-columns:1fr;grid-template-rows:auto 1fr auto;", " ", " ", " border-radius:", ";border-top:", ";"], props => props.hasFooterContent && `height: 100%;`, _styledSystem.overflowX, _styledSystem.overflowY, props => props.sheet ? `${(0, _themeGet.default)(`borderRadii.${props.borderRadius}`)(props)} ${(0, _themeGet.default)(`borderRadii.${props.borderRadius}`)(props)} 0 0` : props.size === 'full' ? 'none' : (0, _themeGet.default)(`borderRadii.${props.borderRadius}`)(props), props => props.hugColor && `4px solid ${(0, _themeGet.default)('palette.' + props.hugColor)(props)}`);
const DialogOverlay = ({
  scrimColor,
  sheet,
  children,
  zIndex
}) => {
  return _react.default.createElement(Dialog.Portal, {
    forceMount: true
  }, _react.default.createElement(_ThemeProvider.ThemeProvider, null, _react.default.createElement(Dialog.Overlay, {
    asChild: true,
    forceMount: true
  }, _react.default.createElement(DialogOverlayWrapper, {
    scrimColor: scrimColor,
    sheet: sheet,
    zIndex: zIndex,
    ...animationStyles.overlay
  }, children))));
};
exports.DialogOverlay = DialogOverlay;
const SmoothTransitionBox = /*#__PURE__*/(0, _styledComponents.default)(_Box.Box).withConfig({
  displayName: "Dialogstyled__SmoothTransitionBox",
  componentId: "sc-1seg3h7-4"
})(["overflow:", ";transition:all 0.3s ease-in-out;"], props => props.innerContentOverflow ?? 'auto');
const DialogContent = ({
  ariaDescription,
  ariaTitle,
  borderRadius,
  children,
  footerContent,
  fullWidth,
  headerColorScheme = 'heading',
  headerContent,
  headerContentProps,
  headerIcon,
  headerShowCloseButton,
  hugColor,
  innerContentOverflow,
  overflowX,
  overflowY,
  scrimDismiss,
  sheet,
  showCloseButton,
  showScrollShadow,
  size,
  zIndex,
  onOpenChange
}) => {
  const headerSizeArray = [headerIcon ? 'heading5' : 'heading4',
  // xs
  headerIcon ? 'heading5' : 'heading4',
  // sm
  headerIcon ? 'heading5' : 'heading4',
  // md
  headerIcon ? 'heading5' : 'heading4',
  // lg
  headerIcon ? 'heading4' : 'heading3',
  // xl
  headerIcon ? 'heading4' : 'heading3' // xxl
  ];
  const {
    boxShadow,
    onScrollHandler
  } = (0, _useScrollWithShadow.useScrollWithShadow)();
  return _react.default.createElement(Dialog.Content, {
    "aria-describedby": ariaDescription,
    onPointerDownOutside: e => {
      e.preventDefault();
      if (scrimDismiss) onOpenChange(false);
    },
    onOpenAutoFocus: e => e.preventDefault(),
    asChild: true,
    forceMount: true
  }, _react.default.createElement(DialogContentWrapper, {
    size: size,
    sheet: sheet,
    fullWidth: fullWidth,
    borderRadius: borderRadius,
    zIndex: zIndex,
    hasFooterContent: footerContent,
    ...(sheet ? animationStyles.sheet : animationStyles.default)
  }, showCloseButton && _react.default.createElement(Dialog.Close, {
    asChild: true
  }, _react.default.createElement(FloatingCloseButton, {
    dialogSize: size,
    fullWidth: fullWidth,
    variant: 'filled'
  })), _react.default.createElement(_reactVisuallyHidden.VisuallyHidden, {
    asChild: true
  }, _react.default.createElement(Dialog.Title, null, ariaTitle)), _react.default.createElement(DialogInnerContentWrapper, {
    overflowX: overflowX,
    overflowY: overflowY,
    sheet: sheet,
    hasFooterContent: footerContent,
    hugColor: hugColor,
    size: size,
    borderRadius: borderRadius
  }, headerContent && _react.default.createElement(_Grid.Grid, {
    px: [3, 3, 3, 3, '24px', '24px'],
    py: 3,
    autoFlow: 'column',
    templateColumns: 'auto 1fr',
    alignItems: 'center',
    colorScheme: headerColorScheme,
    ...headerContentProps
  }, _react.default.createElement(_Grid.Grid, {
    autoFlow: 'column',
    gap: '2'
  }, headerIcon, _react.default.createElement(_Text.Text, {
    textStyle: size === 'sm' ? headerIcon ? 'heading5' : 'heading4' : headerSizeArray
  }, headerContent)), _react.default.createElement(_Grid.Grid, {
    justifySelf: 'end'
  }, headerShowCloseButton && _react.default.createElement(_CloseButton.CloseButton, {
    onClick: () => onOpenChange(false)
  }))), showScrollShadow ? _react.default.createElement(SmoothTransitionBox, {
    innerContentOverflow: innerContentOverflow,
    style: {
      boxShadow
    },
    height: '100%',
    onScroll: onScrollHandler
  }, _react.default.Children.map(children, child => _react.default.cloneElement(child, {
    onScroll: onScrollHandler
  }))) : _react.default.createElement(_Box.Box, {
    height: '100%',
    style: innerContentOverflow ? {
      overflowY: innerContentOverflow
    } : undefined
  }, children), footerContent && _react.default.createElement(_Box.Box, {
    boxShadow: showScrollShadow ? 'lg' : 'none',
    color: 'background.lightest'
  }, _react.default.createElement(_Grid.Grid, {
    px: [3, 3, 3, 3, '24px', '24px'],
    py: 3,
    autoFlow: 'column',
    templateColumns: '1fr',
    alignItems: 'center'
  }, footerContent)))));
};
exports.DialogContent = DialogContent;