"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Drawer = void 0;
var _react = _interopRequireDefault(require("react"));
var _Box = require("../Box/Box");
var _Flex = require("../Flex/Flex");
var _Text = require("../Text/Text");
var _Drawer = require("./Drawer.styled");
var _pclnIcons = require("pcln-icons");
var _framerMotion = require("framer-motion");
var _useScrollWithShadow = require("../useScrollWithShadows/useScrollWithShadow");
var _Animate = require("../Animate/Animate");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const enterAnimation = {
  top: {
    ..._Animate.MotionVariants.slideInTop
  },
  bottom: {
    ..._Animate.MotionVariants.slideInBottom
  },
  right: {
    ..._Animate.MotionVariants.slideInRight
  },
  left: {
    ..._Animate.MotionVariants.slideInLeft
  }
};
const dragToDismissAnimation = onDragEnd => {
  return {
    drag: 'y',
    dragConstraints: {
      top: 0,
      bottom: 0
    },
    dragElastic: {
      top: 0,
      bottom: 0.3
    },
    transition: {
      duration: 0.8,
      ease: [0.04, 0.62, 0.23, 0.98]
    },
    onDragEnd: (event, info) => {
      if (info.offset.y > 200) {
        onDragEnd();
      }
    }
  };
};
const Drawer = ({
  children,
  heading,
  isCollapsed = false,
  isFloating = true,
  isMobile = false,
  isOpen = false,
  onClose,
  onCollapse,
  placement = 'right',
  ...props
}) => {
  const {
    boxShadow,
    onScrollHandler
  } = (0, _useScrollWithShadow.useScrollWithShadow)();
  return _react.default.createElement(_framerMotion.AnimatePresence, null, isOpen && _react.default.createElement(_Drawer.DrawerWrapper, {
    placement: isMobile ? 'bottom' : placement,
    padding: isFloating ? '16px' : 0,
    maxHeight: isMobile ? ['290px', '400px', '480px', 'calc(100vh - 64px)'] : props.height ?? '100%',
    maxWidth: isMobile ? '100%' : ['400px', '600px', '800px', '100%'],
    width: isMobile ? '100%' : props.width,
    height: !isCollapsed && props.height ? props.height : 'fit-content'
  }, _react.default.createElement(_Drawer.DrawerRoot, {
    "data-testid": 'drawer',
    isCollapsed: isCollapsed,
    isFloating: isFloating,
    key: 'drawer',
    placement: isMobile ? 'bottom' : placement,
    ...enterAnimation[isMobile ? 'bottom' : placement],
    ...dragToDismissAnimation(onCollapse),
    height: '100%',
    width: '100%',
    overflow: 'hidden'
  }, _react.default.createElement(_Flex.Flex, {
    flexDirection: 'column'
  }, (heading || onClose || onCollapse) && _react.default.createElement(_Flex.Flex, {
    flexDirection: 'column'
  }, _react.default.createElement(_Flex.Flex, {
    flexDirection: 'row',
    p: 3
  }, typeof heading === 'string' ? _react.default.createElement(_Text.Text, {
    width: '100%',
    textStyle: 'heading4'
  }, heading) : heading, onClose || onCollapse ? _react.default.createElement(_Flex.Flex, {
    flexDirection: 'row',
    ml: 'auto',
    style: {
      columnGap: '8px'
    }
  }, onCollapse && _react.default.createElement(_framerMotion.motion.div, {
    animate: {
      rotate: isCollapsed ? 180 : 0,
      transition: {
        duration: 0.25
      }
    }
  }, _react.default.createElement(_Drawer.HeaderButton, {
    "data-testid": 'drawerCollapse',
    onClick: onCollapse,
    icon: _react.default.createElement(_pclnIcons.ChevronDown, {
      title: 'Dismiss'
    })
  })), onClose && _react.default.createElement(_Drawer.HeaderButton, {
    "data-testid": 'drawerClose',
    onClick: onClose,
    icon: _react.default.createElement(_pclnIcons.Close, {
      title: 'Close'
    })
  })) : null)), _react.default.createElement(_framerMotion.AnimatePresence, {
    initial: false
  }, !isCollapsed && _react.default.createElement(_framerMotion.motion.div, {
    key: 'content',
    exit: {
      scaleY: 0,
      height: 0
    },
    animate: {
      scaleY: 1,
      height: 'auto'
    },
    initial: {
      scaleY: 1,
      height: 'auto'
    }
  }, heading ? _react.default.createElement(_Box.Box, {
    height: '100%',
    maxHeight: `calc(${props.height ?? '100vh'} - 100px)`,
    overflow: 'scroll',
    onScroll: onScrollHandler,
    style: {
      boxShadow
    }
  }, _react.default.createElement(_Box.Box, {
    p: 3,
    height: '100%'
  }, children)) : _react.default.createElement(_Box.Box, {
    p: 3,
    height: '100%'
  }, children)))))));
};
exports.Drawer = Drawer;
Drawer.displayName = 'Drawer';