"use strict";

var _react = _interopRequireDefault(require("react"));
var _testingLibrary = require("../__test__/testing-library");
var _Drawer = require("./Drawer");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
describe('Drawer', () => {
  test('renders Drawer with no heading', () => {
    const {
      queryByText
    } = (0, _testingLibrary.render)(_react.default.createElement(_Drawer.Drawer, {
      isOpen: true,
      placement: 'right',
      onCollapse: jest.fn
    }));
    expect(queryByText('Drawer Heading')).toBeFalsy();
  });
  test('renders collapsed Drawer', () => {
    const {
      queryByText
    } = (0, _testingLibrary.render)(_react.default.createElement(_Drawer.Drawer, {
      isOpen: true,
      isCollapsed: true,
      placement: 'right'
    }, "Drawer Content"));
    expect(queryByText('Drawer Content')).toBeFalsy();
  });
  test('renders mobile Drawer', () => {
    const {
      queryByText
    } = (0, _testingLibrary.render)(_react.default.createElement(_Drawer.Drawer, {
      isOpen: true,
      isMobile: true,
      isCollapsed: true
    }, "Drawer Content"));
    expect(queryByText('Drawer Content')).toBeFalsy();
  });
  test('renders heading from string prop', () => {
    const {
      queryByText
    } = (0, _testingLibrary.render)(_react.default.createElement(_Drawer.Drawer, {
      isOpen: true,
      isMobile: true,
      isCollapsed: true,
      heading: 'Default Heading'
    }, "Drawer Content"));
    expect(queryByText('Default Heading')).toBeTruthy();
  });
  test('renders Drawer with custom heading element', () => {
    const {
      getByText
    } = (0, _testingLibrary.render)(_react.default.createElement(_Drawer.Drawer, {
      isOpen: true,
      placement: 'right',
      onClose: jest.fn,
      onCollapse: jest.fn,
      heading: _react.default.createElement("div", null, "Custom Heading")
    }, "Content"));
    expect(getByText('Custom Heading')).toBeTruthy();
  });
});