"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Flag = void 0;
var _themeGet = _interopRequireDefault(require("@styled-system/theme-get"));
var _react = _interopRequireDefault(require("react"));
var _styledComponents = _interopRequireDefault(require("styled-components"));
var _Box = require("../Box/Box");
var _Flex = require("../Flex/Flex");
var _Hide = require("../Hide/Hide");
var _utils = require("../utils/utils");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const capitalize = str => str.charAt(0).toUpperCase() + str.slice(1);
const shadowColor = props => {
  const darkColor = (0, _utils.hasPaletteColor)(props) ? (0, _utils.getPaletteColor)('dark')(props) : (0, _themeGet.default)(`colors.dark${capitalize(props.color)}`)(props);
  return {
    backgroundImage: !darkColor ? `
        linear-gradient(45deg, transparent 50%, rgba(0, 0, 0, 0.5) 50%),
        linear-gradient(45deg, transparent 50%, ${props.color} 50%)
      ` : `linear-gradient(45deg, transparent 50%, ${darkColor} 50%)`
  };
};
const FlagShadow = /*#__PURE__*/(0, _styledComponents.default)(_Box.Box).withConfig({
  displayName: "Flag__FlagShadow",
  componentId: "sc-e0jgig-0"
})(["width:8px;height:8px;align-self:flex-end;background-color:inherit;", ";position:absolute;bottom:0;"], shadowColor);
const FlagRight = /*#__PURE__*/(0, _styledComponents.default)(_Box.Box).withConfig({
  displayName: "Flag__FlagRight",
  componentId: "sc-e0jgig-1"
})(["flex:none;background-color:", ";border-radius:0 ", " ", " 0;transform:skew(-14deg);position:relative;z-index:1;"], props => (0, _utils.getPaletteColor)('base')(props) || props.color, (0, _themeGet.default)('radius'), (0, _themeGet.default)('radius'));
const flexAuto = props => props.flexAuto ? {
  flex: '1 1 auto'
} : null;
const FlagBody = /*#__PURE__*/(0, _styledComponents.default)(_Box.Box).withConfig({
  displayName: "Flag__FlagBody",
  componentId: "sc-e0jgig-2"
})(["font-size:", "px;border-radius:0 0 ", " 0;", " ", ";z-index:2;"], (0, _themeGet.default)('fontSizes.0'), (0, _themeGet.default)('radius'), flexAuto, _utils.color);
const RelativeHide = /*#__PURE__*/(0, _styledComponents.default)(_Hide.Hide).withConfig({
  displayName: "Flag__RelativeHide",
  componentId: "sc-e0jgig-3"
})(["position:relative;"]);
const StyledFlex = /*#__PURE__*/(0, _styledComponents.default)(_Flex.Flex).withConfig({
  displayName: "Flag__StyledFlex",
  componentId: "sc-e0jgig-4"
})(["", ""], (0, _utils.applyVariations)('Flag'));
/**
 * @public
 */
const Flag = ({
  color,
  bg,
  children,
  pl,
  pr,
  py,
  width,
  ...props
}) => _react.default.createElement(StyledFlex, {
  width: width,
  ...props,
  ml: [0, -2]
}, _react.default.createElement(RelativeHide, {
  xs: true
}, _react.default.createElement(FlagShadow, {
  width: '4px',
  mr: -2,
  mb: -2,
  color: (0, _utils.hasPaletteColor)({
    color,
    ...props
  }) ? color : bg
})), _react.default.createElement(FlagBody, {
  flexAuto: !!width,
  color: color,
  bg: (0, _utils.hasPaletteColor)({
    color,
    ...props
  }) ? false : bg,
  pl: pl,
  pr: pr,
  py: py
}, children), _react.default.createElement(FlagRight, {
  width: '18px',
  color: (0, _utils.hasPaletteColor)({
    color,
    ...props
  }) ? color : bg,
  ml: -2
}));
exports.Flag = Flag;
Flag.defaultProps = {
  color: 'white',
  bg: 'green',
  pl: [1, 3],
  pr: null,
  py: [1, 2]
};
Flag.displayName = 'Flag';