"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.FormField = FormField;
var _react = _interopRequireDefault(require("react"));
var _styledComponents = _interopRequireDefault(require("styled-components"));
var _Box = require("../Box/Box");
var _IconField = require("../IconField/IconField");
var _utils = require("../utils/utils");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
// @ts-nocheck

const DisableableBox = /*#__PURE__*/(0, _styledComponents.default)(_Box.Box).withConfig({
  displayName: "FormField__DisableableBox",
  componentId: "sc-tx1s9e-0"
})(["", ""], props => (props.disabled || props.readOnly) && `
    background-color: ${(0, _utils.getPaletteColor)('background.base')(props)};

    &&& * {
      background-color: transparent;
      color: ${(0, _utils.getPaletteColor)('text.light')(props)};
      cursor: not-allowed;
    }
  `);
const paddingTopWithLabel = {
  sm: '14px',
  md: '16px',
  lg: '20px',
  xl: '24px'
};
const paddingBottomWithLabel = {
  sm: '0px',
  md: '5px',
  lg: '8px',
  xl: '13px'
};
const paddingTopForLabel = {
  sm: '0px',
  md: '2px',
  lg: '6px',
  xl: '10px'
};
const inputPaddingTop = size => {
  return paddingTopWithLabel?.[size] ? paddingTopWithLabel[size] : '20px';
};
const inputPaddingBottom = size => {
  return paddingBottomWithLabel?.[size] ? paddingBottomWithLabel[size] : '8px';
};
const labelPaddingTop = size => {
  return paddingTopForLabel?.[size] ? paddingTopForLabel[size] : '6px';
};
/**
 * @public
 */
function FormField({
  children,
  disabled,
  readOnly,
  ...props
}) {
  let iconBefore = false;
  const childrenArray = _react.default.Children.toArray(children);
  const [field] = childrenArray.filter(child => child.type.isField);
  const [label] = childrenArray.filter(child => child.type.isLabel);
  const valueNoLabel = !label && field && !!field.props.value;
  const showLabel = (label && !label.props.autoHide || field && !!field.props.value) && !valueNoLabel;
  const id = field && (field.props.id || field.props.name);
  const inputSize = field && (field.props.size || undefined);
  const styled = childrenArray.map((child, i, arr) => {
    if (child.type.isField && arr[i - 1] && arr[i - 1].type.isIcon) {
      iconBefore = true;
    }
    if (child === field) {
      return _react.default.cloneElement(child, {
        id,
        disabled,
        readOnly,
        style: {
          ...child.props.style,
          transitionProperty: 'padding-top, padding-bottom',
          transitionDuration: '.1s',
          paddingTop: showLabel ? inputPaddingTop(inputSize) : undefined,
          paddingBottom: showLabel ? inputPaddingBottom(inputSize) : undefined
        }
      });
    }
    return child;
  });
  const ml = iconBefore ? '40px' : '12px';
  const styledLabel = label && _react.default.cloneElement(label, {
    htmlFor: label.props.htmlFor || id,
    fontSize: 10,
    ml,
    pt: labelPaddingTop(inputSize),
    mb: '-20px',
    style: {
      ...label.props.style,
      height: 20,
      transitionProperty: 'opacity',
      transitionDuration: '.1s',
      opacity: showLabel ? 1 : 0,
      pointerEvents: 'none',
      position: 'relative',
      width: `calc(100% - ${ml})`
    }
  });
  return _react.default.createElement(DisableableBox, {
    ...props,
    borderRadius: 'lg',
    disabled: disabled,
    readOnly: readOnly
  }, styledLabel, _react.default.createElement(_IconField.IconField, null, styled));
}
FormField.displayName = 'FormField';