"use strict";

var _pclnIcons = require("pcln-icons");
var _react = _interopRequireDefault(require("react"));
var _Input = require("../Input/Input");
var _Label = require("../Label/Label");
var _Select = require("../Select/Select");
var _testingLibrary = require("../__test__/testing-library");
var _FormField = require("./FormField");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
afterEach(() => {
  // bust cache for propTypes
  _FormField.FormField.displayName = 'FormField' + Math.random();
});
describe('FormField', () => {
  test('renders', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_FormField.FormField, null, _react.default.createElement(_Label.Label, null, "Email Address"), _react.default.createElement(_Input.Input, {
      id: 'email',
      name: 'email'
    }))).toJSON();
    expect(json).toMatchSnapshot();
  });
  test('renders with Icon', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_FormField.FormField, null, _react.default.createElement(_Label.Label, null, "Email Address"), _react.default.createElement(_pclnIcons.Email, null), _react.default.createElement(_Input.Input, {
      id: 'email',
      name: 'email'
    }))).toJSON();
    expect(json).toMatchSnapshot();
  });
  test('renders with Select ', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_FormField.FormField, null, _react.default.createElement(_Label.Label, null, "Pick Option"), _react.default.createElement(_Select.Select, null))).toJSON();
    expect(json).toMatchSnapshot();
  });
  test('renders with Select and Icon', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_FormField.FormField, null, _react.default.createElement(_Label.Label, null, "Pick Email Address"), _react.default.createElement(_pclnIcons.Email, null), _react.default.createElement(_Select.Select, null))).toJSON();
    expect(json).toMatchSnapshot();
  });
  test('renders with Label autoHide prop', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_FormField.FormField, null, _react.default.createElement(_Label.Label, {
      autoHide: true
    }, "Email"), _react.default.createElement(_pclnIcons.Email, null), _react.default.createElement(_Input.Input, {
      id: 'email',
      name: 'email'
    }))).toJSON();
    expect(json).toMatchSnapshot();
  });
  test('shows Label with autoHide prop and field value', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_FormField.FormField, null, _react.default.createElement(_Label.Label, {
      autoHide: true
    }, "Email"), _react.default.createElement(_pclnIcons.Email, null), _react.default.createElement(_Input.Input, {
      id: 'email',
      name: 'email',
      value: 'hello@example.com'
    }))).toJSON();
    const [label] = json.children;
    expect(label.props.style.opacity).toBe(1);
  });
  test('adds htmlFor prop to Label', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_FormField.FormField, null, _react.default.createElement(_Label.Label, null), _react.default.createElement(_Input.Input, {
      id: 'hello',
      name: 'hello'
    }))).toJSON();
    const [label] = json.children;
    expect(label.props.htmlFor).toBe('hello');
  });
  describe('disabled state', () => {
    it('renders input with icon - disabled', () => {
      const {
        asFragment
      } = (0, _testingLibrary.render)(_react.default.createElement(_FormField.FormField, {
        disabled: true
      }, _react.default.createElement(_Label.Label, null, "Email Address"), _react.default.createElement(_pclnIcons.Email, {
        "data-testid": 'email-icon'
      }), _react.default.createElement(_Input.Input, {
        id: 'email',
        name: 'email',
        placeholder: 'Email'
      })));
      expect(asFragment()).toMatchSnapshot();
    });
    it('renders select with icon - disabled', () => {
      const {
        asFragment
      } = (0, _testingLibrary.render)(_react.default.createElement(_FormField.FormField, {
        disabled: true
      }, _react.default.createElement(_Label.Label, null, "Pick Email Address"), _react.default.createElement(_pclnIcons.Email, null), _react.default.createElement(_Select.Select, {
        defaultValue: 'Premium Economy'
      }, _react.default.createElement("option", null, "Premium Economy"))));
      expect(asFragment()).toMatchSnapshot();
    });
  });
});