"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.GenericBanner = GenericBanner;
var _react = _interopRequireDefault(require("react"));
var _styledComponents = _interopRequireDefault(require("styled-components"));
var _Banner = require("../Banner/Banner");
var _Box = require("../Box/Box");
var _Button = require("../Button/Button");
var _Flex = require("../Flex/Flex");
var _Link = require("../Link/Link");
var _Relative = require("../Relative/Relative");
var _utils = require("../utils/utils");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const BannerWithRadius = /*#__PURE__*/(0, _styledComponents.default)(_Banner.Banner).withConfig({
  displayName: "GenericBanner__BannerWithRadius",
  componentId: "sc-1ae3a6t-0"
})(["cursor:", ";", ""], props => props.onClick ? 'pointer' : 'cursor', _utils.colorSchemeCustomForeground);
const WrapperLink = /*#__PURE__*/_styledComponents.default.a.withConfig({
  displayName: "GenericBanner__WrapperLink",
  componentId: "sc-1ae3a6t-1"
})(["z-index:1;display:block;position:absolute;top:0;left:0;right:0;bottom:0;"]);
const CustomLink = /*#__PURE__*/(0, _styledComponents.default)(_Link.Link).withConfig({
  displayName: "GenericBanner__CustomLink",
  componentId: "sc-1ae3a6t-2"
})(["display:inline-flex;z-index:2;"]);
const CustomButton = /*#__PURE__*/(0, _styledComponents.default)(_Button.Button).withConfig({
  displayName: "GenericBanner__CustomButton",
  componentId: "sc-1ae3a6t-3"
})(["z-index:2;text-decoration:", ";"], props => props.buttonTextUnderline ? 'underline' : 'none');
/**
 * @public
 */
function GenericBanner({
  alignItems,
  buttonClick,
  buttonSize,
  buttonVariation,
  ctaText,
  fontSize,
  heading,
  iconLeft,
  iconRight,
  imageLeft,
  justifyContent,
  linkVariation,
  linkColor,
  text,
  /* eslint-disable @typescript-eslint/naming-convention */
  URLProps,
  ...props
}) {
  function onClick(e) {
    e.stopPropagation();
    buttonClick();
  }
  return _react.default.createElement(_Relative.Relative, null, URLProps && _react.default.createElement(WrapperLink, {
    tabIndex: -1,
    "aria-hidden": 'true',
    ...URLProps
  }), _react.default.createElement(BannerWithRadius, {
    ...props,
    onClick: URLProps ? null : buttonClick,
    iconUsesColorScheme: true,
    // we need to unset Banner's color prop if colorScheme is provided so it doesn't render its own icon
    color: !props.colorScheme ? props.color : null
  }, _react.default.createElement(_Flex.Flex, {
    alignItems: alignItems,
    justifyContent: justifyContent
  }, !!iconLeft && iconLeft, !!imageLeft && imageLeft, _react.default.createElement(_Box.Box, {
    px: 2
  }, !!heading && _react.default.cloneElement(heading, {
    fontSize: heading.props.fontSize || fontSize
  }), !!text && _react.default.cloneElement(text, {
    fontSize
  }), URLProps && ctaText && _react.default.createElement(CustomLink, {
    p: linkVariation === 'fill' || linkVariation === 'outline' ? 2 : null,
    color: linkColor,
    variation: linkVariation,
    fontSize: fontSize,
    ...URLProps
  }, _react.default.cloneElement(ctaText, {
    fontSize,
    zIndex: 2
  })), buttonClick && typeof buttonClick === 'function' && ctaText && _react.default.createElement(CustomButton, {
    size: buttonSize,
    buttonTextUnderline: buttonVariation === 'link',
    variation: buttonVariation,
    onClick: onClick
  }, _react.default.cloneElement(ctaText, {
    fontSize
  }))), !!iconRight && iconRight)));
}
GenericBanner.defaultProps = {
  alignItems: 'center',
  buttonVariation: 'link',
  fontSize: [0, null, null, 1],
  justifyContent: 'center',
  linkColor: 'primary',
  linkVariation: 'link',
  borderRadius: '6px'
};