"use strict";

var _pclnIcons = require("pcln-icons");
var _react = _interopRequireDefault(require("react"));
var _Image = require("../Image/Image");
var _Text = require("../Text/Text");
var _testingLibrary = require("../__test__/testing-library");
var _GenericBanner = require("./GenericBanner");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const props = {
  p: 2,
  heading: _react.default.createElement(_Text.Text.span, {
    fontWeight: 'bold',
    textColor: 'primary.base',
    mr: 1
  }, "COVID-19"),
  text: _react.default.createElement(_Text.Text.span, {
    textColor: 'primary.base',
    mr: 1
  }, "Update: Your travel may be impacted. Please review this hotels important info."),
  ctaText: _react.default.createElement(_Text.Text.span, {
    textColor: 'primary.base',
    fontWeight: 'bold'
  }, "Read More"),
  imageLeft: _react.default.createElement(_Image.Image, {
    alt: 'ImageLeft'
  }),
  iconLeft: _react.default.createElement(_pclnIcons.Warning, null),
  iconRight: _react.default.createElement(_pclnIcons.Emoticon, null),
  color: 'caution.light'
};
const propsUpdatedHeading = {
  ...props,
  heading: _react.default.createElement(_Text.Text.span, {
    fontWeight: 'bold',
    textColor: 'primary.base',
    mr: 1,
    fontSize: 4
  }, "COVID-19")
};
describe('GenericBanner', () => {
  test('renders', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_GenericBanner.GenericBanner, null)).toJSON();
    expect(json).toMatchSnapshot();
  });
  test('Renders as expected-onclick', () => {
    const buttonClick = jest.fn();
    const {
      getByText
    } = (0, _testingLibrary.render)(_react.default.createElement(_GenericBanner.GenericBanner, {
      ...props,
      buttonClick: buttonClick
    }));
    const header = getByText('COVID-19');
    const text = getByText('Update: Your travel may be impacted. Please review this hotels important info.');
    expect(header).toBeTruthy();
    expect(text).toBeTruthy();
    const readMoreButton = getByText('Read More');
    expect(readMoreButton).toBeTruthy();
    _testingLibrary.fireEvent.click(readMoreButton);
    expect(buttonClick).toHaveBeenCalled();
    expect(readMoreButton).toHaveStyleRule('font-size', '12px');
    expect(header).toHaveStyleRule('font-size', '12px');
    expect(text).toHaveStyleRule('font-size', '12px');
  });
  test('Renders as expected- url', () => {
    const {
      getByText,
      getByRole
    } = (0, _testingLibrary.render)(_react.default.createElement(_GenericBanner.GenericBanner, {
      ...props,
      URLProps: {
        href: 'https://www.priceline.com',
        target: '_blank'
      }
    }));
    const header = getByText('COVID-19');
    const text = getByText('Update: Your travel may be impacted. Please review this hotels important info.');
    expect(getByRole('img')).toBeTruthy();
    expect(header).toBeTruthy();
    expect(text).toBeTruthy();
    const readMoreButton = getByText('Read More');
    expect(readMoreButton).toBeTruthy();
    _testingLibrary.fireEvent.click(readMoreButton);
    expect(readMoreButton).toHaveStyleRule('font-size', '12px');
    expect(header).toHaveStyleRule('font-size', '12px');
    expect(text).toHaveStyleRule('font-size', '12px');
  });
  test('Renders as expected- with different heading size', () => {
    const {
      getByText,
      getByRole
    } = (0, _testingLibrary.render)(_react.default.createElement(_GenericBanner.GenericBanner, {
      ...propsUpdatedHeading,
      URLProps: {
        href: 'https://www.priceline.com',
        target: '_blank'
      }
    }));
    const header = getByText('COVID-19');
    const text = getByText('Update: Your travel may be impacted. Please review this hotels important info.');
    expect(getByRole('img')).toBeTruthy();
    expect(header).toBeTruthy();
    expect(text).toBeTruthy();
    const readMoreButton = getByText('Read More');
    expect(readMoreButton).toBeTruthy();
    _testingLibrary.fireEvent.click(readMoreButton);
    expect(readMoreButton).toHaveStyleRule('font-size', '12px');
    expect(header).toHaveStyleRule('font-size', '24px');
    expect(text).toHaveStyleRule('font-size', '12px');
  });
});