"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.TemplateAreas = exports.ResponsiveLayout = exports.Playground = exports.NestedGrids = void 0;
var _addonDocs = require("@storybook/addon-docs");
var _addonLinks = require("@storybook/addon-links");
var _react = _interopRequireDefault(require("react"));
var _Box = require("../Box/Box");
var _Hero = require("../DocsUtils/Hero/Hero");
var _RelatedComponent = require("../DocsUtils/RelatedComponent/RelatedComponent");
var _Section = require("../DocsUtils/Section/Section");
var _StoryHeading = require("../DocsUtils/StoryHeading/StoryHeading");
var _TableOfContents = require("../DocsUtils/TableOfContents/TableOfContents");
var _Flex = require("../Flex/Flex");
var _Grid = require("../Grid/Grid");
var _Text = require("../Text/Text");
var _ThemeProvider = require("../ThemeProvider/ThemeProvider");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const GridItem = props => _react.default.createElement(_Grid.Grid, {
  p: 4,
  width: 1,
  placeItems: 'center',
  ...props
});
const Playground = exports.Playground = {
  render: () => _react.default.createElement(_Grid.Grid, {
    templateColumns: ['1fr', '1fr 1fr', '1fr 1fr 1fr'],
    placeItems: 'center',
    gap: 2
  }, _react.default.createElement(GridItem, {
    style: {
      background: '#00f8'
    }
  }, "A"), _react.default.createElement(GridItem, {
    style: {
      background: '#0f08'
    }
  }, "B"), _react.default.createElement(GridItem, {
    style: {
      background: '#0ff8'
    }
  }, "C"), _react.default.createElement(GridItem, {
    style: {
      background: '#f008'
    }
  }, "D"), _react.default.createElement(GridItem, {
    style: {
      background: '#f0f8'
    }
  }, "E"), _react.default.createElement(GridItem, {
    style: {
      background: '#ff08'
    }
  }, "F"))
};
const TemplateAreas = exports.TemplateAreas = {
  render: () => _react.default.createElement(_Grid.Grid, {
    templateAreas: `
        'header header' 
        'sidebar content'
        'footer footer'
      `,
    placeItems: 'center',
    minHeight: 'calc(100vh - 5rem)',
    templateRows: 'auto 1fr auto',
    templateColumns: '15em 1fr',
    gap: 2
  }, _react.default.createElement(GridItem, {
    gridArea: 'header',
    style: {
      background: '#00f8'
    }
  }, "Header"), _react.default.createElement(GridItem, {
    gridArea: 'sidebar',
    height: '100%',
    style: {
      background: '#0f08'
    }
  }, "Sidebar"), _react.default.createElement(GridItem, {
    gridArea: 'content',
    height: '100%',
    style: {
      background: '#0ff8'
    }
  }, "Content"), _react.default.createElement(GridItem, {
    gridArea: 'footer',
    mt: 'auto',
    style: {
      background: '#f008'
    }
  }, "Footer"))
};
const NestedGrids = exports.NestedGrids = {
  render: () => _react.default.createElement(_Grid.Grid, {
    templateColumns: '1fr 1fr',
    placeItems: 'center',
    gap: 2
  }, _react.default.createElement(GridItem, {
    style: {
      background: '#00f8'
    }
  }, "A"), _react.default.createElement(GridItem, {
    style: {
      background: '#0f08'
    }
  }, "B"), _react.default.createElement(GridItem, {
    style: {
      background: '#0ff8'
    }
  }, "C"), _react.default.createElement(_Grid.Grid, {
    width: 1,
    templateColumns: '1fr 1fr 1fr',
    placeItems: 'center',
    gap: 2
  }, _react.default.createElement(GridItem, {
    style: {
      background: '#f008'
    }
  }, "D"), _react.default.createElement(GridItem, {
    style: {
      background: '#f0f8'
    }
  }, "E"), _react.default.createElement(GridItem, {
    style: {
      background: '#ff08'
    }
  }, "F")))
};
const ResponsiveLayout = exports.ResponsiveLayout = {
  render: () => _react.default.createElement(_Grid.Grid, {
    templateColumns: ['1fr', '1fr 1fr', '1fr 1fr 1fr', '1fr 1fr 1fr 1fr', '1fr 1fr 1fr 1fr 1fr', '1fr 1fr 1fr 1fr 1fr 1fr'],
    placeItems: 'center',
    gap: 2
  }, _react.default.createElement(GridItem, {
    style: {
      background: '#00f8'
    }
  }, "A"), _react.default.createElement(GridItem, {
    style: {
      background: '#0f08'
    }
  }, "B"), _react.default.createElement(GridItem, {
    style: {
      background: '#0ff8'
    }
  }, "C"), _react.default.createElement(GridItem, {
    style: {
      background: '#f008'
    }
  }, "D"), _react.default.createElement(GridItem, {
    style: {
      background: '#f0f8'
    }
  }, "E"), _react.default.createElement(GridItem, {
    style: {
      background: '#ff08'
    }
  }, "F"))
};
const meta = {
  title: 'Layout/Grid',
  component: _Grid.Grid,
  parameters: {
    docs: {
      page: () => _react.default.createElement(_ThemeProvider.ThemeProvider, null, _react.default.createElement(_Hero.Hero, {
        name: 'Grid',
        img: ''
      }, "Grids divide a web page into rows and columns and offer comprehensive features for controlling the sizing and positioning of grid items, including the ability to define grid areas, set grid gaps, and control the alignment and distribution of grid items"), _react.default.createElement(_TableOfContents.TableOfContents, {
        links: ['Overview', 'Props', 'Examples', 'Related Components']
      }), _react.default.createElement(_Section.Section, {
        heading: 'Overview'
      }, _react.default.createElement(_Text.Text, {
        textStyle: 'paragraph'
      }, "Grid is based on the CSS Grid Layout Module, which provides a two-dimensional grid-based layout system, with rows and columns, making it easier to design web pages and components.")), _react.default.createElement(_Section.Section, {
        heading: 'Props'
      }, _react.default.createElement(_addonDocs.Primary, null), _react.default.createElement(_addonDocs.ArgsTable, {
        story: _addonDocs.PRIMARY_STORY
      })), _react.default.createElement(_Section.Section, {
        heading: 'Examples'
      }, _react.default.createElement(_StoryHeading.StoryHeading, {
        storyName: 'Template Areas',
        storyTitle: meta.title
      }), _react.default.createElement(_Text.Text, {
        textStyle: 'paragraph'
      }, "Using the ", _react.default.createElement("code", null, "gridTemplateAreas"), " prop, you can define grid areas and assign grid items to them. The grid areas are defined by using the ", _react.default.createElement("code", null, "grid-area"), " property on the grid items. The ", _react.default.createElement("code", null, "grid-area"), " property can be used to assign a name to a grid item, which can then be used as a value of the ", _react.default.createElement("code", null, "grid-template-areas"), " property."), _react.default.createElement(_StoryHeading.StoryHeading, {
        storyName: 'Nested Grids',
        storyTitle: meta.title
      }), _react.default.createElement(_Text.Text, {
        textStyle: 'paragraph'
      }, "Grids can be nested inside other grids. This allows you to create more complex layouts."), _react.default.createElement(_StoryHeading.StoryHeading, {
        storyName: 'Responsive Layout',
        storyTitle: meta.title
      }), _react.default.createElement(_Text.Text, {
        textStyle: 'paragraph'
      }, "Grids can be responsive. You can define the number of columns for each breakpoint using the", _react.default.createElement("code", null, "templateColumns"), " prop.")), _react.default.createElement(_Section.Section, {
        heading: 'Related Components'
      }, _react.default.createElement(_RelatedComponent.RelatedComponentContainer, null, _react.default.createElement(_RelatedComponent.RelatedComponent, {
        name: 'Box',
        onClick: (0, _addonLinks.linkTo)('Core/Box')
      }, _react.default.createElement(_Box.Box, {
        width: '75%',
        height: '75%',
        bg: 'background.lightest'
      }, "Box")), _react.default.createElement(_RelatedComponent.RelatedComponent, {
        name: 'Flex',
        onClick: (0, _addonLinks.linkTo)('Flex')
      }, _react.default.createElement(_Flex.Flex, {
        justifyContent: 'center',
        alignItems: 'center',
        width: '75%',
        height: '75%',
        bg: 'background.lightest'
      }, "Flex")))))
    }
  }
};
var _default = exports.default = meta;