"use strict";

var _pclnIcons = require("pcln-icons");
var _react = _interopRequireDefault(require("react"));
var _IconButton = require("../IconButton/IconButton");
var _Input = require("../Input/Input");
var _testingLibrary = require("../__test__/testing-library");
var _IconField = require("./IconField");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
describe('IconField', () => {
  it('renders', () => {
    (0, _testingLibrary.render)(_react.default.createElement(_IconField.IconField, {
      "data-testid": 'icon-field'
    }, _react.default.createElement(_pclnIcons.Calendar, {
      title: 'calendar'
    }), _react.default.createElement(_Input.Input, {
      id: 'test',
      placeholder: 'IconField'
    })));
    _testingLibrary.screen.getByTestId('icon-field');
    _testingLibrary.screen.getAllByTitle('calendar');
    _testingLibrary.screen.getByPlaceholderText('IconField');
  });
  it('renders icon button', () => {
    (0, _testingLibrary.render)(_react.default.createElement(_IconField.IconField, null, _react.default.createElement(_Input.Input, {
      id: 'test',
      placeholder: 'IconField'
    }), _react.default.createElement(_IconButton.IconButton, {
      id: 'test',
      icon: _react.default.createElement(_pclnIcons.Close, {
        title: 'close'
      })
    })));
    _testingLibrary.screen.getByPlaceholderText('IconField');
    _testingLibrary.screen.getAllByTitle('close');
    _testingLibrary.screen.getByRole('button');
  });
  it('renders icon, input and icon button together', () => {
    (0, _testingLibrary.render)(_react.default.createElement(_IconField.IconField, null, _react.default.createElement(_pclnIcons.Calendar, {
      title: 'calendar'
    }), _react.default.createElement(_Input.Input, {
      id: 'test',
      placeholder: 'IconField'
    }), _react.default.createElement(_IconButton.IconButton, {
      id: 'test',
      icon: _react.default.createElement(_pclnIcons.Close, {
        title: 'close'
      })
    })));
    _testingLibrary.screen.getAllByTitle('calendar');
    _testingLibrary.screen.getByPlaceholderText('IconField');
    _testingLibrary.screen.getAllByTitle('close');
    _testingLibrary.screen.getByRole('button');
  });
  it('does not render unknown children', () => {
    (0, _testingLibrary.render)(_react.default.createElement(_IconField.IconField, {
      "data-testid": 'icon-field'
    }, _react.default.createElement("pre", null, "Does not render")));
    expect(_testingLibrary.screen.queryByTestId('icon-field')).not.toBeInTheDocument();
  });
  it('does not add styles for no icons', () => {
    (0, _testingLibrary.render)(_react.default.createElement(_IconField.IconField, null, _react.default.createElement(_Input.Input, {
      id: 'test',
      placeholder: 'IconField'
    })));
    const prefixIconWrapper = _testingLibrary.screen.queryByTestId('icon-field-prefix-icons');
    const suffixIconWrapper = _testingLibrary.screen.queryByTestId('icon-field-suffix-icons');
    const input = _testingLibrary.screen.getByPlaceholderText('IconField');
    expect(prefixIconWrapper).not.toBeInTheDocument();
    expect(suffixIconWrapper).not.toBeInTheDocument();
    expect(input).not.toHaveStyleRule('padding-left');
    expect(input).not.toHaveStyleRule('padding-right');
  });
  it('adds styles for single icons', () => {
    (0, _testingLibrary.render)(_react.default.createElement(_IconField.IconField, null, _react.default.createElement(_pclnIcons.Calendar, {
      title: 'calendar'
    }), _react.default.createElement(_Input.Input, {
      id: 'test',
      placeholder: 'IconField'
    }), _react.default.createElement(_pclnIcons.Close, {
      title: 'close'
    })));
    const calendarIcon = _testingLibrary.screen.getAllByTitle('calendar')[0];
    const closeIcon = _testingLibrary.screen.getAllByTitle('close')[0];
    const prefixIconWrapper = _testingLibrary.screen.getByTestId('icon-field-prefix-icons');
    const suffixIconWrapper = _testingLibrary.screen.getByTestId('icon-field-suffix-icons');
    const input = _testingLibrary.screen.getByPlaceholderText('IconField');
    expect(calendarIcon).toHaveStyleRule('margin-left', '8px');
    expect(calendarIcon).toHaveStyleRule('margin-right', '8px');
    expect(closeIcon).toHaveStyleRule('margin-left', '8px');
    expect(closeIcon).toHaveStyleRule('margin-right', '8px');
    expect(prefixIconWrapper).toHaveStyleRule('margin-right', '-40px');
    expect(suffixIconWrapper).toHaveStyleRule('margin-left', '-40px');
    expect(input).toHaveStyleRule('padding-left', '40px');
    expect(input).toHaveStyleRule('padding-right', '40px');
  });
  it('adds styles for multiple icons', () => {
    (0, _testingLibrary.render)(_react.default.createElement(_IconField.IconField, null, _react.default.createElement(_pclnIcons.User, {
      title: 'user'
    }), _react.default.createElement(_pclnIcons.Calendar, {
      title: 'calendar'
    }), _react.default.createElement(_Input.Input, {
      id: 'test',
      placeholder: 'IconField'
    }), _react.default.createElement(_pclnIcons.Visibility, {
      title: 'visibility'
    }), _react.default.createElement(_pclnIcons.Close, {
      title: 'close'
    })));
    const prefixIconWrapper = _testingLibrary.screen.getByTestId('icon-field-prefix-icons');
    const suffixIconWrapper = _testingLibrary.screen.getByTestId('icon-field-suffix-icons');
    const input = _testingLibrary.screen.getByPlaceholderText('IconField');
    const calendarIcon = _testingLibrary.screen.getAllByTitle('calendar')[0];
    const closeIcon = _testingLibrary.screen.getAllByTitle('close')[0];
    expect(prefixIconWrapper).toHaveStyleRule('margin-right', '-80px');
    expect(suffixIconWrapper).toHaveStyleRule('margin-left', '-80px');
    expect(input).toHaveStyleRule('padding-left', '80px');
    expect(input).toHaveStyleRule('padding-right', '80px');
    expect(calendarIcon).toHaveStyleRule('margin-left', '0px');
    expect(calendarIcon).toHaveStyleRule('margin-right', '8px');
    expect(closeIcon).toHaveStyleRule('margin-left', '8px');
    expect(closeIcon).toHaveStyleRule('margin-right', '0px');
  });
});