"use strict";

var _react = _interopRequireDefault(require("react"));
var _Button = require("../Button/Button");
var _testingLibrary = require("../__test__/testing-library");
var _ForwardRefsDemo = _interopRequireDefault(require("../storybook/utils/ForwardRefsDemo"));
var _theme = require("../theme/theme");
var _createTheme = require("../utils/createTheme");
var _utils = require("../utils/utils");
var _Input = require("./Input");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const id = 'fake-test-id';
describe('Input', () => {
  test('it renders', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Input.Input, {
      id: id
    })).toJSON();
    expect(json).toMatchSnapshot();
  });
  test('it renders an input element with a red border with a color prop is passed', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Input.Input, {
      id: id,
      color: 'red'
    })).toJSON();
    expect(json).toMatchSnapshot();
  });
  test('it renders an input element with a really large padding and margin', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Input.Input, {
      id: id,
      p: 4,
      m: 4
    })).toJSON();
    expect(json).toMatchSnapshot();
  });
  test('it renders an input element with large text', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Input.Input, {
      id: id,
      fontSize: 4
    })).toJSON();
    expect(json).toMatchSnapshot();
  });
  test('forwards ref to the input', () => {
    const target = 'TARGET';
    const placeholder = 'Apples';
    function refChild(dsRef) {
      function onClick() {
        dsRef.current.focus();
      }
      return _react.default.createElement(_react.default.Fragment, null, _react.default.createElement(_Input.Input, {
        id: id,
        ref: dsRef,
        placeholder: placeholder
      }), _react.default.createElement(_Button.Button, {
        onClick: onClick,
        mt: 3
      }, target));
    }
    const {
      getByText,
      getByPlaceholderText
    } = (0, _testingLibrary.render)(_react.default.createElement(_ForwardRefsDemo.default, {
      refChild: refChild
    }));
    _testingLibrary.fireEvent.click(getByText(target));
    expect(getByPlaceholderText(placeholder)).toHaveFocus();
  });
  test('it renders disabled', () => {
    const paletteTheme = (0, _createTheme.createTheme)(_theme.theme);
    (0, _testingLibrary.render)(_react.default.createElement(_Input.Input, {
      id: id,
      disabled: true,
      placeholder: 'Disabled Input'
    }));
    const input = _testingLibrary.screen.getByPlaceholderText('Disabled Input');
    expect(input).toBeDisabled();
    expect(input).toHaveStyleRule('background-color', (0, _utils.getPaletteColor)('background.light')({
      theme: paletteTheme
    }), {
      modifier: ':disabled'
    });
    expect(input).toHaveStyleRule('color', (0, _utils.getPaletteColor)('text.light')({
      theme: paletteTheme
    }), {
      modifier: ':disabled'
    });
    expect(input).toHaveStyleRule('cursor', 'not-allowed', {
      modifier: ':disabled'
    });
  });
  describe('helper text', function () {
    test('renders with same color as Input', () => {
      const helperText = 'hello world';
      const color = 'error.base';
      const paletteTheme = (0, _createTheme.createTheme)(_theme.theme);
      const {
        getByText
      } = (0, _testingLibrary.render)(_react.default.createElement(_Input.Input, {
        id: id,
        color: color,
        helperText: _react.default.createElement(_Input.Input.HelperText, null, helperText)
      }));
      const helperTextNode = getByText(helperText);
      expect(helperTextNode).not.toBeNull();
      expect(helperTextNode).toHaveStyleRule('color', (0, _utils.getPaletteColor)(color)({
        theme: paletteTheme
      }));
    });
    test('can override the color from Input', () => {
      const helperText = 'hello world';
      const placeholder = 'click me';
      const color = 'error.base';
      const helperTextColor = 'secondary.base';
      const paletteTheme = (0, _createTheme.createTheme)(_theme.theme);
      const {
        getByText,
        getByPlaceholderText
      } = (0, _testingLibrary.render)(_react.default.createElement(_Input.Input, {
        id: id,
        color: color,
        placeholder: placeholder,
        helperText: _react.default.createElement(_Input.Input.HelperText, {
          color: helperTextColor
        }, helperText)
      }));
      const helperTextNode = getByText(helperText);
      expect(helperTextNode).not.toBeNull();
      expect(helperTextNode).toHaveStyleRule('color', (0, _utils.getPaletteColor)(helperTextColor)({
        theme: paletteTheme
      }));
      expect(getByPlaceholderText(placeholder)).toHaveStyleRule('border-color', (0, _utils.getPaletteColor)(color)({
        theme: paletteTheme
      }));
    });
  });
});