"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ALLOWED_LAYOUT_VALUES = exports.ALLOWED_GAP_VALUES = void 0;
exports.Layout = Layout;
var _react = _interopRequireWildcard(require("react"));
var _styledComponents = _interopRequireDefault(require("styled-components"));
var _styledSystem = require("styled-system");
var _Box = require("../Box/Box");
var _Grid = require("../Grid/Grid");
var _theme = require("../theme");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const getWidthsForVariation = variation => {
  return variation && variation.split('-').map(width => `${parseInt(width, 10) / 10}fr`).join(' ');
};
/**
 * Returns an array of responsive arrays of numbers with same length as numChildren. Each value represents the
 * width of the corresponding child.
 * @param variation - variation string to determine how items are sized
 * @param numChildren - number of children
 * @returns
 */
const getGridTemplateColumns = variation => {
  if (Array.isArray(variation)) {
    return variation.map(v => {
      return getWidthsForVariation(v);
    });
  } else {
    return getWidthsForVariation(variation);
  }
};
// After converting Layout from using Flex to Grid, we need to multiply
// the space values by 2 since we're using them for gap instead of padding on each child.
const spaceToGapValue = idx => `${_theme.spaceValues[idx] * 2}px`;
// Map named sizes to responsive size values from theme
const gapValues = {
  sm: spaceToGapValue(1),
  md: spaceToGapValue(2),
  lg: spaceToGapValue(3),
  xl: spaceToGapValue(4)
};
/**
 * Returns an object containing responsive arrays of values for mx to apply to
 * the wrapper flex and px values to apply to the children.
 * @param gapProp - value passed in as gap prop
 * @returns
 */
const getGapValues = (gapProp, rowGapProp) => {
  let columnGap;
  let rowGap;
  if (Array.isArray(rowGapProp)) {
    rowGap = rowGapProp.map(gap => gapValues[gap] || null);
  } else {
    rowGap = gapValues[rowGapProp];
  }
  if (Array.isArray(gapProp)) {
    columnGap = gapProp.map(gap => gapValues[gap] || null);
  } else {
    columnGap = gapValues[gapProp];
  }
  return {
    columnGap,
    rowGap
  };
};
/**
 * @public
 */
const ALLOWED_LAYOUT_VALUES = exports.ALLOWED_LAYOUT_VALUES = ['50-50', '33-33-33', '33-66', '66-33', '25-25-25-25', '60-40', '40-60', '100'];
/**
 * @public
 */
const ALLOWED_GAP_VALUES = exports.ALLOWED_GAP_VALUES = ['sm', 'md', 'lg', 'xl'];
const ZIndexBox = /*#__PURE__*/(0, _styledComponents.default)(_Box.Box).withConfig({
  displayName: "Layout__ZIndexBox",
  componentId: "sc-1t2q5yz-0"
})(["", ""], _styledSystem.zIndex);
/**
 * @public
 */
function Layout({
  children,
  gap,
  rowGap,
  variation,
  stretchHeight,
  ...props
}) {
  const [gapValues, setGapValues] = (0, _react.useState)(getGapValues(gap, rowGap));
  const [gridTemplateColumns, setGridTemplateColumns] = (0, _react.useState)(getGridTemplateColumns(variation));
  (0, _react.useEffect)(() => {
    setGapValues(getGapValues(gap, rowGap));
  }, [gap, rowGap]);
  (0, _react.useEffect)(() => {
    setGridTemplateColumns(getGridTemplateColumns(variation));
  }, [variation]);
  return _react.default.createElement(_Grid.Grid, {
    ...props,
    "data-testid": 'layout-grid',
    width: 1,
    gridTemplateColumns: gridTemplateColumns,
    rowGap: gapValues.rowGap,
    columnGap: gapValues.columnGap
  }, _react.default.Children.map(children, (child, idx) => child && _react.default.isValidElement(child) && _react.default.createElement(ZIndexBox, {
    "data-testid": `box-${idx}`,
    // TS ignored because the type of child.props is unknown
    // @ts-ignore
    zIndex: child?.props?.zIndex
  }, _react.default.cloneElement(child, {
    minHeight: stretchHeight ? '100%' : undefined
  }))));
}
Layout.displayName = 'Layout';