"use strict";

var _react = _interopRequireDefault(require("react"));
var _testingLibrary = require("../__test__/testing-library");
var _Link = require("./Link");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
describe('Link', () => {
  it('should render correctly with no props without throwing', () => {
    expect(() => {
      const {
        asFragment
      } = (0, _testingLibrary.render)(_react.default.createElement(_Link.Link, null, "Dummy"));
      expect(asFragment()).toMatchSnapshot();
    }).not.toThrow();
  });
  it('should add rel="noopener" when target="_blank"', () => {
    const {
      asFragment
    } = (0, _testingLibrary.render)(_react.default.createElement(_Link.Link, {
      target: '_blank'
    }, "Dummy"));
    expect(asFragment()).toMatchSnapshot();
    const link = _testingLibrary.screen.getByText('Dummy');
    expect(link).toHaveAttribute('target', '_blank');
    expect(link).toHaveAttribute('rel', 'noopener');
  });
  it('should not add rel="noopener" when target is not "_blank"', () => {
    const {
      asFragment
    } = (0, _testingLibrary.render)(_react.default.createElement(_Link.Link, null, "Dummy"));
    expect(asFragment()).toMatchSnapshot();
    const link = _testingLibrary.screen.getByText('Dummy');
    expect(link).not.toHaveAttribute('target', '_blank');
    expect(link).not.toHaveAttribute('rel', 'noopener');
  });
  it('should be clickable when not disabled', () => {
    const mockOnClick = jest.fn();
    (0, _testingLibrary.render)(_react.default.createElement(_Link.Link, {
      href: 'href',
      onClick: mockOnClick
    }, "Enabled"));
    const link = _testingLibrary.screen.getByText('Enabled');
    expect(link).toHaveAttribute('href');
    expect(link).toHaveStyleRule('color', '#0068ef');
    expect(link).toHaveStyleRule('cursor', 'pointer');
    expect(link).toHaveStyleRule('text-decoration', 'underline', {
      modifier: ':hover'
    });
    expect(mockOnClick).toHaveBeenCalledTimes(0);
    _testingLibrary.fireEvent.click(link);
    expect(mockOnClick).toHaveBeenCalledTimes(1);
  });
  it('should not be clickable when disabled', () => {
    const mockOnClick = jest.fn();
    (0, _testingLibrary.render)(_react.default.createElement(_Link.Link, {
      disabled: true,
      href: 'href',
      onClick: mockOnClick
    }, "Disabled"));
    const link = _testingLibrary.screen.getByText('Disabled');
    expect(link).not.toHaveAttribute('href');
    expect(link).toHaveStyleRule('color', '#4f6f8f');
    expect(link).toHaveStyleRule('cursor', 'default');
    expect(link).toHaveStyleRule('text-decoration', 'none', {
      modifier: ':hover'
    });
    expect(mockOnClick).toHaveBeenCalledTimes(0);
    _testingLibrary.fireEvent.click(link);
    expect(mockOnClick).toHaveBeenCalledTimes(0);
  });
});