"use strict";

var _react = _interopRequireDefault(require("react"));
var _testingLibrary = require("../__test__/testing-library");
var _List = require("./List");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
describe('List', () => {
  it('renders ordered list', () => {
    (0, _testingLibrary.render)(_react.default.createElement(_List.List.ol, {
      color: 'text.light',
      "data-testid": 'list'
    }, _react.default.createElement("li", null, "Example Text 1"), _react.default.createElement("li", null, "Example Text 2"), _react.default.createElement("li", null, "Example Text 3")));
    const list = _testingLibrary.screen.getByTestId('list');
    expect(list).toHaveStyleRule('color', '#4f6f8f');
    _testingLibrary.screen.getByText('Example Text 1');
    _testingLibrary.screen.getByText('Example Text 2');
    _testingLibrary.screen.getByText('Example Text 3');
  });
  it('renders unordered list', () => {
    (0, _testingLibrary.render)(_react.default.createElement(_List.List.ul, {
      color: 'text.light',
      fontSize: 1,
      "data-testid": 'list'
    }, _react.default.createElement("li", null, "Example Text 1"), _react.default.createElement("li", null, "Example Text 2"), _react.default.createElement("li", null, "Example Text 3")));
    const list = _testingLibrary.screen.getByTestId('list');
    expect(list).toHaveStyleRule('color', '#4f6f8f');
    expect(list).toHaveStyleRule('font-size', '14px');
    _testingLibrary.screen.getByText('Example Text 1');
    _testingLibrary.screen.getByText('Example Text 2');
    _testingLibrary.screen.getByText('Example Text 3');
  });
  it('renders list with listStyles and indentation which is passed in props ', () => {
    (0, _testingLibrary.render)(_react.default.createElement(_List.List.ul, {
      color: 'text.light',
      fontSize: 1,
      listStyle: 'upper-roman',
      indentSize: 'md',
      "data-testid": 'list'
    }, _react.default.createElement("li", null, "Example Text 1"), _react.default.createElement("li", null, "Example Text 2"), _react.default.createElement("li", null, "Example Text 3")));
    const list = _testingLibrary.screen.getByTestId('list');
    expect(list).toHaveStyleRule('list-style-type', 'upper-roman');
    expect(list).toHaveStyleRule('margin-left', '32px');
  });
  it('should render list with default listStyles and indentation if right props are not passed ', () => {
    (0, _testingLibrary.render)(
    // Ignoring TS error to test case when invalid listStyle is provided
    // @ts-ignore
    _react.default.createElement(_List.List.ul, {
      color: 'text.light',
      fontSize: 1,
      listStyle: 'roman',
      "data-testid": 'list'
    }, _react.default.createElement("li", null, "Example Text 1"), _react.default.createElement("li", null, "Example Text 2"), _react.default.createElement("li", null, "Example Text 3")));
    const list = _testingLibrary.screen.getByTestId('list');
    expect(list).toHaveStyleRule('list-style-type', 'auto');
    expect(list).toHaveStyleRule('margin-left', '40px');
  });
});