"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PasswordInput = PasswordInput;
var _pclnIcons = require("pcln-icons");
var _react = _interopRequireWildcard(require("react"));
var _styledComponents = _interopRequireDefault(require("styled-components"));
var _Badge = require("../Badge/Badge");
var _Flex = require("../Flex/Flex");
var _IconButton = require("../IconButton/IconButton");
var _IconField = require("../IconField/IconField");
var _Input = require("../Input/Input");
var _Label = require("../Label/Label");
var _ProgressBar = require("../ProgressBar/ProgressBar");
var _Text = require("../Text/Text");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const NoWrapText = /*#__PURE__*/(0, _styledComponents.default)(_Text.Text).withConfig({
  displayName: "PasswordInput__NoWrapText",
  componentId: "sc-1ch773c-0"
})(["white-space:nowrap;"]);
const maxProgressBarLength = 4;
/**
 * @public
 */
function PasswordInput({
  id,
  isValid,
  label,
  hasProgressBar,
  progressBarSteps,
  regexChecks,
  value,
  onChange,
  autoComplete,
  ...props
}) {
  const [showPassword, setShowPassword] = (0, _react.useState)(false);
  const [passedChecks, setPassedChecks] = (0, _react.useState)([]);
  function changeVisibility() {
    return setShowPassword(!showPassword);
  }
  function handleChange(event) {
    const currentValue = event.target.value;
    const passedChecks = [];
    if (hasProgressBar) {
      regexChecks.forEach((element, index) => element.regex.test(currentValue) && passedChecks.push(index));
      setPassedChecks(passedChecks);
    }
    const lengthsMatch = !hasProgressBar || passedChecks.length === regexChecks.length;
    if (onChange) {
      onChange({
        isValid: lengthsMatch,
        value: currentValue
      });
    }
  }
  const inputType = showPassword ? 'text' : 'password';
  const VisibilityIcon = showPassword ? _pclnIcons.VisibilityOff : _pclnIcons.Visibility;
  const strengthLevel = Math.max(Math.round(maxProgressBarLength / regexChecks.length * passedChecks.length), 0);
  const currentStep = progressBarSteps[strengthLevel - 1];
  const showCheckIcon = isValid || hasProgressBar && strengthLevel === maxProgressBarLength;
  return _react.default.createElement(_Flex.Flex, {
    flexDirection: 'column',
    ...props
  }, _react.default.createElement(_Label.Label, {
    htmlFor: id,
    fontSize: 0,
    mb: 2
  }, label), _react.default.createElement(_IconField.IconField, null, _react.default.createElement(_Input.Input, {
    id: id,
    type: inputType,
    value: value,
    onChange: handleChange,
    "data-testid": 'input-field',
    autoComplete: autoComplete
  }), showCheckIcon && _react.default.createElement(_pclnIcons.Check, {
    color: 'secondary',
    "data-testid": 'check-mark-icon'
  }), _react.default.createElement(_IconButton.IconButton, {
    title: 'visibility-button',
    icon: _react.default.createElement(VisibilityIcon, {
      color: 'text.light'
    }),
    onClick: changeVisibility
  })), hasProgressBar && _react.default.createElement(_Flex.Flex, {
    flexDirection: 'column'
  }, _react.default.createElement(_Flex.Flex, {
    alignItems: 'center',
    my: 2
  }, _react.default.createElement(NoWrapText, {
    fontSize: 0,
    color: 'text.light',
    mr: 2
  }, "Password Strength:", ' '), currentStep && _react.default.createElement(_Badge.Badge, {
    color: currentStep.color,
    size: 'small'
  }, currentStep.text)), _react.default.createElement(_ProgressBar.ProgressBar, {
    steps: progressBarSteps,
    currentStep: strengthLevel
  }), _react.default.createElement(_Flex.Flex, {
    flexDirection: ['column', null, 'row'],
    mt: 2,
    mb: [2, null, 0]
  }, _react.default.createElement(NoWrapText, {
    fontSize: 0,
    color: 'text.light',
    mr: 3
  }, "Must contain:"), _react.default.createElement(_Flex.Flex, {
    flexWrap: 'wrap'
  }, regexChecks.map((check, index) => {
    const didPass = passedChecks.findIndex(value => index === value) !== -1;
    const Icon = didPass ? _pclnIcons.Success : _pclnIcons.SuccessOutline;
    const color = didPass ? 'success' : 'text.light';
    return _react.default.createElement(_Flex.Flex, {
      alignItems: 'center',
      mt: [2, null, 0],
      mb: [0, null, 2],
      key: 'regex-label-' + index
    }, _react.default.createElement(Icon, {
      size: '16px',
      color: color,
      mr: 1,
      "data-testid": Icon === _pclnIcons.Success ? 'check-icon-on' : 'check-icon-off'
    }), _react.default.createElement(NoWrapText, {
      fontSize: 0,
      color: color,
      mr: 3
    }, check.label));
  })))));
}
PasswordInput.defaultProps = {
  hasProgressBar: false,
  progressBarSteps: [{
    color: 'warning',
    text: 'WEAK'
  }, {
    color: 'caution',
    text: 'FAIR'
  }, {
    color: 'primary',
    text: 'GOOD'
  }, {
    color: 'success',
    text: 'STRONG'
  }],
  progressBarDefaultStep: 1,
  regexChecks: [{
    label: '1 Uppercase Letter',
    regex: /(?=.*[A-Z])/
  }, {
    label: '1 Lowercase Letter',
    regex: /(?=.*[a-z])/
  }, {
    label: '1 Number',
    regex: /(?=.*[0-9])/
  }, {
    label: '1 Special Character',
    regex: /(?=.*[!@#$%^&*()])/
  }, {
    label: 'at least 12 Characters',
    regex: /.{12,}/
  }]
};