"use strict";

var _react = _interopRequireDefault(require("react"));
var _testingLibrary = require("../__test__/testing-library");
var _PasswordInput = require("./PasswordInput");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const sampleRegexChecks = [{
  label: '1 Uppercase Letter',
  regex: /(?=.*[A-Z])/
}, {
  label: '1 Lowercase Letter',
  regex: /(?=.*[a-z])/
}];
describe('PasswordInput', () => {
  it('test show/hide password options', () => {
    (0, _testingLibrary.render)(_react.default.createElement(_PasswordInput.PasswordInput, {
      hasProgressBar: true
    }));
    const inputField = _testingLibrary.screen.getByTestId('input-field');
    const visibilityButton = _testingLibrary.screen.getByTitle('visibility-button');
    expect(inputField).toHaveAttribute('type', 'password');
    _testingLibrary.fireEvent.click(visibilityButton);
    expect(inputField).toHaveAttribute('type', 'text');
  });
  it('test with a strong password', () => {
    const mockOnChange = jest.fn();
    (0, _testingLibrary.render)(_react.default.createElement(_PasswordInput.PasswordInput, {
      hasProgressBar: true,
      onChange: mockOnChange
    }));
    const inputField = _testingLibrary.screen.getByTestId('input-field');
    _testingLibrary.fireEvent.change(inputField, {
      target: {
        value: 'GoodPassword1!'
      }
    });
    expect(mockOnChange).toHaveBeenLastCalledWith({
      isValid: true,
      value: 'GoodPassword1!'
    });
    const checkIconOn = _testingLibrary.screen.queryAllByTestId('check-icon-on');
    const checkIconOff = _testingLibrary.screen.queryAllByTestId('check-icon-off');
    expect(checkIconOn).toHaveLength(5);
    expect(checkIconOff).toHaveLength(0);
    expect(checkIconOn[0]).toHaveStyleRule('color', '#0a0');
    const checkMark = _testingLibrary.screen.queryAllByTestId('check-mark-icon');
    expect(checkMark).toHaveLength(1);
  });
  it('test with a no number and special character password', () => {
    const mockOnChange = jest.fn();
    (0, _testingLibrary.render)(_react.default.createElement(_PasswordInput.PasswordInput, {
      hasProgressBar: true,
      onChange: mockOnChange
    }));
    const inputField = _testingLibrary.screen.getByTestId('input-field');
    _testingLibrary.fireEvent.change(inputField, {
      target: {
        value: 'SamplePassword'
      }
    });
    expect(mockOnChange).toHaveBeenLastCalledWith({
      isValid: false,
      value: 'SamplePassword'
    });
    const checkIconOn = _testingLibrary.screen.queryAllByTestId('check-icon-on');
    const checkIconOff = _testingLibrary.screen.queryAllByTestId('check-icon-off');
    expect(checkIconOn).toHaveLength(3);
    expect(checkIconOff).toHaveLength(2);
    expect(checkIconOn[0]).toHaveStyleRule('color', '#0a0');
    expect(checkIconOff[0]).toHaveStyleRule('color', '#4f6f8f');
    const checkMark = _testingLibrary.screen.queryAllByTestId('check-mark-icon');
    expect(checkMark).toHaveLength(0);
  });
  it('test with a weak password', () => {
    const mockOnChange = jest.fn();
    (0, _testingLibrary.render)(_react.default.createElement(_PasswordInput.PasswordInput, {
      hasProgressBar: true,
      onChange: mockOnChange
    }));
    const inputField = _testingLibrary.screen.getByTestId('input-field');
    _testingLibrary.fireEvent.change(inputField, {
      target: {
        value: 'bad'
      }
    });
    expect(mockOnChange).toHaveBeenLastCalledWith({
      isValid: false,
      value: 'bad'
    });
    const checkIconOn = _testingLibrary.screen.queryAllByTestId('check-icon-on');
    const checkIconOff = _testingLibrary.screen.queryAllByTestId('check-icon-off');
    expect(checkIconOn).toHaveLength(1);
    expect(checkIconOff).toHaveLength(4);
    expect(checkIconOff[0]).toHaveStyleRule('color', '#4f6f8f');
    const checkMark = _testingLibrary.screen.queryAllByTestId('check-mark-icon');
    expect(checkMark).toHaveLength(0);
  });
  it('test with a manual regex checks', () => {
    const mockOnChange = jest.fn();
    (0, _testingLibrary.render)(_react.default.createElement(_PasswordInput.PasswordInput, {
      hasProgressBar: true,
      regexChecks: sampleRegexChecks,
      onChange: mockOnChange
    }));
    const inputField = _testingLibrary.screen.getByTestId('input-field');
    _testingLibrary.fireEvent.change(inputField, {
      target: {
        value: 'Password'
      }
    });
    expect(mockOnChange).toHaveBeenLastCalledWith({
      isValid: true,
      value: 'Password'
    });
    const checkIconOn = _testingLibrary.screen.queryAllByTestId('check-icon-on');
    const checkIconOff = _testingLibrary.screen.queryAllByTestId('check-icon-off');
    expect(checkIconOn).toHaveLength(2);
    expect(checkIconOff).toHaveLength(0);
    expect(checkIconOn[0]).toHaveStyleRule('color', '#0a0');
    const checkMark = _testingLibrary.screen.queryAllByTestId('check-mark-icon');
    expect(checkMark).toHaveLength(1);
  });
  it('ignores regex checks and returns valid if no progress bar', () => {
    const mockOnChange = jest.fn();
    (0, _testingLibrary.render)(_react.default.createElement(_PasswordInput.PasswordInput, {
      label: 'Password',
      onChange: mockOnChange
    }));
    const inputField = _testingLibrary.screen.getByTestId('input-field');
    _testingLibrary.fireEvent.change(inputField, {
      target: {
        value: 'test'
      }
    });
    expect(mockOnChange).toHaveBeenCalledWith({
      isValid: true,
      value: 'test'
    });
  });
});