"use strict";

var _react = _interopRequireDefault(require("react"));
var _testingLibrary = require("../__test__/testing-library");
var _PlaceholderImage = require("./PlaceholderImage");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
describe('PlaceholderImage', () => {
  it('should use the default height and width when not specified', () => {
    const {
      getByAltText
    } = (0, _testingLibrary.render)(_react.default.createElement(_PlaceholderImage.PlaceholderImage, null));
    const placeholderImage = getByAltText('Random image used for placeholder content');
    expect(placeholderImage).toHaveStyleRule('height', '500px');
    expect(placeholderImage).toHaveStyleRule('width', '500px');
  });
  it('should use provided height and width', () => {
    const {
      getByAltText
    } = (0, _testingLibrary.render)(_react.default.createElement(_PlaceholderImage.PlaceholderImage, {
      height: '300',
      width: '600'
    }));
    const placeholderImage = getByAltText('Random image used for placeholder content');
    expect(placeholderImage).toHaveStyleRule('height', '300px');
    expect(placeholderImage).toHaveStyleRule('width', '600px');
  });
  it('should use a blurred image', () => {
    const {
      getByAltText
    } = (0, _testingLibrary.render)(_react.default.createElement(_PlaceholderImage.PlaceholderImage, {
      blur: true
    }));
    const placeholderImage = getByAltText('Random image used for placeholder content');
    expect(placeholderImage).toHaveAttribute('src', 'https://picsum.photos/500/500?blur');
  });
  it('should allow the user to specify a placeholder service via chooseSrc', () => {
    const {
      getByAltText
    } = (0, _testingLibrary.render)(_react.default.createElement(_PlaceholderImage.PlaceholderImage, {
      chooseSrc: '0'
    }));
    const placeholderImage = getByAltText('Random image used for placeholder content');
    expect(placeholderImage).toHaveAttribute('src', 'http://placeimg.com/500/500/any');
  });
  it('should apply the `alt` attribute as specified', () => {
    const {
      getByAltText
    } = (0, _testingLibrary.render)(_react.default.createElement(_PlaceholderImage.PlaceholderImage, {
      alt: 'Test alt text here'
    }));
    getByAltText('Test alt text here');
  });
});