"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Popout = Popout;
var _react = _interopRequireWildcard(require("react"));
var _styledComponents = _interopRequireDefault(require("styled-components"));
var _Box = require("../Box/Box");
var _ShadowEffect = require("../ShadowEffect/ShadowEffect");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const TriggerWrapper = /*#__PURE__*/(0, _styledComponents.default)(_Box.Box).withConfig({
  displayName: "Popout__TriggerWrapper",
  componentId: "sc-hnx2ed-0"
})(["position:relative;width:fit-content;"]);
const OnClickHandler = /*#__PURE__*/(0, _styledComponents.default)(_Box.Box).withConfig({
  displayName: "Popout__OnClickHandler",
  componentId: "sc-hnx2ed-1"
})(["position:absolute;top:0;width:100%;height:100%;cursor:pointer;"]);
const PopoutModal = /*#__PURE__*/(0, _styledComponents.default)(_Box.Box).withConfig({
  displayName: "Popout__PopoutModal",
  componentId: "sc-hnx2ed-2"
})(["position:absolute;z-index:2;transition:padding 200ms ease-in-out,margin 200ms ease-in-out,border-radius 200ms ease-in-out;"]);
/**
 * @public
 */
function Popout(props) {
  const {
    trigger,
    content,
    onOpen,
    onClose,
    triggerRef,
    closeOnTriggerRefClick
  } = props;
  const [isOpen, setIsOpen] = (0, _react.useState)(false);
  const [height, setHeight] = (0, _react.useState)(0);
  const [padding, setPadding] = (0, _react.useState)(0);
  const [opacity, setOpacity] = (0, _react.useState)(0);
  const baseInputRef = (0, _react.useRef)(null);
  const modalRef = (0, _react.useRef)(null);
  const isMounted = (0, _react.useRef)(false);
  const handleOpen = (0, _react.useCallback)(() => setIsOpen(true), []);
  const handleClose = (0, _react.useCallback)(() => setIsOpen(false), []);
  (0, _react.useEffect)(() => {
    if (isMounted.current) {
      if (isOpen) {
        setPadding(16);
        setOpacity(0.5);
        /* istanbul ignore next */
        triggerRef?.current?.focus();
        /* istanbul ignore next */
        onOpen?.();
      } else {
        setPadding(0);
        setOpacity(0);
        /* istanbul ignore next */
        onClose?.();
      }
      return;
    }
    isMounted.current = true;
  }, [isOpen, triggerRef]);
  (0, _react.useLayoutEffect)(() => {
    setHeight(baseInputRef.current.clientHeight);
  }, [trigger]);
  (0, _react.useEffect)(() => {
    if (isOpen && closeOnTriggerRefClick) {
      triggerRef?.current?.addEventListener('click', handleClose);
    }
    return () => triggerRef?.current?.removeEventListener('click', handleClose);
  }, [isOpen, closeOnTriggerRefClick, triggerRef, handleClose]);
  (0, _react.useEffect)(() => {
    const escapeListener = e => {
      if (isOpen && e.key === 'Escape') {
        handleClose();
      }
    };
    const focusListener = e => {
      if (isOpen && e.target instanceof HTMLElement && e.target !== baseInputRef.current && !modalRef.current.contains(e.target)) {
        handleClose();
      }
    };
    document.addEventListener('focusin', focusListener);
    document.addEventListener('keydown', escapeListener);
    return () => {
      document.removeEventListener('focusin', focusListener);
      document.removeEventListener('keydown', escapeListener);
    };
  }, [isOpen, handleClose]);
  const placeHolderDiv = _react.default.createElement(_Box.Box, {
    style: {
      height
    }
  });
  return _react.default.createElement(_Box.Box, null, _react.default.createElement(TriggerWrapper, {
    tabIndex: isOpen ? -1 : 0,
    onFocus: handleOpen,
    ref: baseInputRef
  }, isOpen ? placeHolderDiv : trigger, _react.default.createElement(OnClickHandler, {
    onClick: handleOpen
  })), isOpen && _react.default.createElement(_react.default.Fragment, null, _react.default.createElement(_ShadowEffect.ShadowOverlay, {
    zIndex: 1,
    onClick: handleClose,
    style: {
      opacity,
      transition: 'opacity 250ms ease-in-out'
    }
  }), _react.default.createElement(PopoutModal, {
    ref: modalRef,
    boxShadowSize: 'overlay-lg',
    bg: 'background.lightest',
    style: {
      padding: padding,
      borderRadius: padding,
      marginTop: -(height + padding),
      marginLeft: -padding
    }
  }, trigger, content)));
}