"use strict";

var _react = _interopRequireDefault(require("react"));
var _testingLibrary = require("../__test__/testing-library");
var _Popout = require("./Popout");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const trigger = _react.default.createElement("input", {
  "data-testid": 'trigger',
  "aria-label": 'trigger'
});
const content = _react.default.createElement("div", {
  "data-testId": 'content'
}, "Content");
const delay = async ms => new Promise(resolve => setTimeout(resolve, ms));
describe('Popout', () => {
  it('Renders the trigger', () => {
    const {
      getByTestId
    } = (0, _testingLibrary.render)(_react.default.createElement(_Popout.Popout, {
      trigger: trigger
    }));
    expect(getByTestId('trigger')).toBeTruthy();
  });
  it('Handles opening and closing', async () => {
    const handler = jest.fn();
    const {
      getByTestId
    } = (0, _testingLibrary.render)(_react.default.createElement(_Popout.Popout, {
      trigger: trigger,
      content: content,
      onOpen: handler,
      onClose: handler
    }));
    const triggerElement = getByTestId('trigger');
    _testingLibrary.fireEvent.focusIn(triggerElement);
    await delay(100);
    expect(handler).toHaveBeenCalledTimes(1);
    const contentElement = getByTestId('content');
    _testingLibrary.fireEvent.keyDown(contentElement, {
      key: 'Escape',
      code: 'Escape',
      keyCode: 27,
      charCode: 27
    });
    await delay(100);
    expect(handler).toHaveBeenCalledTimes(2);
  });
  it('Handles losing focus', async () => {
    const handler = jest.fn();
    const {
      getByTestId
    } = (0, _testingLibrary.render)(_react.default.createElement(_react.default.Fragment, null, _react.default.createElement("input", {
      "data-testid": 'outside',
      "aria-label": 'outside'
    }), _react.default.createElement(_Popout.Popout, {
      trigger: trigger,
      content: content,
      onOpen: handler,
      onClose: handler
    })));
    const triggerElement = getByTestId('trigger');
    _testingLibrary.fireEvent.focusIn(triggerElement);
    await delay(100);
    expect(handler).toHaveBeenCalledTimes(1);
    const outsideElement = getByTestId('outside');
    _testingLibrary.fireEvent.focusIn(outsideElement);
    await delay(100);
    expect(handler).toHaveBeenCalledTimes(2);
  });
  it('Closes when the trigger ref is clicked', async () => {
    const handler = jest.fn();
    const triggerRef = _react.default.createRef();
    const _trigger = _react.default.cloneElement(trigger, {
      ref: triggerRef
    });
    const {
      getByTestId
    } = (0, _testingLibrary.render)(_react.default.createElement(_Popout.Popout, {
      trigger: _trigger,
      triggerRef: triggerRef,
      content: content,
      onOpen: handler,
      onClose: handler,
      closeOnTriggerRefClick: true
    }));
    const triggerElement = getByTestId('trigger');
    _testingLibrary.fireEvent.focusIn(triggerElement);
    await delay(100);
    expect(handler).toHaveBeenCalledTimes(1);
    _testingLibrary.fireEvent.click(triggerRef.current);
    await delay(100);
    expect(handler).toHaveBeenCalledTimes(2);
  });
});