"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Radio = void 0;
var _pclnIcons = require("pcln-icons");
var _react = _interopRequireDefault(require("react"));
var _styledComponents = _interopRequireDefault(require("styled-components"));
var _utils = require("../utils/utils");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const RadioWrap = /*#__PURE__*/_styledComponents.default.div.withConfig({
  displayName: "Radio__RadioWrap",
  componentId: "sc-7dqaqw-0"
})(["display:inline-block;color:", ";cursor:", ";&:hover > svg{", ";}", ""], (0, _utils.getPaletteColor)('text.light'), props => props.disabled ? `not-allowed` : `pointer`, props => {
  if (props.checked && !props.disabled) {
    return `color: ${(0, _utils.getPaletteColor)('dark')(props)} !important;`;
  }
  return props.disabled ? null : `color: ${(0, _utils.getPaletteColor)('base')(props)};`;
}, (0, _utils.applyVariations)('Radio'));
const RadioInput = /*#__PURE__*/_styledComponents.default.input.withConfig({
  displayName: "Radio__RadioInput",
  componentId: "sc-7dqaqw-1"
})(["appearance:none;opacity:0;position:absolute;z-index:0;& ~ svg{border:1px solid transparent;border-radius:50%;padding:2px;}&:focus{box-shadow:none;& ~ svg{border:1px solid ", ";background-color:", ";}}&:checked ~ svg{color:", ";}&:disabled ~ svg{color:", ";cursor:not-allowed;}"], (0, _utils.getPaletteColor)('border.base'), (0, _utils.getPaletteColor)('background.light'), (0, _utils.getPaletteColor)('base'), (0, _utils.getPaletteColor)('border.base'));
const RadioCheckedIcon = /*#__PURE__*/(0, _styledComponents.default)(_pclnIcons.RadioChecked).withConfig({
  displayName: "Radio__RadioCheckedIcon",
  componentId: "sc-7dqaqw-2"
})(["vertical-align:middle;"]);
const RadioEmptyIcon = /*#__PURE__*/(0, _styledComponents.default)(_pclnIcons.RadioEmpty).withConfig({
  displayName: "Radio__RadioEmptyIcon",
  componentId: "sc-7dqaqw-3"
})(["vertical-align:middle;"]);
const RadioIcon = ({
  checked,
  ...props
}) => {
  return checked ? _react.default.createElement(RadioCheckedIcon, {
    ...props
  }) : _react.default.createElement(RadioEmptyIcon, {
    ...props
  });
};
/**
 * @public
 */
const Radio = exports.Radio = _react.default.forwardRef((props, ref) => {
  const {
    checked,
    disabled,
    size
  } = props;
  const borderAdjustedSize = size + 4;
  const dataNameHelper = (checked, disabled) => {
    if (checked && disabled || !checked && disabled) {
      return 'disabled';
    }
    if (checked && !disabled) {
      return 'checked';
    }
    return 'unchecked';
  };
  return _react.default.createElement(RadioWrap, {
    color: props.color,
    checked: checked,
    disabled: disabled,
    "data-name": dataNameHelper(checked, disabled)
  }, _react.default.createElement(RadioInput, {
    type: 'radio',
    ...props,
    ref: ref
  }), _react.default.createElement(RadioIcon, {
    checked: checked,
    size: borderAdjustedSize
  }));
});
Radio.displayName = 'Radio';
Radio.defaultProps = {
  color: 'primary',
  size: 24
};