"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.RadioCheckToggleCard = RadioCheckToggleCard;
exports.RadioCheckToggleCardVPositions = exports.RadioCheckToggleCardHPositions = exports.RadioCheckToggleCardCardTypes = void 0;
var _themeGet = require("@styled-system/theme-get");
var _pclnIcons = require("pcln-icons");
var _react = _interopRequireDefault(require("react"));
var _styledComponents = _interopRequireDefault(require("styled-components"));
var _Box = require("../Box/Box");
var _Flex = require("../Flex/Flex");
var _Toggle = require("../Toggle/Toggle");
var _utils = require("../utils/utils");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
/**
 * @public
 */
const RadioCheckToggleCardCardTypes = exports.RadioCheckToggleCardCardTypes = ['radio', 'checkbox', 'toggle'];
/**
 * @public
 */
const RadioCheckToggleCardHPositions = exports.RadioCheckToggleCardHPositions = ['left', 'right'];
/**
 * @public
 */
const RadioCheckToggleCardVPositions = exports.RadioCheckToggleCardVPositions = ['top', 'center'];
const CombinedInput = /*#__PURE__*/_styledComponents.default.input.withConfig({
  displayName: "RadioCheckToggleCard__CombinedInput",
  componentId: "sc-1s16dkq-0"
})(["appearance:none;opacity:0;position:absolute;z-index:0;&:hover + div{border-color:", ";& svg{color:", ";}}&:focus-visible + div div.cardIcon > svg{border-color:", ";box-shadow:inset 0 0 0 5px ", ";}&:active + div,&:checked:hover + div{border-color:", ";& div.cardIcon > svg{color:", ";}}&:checked + div{background-color:", ";border:1px solid ", ";& div.cardIcon > svg{color:", ";}}&:checked:focus-visible + div div.cardIcon > svg{border-color:", ";}"], (0, _utils.getPaletteColor)('primary.base'), (0, _utils.getPaletteColor)('primary.base'), (0, _utils.getPaletteColor)('text.light'), (0, _utils.getPaletteColor)('background.light'), (0, _utils.getPaletteColor)('primary.dark'), (0, _utils.getPaletteColor)('primary.dark'), (0, _utils.getPaletteColor)('primary.light'), (0, _utils.getPaletteColor)('primary.base'), (0, _utils.getPaletteColor)('primary.base'), (0, _utils.getPaletteColor)('primary.dark'));
const RCTCardContainer = /*#__PURE__*/(0, _styledComponents.default)(_Flex.Flex).withConfig({
  displayName: "RadioCheckToggleCard__RCTCardContainer",
  componentId: "sc-1s16dkq-1"
})(["background-color:", ";border:1px solid transparent;border-radius:", ";box-shadow:", ";cursor:pointer;padding:", ";"], (0, _utils.getPaletteColor)('background.lightest'), (0, _themeGet.themeGet)('borderRadii.action-lg'), (0, _themeGet.themeGet)('shadows.sm'), (0, _themeGet.themeGet)('space.3'));
const CardHeader = /*#__PURE__*/(0, _styledComponents.default)(_Flex.Flex).withConfig({
  displayName: "RadioCheckToggleCard__CardHeader",
  componentId: "sc-1s16dkq-2"
})(["min-width:0;width:100%;& + *{margin-top:", ";}"], (0, _themeGet.themeGet)('space.3'));
const StyledTitle = /*#__PURE__*/(0, _styledComponents.default)(_Box.Box).withConfig({
  displayName: "RadioCheckToggleCard__StyledTitle",
  componentId: "sc-1s16dkq-3"
})(["font-weight:", ";font-size:", ";line-height:24px;"], props => props.isTitleBold ? '700' : '500', props => props.isTitleBold ? '16px' : '14px');
const CardContent = /*#__PURE__*/(0, _styledComponents.default)(_Box.Box).withConfig({
  displayName: "RadioCheckToggleCard__CardContent",
  componentId: "sc-1s16dkq-4"
})(["flex:1;& > :first-child + *{margin-top:", ";}"], (0, _themeGet.themeGet)('space.3'));
const CardIcon = /*#__PURE__*/(0, _styledComponents.default)(_Box.Box).withConfig({
  displayName: "RadioCheckToggleCard__CardIcon",
  componentId: "sc-1s16dkq-5"
})(["line-height:0px;margin:", ";& > svg{border:1px solid transparent;border-radius:", ";color:", ";padding:2px;}"], props => props.hPosition === 'left' ? `0 16px 0 0` : `0 0 0 16px`, props => props.cardType === 'checkbox' ? '4px' : '9999px', (0, _utils.getPaletteColor)('text.light'));
const RadioIcon = ({
  checked,
  ...props
}) => {
  return checked ? _react.default.createElement(_pclnIcons.RadioChecked, {
    ...props
  }) : _react.default.createElement(_pclnIcons.RadioEmpty, {
    ...props
  });
};
const CheckboxIcon = ({
  checked,
  ...props
}) => {
  return checked ? _react.default.createElement(_pclnIcons.BoxChecked, {
    ...props
  }) : _react.default.createElement(_pclnIcons.BoxEmpty, {
    ...props
  });
};
const ToggleIcon = ({
  checked,
  onChange,
  ...props
}) => {
  const checkIcon = _react.default.createElement(_pclnIcons.Check, {
    size: '16'
  });
  return _react.default.createElement(_Box.Box, {
    ...props
  }, _react.default.createElement(_Toggle.Toggle, {
    height: 24,
    isOn: checked,
    icon: checkIcon,
    onToggle: onChange
  }));
};
const buttonIcon = cardType => {
  if (cardType === 'radio') {
    return RadioIcon;
  } else if (cardType === 'checkbox') {
    return CheckboxIcon;
  } else if (cardType === 'toggle') {
    return ToggleIcon;
  }
};
/**
 * @public
 */
function RadioCheckToggleCard(props) {
  const {
    children,
    cardType,
    hPosition,
    vPosition,
    isTakingFullHeightOfCard,
    title,
    isTitleBold,
    name,
    value,
    onChange,
    isSelected
  } = props;
  const id = `${name}_${value}`;
  const ButtonIcon = buttonIcon(cardType);
  return _react.default.createElement("label", {
    htmlFor: id,
    "data-testId": 'rdt-card-label'
  }, _react.default.createElement(CombinedInput, {
    role: cardType === 'radio' ? 'radio' : 'checkbox',
    id: id,
    name: name,
    value: value,
    type: cardType === 'radio' ? 'radio' : 'checkbox',
    onChange: onChange,
    checked: isSelected
  }), _react.default.createElement(RCTCardContainer, {
    flexDirection: 'column',
    "data-testId": 'rdt-card-main'
  }, _react.default.createElement(CardHeader, {
    alignItems: vPosition,
    flexDirection: hPosition === 'left' ? 'row-reverse' : 'row',
    "data-testId": 'rdt-card-header'
  }, _react.default.createElement(CardContent, null, _react.default.createElement(StyledTitle, {
    isTitleBold: isTitleBold,
    "data-testId": 'rdt-card-title'
  }, title), isTakingFullHeightOfCard && children), _react.default.createElement(CardIcon, {
    className: 'cardIcon',
    cardType: cardType,
    hPosition: hPosition
  }, _react.default.createElement(ButtonIcon, {
    checked: isSelected,
    onChange: onChange,
    size: '24'
  }))), !isTakingFullHeightOfCard && children));
}
RadioCheckToggleCard.displayName = 'RadioCheckToggleCard';
RadioCheckToggleCard.defaultProps = {
  cardType: 'radio',
  isTitleBold: false,
  hPosition: 'right',
  vPosition: 'top',
  isTakingFullHeightOfCard: false,
  onChange: () => {}
};