"use strict";

var _react = _interopRequireDefault(require("react"));
var _Text = require("../Text/Text");
var _testingLibrary = require("../__test__/testing-library");
var _RadioCheckToggleCard = require("./RadioCheckToggleCard");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
describe('RadioCheckToggleCard', () => {
  describe('common', () => {
    it('should render default UI correctly', () => {
      const {
        asFragment,
        getByTestId
      } = (0, _testingLibrary.render)(_react.default.createElement(_RadioCheckToggleCard.RadioCheckToggleCard, {
        cardType: 'radio',
        name: 'radio-1',
        title: 'Title',
        value: 'example-1',
        isSelected: false,
        onChange: () => {}
      }));
      expect(asFragment()).toMatchSnapshot();
      expect(getByTestId('rdt-card-title')).toHaveStyleRule('font-size', '14px');
      expect(getByTestId('rdt-card-header')).toHaveStyleRule('flex-direction', 'row');
      expect(getByTestId('rdt-card-header').querySelector(':nth-child(2)')).toHaveStyle('margin: 0 0 0 16px');
    });
    it('should render bold title correctly', () => {
      const {
        getByTestId,
        asFragment
      } = (0, _testingLibrary.render)(_react.default.createElement(_RadioCheckToggleCard.RadioCheckToggleCard, {
        cardType: 'radio',
        isTitleBold: true,
        name: 'radio-1',
        title: 'Title',
        value: 'example-1',
        isSelected: false,
        onChange: () => {}
      }, _react.default.createElement(_Text.Text, null, "Happy Priceline!")));
      expect(asFragment()).toMatchSnapshot();
      expect(getByTestId('rdt-card-title')).toHaveStyleRule('font-size', '16px');
      expect(getByTestId('rdt-card-title')).toHaveStyleRule('font-weight', '700');
    });
    it('should render left button UI correctly', () => {
      const {
        asFragment,
        getByTestId
      } = (0, _testingLibrary.render)(_react.default.createElement(_RadioCheckToggleCard.RadioCheckToggleCard, {
        cardType: 'radio',
        hPosition: 'left',
        name: 'radio-1',
        title: 'Title',
        value: 'example-1',
        isSelected: false,
        onChange: () => {}
      }));
      expect(asFragment()).toMatchSnapshot();
      expect(getByTestId('rdt-card-header').querySelector(':nth-child(2)')).toHaveStyle('margin: 0 16px 0 0');
    });
    it('should execute handle change function', () => {
      let isSelected = false;
      let selectedValue = '';
      const spyOnChange = jest.fn().mockImplementation(e => {
        isSelected = true;
        selectedValue = e.currentTarget.value;
      });
      const cardTitle = 'Pay by credit card';
      const {
        getByText
      } = (0, _testingLibrary.render)(_react.default.createElement(_RadioCheckToggleCard.RadioCheckToggleCard, {
        cardType: 'radio',
        name: 'radio-1',
        title: cardTitle,
        value: 'example-1',
        isSelected: isSelected,
        onChange: spyOnChange
      }));
      getByText(cardTitle).click();
      expect(isSelected).toEqual(true);
      expect(selectedValue).toEqual('example-1');
      expect(spyOnChange).toHaveBeenCalled();
      expect(spyOnChange).toHaveBeenCalledTimes(1);
    });
    it('should render children correctly', () => {
      const {
        getByText,
        getByTestId,
        asFragment
      } = (0, _testingLibrary.render)(_react.default.createElement(_RadioCheckToggleCard.RadioCheckToggleCard, {
        cardType: 'radio',
        name: 'radio-1',
        title: 'Title',
        value: 'example-1',
        isSelected: false,
        onChange: () => {}
      }, _react.default.createElement(_Text.Text, null, "Happy Priceline!")));
      expect(asFragment()).toMatchSnapshot();
      expect(getByText('Happy Priceline!')).toBeInTheDocument();
      expect(getByTestId('rdt-card-main').childElementCount).toEqual(2);
      expect(getByTestId('rdt-card-header').querySelector('div').childElementCount).toEqual(1);
    });
    it('should render children next to title correctly', () => {
      const {
        getByText,
        getByTestId,
        asFragment
      } = (0, _testingLibrary.render)(_react.default.createElement(_RadioCheckToggleCard.RadioCheckToggleCard, {
        cardType: 'radio',
        isTakingFullHeightOfCard: true,
        name: 'radio-1',
        title: 'Title',
        value: 'example-1',
        isSelected: false,
        onChange: () => {}
      }, _react.default.createElement(_Text.Text, null, "Happy Priceline!")));
      expect(asFragment()).toMatchSnapshot();
      expect(getByText('Happy Priceline!')).toBeInTheDocument();
      expect(getByTestId('rdt-card-main').childElementCount).toEqual(1);
      expect(getByTestId('rdt-card-header').querySelector('div').childElementCount).toEqual(2);
    });
  });
  describe('Radio Card', () => {
    it('should render unchecked state UI correctly', () => {
      const {
        asFragment
      } = (0, _testingLibrary.render)(_react.default.createElement(_RadioCheckToggleCard.RadioCheckToggleCard, {
        cardType: 'radio',
        name: 'radio-1',
        title: 'Title',
        value: 'example-1',
        isSelected: false,
        onChange: () => {}
      }));
      expect(asFragment()).toMatchSnapshot();
    });
    it('should render checked state UI correctly', () => {
      const {
        asFragment
      } = (0, _testingLibrary.render)(_react.default.createElement(_RadioCheckToggleCard.RadioCheckToggleCard, {
        cardType: 'radio',
        name: 'radio-1',
        title: 'Title',
        value: 'example-1',
        isSelected: true,
        onChange: () => {}
      }));
      expect(asFragment()).toMatchSnapshot();
    });
  });
  describe('Checkbox Card', () => {
    it('should render unchecked state UI correctly', () => {
      const {
        asFragment
      } = (0, _testingLibrary.render)(_react.default.createElement(_RadioCheckToggleCard.RadioCheckToggleCard, {
        cardType: 'checkbox',
        name: 'radio-1',
        title: 'Title',
        value: 'example-1',
        isSelected: false,
        onChange: () => {}
      }));
      expect(asFragment()).toMatchSnapshot();
    });
    it('should render checked state UI correctly', () => {
      const {
        asFragment
      } = (0, _testingLibrary.render)(_react.default.createElement(_RadioCheckToggleCard.RadioCheckToggleCard, {
        cardType: 'checkbox',
        name: 'radio-1',
        title: 'Title',
        value: 'example-1',
        isSelected: true,
        onChange: () => {}
      }));
      expect(asFragment()).toMatchSnapshot();
    });
  });
  describe('Toggle Card', () => {
    it('should render unchecked state UI correctly', () => {
      const {
        asFragment
      } = (0, _testingLibrary.render)(_react.default.createElement(_RadioCheckToggleCard.RadioCheckToggleCard, {
        cardType: 'toggle',
        name: 'radio-1',
        title: 'Title',
        value: 'example-1',
        isSelected: false,
        onChange: () => {}
      }));
      expect(asFragment()).toMatchSnapshot();
    });
    it('should render checked state UI correctly', () => {
      const {
        asFragment
      } = (0, _testingLibrary.render)(_react.default.createElement(_RadioCheckToggleCard.RadioCheckToggleCard, {
        cardType: 'toggle',
        name: 'radio-1',
        title: 'Title',
        value: 'example-1',
        isSelected: true,
        onChange: () => {}
      }));
      expect(asFragment()).toMatchSnapshot();
    });
  });
});