"use strict";

var _react = _interopRequireDefault(require("react"));
var _testingLibrary = require("../__test__/testing-library");
var _theme = require("../theme/theme");
var _createTheme = require("../utils/createTheme");
var _utils = require("../utils/utils");
var _Select = require("./Select");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
describe('Select', () => {
  it('renders', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Select.Select, null)).toJSON();
    expect(json).toMatchSnapshot();
  });
  it('renders disabled', () => {
    const paletteTheme = (0, _createTheme.createTheme)(_theme.theme);
    (0, _testingLibrary.render)(_react.default.createElement(_Select.Select, {
      "data-testId": 'disabled-select',
      defaultValue: 'Premium Economy',
      disabled: true
    }, _react.default.createElement("option", null, "Premium Economy")));
    const select = _testingLibrary.screen.getByTestId('disabled-select');
    expect(select).toBeDisabled();
    expect(select).toHaveStyleRule('background-color', (0, _utils.getPaletteColor)('background.light')({
      theme: paletteTheme
    }), {
      modifier: ':disabled'
    });
    expect(select).toHaveStyleRule('color', (0, _utils.getPaletteColor)('text.light')({
      theme: paletteTheme
    }), {
      modifier: ':disabled'
    });
    expect(select).toHaveStyleRule('cursor', 'not-allowed', {
      modifier: ':disabled'
    });
    expect(select).toHaveStyleRule('opacity', '1', {
      modifier: ':disabled'
    });
  });
  describe('variations', () => {
    describe('subtle variation', () => {
      it('should render correctly', () => {
        const paletteTheme = (0, _createTheme.createTheme)(_theme.theme);
        (0, _testingLibrary.render)(_react.default.createElement(_Select.Select, {
          "data-testId": 'select',
          defaultValue: 'Premium Economy',
          variation: 'subtle',
          size: 'lg'
        }, _react.default.createElement("option", null, "Premium Economy")));
        const select = _testingLibrary.screen.getByTestId('select');
        expect(select).toHaveStyleRule('background-color', (0, _utils.getPaletteColor)('background.base')({
          theme: paletteTheme
        }));
        expect(select).toHaveStyleRule('border-color', (0, _utils.getPaletteColor)('background.base')({
          theme: paletteTheme
        }));
        expect(select).toHaveStyleRule('color', (0, _utils.getPaletteColor)('primary.base')({
          theme: paletteTheme
        }));
        expect(select).toHaveStyleRule('font-weight', 'bold');
        expect(select).toHaveStyleRule('border-radius', '12px');
        expect(select).toHaveStyleRule('background-color', (0, _utils.getPaletteColor)('background.tint')({
          theme: paletteTheme
        }), {
          modifier: ':hover'
        });
        expect(select).toHaveStyleRule('border-color', (0, _utils.getPaletteColor)('background.tint')({
          theme: paletteTheme
        }), {
          modifier: ':hover'
        });
        expect(select).toHaveStyleRule('color', (0, _utils.getPaletteColor)('primary.dark')({
          theme: paletteTheme
        }), {
          modifier: ':hover'
        });
        expect(select).toHaveStyleRule('outline', `0px solid ${(0, _utils.getPaletteColor)('primary.dark')({
          theme: paletteTheme
        })}`, {
          modifier: ':focus-visible'
        });
        expect(select).toHaveStyleRule('box-shadow', `0 0 0 2px ${(0, _utils.getPaletteColor)('primary.dark')({
          theme: paletteTheme
        })}`, {
          modifier: ':focus-visible'
        });
      });
      it('should render with round border in small or medium sizes', () => {
        (0, _testingLibrary.render)(_react.default.createElement(_Select.Select, {
          "data-testId": 'select',
          defaultValue: 'Premium Economy',
          variation: 'subtle',
          size: 'md'
        }, _react.default.createElement("option", null, "Premium Economy")));
        const select = _testingLibrary.screen.getByTestId('select');
        expect(select).toHaveStyleRule('border-radius', '9999px');
      });
      it('should render correctly when disabled', () => {
        const paletteTheme = (0, _createTheme.createTheme)(_theme.theme);
        (0, _testingLibrary.render)(_react.default.createElement(_Select.Select, {
          "data-testId": 'disabled-select',
          defaultValue: 'Premium Economy',
          disabled: true,
          variation: 'subtle'
        }, _react.default.createElement("option", null, "Premium Economy")));
        const select = _testingLibrary.screen.getByTestId('disabled-select');
        expect(select).toBeDisabled();
        expect(select).toHaveStyleRule('background-color', (0, _utils.getPaletteColor)('background.light')({
          theme: paletteTheme
        }), {
          modifier: ':disabled'
        });
        expect(select).toHaveStyleRule('color', (0, _utils.getPaletteColor)('text.light')({
          theme: paletteTheme
        }), {
          modifier: ':disabled'
        });
        expect(select).toHaveStyleRule('cursor', 'not-allowed', {
          modifier: ':disabled'
        });
        expect(select).toHaveStyleRule('opacity', '1', {
          modifier: ':disabled'
        });
      });
    });
  });
});