"use strict";

var _react = _interopRequireDefault(require("react"));
var _Input = require("../Input/Input");
var _testingLibrary = require("../__test__/testing-library");
var _ShadowEffect = require("./ShadowEffect");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
describe.skip('ShadowEffect', () => {
  it('opens when clicked', () => {
    const mockOnOpen = jest.fn();
    const mockOnClick = jest.fn();
    (0, _testingLibrary.render)(_react.default.createElement(_ShadowEffect.ShadowEffect, {
      onOpen: mockOnOpen,
      "data-testid": 'overlay'
    }, _react.default.createElement(_Input.Input, {
      onClick: mockOnClick,
      id: 'input',
      "data-testid": 'input'
    })));
    expect(_testingLibrary.screen.queryByTestId('overlay')).not.toBeInTheDocument();
    expect(mockOnOpen).toHaveBeenCalledTimes(0);
    expect(mockOnClick).toHaveBeenCalledTimes(0);
    _testingLibrary.fireEvent.click(_testingLibrary.screen.getByTestId('input'));
    expect(mockOnOpen).toHaveBeenCalledTimes(1);
    expect(mockOnClick).toHaveBeenCalledTimes(1);
    expect(_testingLibrary.screen.queryByTestId('overlay')).toBeInTheDocument();
    expect(_testingLibrary.screen.queryByTestId('overlay')).toHaveStyleRule('z-index', '550');
    expect(_testingLibrary.screen.queryByTestId('input')).toHaveStyleRule('z-index', '600');
  });
  it('opens with custom z-index', () => {
    const mockOnOpen = jest.fn();
    const mockOnClick = jest.fn();
    (0, _testingLibrary.render)(_react.default.createElement(_ShadowEffect.ShadowEffect, {
      zIndex: 5,
      onOpen: mockOnOpen,
      "data-testid": 'overlay'
    }, _react.default.createElement(_Input.Input, {
      onClick: mockOnClick,
      id: 'input',
      "data-testid": 'input'
    })));
    expect(_testingLibrary.screen.queryByTestId('input')).toHaveStyleRule('z-index', undefined);
    _testingLibrary.fireEvent.click(_testingLibrary.screen.getByTestId('input'));
    expect(_testingLibrary.screen.queryByTestId('overlay')).toBeInTheDocument();
    expect(_testingLibrary.screen.queryByTestId('overlay')).toHaveStyleRule('z-index', '5');
    expect(_testingLibrary.screen.queryByTestId('input')).toHaveStyleRule('z-index', '5');
  });
  it('closes if overlay clicked', () => {
    const mockOnClose = jest.fn();
    (0, _testingLibrary.render)(_react.default.createElement(_ShadowEffect.ShadowEffect, {
      onClose: mockOnClose,
      "data-testid": 'overlay'
    }, _react.default.createElement(_Input.Input, {
      id: 'input',
      "data-testid": 'input'
    })));
    expect(_testingLibrary.screen.queryByTestId('overlay')).not.toBeInTheDocument();
    _testingLibrary.fireEvent.click(_testingLibrary.screen.getByTestId('input'));
    expect(_testingLibrary.screen.queryByTestId('overlay')).toBeInTheDocument();
    _testingLibrary.fireEvent.click(_testingLibrary.screen.getByTestId('overlay'));
    expect(_testingLibrary.screen.queryByTestId('overlay')).not.toBeInTheDocument();
  });
  it('opens when focused', () => {
    const mockOnOpen = jest.fn();
    const mockOnFocus = jest.fn();
    (0, _testingLibrary.render)(_react.default.createElement(_ShadowEffect.ShadowEffect, {
      shouldOpenOnFocus: true,
      onOpen: mockOnOpen,
      "data-testid": 'overlay'
    }, _react.default.createElement(_Input.Input, {
      id: 'input',
      onFocus: mockOnFocus,
      "data-testid": 'input'
    })));
    expect(mockOnOpen).toHaveBeenCalledTimes(0);
    expect(mockOnFocus).toHaveBeenCalledTimes(0);
    expect(_testingLibrary.screen.queryByTestId('overlay')).not.toBeInTheDocument();
    _testingLibrary.screen.getByTestId('input').focus();
    expect(mockOnOpen).toHaveBeenCalledTimes(1);
    expect(mockOnFocus).toHaveBeenCalledTimes(1);
    expect(_testingLibrary.screen.queryByTestId('overlay')).toBeInTheDocument();
  });
  it('does not open on focus if not set', () => {
    const mockOnOpen = jest.fn();
    const mockOnFocus = jest.fn();
    (0, _testingLibrary.render)(_react.default.createElement(_ShadowEffect.ShadowEffect, {
      onOpen: mockOnOpen,
      "data-testid": 'overlay'
    }, _react.default.createElement(_Input.Input, {
      onFocus: mockOnFocus,
      id: 'input',
      "data-testid": 'input'
    })));
    expect(mockOnOpen).toHaveBeenCalledTimes(0);
    expect(mockOnFocus).toHaveBeenCalledTimes(0);
    expect(_testingLibrary.screen.queryByTestId('overlay')).not.toBeInTheDocument();
    _testingLibrary.screen.getByTestId('input').focus();
    expect(mockOnOpen).toHaveBeenCalledTimes(0);
    expect(mockOnFocus).toHaveBeenCalledTimes(1);
    expect(_testingLibrary.screen.queryByTestId('overlay')).not.toBeInTheDocument();
  });
  it('closes when blurred', () => {
    const mockOnClose = jest.fn();
    const mockOnBlur = jest.fn();
    (0, _testingLibrary.render)(_react.default.createElement(_ShadowEffect.ShadowEffect, {
      shouldOpenOnFocus: true,
      shouldCloseOnBlur: true,
      onClose: mockOnClose,
      "data-testid": 'overlay'
    }, _react.default.createElement(_Input.Input, {
      id: 'input',
      onBlur: mockOnBlur,
      "data-testid": 'input'
    })));
    expect(_testingLibrary.screen.queryByTestId('overlay')).not.toBeInTheDocument();
    _testingLibrary.screen.getByTestId('input').focus();
    expect(_testingLibrary.screen.queryByTestId('overlay')).toBeInTheDocument();
    expect(mockOnClose).toHaveBeenCalledTimes(0);
    expect(mockOnBlur).toHaveBeenCalledTimes(0);
    _testingLibrary.screen.getByTestId('input').blur();
    expect(mockOnClose).toHaveBeenCalledTimes(1);
    expect(mockOnBlur).toHaveBeenCalledTimes(1);
    expect(_testingLibrary.screen.queryByTestId('overlay')).not.toBeInTheDocument();
  });
  it('does not close when blurred if not set', () => {
    const mockOnClose = jest.fn();
    const mockOnBlur = jest.fn();
    (0, _testingLibrary.render)(_react.default.createElement(_ShadowEffect.ShadowEffect, {
      shouldOpenOnFocus: true,
      onClose: mockOnClose,
      "data-testid": 'overlay'
    }, _react.default.createElement(_Input.Input, {
      id: 'input',
      onBlur: mockOnBlur,
      "data-testid": 'input'
    })));
    expect(_testingLibrary.screen.queryByTestId('overlay')).not.toBeInTheDocument();
    _testingLibrary.screen.getByTestId('input').focus();
    expect(_testingLibrary.screen.queryByTestId('overlay')).toBeInTheDocument();
    expect(mockOnClose).toHaveBeenCalledTimes(0);
    expect(mockOnBlur).toHaveBeenCalledTimes(0);
    _testingLibrary.screen.getByTestId('input').blur();
    expect(mockOnClose).toHaveBeenCalledTimes(0);
    expect(mockOnBlur).toHaveBeenCalledTimes(1);
    expect(_testingLibrary.screen.queryByTestId('overlay')).toBeInTheDocument();
  });
  it('closes when escape is pressed', () => {
    const mockOnKeyDown = jest.fn();
    (0, _testingLibrary.render)(_react.default.createElement(_ShadowEffect.ShadowEffect, {
      "data-testid": 'overlay'
    }, _react.default.createElement(_Input.Input, {
      id: 'input',
      onKeyDown: mockOnKeyDown,
      "data-testid": 'input'
    })));
    expect(_testingLibrary.screen.queryByTestId('overlay')).not.toBeInTheDocument();
    _testingLibrary.fireEvent.click(_testingLibrary.screen.getByTestId('input'));
    expect(_testingLibrary.screen.queryByTestId('overlay')).toBeInTheDocument();
    expect(mockOnKeyDown).toHaveBeenCalledTimes(0);
    _testingLibrary.fireEvent.keyDown(_testingLibrary.screen.getByTestId('input'), {
      key: 'Escape'
    });
    expect(mockOnKeyDown).toHaveBeenCalledTimes(1);
    expect(_testingLibrary.screen.queryByTestId('overlay')).not.toBeInTheDocument();
  });
  it('does not close for other key presses', () => {
    const mockOnKeyDown = jest.fn();
    (0, _testingLibrary.render)(_react.default.createElement(_ShadowEffect.ShadowEffect, {
      "data-testid": 'overlay'
    }, _react.default.createElement(_Input.Input, {
      id: 'input',
      onKeyDown: mockOnKeyDown,
      "data-testid": 'input'
    })));
    expect(_testingLibrary.screen.queryByTestId('overlay')).not.toBeInTheDocument();
    _testingLibrary.fireEvent.click(_testingLibrary.screen.getByTestId('input'));
    expect(_testingLibrary.screen.queryByTestId('overlay')).toBeInTheDocument();
    expect(mockOnKeyDown).toHaveBeenCalledTimes(0);
    _testingLibrary.fireEvent.keyDown(_testingLibrary.screen.getByTestId('input'), {
      key: 'Enter'
    });
    expect(mockOnKeyDown).toHaveBeenCalledTimes(1);
    expect(_testingLibrary.screen.queryByTestId('overlay')).toBeInTheDocument();
  });
  it('errors if provided multiple children', () => {
    expect(() => {
      (0, _testingLibrary.render)(_react.default.createElement(_ShadowEffect.ShadowEffect, null, _react.default.createElement(_Input.Input, {
        id: 'input'
      }), _react.default.createElement(_Input.Input, {
        id: 'input2'
      })));
    }).toThrow();
  });
});