"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SlideBox = SlideBox;
var _react = _interopRequireWildcard(require("react"));
var _BottomArrows = require("./BottomArrows");
var _Slide = require("./Slide");
var _SlideBox = require("./SlideBox.styled");
var _SlideBoxWrapper = require("./SlideBoxWrapper");
var _TopArrows = require("./TopArrows");
var _helpers = require("./helpers");
var _useSlideBoxNav = require("./useSlideBoxNav");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/**
 * @public
 */
function SlideBox({
  children,
  visibleSlides,
  onSlideChange,
  slideSpacing,
  stretchHeight,
  layout,
  currentSlideOverride,
  arrowSizeOverride,
  arrowButtonVariation = 'white',
  arrowPosition = 'hide',
  slideScrollNum = 2,
  mobileSlideScrollNum = 1,
  overflowAllowancePxX = 0,
  overflowAllowancePxY = 4,
  overflowAllowancePxTop
}) {
  const childArray = _react.default.Children.toArray(children);
  const ref = (0, _react.useRef)();
  const {
    setCurrentSlide,
    currentSlide,
    onSlideChangeWrapper,
    arrowProps
  } = (0, _useSlideBoxNav.useSlideBoxNav)({
    onSlideChange,
    currentSlideOverride,
    arrowSizeOverride,
    arrowButtonVariation,
    arrowPosition,
    childArray,
    slideScrollNum,
    mobileSlideScrollNum
  });
  (0, _react.useEffect)(() => {
    setCurrentSlide(currentSlideOverride);
  }, [currentSlideOverride]);
  return _react.default.createElement(_SlideBoxWrapper.SlideBoxWrapper, {
    arrowPosition: arrowPosition
  }, _react.default.createElement(_TopArrows.TopArrows, {
    arrowProps: arrowProps,
    arrowPosition: arrowPosition
  }), _react.default.createElement(_SlideBox.ScrollFlex, {
    "data-testid": 'slide-box',
    ref: ref,
    pt: `${overflowAllowancePxTop || overflowAllowancePxY}px`,
    mt: `-${overflowAllowancePxTop || overflowAllowancePxY}px`,
    pb: `${overflowAllowancePxY}px`,
    mb: `-${overflowAllowancePxY}px`,
    px: `${overflowAllowancePxX}px`,
    mx: `-${overflowAllowancePxX}px`
  }, childArray.map((item, index) => _react.default.createElement(_Slide.Slide, {
    key: item.props.key || `slide${index}`,
    width: layout ? (0, _helpers.getCustomWidths)(layout.split('-'), index) : (0, _helpers.getVisibleSlides)(visibleSlides),
    onSlideChange: onSlideChangeWrapper,
    slideSpacing: slideSpacing,
    stretchHeight: stretchHeight,
    index: index,
    content: item,
    isCurrentSlide: currentSlide === index,
    numSlides: childArray.length,
    slideBoxRef: ref,
    overflowAllowancePxX: overflowAllowancePxX
  }))), _react.default.createElement(_BottomArrows.BottomArrows, {
    arrowProps: arrowProps,
    arrowPosition: arrowPosition
  }));
}