"use strict";

var _react = _interopRequireDefault(require("react"));
var _testUtils = require("react-intersection-observer/test-utils");
var _Box = require("../Box/Box");
var _testingLibrary = require("../__test__/testing-library");
var _SlideBox = require("./SlideBox");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
describe('SlideBox', () => {
  it('renders with layout', () => {
    const {
      getByTestId
    } = (0, _testingLibrary.render)(_react.default.createElement(_SlideBox.SlideBox, {
      layout: '60-40',
      onSlideChange: () => {},
      slideSpacing: 2,
      stretchHeight: true,
      arrowPosition: 'side'
    }, _react.default.createElement(_Box.Box, null, "1"), _react.default.createElement(_Box.Box, null, "2"), _react.default.createElement(_Box.Box, null, "3")));
    (0, _testUtils.mockAllIsIntersecting)(true);
    expect(getByTestId('slide1')).toHaveStyle(`width: ${(100 / 1.1).toString()}%;`);
  });
  it('renders with array visible slides', () => {
    const {
      getByTestId
    } = (0, _testingLibrary.render)(_react.default.createElement(_SlideBox.SlideBox, {
      visibleSlides: [2, 3, 4],
      onSlideChange: () => {},
      slideSpacing: 2,
      currentSlideOverride: 2,
      arrowPosition: 'side',
      overflowAllowancePxX: 20,
      overflowAllowancePxY: 40
    }, _react.default.createElement(_Box.Box, {
      key: 'testkey'
    }, "1"), _react.default.createElement(_Box.Box, null, "2"), _react.default.createElement(_Box.Box, null, "3")));
    (0, _testUtils.mockAllIsIntersecting)(true);
    expect(getByTestId('slide1')).toHaveStyle(`width: 50%;`);
  });
  it('renders with int visible slides (small browser should default to 1.1 slides)', () => {
    const slideChange = jest.fn();
    const {
      getByTestId
    } = (0, _testingLibrary.render)(_react.default.createElement(_SlideBox.SlideBox, {
      visibleSlides: 1,
      onSlideChange: slideChange,
      slideSpacing: 2,
      arrowPosition: 'bottom',
      overflowAllowancePxTop: 10
    }, _react.default.createElement(_Box.Box, null, "1"), _react.default.createElement(_Box.Box, null, "2"), _react.default.createElement(_Box.Box, null, "3")));
    (0, _testUtils.mockIsIntersecting)(getByTestId('render-in-view-1'), true);
    expect(slideChange).toHaveBeenCalledTimes(1);
    expect(slideChange).toHaveBeenCalledWith(1);
    expect(getByTestId('slide1')).toHaveStyle(`width: ${(100 / 1.1).toString()}%;`);
  });
  it('renders with arrows on top', () => {
    const {
      getByTestId
    } = (0, _testingLibrary.render)(_react.default.createElement(_SlideBox.SlideBox, {
      visibleSlides: 1,
      arrowButtonVariation: 'fill',
      arrowPosition: 'top'
    }, _react.default.createElement(_Box.Box, null, "1"), _react.default.createElement(_Box.Box, null, "2"), _react.default.createElement(_Box.Box, null, "3")));
    getByTestId('top-arrows');
  });
  it('renders with no arrows default', () => {
    const {
      queryByTestId
    } = (0, _testingLibrary.render)(_react.default.createElement(_SlideBox.SlideBox, {
      visibleSlides: 1
    }, _react.default.createElement(_Box.Box, null, "1"), _react.default.createElement(_Box.Box, null, "2"), _react.default.createElement(_Box.Box, null, "3")));
    expect(queryByTestId('top-arrows')).not.toBeInTheDocument();
    expect(queryByTestId('bottom-arrows')).not.toBeInTheDocument();
    expect(queryByTestId('side-left-arrow')).not.toBeInTheDocument();
    expect(queryByTestId('side-right-arrow')).not.toBeInTheDocument();
  });
});