"use strict";

var _react = _interopRequireDefault(require("react"));
var _Button = require("../Button/Button");
var _testingLibrary = require("../__test__/testing-library");
var _useSlideBoxNav = require("./useSlideBoxNav");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const getChildArray = () => {
  const childarray = [];
  for (let i = 0; i < 10; i++) {
    childarray.push(_react.default.createElement("div", null, "d", i));
  }
  return childarray;
};
const props = {
  onSlideChange: jest.fn(),
  currentSlideOverride: 0,
  arrowSizeOverride: 'lg',
  arrowButtonVariation: 'white',
  arrowPosition: 'side',
  childArray: getChildArray(),
  slideScrollNum: 1,
  mobileSlideScrollNum: 1
};
const Test = testProps => {
  const {
    setCurrentSlide,
    currentSlide,
    onSlideChangeWrapper,
    arrowProps,
    slideInView
  } = (0, _useSlideBoxNav.useSlideBoxNav)(testProps);
  const {
    leftDisabled,
    rightDisabled,
    arrowButtonVariation,
    arrowPosition,
    size,
    leftArrowClick,
    rightArrowClick
  } = arrowProps;
  const slideChange = () => {
    onSlideChangeWrapper(6, 3);
  };
  const slideChangeOutsideBounds = () => {
    onSlideChangeWrapper(-5, 3);
  };
  const slideChangeOutsideBoundsUpper = () => {
    onSlideChangeWrapper(99, 3);
  };
  return _react.default.createElement("div", null, _react.default.createElement("div", {
    "data-testid": 'leftdisabled'
  }, leftDisabled ? 'true' : 'false'), _react.default.createElement("div", {
    "data-testid": 'rightdisabled'
  }, rightDisabled ? 'true' : 'false'), _react.default.createElement("div", {
    "data-testid": 'arrowButtonVariation'
  }, arrowButtonVariation), _react.default.createElement("div", {
    "data-testid": 'arrowPosition'
  }, arrowPosition), _react.default.createElement("div", {
    "data-testid": 'arrowSize'
  }, size), _react.default.createElement("div", {
    "data-testid": 'currentslide'
  }, "slide ", currentSlide), _react.default.createElement("div", {
    "data-testid": 'slideInView'
  }, "slide ", slideInView), _react.default.createElement(_Button.Button, {
    onClick: setCurrentSlide
  }, "Set Current Slide"), _react.default.createElement(_Button.Button, {
    onClick: leftArrowClick
  }, "Left Arrow Click"), _react.default.createElement(_Button.Button, {
    onClick: rightArrowClick
  }, "Right Arrow Click"), _react.default.createElement(_Button.Button, {
    onClick: slideChange
  }, "Slide Change Wrapper"), _react.default.createElement(_Button.Button, {
    onClick: slideChangeOutsideBounds
  }, "Slide Change Outside Bounds"), _react.default.createElement(_Button.Button, {
    onClick: slideChangeOutsideBoundsUpper
  }, "Slide Change Outside Bounds Upper"));
};
describe('useSlideBoxNav', () => {
  it('Basic functionality', () => {
    const {
      getByTestId,
      getByText
    } = (0, _testingLibrary.render)(_react.default.createElement(Test, {
      ...props
    }));
    expect(getByTestId('leftdisabled').innerHTML).toEqual('true');
    expect(getByTestId('rightdisabled').innerHTML).toEqual('false');
    expect(getByTestId('arrowButtonVariation').innerHTML).toEqual('white');
    expect(getByTestId('arrowPosition').innerHTML).toEqual('side');
    expect(getByTestId('arrowSize').innerHTML).toEqual('lg');
    expect(getByTestId('currentslide').innerHTML).toEqual('slide 0');
    //Right arrow click
    _testingLibrary.fireEvent.click(getByText('Right Arrow Click'));
    expect(getByTestId('currentslide').innerHTML).toEqual('slide 1');
    //Left arrow click
    _testingLibrary.fireEvent.click(getByText('Left Arrow Click'));
    expect(getByTestId('currentslide').innerHTML).toEqual('slide 0');
    //Slide Change (used in useEffect)
    _testingLibrary.fireEvent.click(getByText('Slide Change Wrapper'));
    expect(getByTestId('slideInView').innerHTML).toEqual('slide 6');
    //Slide Change outside bounds
    _testingLibrary.fireEvent.click(getByText('Slide Change Outside Bounds'));
    expect(getByTestId('slideInView').innerHTML).toEqual('slide 2');
    //Slide Change outside bounds (lower)
    _testingLibrary.fireEvent.click(getByText('Slide Change Outside Bounds'));
    expect(getByTestId('slideInView').innerHTML).toEqual('slide 2');
    //Slide Change outside bounds (upper)
    _testingLibrary.fireEvent.click(getByText('Slide Change Outside Bounds Upper'));
    expect(getByTestId('slideInView').innerHTML).toEqual('slide 9');
  });
});
describe('useSlideBoxNav', () => {
  beforeAll(() => {
    // @ts-ignore
    global.window.innerWidth = 800;
  });
  it('Edge cases', () => {
    const {
      getByText,
      getByTestId
    } = (0, _testingLibrary.render)(_react.default.createElement(Test, {
      ...props,
      onSlideChange: undefined,
      arrowSizeOverride: undefined
    }));
    //Slide Change (used in useEffect)
    _testingLibrary.fireEvent.click(getByText('Slide Change Wrapper'));
    expect(getByTestId('slideInView').innerHTML).toEqual('slide 6');
    //Right arrow click
    _testingLibrary.fireEvent.click(getByText('Right Arrow Click'));
    expect(getByTestId('currentslide').innerHTML).toEqual('slide 7');
    //Default arrow size to lg
    expect(getByTestId('arrowSize').innerHTML).toEqual('lg');
  });
  it('Uncovered prop cases', () => {
    const {
      getByTestId
    } = (0, _testingLibrary.render)(_react.default.createElement(Test, {
      ...props,
      arrowPosition: 'top',
      arrowSizeOverride: undefined
    }));
    //Default arrow size to sm when arrowPosition top
    expect(getByTestId('arrowSize').innerHTML).toEqual('sm');
  });
});