"use strict";

var _react = _interopRequireDefault(require("react"));
var _Stamp = require("../Stamp/Stamp");
var _theme = require("../theme/theme");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
describe('Stamp', () => {
  let consoleError;
  beforeEach(() => {
    consoleError = console.error;
    console.error = jest.fn();
  });
  afterEach(() => console.error = consoleError);
  test('renders', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Stamp.Stamp, null)).toJSON();
    expect(json).toMatchSnapshot();
  });
  test('renders small size', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Stamp.Stamp, {
      size: 'small'
    })).toJSON();
    expect(json).toMatchSnapshot();
  });
  test('renders medium fill', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Stamp.Stamp, {
      variation: 'fill'
    })).toJSON();
    expect(json).toMatchSnapshot();
  });
  test('renders small fill', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Stamp.Stamp, {
      size: 'small',
      variation: 'fill'
    })).toJSON();
    expect(json).toMatchSnapshot();
  });
  test('color gray sets text and icon color', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Stamp.Stamp, {
      color: 'gray'
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('color', _theme.theme.colors.gray);
  });
  test('color blue sets text and icon color', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Stamp.Stamp, {
      color: 'blue'
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('color', _theme.theme.colors.blue);
  });
  test('color green sets text and icon color', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Stamp.Stamp, {
      color: 'green'
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('color', _theme.theme.colors.green);
  });
  test('color red sets text and icon color', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Stamp.Stamp, {
      color: 'red'
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('color', _theme.theme.colors.red);
  });
  test('color orange sets text and icon color', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Stamp.Stamp, {
      color: 'orange'
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('color', _theme.theme.colors.orange);
  });
  test('color purple sets text and icon color', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Stamp.Stamp, {
      color: 'purple'
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('color', _theme.theme.colors.purple);
  });
  test('bg blue sets background color', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Stamp.Stamp, {
      bg: 'blue'
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('background-color', _theme.theme.colors.blue);
  });
  test('borderColor green sets border color', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Stamp.Stamp, {
      borderColor: 'green'
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('border-color', _theme.theme.colors.green);
  });
  test('has default borderGray border color', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Stamp.Stamp, null)).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('border-color', _theme.theme.colors.borderGray);
  });
});