"use strict";

var _react = _interopRequireDefault(require("react"));
var _testingLibrary = require("../__test__/testing-library");
var _Step = require("./Step");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
describe('Step', () => {
  it('should render correctly with no props without throwing', () => {
    expect(() => {
      const {
        asFragment
      } = (0, _testingLibrary.render)(_react.default.createElement(_Step.Step, null, "Step"));
      expect(asFragment()).toMatchSnapshot();
    }).not.toThrow();
  });
  it('should render an active step correctly', () => {
    const {
      asFragment,
      container,
      getByTestId
    } = (0, _testingLibrary.render)(_react.default.createElement(_Step.Step, {
      active: true,
      "data-testid": 'Step'
    }, "Step"));
    expect(asFragment()).toMatchSnapshot();
    expect(getByTestId('Step')).toHaveStyleRule('cursor', 'default');
    expect(container.querySelector('svg')).not.toBeInTheDocument();
  });
  it('should render a completed step correctly', () => {
    const {
      asFragment,
      container,
      getByTestId
    } = (0, _testingLibrary.render)(_react.default.createElement(_Step.Step, {
      completed: true,
      "data-testid": 'Step'
    }, "Step"));
    expect(asFragment()).toMatchSnapshot();
    expect(getByTestId('Step')).toHaveStyleRule('cursor', 'default');
    expect(container.querySelector('svg')).toBeInTheDocument();
  });
  it('should render a step that is "active" and "completed" correctly', () => {
    const {
      asFragment,
      container,
      getByTestId
    } = (0, _testingLibrary.render)(_react.default.createElement(_Step.Step, {
      active: true,
      completed: true,
      "data-testid": 'Step'
    }, "Step"));
    expect(asFragment()).toMatchSnapshot();
    expect(getByTestId('Step')).toHaveStyleRule('cursor', 'default');
    expect(container.querySelector('svg')).toBeInTheDocument();
  });
  it('should handle onClick', () => {
    const handleClick = jest.fn();
    const {
      asFragment,
      getByTestId,
      getByText
    } = (0, _testingLibrary.render)(_react.default.createElement(_Step.Step, {
      active: true,
      "data-testid": 'Step',
      onClick: handleClick
    }, "Step"));
    expect(asFragment()).toMatchSnapshot();
    expect(getByTestId('Step')).toHaveStyleRule('cursor', 'pointer');
    _testingLibrary.fireEvent.click(getByText('Step'));
    expect(handleClick).toHaveBeenCalled();
  });
});