"use strict";

var _react = _interopRequireDefault(require("react"));
var _testingLibrary = require("../__test__/testing-library");
var _Swatch = require("./Swatch");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const mockColors = ['red', 'green', 'blue'];
describe('Swatch', () => {
  it('should render correctly', () => {
    const {
      getByTestId
    } = (0, _testingLibrary.render)(_react.default.createElement(_Swatch.Swatch, {
      colors: mockColors
    }));
    mockColors.map((color, idx) => {
      expect(getByTestId(`${idx}-${color}`)).toHaveStyle(`background-color: ${color}`);
      expect(getByTestId(`${idx}-${color}`)).toHaveStyle(`border: 1px solid #c0cad5}`);
    });
  });
  it('should call onClick callback with selected color value', () => {
    const mockOnClick = jest.fn();
    const {
      getByTestId
    } = (0, _testingLibrary.render)(_react.default.createElement(_Swatch.Swatch, {
      colors: mockColors,
      onClick: mockOnClick
    }));
    mockColors.map((color, idx) => {
      expect(getByTestId(`${idx}-${color}`)).toHaveStyle('cursor: pointer');
      _testingLibrary.fireEvent.click(getByTestId(`${idx}-${color}`));
      expect(mockOnClick).toHaveBeenLastCalledWith(color);
    });
  });
  it('does not crash when onClick callback is not provided', () => {
    const mockOnClick = jest.fn();
    const {
      getByTestId
    } = (0, _testingLibrary.render)(_react.default.createElement(_Swatch.Swatch, {
      colors: mockColors
    }));
    mockColors.map((color, idx) => {
      expect(getByTestId(`${idx}-${color}`)).toHaveStyle('cursor: default');
      _testingLibrary.fireEvent.click(getByTestId(`${idx}-${color}`));
      expect(mockOnClick).toHaveBeenCalledTimes(0);
    });
  });
});