"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Tab = void 0;
var Tabs = _interopRequireWildcard(require("@radix-ui/react-tabs"));
var _react = _interopRequireDefault(require("react"));
var _Box = require("../Box/Box");
var _Grid = require("../Grid/Grid");
var _Tab = require("./Tab.styled");
var _TabButton = require("./TabButton");
var _TabChip = require("./TabChip");
var _TabRadio = require("./TabRadio");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const Tab = ({
  tabsData,
  orientation = 'horizontal',
  size = 'md',
  type = 'button',
  border = false,
  tabGap,
  isTransparent = false,
  dynamicTabWidth = false,
  ariaLabel = 'Tabs',
  defaultValue = tabsData[0].id,
  buttonChipProps
}) => {
  const [isActive, setIsActive] = _react.default.useState(`${defaultValue}`);
  function onTabSelect(tab) {
    setIsActive(tab.id);
    tab.onTabSelect();
  }
  const renderTab = tab => {
    switch (type) {
      case 'chip':
        return _react.default.createElement(_TabChip.TabChip, {
          isActive: isActive,
          onTabSelect: () => {
            onTabSelect(tab);
          },
          dynamicTabWidth: dynamicTabWidth,
          tab: tab,
          size: size,
          buttonChipProps: buttonChipProps
        });
      case 'button':
        return _react.default.createElement(_TabButton.TabButton, {
          onTabSelect: () => {
            onTabSelect(tab);
          },
          dynamicTabWidth: dynamicTabWidth,
          isTransparent: isTransparent,
          border: border,
          tab: tab,
          size: size
        });
      case 'radio':
        return _react.default.createElement(_TabRadio.TabRadio, {
          onTabSelect: () => {
            onTabSelect(tab);
          },
          tab: tab,
          isActive: isActive
        });
    }
  };
  const gridProps = dynamicTabWidth => {
    switch (dynamicTabWidth) {
      case true:
        return {
          autoFlow: 'column',
          columnGap: tabGap
        };
      case false:
        return {
          autoFlow: 'column',
          autoColumns: 'max-content',
          columnGap: tabGap
        };
    }
  };
  if (orientation === 'vertical') {
    return _react.default.createElement(Tabs.Root, {
      defaultValue: `tab-${defaultValue}`
    }, _react.default.createElement(_Tab.TabList, {
      orientation: 'vertical',
      "aria-label": ariaLabel
    }, _react.default.createElement(_Grid.Grid, {
      gap: tabGap
    }, tabsData.map((tab, index) => _react.default.createElement(_react.default.Fragment, null, renderTab(tab))))), _react.default.createElement(_Box.Box, null, tabsData.map(tab => {
      return _react.default.createElement(Tabs.Content, {
        key: `tab-${tab.id}`,
        value: `tab-${tab.id}`
      }, tab.children);
    })));
  }
  return _react.default.createElement(Tabs.Root, {
    defaultValue: `tab-${defaultValue}`
  }, _react.default.createElement(_Tab.TabList, {
    orientation: orientation,
    "aria-label": ariaLabel
  }, _react.default.createElement(_Grid.Grid, {
    ...gridProps(dynamicTabWidth)
  }, tabsData.map(tab => {
    return renderTab(tab);
  }))), _react.default.createElement(_Box.Box, null, tabsData.map(tab => {
    return _react.default.createElement(Tabs.Content, {
      key: `tab-${tab.id}`,
      value: `tab-${tab.id}`
    }, tab.children);
  })));
};
exports.Tab = Tab;
Tab.displayName = 'Tab';