"use strict";

var _react = _interopRequireDefault(require("react"));
var _testingLibrary = require("../__test__/testing-library");
var _testingLibrary2 = require("@storybook/testing-library");
var _Tab = require("./Tab");
var _pclnIcons = require("pcln-icons");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
describe('Tab', () => {
  const tabsData = [{
    id: 'tab1',
    text: 'Tab 1',
    children: _react.default.createElement("div", null, "Tab 1 Content"),
    onTabSelect: () => {}
  }, {
    id: 'tab2',
    text: 'Tab 2',
    children: _react.default.createElement("div", null, "Tab 2 Content"),
    onTabSelect: () => {}
  }];
  const tabsDataWithIcon = [{
    id: 'tab1',
    text: 'Tab 1',
    icon: _pclnIcons.Departure,
    children: _react.default.createElement("div", null, "Tab 1 Content"),
    onTabSelect: () => {}
  }, {
    id: 'tab2',
    text: 'Tab 2',
    children: _react.default.createElement("div", null, "Tab 2 Content"),
    onTabSelect: () => {}
  }];
  it('renders tabs with correct text', () => {
    (0, _testingLibrary.render)(_react.default.createElement(_Tab.Tab, {
      type: 'button',
      tabsData: tabsData
    }));
    expect(_testingLibrary.screen.getByRole('tab', {
      name: 'Tab 1'
    })).toBeInTheDocument();
    expect(_testingLibrary.screen.getByRole('tab', {
      name: 'Tab 2'
    })).toBeInTheDocument();
  });
  it('renders tab content based on active tab', async () => {
    (0, _testingLibrary.render)(_react.default.createElement(_Tab.Tab, {
      type: 'button',
      tabsData: tabsData
    }));
    expect(_testingLibrary.screen.getByRole('tab', {
      name: 'Tab 1'
    })).toBeInTheDocument();
    expect(_testingLibrary.screen.getByText('Tab 1 Content')).toBeInTheDocument();
    expect(_testingLibrary.screen.queryByText('Tab 2 Content')).not.toBeInTheDocument();
    await _testingLibrary2.userEvent.click(_testingLibrary.screen.getByText('Tab 2'));
    expect(_testingLibrary.screen.getByRole('tab', {
      name: 'Tab 2'
    })).toBeInTheDocument();
    expect(_testingLibrary.screen.queryByText('Tab 1 Content')).not.toBeInTheDocument();
    expect(_testingLibrary.screen.getByText('Tab 2 Content')).toBeInTheDocument();
  });
  it('renders tab content based on active tab with icon', async () => {
    (0, _testingLibrary.render)(_react.default.createElement(_Tab.Tab, {
      type: 'button',
      tabsData: tabsDataWithIcon
    }));
    expect(_testingLibrary.screen.getByRole('tab', {
      name: 'Tab 1'
    })).toBeInTheDocument();
    expect(_testingLibrary.screen.getByText('Tab 1 Content')).toBeInTheDocument();
    expect(_testingLibrary.screen.queryByText('Tab 2 Content')).not.toBeInTheDocument();
    await _testingLibrary2.userEvent.click(_testingLibrary.screen.getByText('Tab 2'));
    expect(_testingLibrary.screen.getByRole('tab', {
      name: 'Tab 2'
    })).toBeInTheDocument();
    expect(_testingLibrary.screen.queryByText('Tab 1 Content')).not.toBeInTheDocument();
    expect(_testingLibrary.screen.getByText('Tab 2 Content')).toBeInTheDocument();
  });
  it('renders tab content based on active tab in Chip Variation', async () => {
    (0, _testingLibrary.render)(_react.default.createElement(_Tab.Tab, {
      type: 'chip',
      tabsData: tabsData
    }));
    expect(_testingLibrary.screen.getByRole('radio', {
      name: 'Tab 1'
    })).toBeInTheDocument();
    expect(_testingLibrary.screen.getByText('Tab 1 Content')).toBeInTheDocument();
    expect(_testingLibrary.screen.queryByText('Tab 2 Content')).not.toBeInTheDocument();
    await _testingLibrary2.userEvent.click(_testingLibrary.screen.getByText('Tab 2'));
    expect(_testingLibrary.screen.getByRole('radio', {
      name: 'Tab 2'
    })).toBeInTheDocument();
    expect(_testingLibrary.screen.queryByText('Tab 1 Content')).not.toBeInTheDocument();
    expect(_testingLibrary.screen.getByText('Tab 2 Content')).toBeInTheDocument();
  });
  it('renders tab content based on active tab in Radio Variation', async () => {
    (0, _testingLibrary.render)(_react.default.createElement(_Tab.Tab, {
      type: 'radio',
      tabsData: tabsData
    }));
    expect(_testingLibrary.screen.getByRole('tab', {
      name: 'Tab 1'
    })).toBeInTheDocument();
    expect(_testingLibrary.screen.getByText('Tab 1 Content')).toBeInTheDocument();
    expect(_testingLibrary.screen.queryByText('Tab 2 Content')).not.toBeInTheDocument();
    await _testingLibrary2.userEvent.click(_testingLibrary.screen.getByText('Tab 2'));
    expect(_testingLibrary.screen.queryByText('Tab 1 Content')).not.toBeInTheDocument();
    expect(_testingLibrary.screen.getByText('Tab 2 Content')).toBeInTheDocument();
  });
  it('renders tab content based on orientation', async () => {
    (0, _testingLibrary.render)(_react.default.createElement(_Tab.Tab, {
      type: 'button',
      orientation: 'vertical',
      tabsData: tabsData
    }));
    expect(_testingLibrary.screen.getByRole('tab', {
      name: 'Tab 1'
    })).toBeInTheDocument();
    await _testingLibrary2.userEvent.click(_testingLibrary.screen.getByText('Tab 1'));
    expect(_testingLibrary.screen.getByText('Tab 1 Content')).toBeInTheDocument();
    expect(_testingLibrary.screen.queryByText('Tab 2 Content')).not.toBeInTheDocument();
    await _testingLibrary2.userEvent.click(_testingLibrary.screen.getByText('Tab 2'));
    expect(_testingLibrary.screen.queryByText('Tab 1 Content')).not.toBeInTheDocument();
    expect(_testingLibrary.screen.getByText('Tab 2 Content')).toBeInTheDocument();
  });
});