"use strict";

var _react = _interopRequireDefault(require("react"));
var _testingLibrary = require("../__test__/testing-library");
var _theme = require("../theme/theme");
var _Text = require("./Text");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
describe('Text', () => {
  test('renders', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Text.Text, null)).toJSON();
    expect(json).toMatchSnapshot();
  });
  test('textAlign prop sets text-align', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Text.Text, {
      textAlign: 'center'
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('text-align', 'center');
  });
  test('regular prop sets font-weight', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Text.Text, {
      regular: true
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('font-weight', _theme.theme.regular.toString());
  });
  test('bold prop sets font-weight', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Text.Text, {
      bold: true
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('font-weight', _theme.theme.bold.toString());
  });
  test('caps prop sets text-transform', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Text.Text, {
      caps: true
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('text-transform', 'uppercase');
  });
  test('fontSize prop sets font-size', () => {
    const f0 = rendererCreateWithTheme(_react.default.createElement(_Text.Text, {
      fontSize: 0
    })).toJSON();
    const f1 = rendererCreateWithTheme(_react.default.createElement(_Text.Text, {
      fontSize: 1
    })).toJSON();
    const f2 = rendererCreateWithTheme(_react.default.createElement(_Text.Text, {
      fontSize: 2
    })).toJSON();
    const f3 = rendererCreateWithTheme(_react.default.createElement(_Text.Text, {
      fontSize: 3
    })).toJSON();
    const f4 = rendererCreateWithTheme(_react.default.createElement(_Text.Text, {
      fontSize: 4
    })).toJSON();
    const f5 = rendererCreateWithTheme(_react.default.createElement(_Text.Text, {
      fontSize: 5
    })).toJSON();
    const f6 = rendererCreateWithTheme(_react.default.createElement(_Text.Text, {
      fontSize: 6
    })).toJSON();
    expect(f0).toHaveStyleRule('font-size', _theme.theme.fontSizes[0] + 'px');
    expect(f1).toHaveStyleRule('font-size', _theme.theme.fontSizes[1] + 'px');
    expect(f2).toHaveStyleRule('font-size', _theme.theme.fontSizes[2] + 'px');
    expect(f3).toHaveStyleRule('font-size', _theme.theme.fontSizes[3] + 'px');
    expect(f4).toHaveStyleRule('font-size', _theme.theme.fontSizes[4] + 'px');
    expect(f5).toHaveStyleRule('font-size', _theme.theme.fontSizes[5] + 'px');
    expect(f6).toHaveStyleRule('font-size', _theme.theme.fontSizes[6] + 'px');
  });
  test('mt prop sets margin-top', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Text.Text, {
      mt: 2
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('margin-top', _theme.theme.space[2]);
  });
  test('display and overflow', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Text.Text, {
      display: 'inline-block',
      overflow: 'none'
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('display', 'inline-block');
    expect(json).toHaveStyleRule('overflow', 'none');
  });
  test('height and width', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Text.Text, {
      height: 150,
      width: 200
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('height', '150px');
    expect(json).toHaveStyleRule('width', '200px');
  });
  test('min/max values', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_Text.Text, {
      minHeight: 200,
      maxHeight: 400,
      minWidth: 200,
      maxWidth: 400
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('min-height', '200px');
    expect(json).toHaveStyleRule('max-height', '400px');
    expect(json).toHaveStyleRule('min-width', '200px');
    expect(json).toHaveStyleRule('max-width', '400px');
  });
  test('fontStyle', () => {
    (0, _testingLibrary.render)(_react.default.createElement(_Text.Text, {
      fontStyle: 'italic'
    }, "Italic Text"));
    expect(_testingLibrary.screen.getByText('Italic Text')).toHaveStyleRule('font-style', 'italic');
  });
  test('textDecoration', () => {
    (0, _testingLibrary.render)(_react.default.createElement(_Text.Text, {
      textDecoration: 'underline'
    }, "Underlined Text"));
    expect(_testingLibrary.screen.getByText('Underlined Text')).toHaveStyleRule('text-decoration', 'underline');
  });
  test('textTransform', () => {
    (0, _testingLibrary.render)(_react.default.createElement(_Text.Text, {
      textTransform: 'lowercase'
    }, "Lowercase Text"));
    expect(_testingLibrary.screen.getByText('Lowercase Text')).toHaveStyleRule('text-transform', 'lowercase');
  });
});