"use strict";

var _pclnIcons = require("pcln-icons");
var _react = _interopRequireDefault(require("react"));
var _testingLibrary = require("../__test__/testing-library");
var _Toast = require("./Toast");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
jest.useFakeTimers();
describe('Toast', () => {
  it('renders a success toast that closes after 2 seconds', () => {
    const mockRemoveClick = jest.fn();
    (0, _testingLibrary.render)(_react.default.createElement(_Toast.Toast, {
      id: 10,
      lifespan: 2000,
      color: 'success',
      onRemoveClick: mockRemoveClick
    }, "Success Message"));
    expect(_testingLibrary.screen.getByText('Success Message')).toBeInTheDocument();
    expect(mockRemoveClick).toHaveBeenCalledTimes(0);
    jest.runAllTimers();
    expect(mockRemoveClick).toHaveBeenCalledTimes(1);
    expect(mockRemoveClick).toHaveBeenCalledWith(10);
  });
  it('renders an error toast that needs to be closed manually', () => {
    const mockRemoveClick = jest.fn();
    (0, _testingLibrary.render)(_react.default.createElement(_Toast.Toast, {
      id: 10,
      color: 'error',
      onRemoveClick: mockRemoveClick
    }, "Error Message"));
    expect(_testingLibrary.screen.getByText('Error Message')).toBeInTheDocument();
    expect(mockRemoveClick).toHaveBeenCalledTimes(0);
    jest.runAllTimers();
    expect(mockRemoveClick).toHaveBeenCalledTimes(0);
    _testingLibrary.fireEvent.click(_testingLibrary.screen.getByRole('button'));
    expect(mockRemoveClick).toHaveBeenCalledTimes(1);
    expect(mockRemoveClick).toHaveBeenCalledWith(10);
  });
  it('renders a default toast', () => {
    const mockRemoveClick = jest.fn();
    (0, _testingLibrary.render)(_react.default.createElement(_Toast.Toast, {
      id: 10,
      lifespan: 2000,
      onRemoveClick: mockRemoveClick
    }, "Information Message"));
    expect(_testingLibrary.screen.getByText('Information Message')).toBeInTheDocument();
  });
  it('renders a success border toast', () => {
    (0, _testingLibrary.render)(_react.default.createElement(_Toast.Toast, {
      id: 10,
      color: 'success',
      icon: _react.default.createElement(_pclnIcons.Success, {
        "data-testid": 'success-icon'
      }),
      variation: 'border'
    }, "Success Border Message"));
    const toast = _testingLibrary.screen.getByText('Success Border Message');
    expect(toast).toBeInTheDocument();
    expect(toast.parentNode.parentNode).toHaveStyleRule('background-color', '#ecf7ec');
    expect(toast.parentNode.parentNode).toHaveStyleRule('color', '#001833');
    expect(toast.parentNode.parentNode).toHaveStyleRule('border-left', '4px solid #0a0');
    const icon = _testingLibrary.screen.getByTestId('success-icon');
    expect(icon).toBeInTheDocument();
    expect(icon).toHaveStyleRule('color', '#0a0');
  });
});