"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useToast = exports.ToastProvider = exports.ToastContext = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactDom = require("react-dom");
var _styledComponents = _interopRequireWildcard(require("styled-components"));
var _Absolute = require("../Absolute/Absolute");
var _Animate = require("../Animate/Animate");
var _Flex = require("../Flex/Flex");
var _ThemeProvider = require("../ThemeProvider/ThemeProvider");
var _Toast = require("../Toast/Toast");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const ClickthroughAbsolute = /*#__PURE__*/(0, _styledComponents.default)(_Absolute.Absolute).withConfig({
  displayName: "ToastProvider__ClickthroughAbsolute",
  componentId: "sc-5saebu-0"
})(["pointer-events:none;"]);
/* istanbul ignore next */
const ToastContext = exports.ToastContext = (0, _react.createContext)({
  addToast: () => {},
  removeToast: () => {}
});
/**
 * @public
 */
const useToast = () => {
  return (0, _react.useContext)(ToastContext);
};
exports.useToast = useToast;
let id = 0;
function _ToastProvider({
  children,
  domRootId = 'root',
  enterAnimation = 'slideInLeft',
  exitAnimation = 'slideOutLeft',
  lifespan,
  maxToasts = 3,
  theme,
  bottom = 20,
  top
}) {
  const [toasts, setToasts] = (0, _react.useState)([]);
  const addToast = (0, _react.useCallback)(options => {
    setToasts(prevToasts => [...prevToasts, {
      ...options,
      id: id++
    }]);
  }, []);
  const removeToast = (0, _react.useCallback)(id => {
    setToasts(prevToasts => prevToasts.map(toast => toast.id === id ? {
      ...toast,
      removed: true
    } : toast));
  }, []);
  (0, _react.useEffect)(() => {
    toasts.forEach(toast => {
      if (toast.removed) {
        setTimeout(() => {
          setToasts(prevToasts => prevToasts.filter(t => t.id !== toast.id));
        }, 200);
      }
    });
  }, [toasts, setToasts]);
  const toastsToRender = toasts.slice(0, maxToasts);
  return _react.default.createElement(ToastContext.Provider, {
    value: {
      addToast,
      removeToast
    }
  }, children, (0, _reactDom.createPortal)(_react.default.createElement(_ThemeProvider.ThemeProvider, {
    theme: theme
  }, _react.default.createElement(ClickthroughAbsolute, {
    top: top ? top : undefined,
    bottom: top ? undefined : bottom,
    width: '100%'
  }, _react.default.createElement(_Flex.Flex, {
    justifyContent: 'center',
    width: '100%'
  }, _react.default.createElement(_Flex.Flex, {
    flexDirection: 'column-reverse',
    justifyContent: 'center',
    minWidth: '300px'
  }, toastsToRender.map(toast => {
    const enterAnim = toast.enterAnimation || enterAnimation;
    const exitAnim = toast.exitAnimation || exitAnimation;
    return _react.default.createElement(_Animate.Animate, {
      key: toast.id,
      variant: toast.removed ? exitAnim : enterAnim
    }, _react.default.createElement(_Toast.Toast, {
      lifespan: lifespan,
      onRemoveClick: removeToast,
      ...toast,
      mt: 3
    }));
  }))))), document.getElementById(domRootId)));
}
/**
 * @public
 */
const ToastProvider = exports.ToastProvider = /*#__PURE__*/(0, _styledComponents.withTheme)(_ToastProvider);