"use strict";

var _react = _interopRequireDefault(require("react"));
var _testingLibrary = require("../__test__/testing-library");
var _theme = require("../theme/theme");
var _createTheme = require("../utils/createTheme");
var _Toggle = require("./Toggle");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const theme = (0, _createTheme.createTheme)();
describe('Toggle', () => {
  test('renders correctly when off', () => {
    const {
      getByRole
    } = (0, _testingLibrary.render)(_react.default.createElement(_Toggle.Toggle, {
      label: 'Total price toggle'
    }));
    const container = getByRole('switch').parentNode;
    expect(container).toHaveStyleRule('background-color', theme.palette.background.dark);
  });
  test('renders correctly when on', () => {
    const {
      getByRole
    } = (0, _testingLibrary.render)(_react.default.createElement(_Toggle.Toggle, {
      isOn: true,
      label: 'Total price toggle'
    }));
    const container = getByRole('switch').parentNode;
    expect(container).toHaveStyleRule('background-color', theme.palette.primary.base);
  });
  test('renders correctly when disabled', () => {
    const {
      getByRole
    } = (0, _testingLibrary.render)(_react.default.createElement(_Toggle.Toggle, {
      label: 'Total price toggle',
      disabled: true
    }));
    const container = getByRole('switch').parentNode;
    expect(container).toHaveStyleRule('background-color', theme.palette.background.light);
  });
  test('calls callback', () => {
    const cb = jest.fn();
    const {
      getByLabelText
    } = (0, _testingLibrary.render)(_react.default.createElement(_Toggle.Toggle, {
      label: 'Total price toggle',
      onToggle: cb
    }));
    const input = getByLabelText('Total price toggle');
    _testingLibrary.fireEvent.click(input);
    expect(cb).toHaveBeenCalled();
  });
  test('add boxshadow and bgColor when hover over the selected states', () => {
    const {
      getByTestId,
      getByRole
    } = (0, _testingLibrary.render)(_react.default.createElement(_Toggle.Toggle, {
      label: 'Total price toggle',
      isOn: true
    }));
    const wrapper = getByRole('switch').parentNode;
    const circleHandle = getByTestId('handle-div');
    expect(wrapper).toHaveStyleRule('background-color', theme.palette.primary.base);
    expect(circleHandle).toHaveStyleRule('box-shadow', _theme.theme.shadows.sm);
    // when it is hover
    expect(wrapper).toHaveStyleRule('background-color', theme.palette.primary.dark, {
      modifier: ':hover:not([disabled])'
    });
    expect(wrapper).toHaveStyleRule('box-shadow', _theme.theme.shadows.xl, {
      modifier: ':hover:not([disabled]) > #circle-handle'
    });
  });
});