"use strict";

var _react = _interopRequireDefault(require("react"));
var _ToggleBadge = require("../ToggleBadge/ToggleBadge");
var _createTheme = require("../utils/createTheme");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
describe('ToggleBadge', () => {
  let consoleError;
  let theme;
  beforeEach(() => {
    consoleError = console.error;
    console.error = jest.fn();
    theme = (0, _createTheme.createTheme)();
  });
  afterEach(() => console.error = consoleError);
  test('selected ToggleBadge renders with default props', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_ToggleBadge.ToggleBadge, {
      selected: true
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('background-color', theme.colors.lightBlue);
    expect(json).toHaveStyleRule('color', theme.colors.blue);
  });
  test('unselected ToggleBadge renders with default props', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_ToggleBadge.ToggleBadge, null)).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('color', theme.colors.blue);
  });
  test('selected one with background-color and text color passed as props hover state', () => {
    const json = rendererCreateWithTheme(_react.default.createElement(_ToggleBadge.ToggleBadge, {
      selected: true,
      bg: 'secondary',
      color: 'error',
      fontSize: 1
    })).toJSON();
    expect(json).toMatchSnapshot();
    expect(json).toHaveStyleRule('background-color', theme.palette.secondary.light);
    expect(json).toHaveStyleRule('color', theme.palette.error.base);
  });
});