"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.Palette = exports.Colors = exports.ColorScheme = void 0;
var _pclnIcons = require("pcln-icons");
var _react = _interopRequireDefault(require("react"));
var _styledComponents = require("styled-components");
var _Box = require("../Box/Box");
var _Card = require("../Card/Card");
var _Flex = require("../Flex/Flex");
var _Text = require("../Text/Text");
var _createTheme = require("../utils/createTheme");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const theme = (0, _createTheme.createTheme)();
const blacklist = ['darkPurple'];
const keys = Object.keys(theme.colors).filter(key => !blacklist.includes(key));
const next = keys.map(key => ({
  key,
  value: theme.colors[key]
}));
const colorSchemeFamilies = ['Primary', 'Secondary', 'Neutral', 'Success', 'Warning', 'Caution', 'Highlight', 'Promo', 'Alert', 'Heading'];
const ColorCard = props => _react.default.createElement(_Flex.Flex, {
  flexDirection: 'column',
  width: '100%'
}, _react.default.createElement(_Card.Card, {
  borderRadius: 'xl',
  bg: props.color || props.shade,
  height: '100px'
}), _react.default.createElement(_Text.Text, {
  f: 0
}, props.shade), _react.default.createElement(_Text.Text, {
  as: 'pre',
  m: 0
}, props.hex));
const ColorSchemeColumnCard = ({
  title
}) => {
  return _react.default.createElement(_Card.Card, {
    height: '100px',
    width: '108px',
    borderRadius: 'xl'
  }, _react.default.createElement(_Flex.Flex, {
    flexDirection: 'column',
    alignItems: 'center',
    justifyContent: 'center',
    height: '100%'
  }, _react.default.createElement(_Text.Text, {
    mb: 2,
    fontSize: '14px'
  }, title), _react.default.createElement(_pclnIcons.ArrowDown, {
    size: '16px'
  })));
};
const BackgroundForegroundCard = () => {
  return _react.default.createElement(_Flex.Flex, {
    width: '100%',
    justifyContent: 'space-around',
    my: 2
  }, _react.default.createElement(ColorSchemeColumnCard, {
    title: 'Background'
  }), _react.default.createElement(ColorSchemeColumnCard, {
    title: 'Foreground'
  }));
};
var _default = exports.default = {
  title: 'Design / Color'
};
const Palette = () => _react.default.createElement(_styledComponents.ThemeConsumer, null, theme => {
  return _react.default.createElement("div", null, _react.default.createElement(_Box.Box, {
    p: 3
  }, _react.default.createElement("h1", null, "Palette"), _react.default.createElement("p", null, "The palette allows you to change the color of components."), _react.default.createElement(_Flex.Flex, {
    flexWrap: 'wrap'
  }, Object.keys(theme.palette).map(color => {
    const shades = theme.palette[color];
    if (typeof shades === 'object') {
      return _react.default.createElement("div", {
        style: {
          width: '100%'
        }
      }, _react.default.createElement("h4", null, color), _react.default.createElement(_Flex.Flex, {
        flexWrap: 'wrap'
      }, Object.keys(shades).map(shade => {
        const fullColor = `${color}.${shade}`;
        return _react.default.createElement(_Box.Box, {
          key: fullColor,
          p: 3,
          width: [1, 1 / 2, 1 / 3, 1 / 4, 1 / 7]
        }, _react.default.createElement(ColorCard, {
          name: fullColor,
          color: fullColor,
          shade: shade,
          hex: shades[shade]
        }));
      })), _react.default.createElement("hr", null));
    } else {
      const fullColor = `${color}.${shades}`;
      return _react.default.createElement(_Box.Box, {
        key: fullColor,
        p: 3,
        width: [1, 1 / 2, 1 / 3, 1 / 4, 1 / 5]
      }, _react.default.createElement(ColorCard, {
        name: fullColor,
        color: fullColor
      }));
    }
  }))));
});
exports.Palette = Palette;
const Colors = () => _react.default.createElement("div", null, _react.default.createElement(_Box.Box, {
  p: 3
}, _react.default.createElement("h1", null, "Colors")), _react.default.createElement(_Flex.Flex, {
  flexWrap: 'wrap'
}, next.map(color => _react.default.createElement(_Box.Box, {
  key: color.key,
  p: 3,
  width: [1, 1 / 2, 1 / 3, 1 / 4, 1 / 5]
}, _react.default.createElement(ColorCard, {
  name: color.key,
  shade: color.key,
  hex: color.value
})))));
exports.Colors = Colors;
const ColorScheme = () => _react.default.createElement(_styledComponents.ThemeConsumer, null, theme => {
  return _react.default.createElement("div", null, _react.default.createElement(_Box.Box, {
    p: 3
  }, _react.default.createElement("h1", null, "Color Scheme"), _react.default.createElement(_Flex.Flex, {
    flexWrap: 'wrap'
  }, colorSchemeFamilies.map(colorSchemeFamily => {
    return _react.default.createElement(_Card.Card, {
      borderRadius: 'xl',
      m: 2,
      p: 3,
      key: colorSchemeFamily
    }, _react.default.createElement(_Flex.Flex, {
      flexDirection: 'column'
    }, _react.default.createElement(_Text.Text, {
      textStyle: 'heading3'
    }, colorSchemeFamily), _react.default.createElement(BackgroundForegroundCard, null), Object.entries(theme.colorSchemes).filter(entry => entry[0].includes(colorSchemeFamily.toLowerCase())).map(entry => {
      const [key, colorScheme] = entry;
      return _react.default.createElement(_Flex.Flex, {
        flexDirection: 'column',
        py: 3,
        key: key
      }, _react.default.createElement(_Text.Text, {
        fontWeight: 'bold',
        mb: 2
      }, key), _react.default.createElement(_Flex.Flex, null, _react.default.createElement(_Box.Box, {
        px: 3,
        width: '140px'
      }, _react.default.createElement(ColorCard, {
        color: colorScheme.background
      })), _react.default.createElement(_Box.Box, {
        px: 3,
        width: '140px'
      }, _react.default.createElement(ColorCard, {
        color: colorScheme.foreground
      }))));
    })));
  }))));
});
exports.ColorScheme = ColorScheme;