"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createTheme = void 0;
var _deepmerge = _interopRequireDefault(require("deepmerge"));
var _theme = require("../theme/theme");
var _createColorScheme = require("./createColorScheme");
var _createColorStyles = require("./createColorStyles");
var _createMediaQueries = require("./createMediaQueries");
var _createPalette = require("./createPalette");
var _createTextStyles = require("./createTextStyles");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
/**
 * Adds aliases to an array of keys
 *
 * @param arr - The array to add aliases to
 *
 * @public
 */
const addAliases = arr => {
  arr.forEach((val, key) => {
    arr[['sm', 'md', 'lg', 'xl', 'xxl'][key]] = val;
  });
  return arr;
};
/**
 * Create the theme
 * @param theme -             The theme to merge against the default
 * @param customBreakpoints - Custom breakpoints for the theme
 * @param existingTheme -     Existing theme passed from a parent provider (Undefined if it's most outer provider)
 *
 * @returns The generated theme
 *
 * @public
 */
const createTheme = (theme = {}, customBreakpoints = null, existingTheme = _theme.theme) => {
  const finalMergedTheme = (0, _deepmerge.default)(existingTheme, theme);
  const mediaQueries = customBreakpoints ? (0, _createMediaQueries.createMediaQueries)(customBreakpoints) : finalMergedTheme.mediaQueries;
  const palette = (0, _createPalette.createPalette)(finalMergedTheme);
  return {
    ...finalMergedTheme,
    contrastRatio: finalMergedTheme.contrastRatio || 2.6,
    breakpoints: addAliases(customBreakpoints || finalMergedTheme.breakpoints),
    mediaQueries: addAliases(mediaQueries),
    palette,
    colorSchemes: (0, _createColorScheme.createColorScheme)({
      palette
    }),
    colorStyles: (0, _createColorStyles.createColorStyles)(finalMergedTheme),
    textStyles: (0, _createTextStyles.createTextStyles)(finalMergedTheme)
  };
};
exports.createTheme = createTheme;