import { expect } from '@storybook/jest';
import { userEvent, within } from '@storybook/testing-library';
import React, { useState } from 'react';
import { Button } from '../Button/Button';
import { Flex } from '../Flex/Flex';
import { Text } from '../Text/Text';
import { theme } from '../theme/theme';
import { Accordion } from './Accordion';
export default {
  title: 'Accordion',
  component: Accordion,
  argTypes: {
    onToggle: {
      action: true
    },
    p: {
      options: theme.space,
      control: {
        type: 'select'
      },
      description: 'Padding for the content and header sections'
    }
  }
};
const items = [{
  headerLabel: React.createElement(React.Fragment, null, React.createElement(Text, null, "Header Label First Item")),
  content: React.createElement(React.Fragment, null, React.createElement(Text, null, "I am some content"), React.createElement(Text, null, "I am some content"), React.createElement(Text, null, "I am some content")),
  value: 'item-1'
}, {
  headerLabel: React.createElement(React.Fragment, null, React.createElement(Text, null, "Second Header")),
  headerActions: React.createElement(Button, {
    onClick: () => console.log('test')
  }, "Test Button"),
  content: React.createElement(React.Fragment, null, React.createElement(Text, null, "I am secondary content"), React.createElement(Text, null, "I am secondary content"), React.createElement(Text, null, "I am secondary content")),
  value: 'item-2'
}, {
  content: React.createElement(React.Fragment, null, React.createElement(Text, null, "No Header Label on Third Item"), React.createElement(Text, null, "Tertiary text"), React.createElement(Text, null, "Tertiary text"), React.createElement(Text, null, "Tertiary text")),
  value: 'item-3'
}];
export const Basic = {
  play: async ({
    args,
    canvasElement
  }) => {
    const canvas = within(canvasElement);
    const headerLabel = canvas.getByText('Header Label First Item');
    await expect(args.onToggle).not.toHaveBeenCalled();
    await expect(canvas.queryAllByText('I am some content')).toHaveLength(3);
    await userEvent.click(headerLabel);
    setTimeout(async () => {
      await expect(canvas.queryAllByText('I am some content')).toHaveLength(0);
      await expect(args.onToggle).toHaveBeenCalled();
    }, 350);
  },
  render: args => React.createElement(Accordion, {
    ...args,
    items: items
  })
};
export const Underlined = {
  render: args => React.createElement(Accordion, {
    ...args,
    items: items,
    variation: 'underline'
  })
};
export const Hug = {
  render: args => React.createElement(Accordion, {
    ...args,
    items: items,
    variation: 'hug'
  })
};
export const Ladder = {
  render: args => React.createElement(Accordion, {
    ...args,
    headerDividerColor: 'border.base',
    items: [{
      ...items[0],
      headerBg: 'success.light'
    }, {
      ...items[1]
    }],
    variation: 'ladder'
  })
};
export const Card = {
  render: args => React.createElement(Accordion, {
    ...args,
    items: items,
    variation: 'card'
  })
};
export const ItemStatePropCard = {
  render: args => React.createElement(Accordion, {
    ...args,
    items: items,
    variation: 'card',
    itemsState: ['item-1', 'item-2']
  })
};
export const FlatCard = {
  render: args => React.createElement(Accordion, {
    ...args,
    items: items,
    variation: 'flatCard'
  })
};
export const Singular = {
  render: args => React.createElement(Accordion, {
    ...args,
    items: items,
    type: 'single'
  })
};
export const ChevronClose = {
  render: args => React.createElement(Accordion, {
    ...args,
    isAnimatedChevron: true,
    items: items
  })
};
export const TrackStateMultiple = {
  render: args => {
    const [itemsState, setItemsState] = useState(['item-1', 'item-3']);
    return React.createElement(React.Fragment, null, React.createElement(Text, null, "Items Open: ", itemsState.join(', ')), React.createElement(Button, {
      onClick: () => {
        setItemsState([]);
      }
    }, "Collapse all items"), React.createElement(Accordion, {
      ...args,
      items: items,
      itemsState: itemsState,
      isExternallyControlled: true,
      onToggle: newItemsState => {
        setItemsState(newItemsState);
        console.log('previousState:', itemsState, 'newState:', newItemsState);
      }
    }));
  }
};
export const TrackStateSingular = {
  play: async ({
    canvasElement
  }) => {
    const canvas = within(canvasElement);
    const headerLabel = canvas.getByText('Header Label First Item');
    await expect(canvas.queryAllByText('I am some content')).toHaveLength(0);
    await expect(canvas.queryAllByText('I am secondary content')).toHaveLength(3);
    await expect(canvas.queryByText('Item Open: item-1')).toBeFalsy();
    await expect(canvas.queryByText('Item Open: item-2')).toBeTruthy();
    await userEvent.click(headerLabel);
    setTimeout(async () => {
      await expect(canvas.queryAllByText('I am some content')).toHaveLength(3);
      await expect(canvas.queryAllByText('I am secondary content')).toHaveLength(0);
      await expect(canvas.queryByText('Item Open: item-1')).toBeTruthy();
      await expect(canvas.queryByText('Item Open: item-2')).toBeFalsy();
    }, 350);
  },
  render: args => {
    const [itemsState, setItemsState] = useState('item-2');
    return React.createElement(React.Fragment, null, React.createElement(Text, null, "Item Open: ", itemsState), React.createElement(Accordion, {
      ...args,
      items: items,
      itemsState: itemsState,
      onToggle: newItemsState => {
        setItemsState(newItemsState);
        console.log('previousState:', itemsState, 'newState:', newItemsState);
      },
      type: 'single'
    }));
  }
};
const itemWithFunc = {
  headerLabel: React.createElement(Flex, {
    justifyContent: 'left',
    alignItems: 'center'
  }, React.createElement(Text, {
    mr: 3
  }, "Header Label First Item"), React.createElement(Button, {
    onClick: e => {
      e.stopPropagation();
      alert('testClick');
    }
  }, "TestButton")),
  content: React.createElement(Text, null, "Single content"),
  value: 'item-4'
};
export const HeaderWithFunction = {
  render: args => React.createElement(Accordion, {
    ...args,
    items: [...items, itemWithFunc],
    type: 'single'
  })
};