import { Overnight } from 'pcln-icons';
import React from 'react';
import { Flex } from '../Flex/Flex';
import { Text } from '../Text/Text';
import { ChatMessage, ChatMessageVariations } from './ChatMessage';
export default {
  title: 'Chat / ChatMessage',
  component: ChatMessage,
  args: {
    message: "Hi! I'm Penny, your virtual travel assistant!",
    variation: 'initial'
  },
  argTypes: {
    variation: {
      options: ChatMessageVariations,
      control: {
        type: 'select',
        options: ChatMessageVariations
      }
    }
  }
};
const HeaderFooter = React.createElement(Flex, {
  alignItems: 'center',
  justifyContent: 'space-between'
}, React.createElement(Text, {
  color: 'text.light',
  textStyle: 'subheading6'
}, "Penny"), React.createElement(Text, {
  color: 'text.light',
  textStyle: 'subheading6'
}, "12:55 pm"));
export const _ChatMessage = {
  render: args => React.createElement(ChatMessage, {
    ...args
  })
};
export const InitialMessage = {
  render: args => React.createElement(ChatMessage, {
    ...args,
    variation: 'initial'
  })
};
export const WithReactNodeMessage = {
  render: args => React.createElement(ChatMessage, {
    ...args,
    variation: 'initial',
    message: React.createElement("div", null, "How can I help you?")
  })
};
export const IncomingMessage = {
  render: args => React.createElement(ChatMessage, {
    ...args,
    variation: 'incoming'
  })
};
export const OutgoingMessage = {
  render: args => React.createElement(ChatMessage, {
    ...args,
    variation: 'outgoing'
  })
};
export const WithIconOverride = {
  render: args => React.createElement(ChatMessage, {
    ...args,
    Icon: props => React.createElement(Overnight, {
      ...props,
      title: 'overnight'
    }),
    variation: 'initial'
  })
};
export const WithHeader = {
  render: args => React.createElement(ChatMessage, {
    ...args,
    header: HeaderFooter,
    variation: 'incoming'
  })
};
export const WithFooter = {
  render: args => React.createElement(ChatMessage, {
    ...args,
    footer: HeaderFooter,
    variation: 'incoming'
  })
};
export const OutgoingWithFooter = {
  render: args => React.createElement(ChatMessage, {
    ...args,
    ml: '60px',
    variation: 'outgoing',
    message: 'hello!!',
    footer: React.createElement(Flex, {
      alignItems: 'center',
      justifyContent: 'flex-end'
    }, React.createElement(Text, {
      color: 'text.light',
      textStyle: 'subheading6',
      mr: 2
    }, "READ"), React.createElement(Text, {
      color: 'text.light',
      textStyle: 'subheading6'
    }, "12:55 pm"))
  })
};
export const MessageList = {
  render: args => React.createElement(React.Fragment, null, React.createElement(ChatMessage, {
    ...args,
    variation: 'initial',
    mb: 3
  }), React.createElement(ChatMessage, {
    ...args,
    variation: 'outgoing',
    mb: 1
  }), React.createElement(ChatMessage, {
    ...args,
    variation: 'outgoing'
  }), React.createElement(ChatMessage, {
    ...args,
    variation: 'incoming',
    mt: 3
  }), React.createElement(ChatMessage, {
    ...args,
    variation: 'incoming',
    my: 1
  }), React.createElement(ChatMessage, {
    ...args,
    variation: 'incoming'
  }), React.createElement(ChatMessage, {
    ...args,
    variation: 'outgoing',
    mt: 3,
    mb: 1
  }), React.createElement(ChatMessage, {
    ...args,
    variation: 'outgoing'
  }))
};