import { action } from '@storybook/addon-actions';
import React, { useState } from 'react';
import styled from 'styled-components';
import { Box } from '../Box/Box';
import { Button } from '../Button/Button';
import { Heading } from '../Heading/Heading';
import { Label } from '../Label/Label';
import { Text } from '../Text/Text';
import ForwardRefDemo from '../storybook/utils/ForwardRefsDemo';
import { Checkbox } from './Checkbox';
const StyledLabel = /*#__PURE__*/styled(Label).withConfig({
  displayName: "Checkboxstories__StyledLabel",
  componentId: "sc-1kfzbwz-0"
})(["cursor:pointer;font-size:12px;vertical-align:middle;"]);
const Wrapper = props => React.createElement(Box, {
  p: '12px',
  my: '6px'
}, props.title ? React.createElement(Heading.h6, {
  mb: '12px'
}, props.title) : null, props.children);
const formAction = e => {
  e.preventDefault();
  action('form was submitted, is checkbox checked?')(e.target[1].id, e.target[1].checked);
};
const checkAction = e => {
  action(`${e.target.id} was clicked`)(e.target.value, e.target.checked);
};
export default {
  title: 'Checkbox',
  component: Checkbox
};
function onSubmit(e) {
  return formAction(e);
}
const FilterExample = () => {
  const [filterState, setFilterState] = useState({
    all: false,
    indeterminate: false,
    small: false,
    medium: false,
    large: false
  });
  const handleFilterSelection = event => {
    const target = event.target;
    // @ts-ignore
    if (target?.id === 'all') {
      if (filterState.all || filterState.indeterminate) {
        setFilterState({
          all: false,
          indeterminate: false,
          small: false,
          medium: false,
          large: false
        });
      } else {
        setFilterState({
          all: true,
          indeterminate: false,
          small: true,
          medium: true,
          large: true
        });
      }
    } else {
      // @ts-ignore
      const newFilterState = {
        ...filterState,
        [target.id]: !filterState[target.id]
      };
      const indeterminate = !(newFilterState.small === newFilterState.medium && newFilterState.small === newFilterState.large);
      const all = newFilterState.small && newFilterState.medium && newFilterState.large;
      setFilterState({
        ...filterState,
        // @ts-ignore
        [target.id]: !filterState[target.id],
        indeterminate,
        all
      });
    }
  };
  return React.createElement(React.Fragment, null, React.createElement(Wrapper, null, React.createElement(StyledLabel, {
    htmlFor: 'all'
  }, React.createElement(Checkbox, {
    id: 'all',
    onChange: handleFilterSelection,
    indeterminate: filterState.indeterminate,
    checked: filterState.all
  }), "Cars"), React.createElement(Box, {
    ml: 2
  }, React.createElement(StyledLabel, {
    htmlFor: 'small'
  }, React.createElement(Checkbox, {
    id: 'small',
    onChange: handleFilterSelection,
    checked: filterState.small
  }), "Small"), React.createElement(StyledLabel, {
    htmlFor: 'medium'
  }, React.createElement(Checkbox, {
    id: 'medium',
    onChange: handleFilterSelection,
    checked: filterState.medium
  }), "Medium"), React.createElement(StyledLabel, {
    htmlFor: 'large'
  }, React.createElement(Checkbox, {
    id: 'large',
    onChange: handleFilterSelection,
    checked: filterState.large
  }), "Large"))));
};
export const CheckboxStates = () => {
  return React.createElement("div", null, React.createElement(Wrapper, null, React.createElement(StyledLabel, {
    htmlFor: 'unchecked_box'
  }, React.createElement(Checkbox, {
    id: 'unchecked_box',
    onChange: checkAction,
    unselectedColor: 'text.light'
  }), "Unchecked by default")), React.createElement(Wrapper, null, React.createElement(StyledLabel, {
    htmlFor: 'checked_box'
  }, React.createElement(Checkbox, {
    id: 'checked_box',
    defaultChecked: true,
    onChange: checkAction
  }), "Checked by default")), React.createElement(Wrapper, null, React.createElement(StyledLabel, {
    htmlFor: 'disabled_box'
  }, React.createElement(Checkbox, {
    id: 'disabled_box',
    disabled: true,
    onChange: checkAction
  }), React.createElement(Text.span, {
    color: 'border.base'
  }, "Disabled"))), React.createElement(Wrapper, null, React.createElement(StyledLabel, {
    htmlFor: 'disabled_checked_box'
  }, React.createElement(Checkbox, {
    id: 'disabled_checked_box',
    disabled: true,
    defaultChecked: true,
    onChange: checkAction
  }), React.createElement(Text.span, {
    color: 'border.base'
  }, "Disabled & Checked"))), React.createElement(Wrapper, null, React.createElement(StyledLabel, {
    htmlFor: 'indeterminate_box'
  }, React.createElement(Checkbox, {
    id: 'indeterminate_box',
    indeterminate: true,
    onChange: checkAction
  }), "Initially indeterminate check box (clicking will checkmark it)")), React.createElement(Wrapper, null, React.createElement(StyledLabel, {
    htmlFor: 'indeterminate_checked_box'
  }, React.createElement(Checkbox, {
    id: 'indeterminate_checked_box',
    defaultChecked: true,
    indeterminate: true,
    onChange: checkAction
  }), "Initially indeterminate check box (clicking will uncheck it)")), React.createElement(Wrapper, {
    title: 'Indeterminate Checkboxes'
  }, React.createElement(FilterExample, null)), React.createElement(Wrapper, {
    title: 'In A Form'
  }, React.createElement("form", {
    onSubmit: onSubmit
  }, React.createElement("fieldset", {
    style: {
      display: 'inline-block',
      padding: '16px'
    }
  }, React.createElement("legend", null, "Fancy Form"), React.createElement(Wrapper, null, React.createElement(StyledLabel, {
    fontSize: '14px',
    htmlFor: 'form_checkbox'
  }, React.createElement(Checkbox, {
    id: 'form_checkbox',
    size: 30,
    onChange: checkAction
  }), "\u00A0In This Form")), React.createElement(Button, {
    type: 'submit'
  }, "Submit Me"), React.createElement("br", null), React.createElement("br", null), React.createElement(Button, {
    variation: 'outline',
    color: 'border.base',
    type: 'reset'
  }, "Reset Me")))));
};
export const Color = () => React.createElement("div", null, React.createElement(Wrapper, null, React.createElement(StyledLabel, {
  htmlFor: 'secondary_unchecked_box'
}, React.createElement(Checkbox, {
  id: 'secondary_unchecked_box',
  onChange: checkAction,
  color: 'secondary'
}), "Secondary color unchecked by default"), React.createElement(StyledLabel, {
  htmlFor: 'secondary_checked_box'
}, React.createElement(Checkbox, {
  id: 'secondary_checked_box',
  defaultChecked: true,
  onChange: checkAction,
  color: 'secondary'
}), "Secondary color checked by default"), React.createElement(StyledLabel, {
  htmlFor: 'secondary_indeterminate_box'
}, React.createElement(Checkbox, {
  id: 'secondary_indeterminate_box',
  indeterminate: true,
  onChange: checkAction,
  color: 'secondary'
}), "Secondary color indeterminate"), React.createElement(StyledLabel, {
  htmlFor: 'secondary_disabled_box'
}, React.createElement(Checkbox, {
  id: 'secondary_disabled_box',
  disabled: true,
  onChange: checkAction,
  color: 'secondary'
}), "Secondary color disabled")), React.createElement(Wrapper, null, React.createElement(StyledLabel, {
  htmlFor: 'error_unchecked_box'
}, React.createElement(Checkbox, {
  id: 'error_unchecked_box',
  onChange: checkAction,
  color: 'error'
}), "Error color unchecked by default"), React.createElement(StyledLabel, {
  htmlFor: 'error_checked_box'
}, React.createElement(Checkbox, {
  id: 'error_checked_box',
  defaultChecked: true,
  onChange: checkAction,
  color: 'error'
}), "Error color checked by default"), React.createElement(StyledLabel, {
  htmlFor: 'error_indeterminate_box'
}, React.createElement(Checkbox, {
  id: 'error_indeterminate_box',
  indeterminate: true,
  onChange: checkAction,
  color: 'error'
}), "Error color indeterminate"), React.createElement(StyledLabel, {
  htmlFor: 'error_disabled_box'
}, React.createElement(Checkbox, {
  id: 'error_disabled_box',
  disabled: true,
  onChange: checkAction,
  color: 'error'
}), "Error color disabled")));
export function ForwardRefs() {
  function refChild(dsRef) {
    function onClick() {
      return dsRef.current.focus();
    }
    return React.createElement(React.Fragment, null, React.createElement(StyledLabel, {
      htmlFor: 'check'
    }, React.createElement(Checkbox, {
      id: 'check',
      ref: dsRef
    }), "Checkbox with ref"), React.createElement(Button, {
      onClick: onClick,
      mt: 4
    }, "Click to focus checkbox via ref"));
  }
  return React.createElement(ForwardRefDemo, {
    refChild: refChild
  });
}