import { render, screen, waitFor } from '@testing-library/react';
import React from 'react';
import { Dialog } from './Dialog';
const triggerText = 'Open Dialog';
const contentText = 'Dialog Content';
describe('Dialog', () => {
  it('renders the trigger node', () => {
    render(React.createElement(Dialog, {
      triggerNode: React.createElement("button", null, triggerText),
      ariaDescription: 'Description',
      ariaTitle: 'Title'
    }, contentText));
    const triggerNode = screen.getByText(triggerText);
    expect(triggerNode).toBeInTheDocument();
  });
  it('renders the dialog content when trigger is clicked', async () => {
    render(React.createElement(Dialog, {
      triggerNode: React.createElement("button", null, triggerText),
      ariaDescription: 'Description',
      ariaTitle: 'Title'
    }, contentText));
    const triggerNode = screen.getByText(triggerText);
    triggerNode.click();
    await new Promise(resolve => setTimeout(resolve, 1000));
    const contentNode = screen.getByText(contentText);
    expect(contentNode).toBeInTheDocument();
  });
  it('renders the dialog with footer content', async () => {
    render(React.createElement(Dialog, {
      triggerNode: React.createElement("button", null, triggerText),
      ariaDescription: 'Description',
      ariaTitle: 'Title',
      footerContent: React.createElement("div", null, "Footer Content")
    }, contentText));
    const triggerNode = screen.getByText(triggerText);
    triggerNode.click();
    await waitFor(() => {
      expect(screen.getByText('Footer Content')).toBeInTheDocument();
    });
  });
  it.skip('calls onOpenChange when trigger is clicked', () => {
    const onOpenChange = jest.fn();
    render(React.createElement(Dialog, {
      triggerNode: React.createElement("button", null, triggerText),
      ariaDescription: 'Description',
      ariaTitle: 'Title',
      onOpenChange: onOpenChange
    }, contentText));
    const triggerNode = screen.getByText(triggerText);
    triggerNode.click();
    expect(onOpenChange).toHaveBeenCalledWith(true);
  });
  it.skip('handles controlled state when open', () => {
    render(React.createElement(Dialog, {
      triggerNode: React.createElement("button", null, triggerText),
      ariaDescription: 'Description',
      ariaTitle: 'Title',
      open: false
    }, contentText));
    const triggerNode = screen.getByText(triggerText);
    triggerNode.click();
    const contentNode = screen.queryByText(contentText);
    expect(contentNode).not.toBeVisible();
  });
});