import React from 'react';
import { Box } from '../Box/Box';
import { Flex } from '../Flex/Flex';
import { Text } from '../Text/Text';
import { DrawerRoot, DrawerWrapper, HeaderButton } from './Drawer.styled';
import { ChevronDown, Close } from 'pcln-icons';
import { AnimatePresence, motion } from 'framer-motion';
import { useScrollWithShadow } from '../useScrollWithShadows/useScrollWithShadow';
import { MotionVariants } from '../Animate/Animate';
const enterAnimation = {
  top: {
    ...MotionVariants.slideInTop
  },
  bottom: {
    ...MotionVariants.slideInBottom
  },
  right: {
    ...MotionVariants.slideInRight
  },
  left: {
    ...MotionVariants.slideInLeft
  }
};
const dragToDismissAnimation = onDragEnd => {
  return {
    drag: 'y',
    dragConstraints: {
      top: 0,
      bottom: 0
    },
    dragElastic: {
      top: 0,
      bottom: 0.3
    },
    transition: {
      duration: 0.8,
      ease: [0.04, 0.62, 0.23, 0.98]
    },
    onDragEnd: (event, info) => {
      if (info.offset.y > 200) {
        onDragEnd();
      }
    }
  };
};
export const Drawer = ({
  children,
  heading,
  isCollapsed = false,
  isFloating = true,
  isMobile = false,
  isOpen = false,
  onClose,
  onCollapse,
  placement = 'right',
  ...props
}) => {
  const {
    boxShadow,
    onScrollHandler
  } = useScrollWithShadow();
  return React.createElement(AnimatePresence, null, isOpen && React.createElement(DrawerWrapper, {
    placement: isMobile ? 'bottom' : placement,
    padding: isFloating ? '16px' : 0,
    maxHeight: isMobile ? ['290px', '400px', '480px', 'calc(100vh - 64px)'] : props.height ?? '100%',
    maxWidth: isMobile ? '100%' : ['400px', '600px', '800px', '100%'],
    width: isMobile ? '100%' : props.width,
    height: !isCollapsed && props.height ? props.height : 'fit-content'
  }, React.createElement(DrawerRoot, {
    "data-testid": 'drawer',
    isCollapsed: isCollapsed,
    isFloating: isFloating,
    key: 'drawer',
    placement: isMobile ? 'bottom' : placement,
    ...enterAnimation[isMobile ? 'bottom' : placement],
    ...dragToDismissAnimation(onCollapse),
    height: '100%',
    width: '100%',
    overflow: 'hidden'
  }, React.createElement(Flex, {
    flexDirection: 'column'
  }, (heading || onClose || onCollapse) && React.createElement(Flex, {
    flexDirection: 'column'
  }, React.createElement(Flex, {
    flexDirection: 'row',
    p: 3
  }, typeof heading === 'string' ? React.createElement(Text, {
    width: '100%',
    textStyle: 'heading4'
  }, heading) : heading, onClose || onCollapse ? React.createElement(Flex, {
    flexDirection: 'row',
    ml: 'auto',
    style: {
      columnGap: '8px'
    }
  }, onCollapse && React.createElement(motion.div, {
    animate: {
      rotate: isCollapsed ? 180 : 0,
      transition: {
        duration: 0.25
      }
    }
  }, React.createElement(HeaderButton, {
    "data-testid": 'drawerCollapse',
    onClick: onCollapse,
    icon: React.createElement(ChevronDown, {
      title: 'Dismiss'
    })
  })), onClose && React.createElement(HeaderButton, {
    "data-testid": 'drawerClose',
    onClick: onClose,
    icon: React.createElement(Close, {
      title: 'Close'
    })
  })) : null)), React.createElement(AnimatePresence, {
    initial: false
  }, !isCollapsed && React.createElement(motion.div, {
    key: 'content',
    exit: {
      scaleY: 0,
      height: 0
    },
    animate: {
      scaleY: 1,
      height: 'auto'
    },
    initial: {
      scaleY: 1,
      height: 'auto'
    }
  }, heading ? React.createElement(Box, {
    height: '100%',
    maxHeight: `calc(${props.height ?? '100vh'} - 100px)`,
    overflow: 'scroll',
    onScroll: onScrollHandler,
    style: {
      boxShadow
    }
  }, React.createElement(Box, {
    p: 3,
    height: '100%'
  }, children)) : React.createElement(Box, {
    p: 3,
    height: '100%'
  }, children)))))));
};
Drawer.displayName = 'Drawer';