import { Box } from '../Box/Box';
import { Flex } from '../Flex/Flex';
import { Sparkle } from 'pcln-icons';
import { Drawer } from './Drawer';
import React, { useState } from 'react';
import { Text } from '../Text/Text';
import { Stamp } from '../Stamp/Stamp';
import { ChatMessageContainer } from '../ChatMessageContainer/ChatMessageContainer';
function DrawerStory(props) {
  const [isOpen, setIsOpen] = useState(true);
  const [isCollapsed, setIsCollapsed] = useState(false);
  const {
    includeCloseButton = true,
    includeCollapseButton = true
  } = props;
  return React.createElement(Box, {
    height: '50vh',
    p: 0
  }, React.createElement(Drawer, {
    heading: 'Header',
    isOpen: isOpen,
    isCollapsed: isCollapsed,
    onClose: includeCloseButton ? () => setIsOpen(false) : undefined,
    onCollapse: includeCollapseButton ? () => setIsCollapsed(isCollapsed => !isCollapsed) : undefined,
    ...props
  }, props.children));
}
const CustomPennyHeader = React.createElement(Flex, {
  width: '100%',
  alignItems: 'center'
}, React.createElement(Text, {
  color: 'text.heading',
  textStyle: 'heading5'
}, "Penny", React.createElement(Sparkle, {
  color: 'promoPrimary',
  size: '16px'
})), React.createElement(Stamp, {
  color: 'primary',
  mx: 2
}, "Beta"));
const CustomPennyContent = React.createElement(ChatMessageContainer, {
  messageMaxWidth: '90%',
  messages: [{
    dateTime: 'Wed Jul 11 2023 11:33:52 GMT-0500',
    message: "Hi! I'm Penny, your virtual travel assistant!",
    variation: 'initial'
  }, {
    dateTime: 'Wed Jul 11 2023 11:33:52 GMT-0500',
    message: 'I see that you are interested in booking the Hilton Hawaiian Village for 3 nights from Mon, Apr 10, 2023, to Thu, Apr 13, 2023. The total cost for this stay is $796.68, with a total tax and fee of $111.57. There is an additional fee of $130.83 for facilities when you check-in. This hotel features free WiFi and is located in the Waikiki Beach Marina area. The room has 1 king bed and is rated 4 stars.',
    variation: 'incoming'
  }, {
    dateTime: 'Wed Jul 11 2023 11:34:12 GMT-0500',
    message: 'Is this hotel in a good location?',
    variation: 'outgoing'
  }, {
    dateTime: 'Wed Jul 11 2023 11:34:30 GMT-0500',
    message: "Yes, the Hilton Hawaiian Village is located in a fantastic area, specifically in the Waikiki Beach Marina - Ala Moana neighborhood. This location is renowned for its beautiful beaches, vibrant nightlife, and a wide variety of shopping and dining options. It's a great spot if you're looking to experience the best of Honolulu. If you have any other questions or if you're ready to book, feel free to ask!",
    variation: 'incoming'
  }, {
    dateTime: 'Wed Jul 11 2023 11:33:52 GMT-0500',
    message: "Hi! I'm Penny, your virtual travel assistant!",
    variation: 'initial'
  }, {
    dateTime: 'Wed Jul 11 2023 11:33:52 GMT-0500',
    message: 'I see that you are interested in booking the Hilton Hawaiian Village for 3 nights from Mon, Apr 10, 2023, to Thu, Apr 13, 2023. The total cost for this stay is $796.68, with a total tax and fee of $111.57. There is an additional fee of $130.83 for facilities when you check-in. This hotel features free WiFi and is located in the Waikiki Beach Marina area. The room has 1 king bed and is rated 4 stars.',
    variation: 'incoming'
  }, {
    dateTime: 'Wed Jul 11 2023 11:34:12 GMT-0500',
    message: 'Is this hotel in a good location?',
    variation: 'outgoing'
  }, {
    dateTime: 'Wed Jul 11 2023 11:34:30 GMT-0500',
    message: "Yes, the Hilton Hawaiian Village is located in a fantastic area, specifically in the Waikiki Beach Marina - Ala Moana neighborhood. This location is renowned for its beautiful beaches, vibrant nightlife, and a wide variety of shopping and dining options. It's a great spot if you're looking to experience the best of Honolulu. If you have any other questions or if you're ready to book, feel free to ask!",
    variation: 'incoming'
  }]
});
export default {
  title: 'Drawer',
  component: Drawer,
  args: {
    width: '50%',
    height: '100%',
    placement: 'right',
    isFloating: true
  },
  argTypes: {
    placement: {
      options: ['top', 'right', 'bottom', 'left'],
      control: {
        type: 'select'
      },
      description: 'moves the drawer to the specified position'
    },
    isFloating: {
      description: 'set to false to anchor the drawer to a specific side'
    }
  }
};
export const Top = args => React.createElement(DrawerStory, {
  ...args,
  height: '50%',
  width: '100%',
  placement: 'top'
}, "Drawer Content");
export const Bottom = args => React.createElement(DrawerStory, {
  ...args,
  height: '50%',
  width: '100%',
  placement: 'bottom'
}, "Drawer Content");
export const Left = args => React.createElement(DrawerStory, {
  ...args,
  placement: 'left'
}, "Drawer Content");
export const Right = args => React.createElement(DrawerStory, {
  ...args,
  placement: 'right'
}, "Drawer Content");
export const Anchored = args => React.createElement(DrawerStory, {
  ...args,
  isFloating: false,
  placement: 'right'
}, "Drawer Content");
export const Mobile = args => React.createElement(DrawerStory, {
  ...args,
  isMobile: true,
  isFloating: false,
  placement: 'right'
}, "Drawer Content");
export const WithNoHeader = args => React.createElement(DrawerStory, {
  ...args,
  placement: 'right',
  heading: undefined,
  includeCloseButton: false,
  includeCollapseButton: false
}, CustomPennyContent);
export const WithCustomHeaderAndContent = args => React.createElement(DrawerStory, {
  ...args,
  placement: 'right',
  heading: CustomPennyHeader
}, CustomPennyContent);
export const WithCloseButton = args => React.createElement(DrawerStory, {
  ...args,
  placement: 'right',
  onCollapse: undefined,
  includeCollapseButton: false
}, "Drawer Content");
export const WithCollapseButton = args => React.createElement(DrawerStory, {
  ...args,
  placement: 'right',
  includeCloseButton: false
}, "Drawer Content");
export const WithContentOverflow = args => React.createElement(DrawerStory, {
  ...args,
  height: '50vh',
  placement: 'right'
}, CustomPennyContent);