import styled from 'styled-components';
import { Flex } from '../Flex/Flex';
import { theme } from '../theme';
import { motion } from 'framer-motion';
import React from 'react';
import { Absolute } from '../Absolute/Absolute';
import { getPaletteColor } from '../utils';
import { Box } from '../Box/Box';
import { IconButton } from '../IconButton/IconButton';
const Component = React.forwardRef((props, ref) => React.createElement(Box, {
  ...props,
  ref: ref
}));
const AnimatedAbsolute = motion(Component);
const getBorderRadiusStyles = (placement, isFloating) => {
  const themeRadius = theme.borderRadii['2xl'];
  if (isFloating) {
    return themeRadius;
  }
  switch (placement) {
    case 'top':
      return `0px 0px ${themeRadius} ${themeRadius}`;
    case 'right':
      return `${themeRadius} 0px 0px  ${themeRadius}`;
    case 'bottom':
      return `${themeRadius} ${themeRadius} 0px 0px`;
    case 'left':
      return `0px ${themeRadius} ${themeRadius} 0px`;
  }
};
const positions = {
  top: `top:0; left:0; right:0;`,
  right: `right: 0; bottom:0;`,
  bottom: `bottom:0; left:0; right:0;`,
  left: `left:0;bottom:0;`
};
const getPlacementStyles = placement => placement ? `margin-inline:auto; margin-block:auto; ${positions[placement]};` : ``;
export const DrawerWrapper = /*#__PURE__*/styled(Absolute).withConfig({
  displayName: "Drawerstyled__DrawerWrapper",
  componentId: "sc-19fw04m-0"
})(["", ""], ({
  placement
}) => `
    ${getPlacementStyles(placement)}
    `);
export const DrawerRoot = /*#__PURE__*/styled(AnimatedAbsolute).withConfig({
  displayName: "Drawerstyled__DrawerRoot",
  componentId: "sc-19fw04m-1"
})(["background-color:", ";", ""], getPaletteColor('background.lightest'), ({
  theme,
  placement,
  isFloating
}) => `box-shadow: ${theme.shadows['overlay-md']};
    border-radius: ${getBorderRadiusStyles(placement, isFloating)};
    `);
export const HeadingWrapper = /*#__PURE__*/styled(Flex).withConfig({
  displayName: "Drawerstyled__HeadingWrapper",
  componentId: "sc-19fw04m-2"
})([""]);
export const HeaderButton = /*#__PURE__*/styled(IconButton).withConfig({
  displayName: "Drawerstyled__HeaderButton",
  componentId: "sc-19fw04m-3"
})(["background-color:", ";color:", ";padding:0;&:hover{background-color:", ";color:", ";}"], getPaletteColor('background.lightest'), getPaletteColor('text.dark'), getPaletteColor('background.light'), getPaletteColor('text.dark'));