import React from 'react';
import { action } from '@storybook/addon-actions';
import { within } from '@storybook/testing-library';
import { expect } from '@storybook/jest';
import { FloatingActionButtonProvider } from './FloatingActionButtonProvider';
import { ArrowUp, ArrowDown } from 'pcln-icons';
import { Box } from '../Box/Box';
import { animateArgs } from '../Animate/Animate.args';
export default {
  title: 'Core / FloatingActionButtonProvider',
  component: FloatingActionButtonProvider,
  argTypes: {
    animationVariant: {
      name: 'animationVariant',
      options: animateArgs,
      control: 'select'
    },
    position: {
      name: 'position',
      options: ['topRight', 'centerRight', 'bottomRight'],
      control: 'select'
    }
  },
  args: {
    position: 'bottomRight',
    animationVariant: 'slideInBottom',
    floatingActionButtons: [{
      tooltip: 'Tooltip Text',
      onClick: action('Clicked FAB'),
      icon: ArrowUp,
      key: 'up_arrow'
    }]
  }
};
export const Default = {
  render: args => React.createElement(Box, {
    height: '200px'
  }, React.createElement(FloatingActionButtonProvider, {
    ...args
  })),
  play: async ({
    args,
    canvasElement
  }) => {
    const canvas = within(canvasElement);
    await expect(canvas.getByRole('button')).toBeInTheDocument();
  }
};
export const DelayDisplay = {
  render: args => React.createElement(Box, {
    height: '200px'
  }, React.createElement(FloatingActionButtonProvider, {
    ...args,
    delayDisplayMs: 2000
  })),
  play: async ({
    args,
    canvasElement
  }) => {
    const canvas = within(canvasElement);
    await expect(canvas.queryByRole('button')).not.toBeInTheDocument();
    setTimeout(async () => {
      await expect(canvas.queryByRole('button')).toBeInTheDocument();
    }, 2100);
  }
};
export const HideUntilScroll = {
  render: args => React.createElement(Box, {
    height: '4000px'
  }, React.createElement(Box, null, "Scroll down to see FAB "), React.createElement(ArrowDown, null), React.createElement(FloatingActionButtonProvider, {
    ...args,
    hideUntilScrollPercent: 10
  })),
  play: async ({
    args,
    canvasElement
  }) => {
    const canvas = within(canvasElement);
    await expect(canvas.queryByRole('button')).not.toBeInTheDocument();
    window.scrollTo({
      top: 500
    });
    setTimeout(async () => {
      await expect(canvas.getByRole('button')).toBeInTheDocument();
    }, 2000);
  }
};
export const MultipleSamePosition = {
  render: args => React.createElement(Box, {
    height: '400px'
  }, React.createElement(FloatingActionButtonProvider, {
    ...args,
    floatingActionButtons: [{
      tooltip: 'Tooltip Text',
      onClick: action('Clicked FAB'),
      icon: ArrowUp,
      key: 'up_arrow'
    }, {
      tooltip: 'Tooltip Text',
      onClick: action('Clicked FAB'),
      icon: ArrowDown,
      mt: 2,
      key: 'down_arrow'
    }]
  }))
};
export const MultiplePositions = {
  render: args => React.createElement(Box, {
    height: '400px'
  }, React.createElement(FloatingActionButtonProvider, {
    ...args,
    position: 'topRight',
    animationVariant: 'slideInTop'
  }), React.createElement(FloatingActionButtonProvider, {
    ...args,
    position: 'centerRight',
    animationVariant: 'slideInRight',
    delayDisplayMs: 300
  }), React.createElement(FloatingActionButtonProvider, {
    ...args,
    delayDisplayMs: 600
  }))
};
export const CustomPositionUsingMargin = {
  render: args => React.createElement(Box, {
    height: '400px'
  }, React.createElement(FloatingActionButtonProvider, {
    ...args,
    position: 'topRight',
    animationVariant: 'slideInTop',
    mt: 6,
    mr: 6
  }))
};