import { action } from '@storybook/addon-actions';
import { Emoticon, Rowing, Tea, Warning } from 'pcln-icons';
import React from 'react';
import styled from 'styled-components';
import { Text } from '../Text/Text';
import { colorSchemeNames } from '../storybook/args';
import { getPaletteColor } from '../utils';
import { GenericBanner } from './GenericBanner';
import { argTypes } from './GenericBanner.stories.args';
export default {
  title: 'GenericBanner',
  component: GenericBanner,
  argTypes
};
const UnderlinedLinkText = /*#__PURE__*/styled(Text).withConfig({
  displayName: "GenericBannerstories__UnderlinedLinkText",
  componentId: "sc-xmdpqu-0"
})(["text-decoration:underline;&:hover{color:", ";}"], props => getPaletteColor(props.hoverColor));
const Template = args => React.createElement(GenericBanner, {
  ...args
});
export const BasicBannerAllInline = Template.bind({});
BasicBannerAllInline.args = {
  p: 3,
  heading: React.createElement(Text.span, {
    fontWeight: 'bold',
    mr: 1
  }, "COVID-19"),
  text: React.createElement(Text.span, null, "Update: Your travel may be impacted. Please review this hotels important info."),
  iconLeft: React.createElement(Warning, null),
  color: 'caution.light'
};
export const BasicBannerAllInlineRightIcon = () => React.createElement(GenericBanner, {
  p: 2,
  heading: React.createElement(Text.span, {
    fontWeight: 'bold',
    color: 'secondary',
    mr: 1
  }, "This is a Heading"),
  text: React.createElement(Text.span, {
    textColor: 'primary.base'
  }, "This is some text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nunc at lacus vel dolor fringilla rhoncus."),
  iconRight: React.createElement(Tea, null),
  color: 'primary.light'
});
export const BasicBannerBlockWithURLPropsCTA = () => React.createElement(GenericBanner, {
  p: 2,
  heading: React.createElement(Text, {
    fontWeight: 'bold',
    mr: 1
  }, "This is a Heading"),
  text: React.createElement(Text, null, "This is some text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nunc at lacus vel dolor fringilla rhoncus."),
  URLProps: {
    href: 'https://www.priceline.com',
    target: '_blank'
  },
  ctaText: React.createElement(UnderlinedLinkText, {
    color: 'primary',
    fontWeight: 'bold',
    hoverColor: 'primary.dark'
  }, ' ', "Read More"),
  iconLeft: React.createElement(Rowing, null),
  color: 'secondary.light'
});
export const BannerWithOnClick = () => React.createElement(GenericBanner, {
  p: 2,
  heading: React.createElement(Text.span, {
    fontWeight: 'bold',
    textColor: 'primary.base',
    mr: 1
  }, "COVID-19"),
  text: React.createElement(Text.span, {
    textColor: 'primary.base',
    mr: 1
  }, "Update: Your travel may be impacted. Please review this hotels important info."),
  buttonClick: action('clicked on the banner or the read more link-button'),
  iconLeft: React.createElement(Warning, null),
  color: 'caution.light'
});
export const BannerWithOnClickAndCTA = () => React.createElement(GenericBanner, {
  p: 2,
  heading: React.createElement(Text.span, {
    fontWeight: 'bold',
    textColor: 'primary.base',
    mr: 1
  }, "COVID-19"),
  text: React.createElement(Text.span, {
    textColor: 'primary.base',
    mr: 1
  }, "Update: Your travel may be impacted. Please review this hotels important info."),
  ctaText: React.createElement(Text.span, {
    textColor: 'primary.base',
    fontWeight: 'bold'
  }, "Read More"),
  buttonClick: action('clicked on the banner or the read more link-button'),
  iconLeft: React.createElement(Warning, null),
  color: 'caution.light'
});
export const BannerWithOnClickButtonStyleCta = () => React.createElement(GenericBanner, {
  buttonVariation: 'fill',
  buttonSize: 'small',
  p: 2,
  heading: React.createElement(Text.span, {
    fontWeight: 'bold',
    textColor: 'primary.base',
    mr: 1
  }, "COVID-19"),
  text: React.createElement(Text.span, {
    mr: 1,
    textColor: 'primary.base'
  }, "Update: Your travel may be impacted. Please review this hotels important info."),
  ctaText: React.createElement(Text, {
    textColor: 'primary',
    fontWeight: 'bold'
  }, "Read More"),
  buttonClick: action('clicked on the banner or the read more link-button'),
  iconLeft: React.createElement(Warning, null),
  color: 'caution.light'
});
export const BannerWithURLPropsAndCta = () => React.createElement(GenericBanner, {
  p: 2,
  heading: React.createElement(Text.span, {
    fontWeight: 'bold',
    textColor: 'primary.base',
    mr: 1
  }, "This is a Heading"),
  text: React.createElement(Text.span, {
    color: 'warning',
    mr: 1
  }, "This is some text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nunc at lacus vel dolor fringilla rhoncus."),
  URLProps: {
    href: 'https://www.priceline.com',
    target: '_blank'
  },
  ctaText: React.createElement(UnderlinedLinkText, {
    color: 'primary',
    fontWeight: 'bold',
    hoverColor: 'primary.dark'
  }, "Read More"),
  iconLeft: React.createElement(Emoticon, null),
  color: 'alert.light'
});
export const BannerWithURLProps = () => React.createElement(GenericBanner, {
  p: 2,
  heading: React.createElement(Text.span, {
    fontWeight: 'bold',
    textColor: 'primary.base',
    mr: 1
  }, "This is a Heading"),
  text: React.createElement(Text.span, {
    color: 'warning',
    mr: 1
  }, "This is some text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nunc at lacus vel dolor fringilla rhoncus."),
  URLProps: {
    href: 'https://www.priceline.com',
    target: '_blank'
  },
  iconLeft: React.createElement(Emoticon, null),
  color: 'alert.light'
});
export const BannerWithURLPropsAndCustomHeadingSize = () => React.createElement(GenericBanner, {
  p: 2,
  heading: React.createElement(Text.span, {
    fontWeight: 'bold',
    textColor: 'primary.base',
    mr: 1,
    fontSize: 4
  }, "This is a Heading"),
  text: React.createElement(Text.span, {
    color: 'warning',
    mr: 1
  }, "This is some text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nunc at lacus vel dolor fringilla rhoncus."),
  URLProps: {
    href: 'https://www.priceline.com',
    target: '_blank'
  },
  iconLeft: React.createElement(Emoticon, null),
  color: 'alert.light'
});
export const BannerWithURLPropsButtonStyleCta = () => React.createElement(GenericBanner, {
  p: 2,
  color: 'alert.light',
  linkColor: 'secondary',
  linkVariation: 'fill',
  heading: React.createElement(Text.span, {
    fontWeight: 'bold',
    mr: 1
  }, "This is a Heading"),
  text: React.createElement(Text.span, {
    color: 'warning',
    mr: 1
  }, "This is some text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nunc at lacus vel dolor fringilla rhoncus."),
  URLProps: {
    href: 'https://www.priceline.com',
    target: '_blank'
  },
  ctaText: React.createElement(Text, {
    color: 'text.lightest',
    fontWeight: 'bold'
  }, "Read More"),
  iconLeft: React.createElement(Emoticon, null)
});
export const ColorScheme = () => {
  return colorSchemeNames.map(colorScheme => React.createElement(GenericBanner, {
    key: colorScheme,
    colorScheme: colorScheme,
    p: 3,
    m: 2,
    heading: React.createElement(Text.span, {
      fontWeight: 'bold',
      mr: 1
    }, colorScheme),
    text: React.createElement(Text.span, null, "Update: Your travel may be impacted. Please review this hotels important info."),
    iconLeft: React.createElement(Warning, null)
  }));
};