import { ArgsTable, PRIMARY_STORY, Primary } from '@storybook/addon-docs';
import { linkTo } from '@storybook/addon-links';
import React from 'react';
import { Box } from '../Box/Box';
import { Hero } from '../DocsUtils/Hero/Hero';
import { RelatedComponent, RelatedComponentContainer } from '../DocsUtils/RelatedComponent/RelatedComponent';
import { Section } from '../DocsUtils/Section/Section';
import { StoryHeading } from '../DocsUtils/StoryHeading/StoryHeading';
import { TableOfContents } from '../DocsUtils/TableOfContents/TableOfContents';
import { Flex } from '../Flex/Flex';
import { Grid } from '../Grid/Grid';
import { Text } from '../Text/Text';
import { ThemeProvider } from '../ThemeProvider/ThemeProvider';
const GridItem = props => React.createElement(Grid, {
  p: 4,
  width: 1,
  placeItems: 'center',
  ...props
});
export const Playground = {
  render: () => React.createElement(Grid, {
    templateColumns: ['1fr', '1fr 1fr', '1fr 1fr 1fr'],
    placeItems: 'center',
    gap: 2
  }, React.createElement(GridItem, {
    style: {
      background: '#00f8'
    }
  }, "A"), React.createElement(GridItem, {
    style: {
      background: '#0f08'
    }
  }, "B"), React.createElement(GridItem, {
    style: {
      background: '#0ff8'
    }
  }, "C"), React.createElement(GridItem, {
    style: {
      background: '#f008'
    }
  }, "D"), React.createElement(GridItem, {
    style: {
      background: '#f0f8'
    }
  }, "E"), React.createElement(GridItem, {
    style: {
      background: '#ff08'
    }
  }, "F"))
};
export const TemplateAreas = {
  render: () => React.createElement(Grid, {
    templateAreas: `
        'header header' 
        'sidebar content'
        'footer footer'
      `,
    placeItems: 'center',
    minHeight: 'calc(100vh - 5rem)',
    templateRows: 'auto 1fr auto',
    templateColumns: '15em 1fr',
    gap: 2
  }, React.createElement(GridItem, {
    gridArea: 'header',
    style: {
      background: '#00f8'
    }
  }, "Header"), React.createElement(GridItem, {
    gridArea: 'sidebar',
    height: '100%',
    style: {
      background: '#0f08'
    }
  }, "Sidebar"), React.createElement(GridItem, {
    gridArea: 'content',
    height: '100%',
    style: {
      background: '#0ff8'
    }
  }, "Content"), React.createElement(GridItem, {
    gridArea: 'footer',
    mt: 'auto',
    style: {
      background: '#f008'
    }
  }, "Footer"))
};
export const NestedGrids = {
  render: () => React.createElement(Grid, {
    templateColumns: '1fr 1fr',
    placeItems: 'center',
    gap: 2
  }, React.createElement(GridItem, {
    style: {
      background: '#00f8'
    }
  }, "A"), React.createElement(GridItem, {
    style: {
      background: '#0f08'
    }
  }, "B"), React.createElement(GridItem, {
    style: {
      background: '#0ff8'
    }
  }, "C"), React.createElement(Grid, {
    width: 1,
    templateColumns: '1fr 1fr 1fr',
    placeItems: 'center',
    gap: 2
  }, React.createElement(GridItem, {
    style: {
      background: '#f008'
    }
  }, "D"), React.createElement(GridItem, {
    style: {
      background: '#f0f8'
    }
  }, "E"), React.createElement(GridItem, {
    style: {
      background: '#ff08'
    }
  }, "F")))
};
export const ResponsiveLayout = {
  render: () => React.createElement(Grid, {
    templateColumns: ['1fr', '1fr 1fr', '1fr 1fr 1fr', '1fr 1fr 1fr 1fr', '1fr 1fr 1fr 1fr 1fr', '1fr 1fr 1fr 1fr 1fr 1fr'],
    placeItems: 'center',
    gap: 2
  }, React.createElement(GridItem, {
    style: {
      background: '#00f8'
    }
  }, "A"), React.createElement(GridItem, {
    style: {
      background: '#0f08'
    }
  }, "B"), React.createElement(GridItem, {
    style: {
      background: '#0ff8'
    }
  }, "C"), React.createElement(GridItem, {
    style: {
      background: '#f008'
    }
  }, "D"), React.createElement(GridItem, {
    style: {
      background: '#f0f8'
    }
  }, "E"), React.createElement(GridItem, {
    style: {
      background: '#ff08'
    }
  }, "F"))
};
const meta = {
  title: 'Layout/Grid',
  component: Grid,
  parameters: {
    docs: {
      page: () => React.createElement(ThemeProvider, null, React.createElement(Hero, {
        name: 'Grid',
        img: ''
      }, "Grids divide a web page into rows and columns and offer comprehensive features for controlling the sizing and positioning of grid items, including the ability to define grid areas, set grid gaps, and control the alignment and distribution of grid items"), React.createElement(TableOfContents, {
        links: ['Overview', 'Props', 'Examples', 'Related Components']
      }), React.createElement(Section, {
        heading: 'Overview'
      }, React.createElement(Text, {
        textStyle: 'paragraph'
      }, "Grid is based on the CSS Grid Layout Module, which provides a two-dimensional grid-based layout system, with rows and columns, making it easier to design web pages and components.")), React.createElement(Section, {
        heading: 'Props'
      }, React.createElement(Primary, null), React.createElement(ArgsTable, {
        story: PRIMARY_STORY
      })), React.createElement(Section, {
        heading: 'Examples'
      }, React.createElement(StoryHeading, {
        storyName: 'Template Areas',
        storyTitle: meta.title
      }), React.createElement(Text, {
        textStyle: 'paragraph'
      }, "Using the ", React.createElement("code", null, "gridTemplateAreas"), " prop, you can define grid areas and assign grid items to them. The grid areas are defined by using the ", React.createElement("code", null, "grid-area"), " property on the grid items. The ", React.createElement("code", null, "grid-area"), " property can be used to assign a name to a grid item, which can then be used as a value of the ", React.createElement("code", null, "grid-template-areas"), " property."), React.createElement(StoryHeading, {
        storyName: 'Nested Grids',
        storyTitle: meta.title
      }), React.createElement(Text, {
        textStyle: 'paragraph'
      }, "Grids can be nested inside other grids. This allows you to create more complex layouts."), React.createElement(StoryHeading, {
        storyName: 'Responsive Layout',
        storyTitle: meta.title
      }), React.createElement(Text, {
        textStyle: 'paragraph'
      }, "Grids can be responsive. You can define the number of columns for each breakpoint using the", React.createElement("code", null, "templateColumns"), " prop.")), React.createElement(Section, {
        heading: 'Related Components'
      }, React.createElement(RelatedComponentContainer, null, React.createElement(RelatedComponent, {
        name: 'Box',
        onClick: linkTo('Core/Box')
      }, React.createElement(Box, {
        width: '75%',
        height: '75%',
        bg: 'background.lightest'
      }, "Box")), React.createElement(RelatedComponent, {
        name: 'Flex',
        onClick: linkTo('Flex')
      }, React.createElement(Flex, {
        justifyContent: 'center',
        alignItems: 'center',
        width: '75%',
        height: '75%',
        bg: 'background.lightest'
      }, "Flex")))))
    }
  }
};
export default meta;