import React from 'react';
import styled from 'styled-components';
import { Box } from '../Box/Box';
import { Button } from '../Button/Button';
import { Container } from '../Container/Container';
import { Grid } from '../Grid/Grid';
import { Link } from '../Link/Link';
import { Text } from '../Text/Text';
import { colors } from '../storybook/args';
import ForwardRefDemo from '../storybook/utils/ForwardRefsDemo';
import { getLinkStylesOn } from '../utils/utils';
import { argTypes, defaultArgs, sizeOptions, variationOptions } from './Link.stories.args';
export default {
  title: 'Link',
  component: Link,
  args: defaultArgs,
  argTypes
};
const Template = args => React.createElement(Link, {
  ...args
});
export const _Link = Template.bind({});
export const Playground = {
  render: args => React.createElement(Button, {
    ...args
  }, "Button"),
  argTypes: {
    color: {
      control: 'select',
      options: colors,
      defaultValue: Button.defaultProps.color
    },
    size: {
      control: 'select',
      options: sizeOptions,
      defaultValue: Button.defaultProps.size
    },
    disabled: {
      defaultValue: false,
      type: 'boolean'
    }
  }
};
export function Variations(args) {
  return React.createElement(React.Fragment, null, React.createElement(Text, {
    textStyle: 'heading3',
    mb: 2
  }, "Link Variations"), React.createElement(Grid, {
    gap: 4,
    templateColumns: ['1fr'],
    background: 'primary'
  }, variationOptions.map(variation => React.createElement(Link, {
    ...args,
    key: variation,
    variation: variation,
    m: 1
  }, variation, " link"))));
}
export function Sizes(args) {
  return React.createElement(React.Fragment, null, React.createElement(Text, {
    textStyle: 'heading3',
    mb: 2
  }, "Link Sizes"), React.createElement(Container, null, sizeOptions.map(size => React.createElement(Link, {
    ...args,
    key: size,
    size: size,
    variation: 'fill',
    m: 3
  }, size))));
}
export function ForwardRefs() {
  function refChild(dsRef) {
    function onClick() {
      return dsRef.current.innerHTML = 'Bacon!';
    }
    return React.createElement(React.Fragment, null, React.createElement(Link, {
      color: 'text.dark',
      ref: dsRef
    }, "I am a link!"), React.createElement("br", null), React.createElement(Button, {
      color: 'error',
      onClick: onClick,
      mt: 4
    }, "Click to update link text via ref"));
  }
  return React.createElement(ForwardRefDemo, {
    refChild: refChild
  });
}
export const LargeText = () => React.createElement(Link, {
  color: 'text.light'
}, React.createElement(Text, {
  textStyle: 'heading2'
}, "I am a link with text styles"));
const ReactiveLink = /*#__PURE__*/styled(Link).withConfig({
  displayName: "Linkstories__ReactiveLink",
  componentId: "sc-tqkbvh-0"
})(["", ";"], props => getLinkStylesOn(props.backgroundColor, props.linkLightColor, props.linkDarkColor, props.isLinkBold)(props));
const ReactiveLinkTemplate = args => React.createElement(React.Fragment, null, React.createElement(Text, {
  mb: 2
}, "Uses the ", React.createElement("code", null, "getLinkStylesOn"), " utility"), React.createElement(Box, {
  color: args.backgroundColor,
  p: 2,
  width: 300
}, React.createElement(ReactiveLink, {
  ...args
}, args.children)), React.createElement(Box, {
  color: 'background.lightest',
  p: 2,
  width: 300
}, React.createElement(ReactiveLink, {
  ...args,
  backgroundColor: 'background.lightest'
}, args.children)), React.createElement(Box, {
  color: 'highlight.tone',
  p: 2,
  width: 300
}, React.createElement(ReactiveLink, {
  ...args,
  backgroundColor: 'highlight.tone'
}, args.children)), React.createElement(Box, {
  color: 'background.darkest',
  p: 2,
  width: 300
}, React.createElement(ReactiveLink, {
  ...args,
  backgroundColor: 'background.darkest'
}, args.children)));
export const ReactiveStyling = ReactiveLinkTemplate.bind({});
ReactiveStyling.args = {
  backgroundColor: 'primary.base',
  linkLightColor: 'text.lightest',
  linkDarkColor: 'text.base',
  isLinkBold: false
};