import { action } from '@storybook/addon-actions';
import React, { useState } from 'react';
import { Box } from '../Box/Box';
import { Button } from '../Button/Button';
import { Text } from '../Text/Text';
import { PasswordInput } from './PasswordInput';
export default {
  title: 'PasswordInput',
  component: PasswordInput
};
const customRegexChecks = [{
  label: '1 Uppercase Letter',
  regex: /(?=.*[A-Z])/
}, {
  label: '1 Lowercase Letter',
  regex: /(?=.*[a-z])/
}];
export const Basic = () => React.createElement(PasswordInput, null);
export const WithTitle = () => React.createElement(PasswordInput, {
  label: 'New Password'
});
export const WithProgressBar = () => React.createElement(PasswordInput, {
  label: 'New Password',
  hasProgressBar: true
});
export const WithCustomRegex = () => React.createElement(PasswordInput, {
  label: 'New Password',
  hasProgressBar: true,
  regexChecks: customRegexChecks
});
export const UpdatePasswordForm = () => {
  const [currentPassword, setCurrentPassword] = useState('');
  const [newPassword, setNewPassword] = useState('');
  const [confirmPassword, setConfirmPassword] = useState('');
  const [isNewPasswordValid, setNewPasswordValid] = useState(false);
  function onCurrentPasswordChange({
    value
  }) {
    return setCurrentPassword(value);
  }
  function onConfirmPasswordChange({
    value
  }) {
    return setConfirmPassword(value);
  }
  function onNewPasswordChange({
    isValid,
    value
  }) {
    setNewPassword(value);
    setNewPasswordValid(isValid);
  }
  const currentPasswordMatches = !!currentPassword && currentPassword === newPassword;
  const newPasswordsMatch = newPassword === confirmPassword && isNewPasswordValid;
  const isSaveEnabled = !currentPasswordMatches && newPasswordsMatch;
  const onClick = action('Password changed');
  return React.createElement(Box, {
    width: [1, null, 500]
  }, React.createElement(PasswordInput, {
    label: 'Current Password',
    onChange: onCurrentPasswordChange,
    mb: 3
  }), React.createElement(PasswordInput, {
    label: 'New Password',
    hasProgressBar: true,
    onChange: onNewPasswordChange,
    mb: 3
  }), React.createElement(PasswordInput, {
    isValid: newPasswordsMatch,
    label: 'Confirm Password',
    onChange: onConfirmPasswordChange
  }), React.createElement(Button, {
    disabled: !isSaveEnabled,
    onClick: onClick,
    mt: 3
  }, "Save"), currentPasswordMatches && React.createElement(Text, {
    color: 'error',
    fontSize: 0,
    mt: 2
  }, "New Password must be different from your current password"));
};