import React from 'react';
import { fireEvent, render } from '../__test__/testing-library';
import { Popout } from './Popout';
const trigger = React.createElement("input", {
  "data-testid": 'trigger',
  "aria-label": 'trigger'
});
const content = React.createElement("div", {
  "data-testId": 'content'
}, "Content");
const delay = async ms => new Promise(resolve => setTimeout(resolve, ms));
describe('Popout', () => {
  it('Renders the trigger', () => {
    const {
      getByTestId
    } = render(React.createElement(Popout, {
      trigger: trigger
    }));
    expect(getByTestId('trigger')).toBeTruthy();
  });
  it('Handles opening and closing', async () => {
    const handler = jest.fn();
    const {
      getByTestId
    } = render(React.createElement(Popout, {
      trigger: trigger,
      content: content,
      onOpen: handler,
      onClose: handler
    }));
    const triggerElement = getByTestId('trigger');
    fireEvent.focusIn(triggerElement);
    await delay(100);
    expect(handler).toHaveBeenCalledTimes(1);
    const contentElement = getByTestId('content');
    fireEvent.keyDown(contentElement, {
      key: 'Escape',
      code: 'Escape',
      keyCode: 27,
      charCode: 27
    });
    await delay(100);
    expect(handler).toHaveBeenCalledTimes(2);
  });
  it('Handles losing focus', async () => {
    const handler = jest.fn();
    const {
      getByTestId
    } = render(React.createElement(React.Fragment, null, React.createElement("input", {
      "data-testid": 'outside',
      "aria-label": 'outside'
    }), React.createElement(Popout, {
      trigger: trigger,
      content: content,
      onOpen: handler,
      onClose: handler
    })));
    const triggerElement = getByTestId('trigger');
    fireEvent.focusIn(triggerElement);
    await delay(100);
    expect(handler).toHaveBeenCalledTimes(1);
    const outsideElement = getByTestId('outside');
    fireEvent.focusIn(outsideElement);
    await delay(100);
    expect(handler).toHaveBeenCalledTimes(2);
  });
  it('Closes when the trigger ref is clicked', async () => {
    const handler = jest.fn();
    const triggerRef = React.createRef();
    const _trigger = React.cloneElement(trigger, {
      ref: triggerRef
    });
    const {
      getByTestId
    } = render(React.createElement(Popout, {
      trigger: _trigger,
      triggerRef: triggerRef,
      content: content,
      onOpen: handler,
      onClose: handler,
      closeOnTriggerRefClick: true
    }));
    const triggerElement = getByTestId('trigger');
    fireEvent.focusIn(triggerElement);
    await delay(100);
    expect(handler).toHaveBeenCalledTimes(1);
    fireEvent.click(triggerRef.current);
    await delay(100);
    expect(handler).toHaveBeenCalledTimes(2);
  });
});