import React, { useState } from 'react';
import styled from 'styled-components';
import { Box } from '../Box/Box';
import { Button } from '../Button/Button';
import { Section } from '../DocsUtils/Section/Section';
import { Flex } from '../Flex/Flex';
import { Image } from '../Image/Image';
import { Input } from '../Input/Input';
import { Text } from '../Text/Text';
import { ThemeProvider } from '../ThemeProvider/ThemeProvider';
import { theme } from '../theme/theme';
import { getPaletteColor } from '../utils/utils';
import { RadioCheckToggleCard } from './RadioCheckToggleCard';
import { argTypes } from './RadioCheckToggleCard.stories.args';
const dumpText = 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec eros neque, sodales eu urna at, porta rutrum metus. Aliquam aliquam dolor erat, in convallis ipsum volutpat quis.';
const exampleImage = () => React.createElement(Image, {
  borderRadius: 'lg',
  src: 'https://s1.pclncdn.com/design-assets/hero/beach.jpg'
});
const exampleInput = ({
  disabled
}) => React.createElement(Box, {
  width: '100%',
  mt: 2,
  bg: 'background.lightest'
}, React.createElement(Input, {
  borderRadius: 'lg',
  style: {
    background: theme.colors.lightestBackground
  },
  placeholder: 'Placeholder',
  disabled: disabled
}));
const divider = () => React.createElement(Box, {
  width: '100%',
  my: 4,
  style: {
    border: '1px solid #e0e5ea'
  }
});
const EnabledStateCard = /*#__PURE__*/styled(Box).withConfig({
  displayName: "RadioCheckToggleCardstories__EnabledStateCard",
  componentId: "sc-2mal6o-0"
})(["flex:1 1 30%;& > label > div{background-color:", " !important;border-color:transparent !important;& div.cardIcon > svg{color:", " !important;border-color:transparent !important;box-shadow:none !important;}}"], getPaletteColor('background.lightest'), getPaletteColor('text.light'));
const HoverStateCard = /*#__PURE__*/styled(Box).withConfig({
  displayName: "RadioCheckToggleCardstories__HoverStateCard",
  componentId: "sc-2mal6o-1"
})(["flex:1 1 30%;& > label > div{background-color:", " !important;border-color:", " !important;& div.cardIcon > svg{color:", " !important;border-color:transparent !important;box-shadow:none !important;}}"], getPaletteColor('background.lightest'), getPaletteColor('primary.base'), getPaletteColor('primary.base'));
const FocusStateCard = /*#__PURE__*/styled(Box).withConfig({
  displayName: "RadioCheckToggleCardstories__FocusStateCard",
  componentId: "sc-2mal6o-2"
})(["flex:1 1 30%;& > label > div{background-color:", " !important;border-color:transparent !important;& div.cardIcon > svg{color:", " !important;border-color:", " !important;box-shadow:inset 0 0 0 5px ", " !important;}}"], getPaletteColor('background.lightest'), getPaletteColor('text.light'), getPaletteColor('text.light'), getPaletteColor('background.light'));
const SelectedStateCard = /*#__PURE__*/styled(Box).withConfig({
  displayName: "RadioCheckToggleCardstories__SelectedStateCard",
  componentId: "sc-2mal6o-3"
})(["flex:1 1 30%;& > label > div{background-color:", " !important;border-color:", " !important;& div.cardIcon > svg{color:", " !important;border-color:transparent !important;box-shadow:none !important;}}"], getPaletteColor('primary.light'), getPaletteColor('primary.base'), getPaletteColor('primary.base'));
const SelectedHoverStateCard = /*#__PURE__*/styled(Box).withConfig({
  displayName: "RadioCheckToggleCardstories__SelectedHoverStateCard",
  componentId: "sc-2mal6o-4"
})(["flex:1 1 30%;& > label > div{background-color:", " !important;border-color:", " !important;& div.cardIcon > svg{color:", " !important;border-color:transparent !important;box-shadow:none !important;}}"], getPaletteColor('primary.light'), getPaletteColor('primary.dark'), getPaletteColor('primary.dark'));
const SelectedFocusStateCard = /*#__PURE__*/styled(Box).withConfig({
  displayName: "RadioCheckToggleCardstories__SelectedFocusStateCard",
  componentId: "sc-2mal6o-5"
})(["flex:1 1 30%;& > label > div{background-color:", " !important;border-color:", " !important;& div.cardIcon > svg{color:", " !important;border-color:", " !important;box-shadow:none !important;}}"], getPaletteColor('primary.light'), getPaletteColor('primary.base'), getPaletteColor('primary.base'), getPaletteColor('primary.base'));
const DefaultDocPage = () => {
  const [examples, setExamples] = useState({
    ['types-label']: [],
    ['formatting-position']: 'example-1',
    ['formatting-label-with-children']: ['example-1'],
    ['formatting-full-width-children']: ['example-1'],
    ['additional-actions-buttons']: 'example-1',
    ['additional-actions-forms-1']: 'example-1',
    ['additional-actions-forms-2']: 'example-1'
  });
  const data = {
    cardType: 'radio',
    name: 'formatting-position',
    options: [{
      hPosition: 'left',
      vPosition: 'top',
      title: dumpText,
      value: 'example-1'
    }, {
      hPosition: 'right',
      vPosition: 'top',
      title: dumpText,
      value: 'example-2'
    }, {
      hPosition: 'left',
      vPosition: 'center',
      title: dumpText,
      value: 'example-3'
    }, {
      hPosition: 'right',
      vPosition: 'center',
      title: dumpText,
      value: 'example-4'
    }]
  };
  const handleOnChangeInLabel = e => {
    const {
      value
    } = e.currentTarget;
    const result = examples['types-label'];
    const index = result.indexOf(value);
    if (index >= 0) {
      result.splice(index, 1);
    } else {
      result.unshift(value);
    }
    if (result.length > 2) {
      result.pop();
    }
    setExamples(previousState => ({
      ...previousState,
      ['types-label']: result
    }));
  };
  const handleOnChange = e => ({
    cardType,
    name
  }) => {
    const {
      value
    } = e.currentTarget;
    let result = value;
    if (cardType !== 'radio') {
      result = examples[name];
      const index = result.indexOf(value);
      if (index >= 0) {
        result.splice(index, 1);
      } else {
        result.push(value);
      }
    }
    setExamples(previousState => ({
      ...previousState,
      [name]: result
    }));
  };
  return React.createElement(ThemeProvider, null, React.createElement(Section, {
    heading: 'Types'
  }, React.createElement(Text, {
    textStyle: 'subheading3',
    my: 3
  }, "Label"), React.createElement(Text, {
    textStyle: 'paragraph',
    my: 3
  }, "In its checked state, by default the color is to be primary.base."), React.createElement(Flex, {
    flexDirection: 'column',
    style: {
      width: '50%',
      gap: '16px'
    }
  }, React.createElement(RadioCheckToggleCard, {
    name: 'types-label',
    title: 'Radio',
    value: 'example-1',
    isSelected: examples['types-label'].includes('example-1'),
    onChange: handleOnChangeInLabel
  }), React.createElement(RadioCheckToggleCard, {
    cardType: 'checkbox',
    name: 'types-label',
    title: 'Checkbox',
    value: 'example-2',
    isSelected: examples['types-label'].includes('example-2'),
    onChange: handleOnChangeInLabel
  }), React.createElement(RadioCheckToggleCard, {
    cardType: 'toggle',
    name: 'types-label',
    title: 'Toggle',
    value: 'example-3',
    isSelected: examples['types-label'].includes('example-3'),
    onChange: handleOnChangeInLabel
  }))), divider(), React.createElement(Section, {
    heading: 'States'
  }, React.createElement(Text, {
    textStyle: 'paragraph',
    my: 3
  }, "Radio - Examples shown indicate the card & action states"), React.createElement(Flex, {
    my: 4,
    flexWrap: 'wrap',
    style: {
      width: '100%',
      gap: '16px'
    }
  }, React.createElement(EnabledStateCard, null, React.createElement(RadioCheckToggleCard, {
    name: 'states-radio',
    title: 'Enabled',
    value: 'example-1',
    isSelected: false,
    onChange: () => {}
  }, React.createElement(Box, {
    width: '100%',
    height: '75px'
  }))), React.createElement(HoverStateCard, null, React.createElement(RadioCheckToggleCard, {
    name: 'states-radio',
    title: 'Hover',
    value: 'example-2',
    isSelected: false,
    onChange: () => {}
  }, React.createElement(Box, {
    width: '100%',
    height: '75px'
  }))), React.createElement(FocusStateCard, null, React.createElement(RadioCheckToggleCard, {
    name: 'states-radio',
    title: 'Focus',
    value: 'example-3',
    isSelected: false,
    onChange: () => {}
  }, React.createElement(Box, {
    width: '100%',
    height: '75px'
  }))), React.createElement(SelectedStateCard, null, React.createElement(RadioCheckToggleCard, {
    name: 'states-radio',
    title: 'Selected',
    value: 'example-4',
    isSelected: true,
    onChange: () => {}
  }, React.createElement(Box, {
    width: '100%',
    height: '75px'
  }))), React.createElement(SelectedHoverStateCard, null, React.createElement(RadioCheckToggleCard, {
    name: 'states-radio',
    title: 'Selected Hover',
    value: 'example-5',
    isSelected: true,
    onChange: () => {}
  }, React.createElement(Box, {
    width: '100%',
    height: '75px'
  }))), React.createElement(SelectedFocusStateCard, null, React.createElement(RadioCheckToggleCard, {
    name: 'states-radio',
    title: 'Selected Focus',
    value: 'example-6',
    isSelected: true,
    onChange: () => {}
  }, React.createElement(Box, {
    width: '100%',
    height: '75px'
  })))), React.createElement(Text, {
    textStyle: 'paragraph',
    my: 3
  }, "Checkbox - Examples shown indicate the card & action states"), React.createElement(Flex, {
    my: 4,
    flexWrap: 'wrap',
    style: {
      width: '100%',
      gap: '16px'
    }
  }, React.createElement(EnabledStateCard, null, React.createElement(RadioCheckToggleCard, {
    cardType: 'checkbox',
    name: 'states-checkbox',
    title: 'Enabled',
    value: 'example-1',
    isSelected: false,
    onChange: () => {}
  }, React.createElement(Box, {
    width: '100%',
    height: '75px'
  }))), React.createElement(HoverStateCard, null, React.createElement(RadioCheckToggleCard, {
    cardType: 'checkbox',
    name: 'states-checkbox',
    title: 'Hover',
    value: 'example-2',
    isSelected: false,
    onChange: () => {}
  }, React.createElement(Box, {
    width: '100%',
    height: '75px'
  }))), React.createElement(FocusStateCard, null, React.createElement(RadioCheckToggleCard, {
    cardType: 'checkbox',
    name: 'states-checkbox',
    title: 'Focus',
    value: 'example-3',
    isSelected: false,
    onChange: () => {}
  }, React.createElement(Box, {
    width: '100%',
    height: '75px'
  }))), React.createElement(SelectedStateCard, null, React.createElement(RadioCheckToggleCard, {
    cardType: 'checkbox',
    name: 'states-checkbox',
    title: 'Selected',
    value: 'example-4',
    isSelected: true,
    onChange: () => {}
  }, React.createElement(Box, {
    width: '100%',
    height: '75px'
  }))), React.createElement(SelectedHoverStateCard, null, React.createElement(RadioCheckToggleCard, {
    cardType: 'checkbox',
    name: 'states-checkbox',
    title: 'Selected Hover',
    value: 'example-5',
    isSelected: true,
    onChange: () => {}
  }, React.createElement(Box, {
    width: '100%',
    height: '75px'
  }))), React.createElement(SelectedFocusStateCard, null, React.createElement(RadioCheckToggleCard, {
    cardType: 'checkbox',
    name: 'states-checkbox',
    title: 'Selected Focus',
    value: 'example-6',
    isSelected: true,
    onChange: () => {}
  }, React.createElement(Box, {
    width: '100%',
    height: '75px'
  })))), React.createElement(Text, {
    textStyle: 'paragraph',
    my: 3
  }, "Toggle - Examples shown indicate the card & action states"), React.createElement(Flex, {
    my: 4,
    flexWrap: 'wrap',
    style: {
      width: '100%',
      gap: '16px'
    }
  }, React.createElement(EnabledStateCard, null, React.createElement(RadioCheckToggleCard, {
    cardType: 'toggle',
    name: 'states-toggle',
    title: 'Enabled',
    value: 'example-1',
    isSelected: false,
    onChange: () => {}
  }, React.createElement(Box, {
    width: '100%',
    height: '75px'
  }))), React.createElement(HoverStateCard, null, React.createElement(RadioCheckToggleCard, {
    cardType: 'toggle',
    name: 'states-toggle',
    title: 'Hover',
    value: 'example-2',
    isSelected: false,
    onChange: () => {}
  }, React.createElement(Box, {
    width: '100%',
    height: '75px'
  }))), React.createElement(FocusStateCard, null, React.createElement(RadioCheckToggleCard, {
    cardType: 'toggle',
    name: 'states-toggle',
    title: 'Focus',
    value: 'example-3',
    isSelected: false,
    onChange: () => {}
  }, React.createElement(Box, {
    width: '100%',
    height: '75px'
  }))), React.createElement(SelectedStateCard, null, React.createElement(RadioCheckToggleCard, {
    cardType: 'toggle',
    name: 'states-toggle',
    title: 'Selected',
    value: 'example-1',
    isSelected: true,
    onChange: () => {}
  }, React.createElement(Box, {
    width: '100%',
    height: '75px'
  }))), React.createElement(SelectedHoverStateCard, null, React.createElement(RadioCheckToggleCard, {
    cardType: 'toggle',
    name: 'states-toggle',
    title: 'Selected Hover',
    value: 'example-2',
    isSelected: true,
    onChange: () => {}
  }, React.createElement(Box, {
    width: '100%',
    height: '75px'
  }))), React.createElement(SelectedFocusStateCard, null, React.createElement(RadioCheckToggleCard, {
    cardType: 'toggle',
    name: 'states-toggle',
    title: 'Selected Focus',
    value: 'example-3',
    isSelected: true,
    onChange: () => {}
  }, React.createElement(Box, {
    width: '100%',
    height: '75px'
  }))))), divider(), React.createElement(Section, {
    heading: 'Formatting'
  }, React.createElement(Text, {
    textStyle: 'subheading3',
    my: 3
  }, "Position"), React.createElement(Flex, {
    my: 4,
    flexWrap: 'wrap',
    style: {
      width: '65%',
      gap: '16px'
    }
  }, data.options.map(option => React.createElement(Box, {
    key: `${data.name}_${option.value}`,
    style: {
      flex: '1 1 45%'
    }
  }, React.createElement(RadioCheckToggleCard, {
    ...option,
    cardType: data.cardType,
    name: data.name,
    isSelected: examples['formatting-position'] === option.value,
    onChange: e => handleOnChange(e)({
      cardType: data.cardType,
      name: data.name
    })
  })))), React.createElement(Text, {
    textStyle: 'subheading3',
    my: 3
  }, "Label with children"), React.createElement(Flex, {
    my: 4,
    flexWrap: 'wrap',
    style: {
      width: '65%',
      gap: '16px'
    }
  }, React.createElement(Box, {
    style: {
      flex: '1 1 45%'
    }
  }, React.createElement(RadioCheckToggleCard, {
    cardType: 'checkbox',
    hPosition: 'left',
    isTakingFullHeightOfCard: true,
    isTitleBold: true,
    name: 'formatting-label-with-children',
    title: 'Title',
    value: 'example-1',
    isSelected: examples['formatting-label-with-children'].includes('example-1'),
    onChange: e => handleOnChange(e)({
      cardType: 'checkbox',
      name: 'formatting-label-with-children'
    })
  }, React.createElement(Text, {
    textStyle: 'paragraph',
    style: {
      marginTop: '8px'
    }
  }, dumpText))), React.createElement(Box, {
    style: {
      flex: '1 1 45%'
    }
  }, React.createElement(RadioCheckToggleCard, {
    cardType: 'checkbox',
    isTakingFullHeightOfCard: true,
    isTitleBold: true,
    name: 'formatting-label-with-children',
    title: 'Title',
    value: 'example-2',
    isSelected: examples['formatting-label-with-children'].includes('example-2'),
    onChange: e => handleOnChange(e)({
      cardType: 'checkbox',
      name: 'formatting-label-with-children'
    })
  }, React.createElement(Text, {
    textStyle: 'paragraph',
    style: {
      marginTop: '8px'
    }
  }, dumpText))), React.createElement(Box, {
    style: {
      flex: '1 1 45%'
    }
  }, React.createElement(RadioCheckToggleCard, {
    cardType: 'checkbox',
    hPosition: 'left',
    vPosition: 'center',
    isTakingFullHeightOfCard: true,
    isTitleBold: true,
    name: 'formatting-label-with-children',
    title: 'Title',
    value: 'example-3',
    isSelected: examples['formatting-label-with-children'].includes('example-3'),
    onChange: e => handleOnChange(e)({
      cardType: 'checkbox',
      name: 'formatting-label-with-children'
    })
  }, exampleImage())), React.createElement(Box, {
    style: {
      flex: '1 1 45%'
    }
  }, React.createElement(RadioCheckToggleCard, {
    cardType: 'checkbox',
    vPosition: 'center',
    isTakingFullHeightOfCard: true,
    isTitleBold: true,
    name: 'formatting-label-with-children',
    title: 'Title',
    value: 'example-4',
    isSelected: examples['formatting-label-with-children'].includes('example-4'),
    onChange: e => handleOnChange(e)({
      cardType: 'checkbox',
      name: 'formatting-label-with-children'
    })
  }, exampleImage()))), React.createElement(Text, {
    textStyle: 'subheading3',
    my: 3
  }, "Full width children"), React.createElement(Flex, {
    my: 4,
    flexWrap: 'wrap',
    style: {
      width: '65%',
      gap: '16px'
    }
  }, React.createElement(Box, {
    style: {
      flex: '1 1 45%'
    }
  }, React.createElement(RadioCheckToggleCard, {
    cardType: 'toggle',
    hPosition: 'left',
    name: 'formatting-full-width-children',
    title: 'Title',
    value: 'example-1',
    isSelected: examples['formatting-full-width-children'].includes('example-1'),
    onChange: e => handleOnChange(e)({
      cardType: 'toggle',
      name: 'formatting-full-width-children'
    })
  }, React.createElement(Text, {
    textStyle: 'paragraph',
    style: {
      marginTop: '8px'
    }
  }, dumpText), React.createElement(Button, {
    mt: 2,
    disabled: !examples['formatting-full-width-children'].includes('example-1')
  }, "Button"))), React.createElement(Box, {
    style: {
      flex: '1 1 45%'
    }
  }, React.createElement(RadioCheckToggleCard, {
    cardType: 'toggle',
    name: 'formatting-full-width-children',
    title: 'Title',
    value: 'example-2',
    isSelected: examples['formatting-full-width-children'].includes('example-2'),
    onChange: e => handleOnChange(e)({
      cardType: 'toggle',
      name: 'formatting-full-width-children'
    })
  }, React.createElement(Text, {
    textStyle: 'paragraph',
    style: {
      marginTop: '8px'
    }
  }, dumpText), React.createElement(Button, {
    mt: 2,
    disabled: !examples['formatting-full-width-children'].includes('example-2')
  }, "Button"))), React.createElement(Box, {
    style: {
      flex: '1 1 45%'
    }
  }, React.createElement(RadioCheckToggleCard, {
    cardType: 'toggle',
    hPosition: 'left',
    name: 'formatting-full-width-children',
    title: 'Title',
    value: 'example-3',
    isSelected: examples['formatting-full-width-children'].includes('example-3'),
    onChange: e => handleOnChange(e)({
      cardType: 'toggle',
      name: 'formatting-full-width-children'
    })
  }, exampleImage(), React.createElement(Text, {
    textStyle: 'paragraph',
    style: {
      marginTop: '8px'
    }
  }, dumpText), React.createElement(Button, {
    mt: 2,
    disabled: !examples['formatting-full-width-children'].includes('example-3')
  }, "Button"))), React.createElement(Box, {
    style: {
      flex: '1 1 45%'
    }
  }, React.createElement(RadioCheckToggleCard, {
    cardType: 'toggle',
    name: 'formatting-full-width-children',
    title: 'Title',
    value: 'example-4',
    isSelected: examples['formatting-full-width-children'].includes('example-4'),
    onChange: e => handleOnChange(e)({
      cardType: 'toggle',
      name: 'formatting-full-width-children'
    })
  }, exampleImage(), React.createElement(Text, {
    textStyle: 'paragraph',
    style: {
      marginTop: '8px'
    }
  }, dumpText), React.createElement(Button, {
    mt: 2,
    disabled: !examples['formatting-full-width-children'].includes('example-4')
  }, "Button"))))), divider(), React.createElement(Section, {
    heading: 'Additional Actions'
  }, React.createElement(Text, {
    textStyle: 'subheading3',
    my: 3
  }, "Buttons"), React.createElement(Text, {
    textStyle: 'paragraph',
    my: 3
  }, "In its checked state, by default the color is to be primary.base."), React.createElement(Flex, {
    my: 4,
    flexWrap: 'wrap',
    style: {
      width: '65%',
      gap: '16px'
    }
  }, React.createElement(Box, {
    style: {
      flex: '1 1 45%'
    }
  }, React.createElement(RadioCheckToggleCard, {
    name: 'additional-actions-buttons',
    title: 'Title',
    value: 'example-1',
    isSelected: examples['additional-actions-buttons'].includes('example-1'),
    onChange: e => handleOnChange(e)({
      cardType: 'radio',
      name: 'additional-actions-buttons'
    })
  }, exampleImage(), React.createElement(Text, {
    textStyle: 'paragraph',
    style: {
      marginTop: '8px'
    }
  }, dumpText), React.createElement(Button, {
    mt: 2,
    disabled: !examples['additional-actions-buttons'].includes('example-1')
  }, "I Select the Radio Card"))), React.createElement(Box, {
    style: {
      flex: '1 1 45%'
    }
  }, React.createElement(RadioCheckToggleCard, {
    name: 'additional-actions-buttons',
    title: 'Title',
    value: 'example-2',
    isSelected: examples['additional-actions-buttons'].includes('example-2'),
    onChange: e => handleOnChange(e)({
      cardType: 'radio',
      name: 'additional-actions-buttons'
    })
  }, exampleImage(), React.createElement(Text, {
    textStyle: 'paragraph',
    style: {
      marginTop: '8px'
    }
  }, dumpText), React.createElement(Button, {
    mt: 2,
    disabled: !examples['additional-actions-buttons'].includes('example-2')
  }, "I Select the Radio Card")))), React.createElement(Text, {
    textStyle: 'subheading3',
    my: 3
  }, "Forms"), React.createElement(Text, {
    textStyle: 'paragraph',
    my: 3
  }, "In its checked state, by default the color is to be primary.base."), React.createElement(Flex, {
    my: 4,
    flexWrap: 'wrap',
    style: {
      width: '100%',
      gap: '16px'
    }
  }, React.createElement(Box, {
    style: {
      flex: '1 1 45%'
    }
  }, React.createElement(RadioCheckToggleCard, {
    hPosition: 'left',
    isTakingFullHeightOfCard: true,
    name: 'additional-actions-forms-1',
    title: 'Title',
    value: 'example-1',
    isSelected: examples['additional-actions-forms-1'].includes('example-1'),
    onChange: e => handleOnChange(e)({
      cardType: 'radio',
      name: 'additional-actions-forms-1'
    })
  }, React.createElement(Text, {
    textStyle: 'paragraph',
    style: {
      marginTop: '8px'
    }
  }, dumpText), exampleInput({
    disabled: !examples['additional-actions-forms-1'].includes('example-1')
  }), exampleInput({
    disabled: !examples['additional-actions-forms-1'].includes('example-1')
  }))), React.createElement(Box, {
    style: {
      flex: '1 1 45%'
    }
  }, React.createElement(RadioCheckToggleCard, {
    hPosition: 'left',
    isTakingFullHeightOfCard: true,
    name: 'additional-actions-forms-1',
    title: 'Title',
    value: 'example-2',
    isSelected: examples['additional-actions-forms-1'].includes('example-2'),
    onChange: e => handleOnChange(e)({
      cardType: 'radio',
      name: 'additional-actions-forms-1'
    })
  }, React.createElement(Text, {
    textStyle: 'paragraph',
    style: {
      marginTop: '8px'
    }
  }, dumpText), exampleInput({
    disabled: !examples['additional-actions-forms-1'].includes('example-2')
  }), exampleInput({
    disabled: !examples['additional-actions-forms-1'].includes('example-2')
  })))), React.createElement(Text, {
    textStyle: 'paragraph',
    my: 3
  }, "with nested disabled function/action"), React.createElement(Flex, {
    my: 4,
    flexWrap: 'wrap',
    style: {
      width: '100%',
      gap: '16px'
    }
  }, React.createElement(Box, {
    style: {
      flex: '1 1 45%'
    }
  }, React.createElement(RadioCheckToggleCard, {
    hPosition: 'left',
    isTakingFullHeightOfCard: true,
    name: 'additional-actions-forms-2',
    title: 'Title',
    value: 'example-1',
    isSelected: examples['additional-actions-forms-2'].includes('example-1'),
    onChange: e => handleOnChange(e)({
      cardType: 'radio',
      name: 'additional-actions-forms-2'
    })
  }, React.createElement(Text, {
    textStyle: 'paragraph',
    style: {
      marginTop: '8px'
    }
  }, dumpText), exampleInput({
    disabled: !examples['additional-actions-forms-2'].includes('example-1')
  }), exampleInput({
    disabled: !examples['additional-actions-forms-2'].includes('example-1')
  }), React.createElement(Button, {
    mt: 2,
    disabled: !examples['additional-actions-forms-2'].includes('example-1')
  }, "I Select the Radio Card"))), React.createElement(Box, {
    style: {
      flex: '1 1 45%'
    }
  }, React.createElement(RadioCheckToggleCard, {
    hPosition: 'left',
    isTakingFullHeightOfCard: true,
    name: 'additional-actions-forms-2',
    title: 'Title',
    value: 'example-2',
    isSelected: examples['additional-actions-forms-2'].includes('example-2'),
    onChange: e => handleOnChange(e)({
      cardType: 'radio',
      name: 'additional-actions-forms-2'
    })
  }, React.createElement(Text, {
    textStyle: 'paragraph',
    style: {
      marginTop: '8px'
    }
  }, dumpText), exampleInput({
    disabled: !examples['additional-actions-forms-2'].includes('example-2')
  }), exampleInput({
    disabled: !examples['additional-actions-forms-2'].includes('example-2')
  }), React.createElement(Button, {
    mt: 2,
    disabled: !examples['additional-actions-forms-2'].includes('example-2')
  }, "I Select the Radio Card"))))), divider());
};
const meta = {
  title: 'Core / RadioCheckToggleCard',
  component: RadioCheckToggleCard,
  parameters: {
    design: {
      type: 'figma',
      url: 'https://www.figma.com/file/gpbXA3aonRBAJbQiZvrayO/Design-Ops-Dev-Week?type=design&node-id=2-1755&mode=dev'
    },
    docs: {
      page: () => React.createElement(DefaultDocPage, null)
    }
  }
};
export default meta;
export const Radio = {
  args: {
    cardType: 'radio',
    name: 'radio-card',
    title: 'Title'
  },
  argTypes,
  render: args => React.createElement(Section, {
    heading: args.cardType
  }, React.createElement(Flex, {
    flexDirection: 'column',
    style: {
      maxWidth: '350px',
      gap: '16px'
    }
  }, React.createElement(RadioCheckToggleCard, {
    value: 'example-1',
    isSelected: false,
    onChange: e => {},
    ...args
  }, React.createElement(Box, {
    width: '100%',
    height: '75px'
  })), React.createElement(RadioCheckToggleCard, {
    value: 'example-2',
    isSelected: false,
    onChange: e => {},
    ...args
  }, React.createElement(Text, {
    textStyle: 'paragraph'
  }, "I am some content. I am some content. I am some content. I am some content.")), React.createElement(RadioCheckToggleCard, {
    value: 'example-3',
    isSelected: false,
    onChange: e => {},
    ...args
  }, React.createElement(Text, {
    textStyle: 'paragraph'
  }, "I am some content. I am some content. I am some content. I am some content."), React.createElement(Button, {
    mt: 2,
    width: '100%'
  }, "Button")), React.createElement(RadioCheckToggleCard, {
    value: 'example-4',
    isSelected: false,
    onChange: e => {},
    ...args
  }, exampleImage())))
};
export const Checkbox = {
  args: {
    ...Radio.args,
    cardType: 'checkbox',
    name: 'checkbox-card'
  },
  argTypes,
  render: Radio.render
};
export const Toggle = {
  args: {
    ...Radio.args,
    cardType: 'toggle',
    name: 'toggle-card'
  },
  argTypes,
  render: Radio.render
};