import React from 'react';
import styled from 'styled-components';
import { Box } from '../Box/Box';
import { Divider } from '../Divider/Divider';
import { colorSchemeNames } from '../storybook/args';
import { textStylesValues } from '../utils/attrs/typographyAttrs';
import { getTextColorOn } from '../utils/utils';
import { Text } from './Text';
import { argTypes, defaultArgs } from './Text.stories.args';
export default {
  title: 'Typography / Text',
  component: Text,
  args: defaultArgs,
  argTypes,
  parameters: {
    docs: {
      description: {
        component: 'A low-level component for setting font-size, typographic styles, margin, and color'
      }
    }
  }
};
const Template = args => React.createElement(Box, null, React.createElement(Text, {
  m: 3,
  ...args
}, "Hello there."), React.createElement(Text, {
  m: 3,
  ...args
}, "The quick brown fox jumps over the lazy dog to discover new deals every day."));
export const TextStyle = Template.bind({});
export const TextStyleGallery = () => React.createElement(Box, null, textStylesValues.map(textStyle => React.createElement(Box, {
  mb: 5,
  key: textStyle
}, React.createElement(Text, {
  textStyle: textStyle
}, "The quick brown fox jumps over the lazy dog to discover new deals every day."), React.createElement(Text, {
  my: 2,
  color: 'text.tint',
  textStyle: 'subheading5'
}, textStyle))));
export const TextStyleResponsive = Template.bind({});
TextStyleResponsive.args = {
  textStyle: ['heading6', 'heading5', 'heading4', 'heading3', 'heading2', 'heading1']
};
export const FontSize = () => React.createElement("div", null, React.createElement(Text, {
  fontSize: 6
}, "Hello 6"), React.createElement(Text, {
  fontSize: 5
}, "Hello 5"), React.createElement(Text, {
  fontSize: 4
}, "Hello 4"), React.createElement(Text, {
  fontSize: 3
}, "Hello 3"), React.createElement(Text, {
  fontSize: 2
}, "Hello 2"), React.createElement(Text, {
  fontSize: 1
}, "Hello 1"), React.createElement(Text, {
  fontSize: 0
}, "Hello 0"));
export const FontStyle = () => React.createElement("div", null, React.createElement(Text, {
  fontStyle: 'italic'
}, "Hello Italic"), React.createElement(Text, {
  fontStyle: 'oblique'
}, "Hello Oblique"));
export const TextAlign = () => React.createElement("div", null, React.createElement(Text, {
  textAlign: 'left'
}, "Hello Left"), React.createElement(Text, {
  textAlign: 'center'
}, "Hello Center"), React.createElement(Text, {
  textAlign: 'right'
}, "Hello Right"));
export const TextDecoration = () => React.createElement("div", null, React.createElement(Text, {
  textDecoration: 'overline'
}, "Hello Overline"), React.createElement(Text, {
  textDecoration: 'line-through'
}, "Hello Line-Through"), React.createElement(Text, {
  textDecoration: 'underline'
}, "Hello Underline"));
export const TextTransform = () => React.createElement("div", null, React.createElement(Text, {
  textTransform: 'capitalize'
}, "hello capitalize"), React.createElement(Text, {
  textTransform: 'uppercase'
}, "hello uppercase"), React.createElement(Text, {
  textTransform: 'lowercase'
}, "HELLO LOWERCASE"), React.createElement(Text, {
  textTransform: 'none'
}, "Hello none"), React.createElement(Text, {
  textTransform: 'uppercase',
  textStyle: 'heading5'
}, "hello uppercase heading5"));
export const Regular = () => React.createElement(Text, {
  regular: true
}, "Hello Regular");
export const Bold = () => React.createElement(Text, {
  bold: true
}, "Hello Bold");
export const Caps = () => React.createElement(Text, {
  caps: true
}, "Hello Caps");
export const Italic = () => React.createElement(Text, {
  italic: true
}, "Hello italic");
export const Strikethrough = () => React.createElement(Text.s, null, "Hello Strikethrough");
export const Margin = () => React.createElement(Text, {
  mt: 4,
  mb: 2
}, "Hello Margin");
export const Color = () => React.createElement("div", null, React.createElement(Text, {
  color: 'blue'
}, "Hello Blue"), React.createElement(Text, {
  color: 'green'
}, "Hello Green"));
const ReactiveText = /*#__PURE__*/styled(Text).withConfig({
  displayName: "Textstories__ReactiveText",
  componentId: "sc-1etsznv-0"
})(["color:", ";"], props => getTextColorOn(props.backgroundColor, props.lightColor, props.darkColor)(props));
const ReactiveColorTemplate = args => React.createElement(React.Fragment, null, React.createElement(Text, {
  mb: 2
}, "Uses the ", React.createElement("code", null, "getTextColorOn"), " utility"), React.createElement(Box, {
  color: args.backgroundColor,
  p: 2,
  width: 300
}, React.createElement(ReactiveText, {
  ...args
}, args.children)), React.createElement(Box, {
  color: 'primary.light',
  p: 2,
  width: 300
}, React.createElement(ReactiveText, {
  ...args,
  backgroundColor: 'background.lightest'
}, args.children)));
export const ReactiveColor = ReactiveColorTemplate.bind({});
ReactiveColor.args = {
  children: 'Hello There',
  backgroundColor: 'primary.base',
  lightColor: 'text.lightest',
  darkColor: 'text.base'
};
export const MinMaxHeight = () => React.createElement("div", null, React.createElement(Text, {
  color: 'blue',
  minHeight: 200,
  minWidth: 300,
  width: 1
}, "Hello Blue"), React.createElement(Text, {
  color: 'green',
  maxHeight: 200,
  maxWidth: 300
}, "Hello Green"));
export const HideOnLgBreakpoints = () => React.createElement("div", null, React.createElement(Text, {
  color: 'primary',
  display: [null, null, null, 'none'],
  fontSize: 4,
  width: 1
}, "Hidden text on larger screens"), React.createElement(Text, {
  color: 'secondary',
  fontSize: 4,
  width: 1
}, "I am always show. But the text above, hides on larger screens."));
export const Span = () => React.createElement(Text, null, "Just some text ", React.createElement(Text.span, {
  bold: true
}, "Some span text"), " Just some more text");
export const Paragraph = () => React.createElement(Text.p, null, "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.");
export const ResponsiveTypographyVsFontSize = () => React.createElement(React.Fragment, null, React.createElement(Text, null, "Actual (heading):"), React.createElement(Text, {
  textStyle: ['heading2', null, null, 'heading1']
}, "Words and stuff heading textStyle"), React.createElement(Text, null, "Expected (heading):"), React.createElement(Text, {
  bold: true,
  fontSize: ['5', null, null, '6']
}, "Words and stuff heading fontSize"), React.createElement(Divider, null), React.createElement(Text, null, "Actual (subheading):"), React.createElement(Text, {
  textStyle: ['subheading4', null, null, 'subheading3']
}, "Words and stuff subheading textStyle"), React.createElement(Text, null, "Expected (subheading):"), React.createElement(Text, {
  fontSize: ['3', null, null, '4']
}, "Words and stuff subheading"));
const ColorSchemesTemplate = () => {
  return React.createElement(React.Fragment, null, colorSchemeNames.map(colorScheme => React.createElement(Text, {
    m: 3,
    p: 3,
    colorScheme: colorScheme,
    key: colorScheme,
    textStyle: 'heading1'
  }, React.createElement(Text, null, colorScheme))));
};
export const ColorSchemes = ColorSchemesTemplate.bind({});
ColorSchemesTemplate.args = {};