"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const theme_1 = require("../theme/theme");
const BackgroundImage_1 = require("./BackgroundImage");
describe('BackgroundImage', () => {
    test('renders', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(BackgroundImage_1.BackgroundImage, null)).toJSON();
        expect(json).toMatchSnapshot();
    });
    test('renders with image', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(BackgroundImage_1.BackgroundImage, { image: 'hello.png' })).toJSON();
        expect(json).toMatchSnapshot();
    });
    test('renders with height', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(BackgroundImage_1.BackgroundImage, { height: '320px' })).toJSON();
        expect(json).toMatchSnapshot();
    });
    test('renders with border radius', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(BackgroundImage_1.BackgroundImage, { height: '320px', borderRadius: 'full', rounded: 'top' })).toJSON();
        expect(json).toMatchSnapshot();
        const { borderRadii: { full }, } = theme_1.theme;
        expect(json).toHaveStyleRule('border-radius', `${full} ${full} 0 0`);
    });
    test('renders with background position', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(BackgroundImage_1.BackgroundImage, { height: '320px', borderRadius: 'full', rounded: 'top', backgroundPosition: 'top' })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('background-position', 'top');
    });
    test('renders with default background position', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(BackgroundImage_1.BackgroundImage, { height: '320px', borderRadius: 'full', rounded: 'top' })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('background-position', 'center');
    });
    describe('variations', () => {
        describe('parallax variation', () => {
            test('default render', () => {
                const json = rendererCreateWithTheme(react_1.default.createElement(BackgroundImage_1.BackgroundImage, { variation: 'parallax', image: 'hello.png' })).toJSON();
                expect(json).toMatchSnapshot();
                expect(json).toHaveStyleRule('background-attachment', 'fixed');
            });
        });
    });
});
//# sourceMappingURL=BackgroundImage.spec.js.map