"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const testing_library_1 = require("../__test__/testing-library");
const theme_1 = require("../theme");
const Badge_1 = require("./Badge");
describe('Badge', () => {
    let consoleError;
    beforeEach(() => {
        consoleError = console.error;
        console.error = jest.fn();
    });
    afterEach(() => (console.error = consoleError));
    test('renders', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Badge_1.Badge, null)).toJSON();
        expect(json).toMatchSnapshot();
    });
    test('renders small', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Badge_1.Badge, { size: 'small' })).toJSON();
        expect(json).toMatchSnapshot();
    });
    test('bg green sets background-color and color', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Badge_1.Badge, { bg: 'green' })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('background-color', theme_1.theme.colors.green);
        expect(json).toHaveStyleRule('color', theme_1.theme.colors.white);
    });
    test('bg lightGreen sets background-color and color', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Badge_1.Badge, { bg: 'lightGreen' })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('background-color', theme_1.theme.colors.lightGreen);
        expect(json).toHaveStyleRule('color', theme_1.theme.colors.darkGreen);
    });
    test('bg red sets background-color and color', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Badge_1.Badge, { bg: 'red' })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('background-color', theme_1.theme.colors.red);
        expect(json).toHaveStyleRule('color', theme_1.theme.colors.white);
    });
    test('bg lightRed sets background-color and color', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Badge_1.Badge, { bg: 'lightRed' })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('background-color', theme_1.theme.colors.lightRed);
        expect(json).toHaveStyleRule('color', theme_1.theme.colors.darkRed);
    });
    test('bg orange sets background-color and color', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Badge_1.Badge, { bg: 'orange' })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('background-color', theme_1.theme.colors.orange);
        expect(json).toHaveStyleRule('color', theme_1.theme.colors.text);
    });
    test('bg blue sets background-color and color', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Badge_1.Badge, { bg: 'blue' })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('background-color', theme_1.theme.colors.blue);
        expect(json).toHaveStyleRule('color', theme_1.theme.colors.white);
    });
    test('bg lightBlue sets background-color and color', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Badge_1.Badge, { bg: 'lightBlue' })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('background-color', theme_1.theme.colors.lightBlue);
        expect(json).toHaveStyleRule('color', theme_1.theme.colors.darkBlue);
    });
    test('non-preset: bg text sets background-color and color white sets color', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Badge_1.Badge, { bg: 'text', color: 'white' })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('background-color', theme_1.theme.colors.text);
        expect(json).toHaveStyleRule('color', theme_1.theme.colors.white);
    });
    test('can escape preset: bg lightBlue sets background-color and color text sets color', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Badge_1.Badge, { bg: 'lightBlue', color: 'text' })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('background-color', theme_1.theme.colors.lightBlue);
        expect(json).toHaveStyleRule('color', theme_1.theme.colors.text);
    });
    test('textTransform', () => {
        (0, testing_library_1.render)(react_1.default.createElement(Badge_1.Badge, { textTransform: 'lowercase' }, "Lowercase Text"));
        expect(testing_library_1.screen.getByText('Lowercase Text')).toHaveStyleRule('text-transform', 'lowercase');
        expect(testing_library_1.screen.getByText('Lowercase Text')).toHaveStyleRule('letter-spacing', 'normal');
    });
    test('size', () => {
        (0, testing_library_1.render)(react_1.default.createElement(Badge_1.Badge, { size: 'captionMedium' }, "Caption"));
        expect(testing_library_1.screen.getByText('Caption')).toHaveStyleRule('padding-right', theme_1.theme.space[2]);
    });
});
//# sourceMappingURL=Badge.spec.js.map