"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Banner = void 0;
const pcln_icons_1 = require("pcln-icons");
const react_1 = __importDefault(require("react"));
const styled_components_1 = __importDefault(require("styled-components"));
const Box_1 = require("../Box/Box");
const CloseButton_1 = require("../CloseButton/CloseButton");
const Flex_1 = require("../Flex/Flex");
const Text_1 = require("../Text/Text");
const utils_1 = require("../utils/utils");
const bannerColors = {
    green: {
        backgroundColor: 'secondary.base',
        color: 'text.lightest',
        icon: react_1.default.createElement(pcln_icons_1.Success, null),
    },
    lightGreen: {
        backgroundColor: 'secondary.light',
        color: 'secondary.dark',
        icon: react_1.default.createElement(pcln_icons_1.Success, null),
    },
    red: {
        backgroundColor: 'error.base',
        color: 'text.lightest',
        icon: react_1.default.createElement(pcln_icons_1.Warning, null),
    },
    lightRed: {
        backgroundColor: 'error.light',
        color: 'error.dark',
        icon: react_1.default.createElement(pcln_icons_1.Warning, null),
    },
    orange: {
        backgroundColor: 'alert.base',
        color: 'text.lightest',
        icon: react_1.default.createElement(pcln_icons_1.Attention, null),
    },
    blue: {
        backgroundColor: 'primary.base',
        color: 'text.lightest',
        icon: react_1.default.createElement(pcln_icons_1.Information, null),
    },
    lightBlue: {
        backgroundColor: 'primary.light',
        color: 'primary.dark',
        icon: react_1.default.createElement(pcln_icons_1.Information, null),
    },
};
const StyledBox = (0, styled_components_1.default)(Box_1.Box) `
  ${(0, utils_1.applyVariations)('Banner')}
`;
/**
 * @public
 */
function Banner(props) {
    const bannerColor = bannerColors[!props.bg && props.color === 'green' ? props.color : props.bg] || {};
    const Icon = props.icon || bannerColor.icon;
    const color = !bannerColor.color ? props.color : bannerColor.color;
    let header = null;
    if (props.header) {
        header = react_1.default.isValidElement(props.header) ? (props.header) : (react_1.default.createElement(Text_1.Text, { textStyle: 'display2' }, props.header));
    }
    return (react_1.default.createElement(StyledBox, { ...props, bg: bannerColor.backgroundColor || props.bg, color: color },
        react_1.default.createElement(Flex_1.Flex, { justifyContent: 'space-between', alignItems: 'flex-start' },
            !!Icon && !!props.showIcon && react_1.default.cloneElement(Icon, { mr: 2, size: 24, mt: '-2px' }),
            react_1.default.createElement(Box_1.Box, { textAlign: props.textAlign, width: 1 },
                header,
                react_1.default.createElement(Text_1.Text.span, { fontSize: 1 }, props.text),
                props.children),
            !!props.onClose && react_1.default.createElement(CloseButton_1.CloseButton, { onClick: props.onClose, ml: 2, size: 24, title: 'close', mt: '-2px' }))));
}
exports.Banner = Banner;
Banner.displayName = 'Banner';
Banner.defaultProps = {
    textAlign: 'left',
    showIcon: true,
    color: 'green',
};
//# sourceMappingURL=Banner.js.map