"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const pcln_icons_1 = require("pcln-icons");
const react_1 = __importDefault(require("react"));
const Banner_1 = require("../Banner/Banner");
const Heading_1 = require("../Heading/Heading");
const Text_1 = require("../Text/Text");
const testing_library_1 = require("../__test__/testing-library");
const theme_1 = require("../theme/theme");
describe('Banner', () => {
    let consoleError;
    beforeEach(() => {
        consoleError = console.error;
        console.error = jest.fn();
    });
    afterEach(() => (console.error = consoleError));
    test('renders with no props other than theme', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Banner_1.Banner, null)).toJSON();
        expect(json).toMatchSnapshot();
    });
    test('renders with an icon', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Banner_1.Banner, { icon: react_1.default.createElement(pcln_icons_1.Star, null) })).toJSON();
        expect(json).toMatchSnapshot();
    });
    test('renders with text string', () => {
        const { asFragment } = (0, testing_library_1.render)(react_1.default.createElement(Banner_1.Banner, { header: 'Header', text: 'Text', icon: react_1.default.createElement(pcln_icons_1.Star, null) }));
        expect(asFragment()).toMatchSnapshot();
    });
    test('renders with text node', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Banner_1.Banner, { header: 'Header', text: react_1.default.createElement(Text_1.Text, null, "Text"), icon: react_1.default.createElement(pcln_icons_1.Star, null) })).toJSON();
        expect(json).toMatchSnapshot();
    });
    test('renders with blue bg', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Banner_1.Banner, { bg: 'blue' })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('background-color', theme_1.theme.colors.blue);
        expect(json).toHaveStyleRule('color', theme_1.theme.colors.white);
    });
    test('renders with green bg', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Banner_1.Banner, { bg: 'green' })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('background-color', theme_1.theme.colors.green);
        expect(json).toHaveStyleRule('color', theme_1.theme.colors.white);
    });
    test('renders with orange bg', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Banner_1.Banner, { bg: 'orange' })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('background-color', theme_1.theme.colors.orange);
        expect(json).toHaveStyleRule('color', theme_1.theme.colors.white);
    });
    test('renders with red bg', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Banner_1.Banner, { bg: 'red' })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('background-color', theme_1.theme.colors.red);
        expect(json).toHaveStyleRule('color', theme_1.theme.colors.white);
    });
    test('renders with lightBlue bg', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Banner_1.Banner, { bg: 'lightBlue' })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('background-color', theme_1.theme.colors.lightBlue);
        expect(json).toHaveStyleRule('color', theme_1.theme.colors.darkBlue);
    });
    test('renders with lightGreen bg', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Banner_1.Banner, { bg: 'lightGreen' })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('background-color', theme_1.theme.colors.lightGreen);
        expect(json).toHaveStyleRule('color', theme_1.theme.colors.darkGreen);
    });
    test('renders with lightRed bg', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Banner_1.Banner, { bg: 'lightRed' })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('background-color', theme_1.theme.colors.lightRed);
        expect(json).toHaveStyleRule('color', theme_1.theme.colors.darkRed);
    });
    test('renders close button if onClose func is provided', () => {
        function noop() { }
        const { container } = (0, testing_library_1.render)(react_1.default.createElement(Banner_1.Banner, { onClose: noop }));
        const closeButton = container.querySelector('button');
        expect(closeButton).toBeTruthy();
    });
    test('does render blue left-hand icon by default', () => {
        const { container } = (0, testing_library_1.render)(react_1.default.createElement(Banner_1.Banner, { bg: 'blue' }));
        const icon = container.querySelector('svg');
        // todo: check svg path/attrs for correct icon
        expect(icon).toBeTruthy();
    });
    test('does not render blue left-hand icon if showIcon is false', () => {
        const { container } = (0, testing_library_1.render)(react_1.default.createElement(Banner_1.Banner, { bg: 'blue', showIcon: false }));
        const icon = container.querySelector('svg');
        expect(icon).toBeFalsy();
    });
    test('accepts non-preset colors', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Banner_1.Banner, { bg: 'gray' })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('background-color', theme_1.theme.colors.gray);
    });
    test('renders content from children props', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Banner_1.Banner, null,
            react_1.default.createElement("span", null, "123"))).toJSON();
        expect(json).toMatchSnapshot();
    });
    test('renders with header node', () => {
        const { asFragment, getByText } = (0, testing_library_1.render)(react_1.default.createElement(Banner_1.Banner, { header: react_1.default.createElement(Heading_1.Heading, null, "Hello world"), text: react_1.default.createElement(Text_1.Text, null, "Text") }));
        getByText(/Hello world/);
        expect(asFragment()).toMatchSnapshot();
    });
});
//# sourceMappingURL=Banner.spec.js.map