"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const testing_library_1 = require("../__test__/testing-library");
const theme_1 = require("../theme/theme");
const Box_1 = require("./Box");
describe('Box', () => {
    test('renders', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Box_1.Box, null)).toJSON();
        expect(json).toMatchSnapshot();
    });
    test('width and height props set width/height', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Box_1.Box, { width: 1 / 2, height: '50%' })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('height', '50%');
        expect(json).toHaveStyleRule('width', '50%');
    });
    test('m prop sets margin', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Box_1.Box, { m: 2 })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('margin', theme_1.theme.space[2]);
    });
    test('maxHeight, maxWidth, minHeight, minWidth', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Box_1.Box, { maxHeight: 250, maxWidth: 250, minHeight: 55, minWidth: 55 })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('max-height', '250px');
        expect(json).toHaveStyleRule('max-width', '250px');
        expect(json).toHaveStyleRule('min-height', '55px');
        expect(json).toHaveStyleRule('min-width', '55px');
    });
    test('p prop sets padding', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Box_1.Box, { p: 2 })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('padding', theme_1.theme.space[2]);
    });
    test('color prop sets color', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Box_1.Box, { color: 'blue' })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('color', theme_1.theme.colors.blue);
    });
    test('boxShadowSize prop sets box-shadow', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Box_1.Box, { boxShadowSize: 'sm' })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('box-shadow', theme_1.theme.shadows.sm);
    });
    test('overflow prop sets overflow', () => {
        const { asFragment, getByTestId } = (0, testing_library_1.render)(react_1.default.createElement(Box_1.Box, { overflow: 'scroll', "data-testid": 'Box' }));
        expect(asFragment()).toMatchSnapshot();
        expect(getByTestId('Box')).toHaveStyleRule('overflow', 'scroll');
    });
});
//# sourceMappingURL=Box.spec.js.map