"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const pcln_icons_1 = require("pcln-icons");
const react_1 = __importDefault(require("react"));
const styled_components_1 = __importDefault(require("styled-components"));
const testing_library_1 = require("../__test__/testing-library");
const theme_1 = require("../theme/theme");
const boxShadowAttrs_1 = require("../utils/attrs/boxShadowAttrs");
const createTheme_1 = require("../utils/createTheme");
const Button_1 = require("./Button");
const theme = (0, createTheme_1.createTheme)();
const StyledButton = (0, styled_components_1.default)(Button_1.Button) `
  padding: 100px;
`;
const consoleError = console.error;
afterEach(() => {
    console.error = consoleError;
});
describe('Button', () => {
    it('should render correctly with no props', () => {
        const { getByRole } = (0, testing_library_1.render)(react_1.default.createElement(Button_1.Button, null, "BUTTON"));
        const button = getByRole('button');
        expect(button).toHaveStyleRule('background-color', theme.palette.primary.base);
        expect(button).toHaveStyleRule('color', theme.palette.text.lightest);
        expect(button).toHaveStyleRule('background-color', theme.palette.primary.dark, {
            modifier: ':hover',
        });
        expect(button).toHaveStyleRule('color', theme.palette.text.lightest, {
            modifier: ':hover',
        });
    });
    it('should render correctly when disabled', () => {
        const { getByRole } = (0, testing_library_1.render)(react_1.default.createElement(Button_1.Button, { disabled: true }, "BUTTON"));
        const button = getByRole('button');
        expect(button).toHaveStyleRule('background-color', theme.palette.primary.light);
        expect(button).toHaveStyleRule('color', theme.palette.text.base);
        expect(button).toHaveStyleRule('cursor', 'not-allowed', {
            modifier: ':disabled',
        });
        expect(button).toHaveStyleRule('background-color', theme.palette.primary.light, {
            modifier: ':hover',
        });
        expect(button).toHaveStyleRule('color', theme.palette.text.base);
    });
    it('should render correctly for "size" prop', () => {
        const { getByRole, rerender } = (0, testing_library_1.render)(react_1.default.createElement(Button_1.Button, null, "BUTTON"));
        const button = getByRole('button');
        expect(button).toHaveStyleRule('font-size', '14px');
        expect(button).toHaveStyleRule('padding', '9.5px 18px');
        rerender(react_1.default.createElement(Button_1.Button, { size: 'small' }, "BUTTON"));
        expect(button).toHaveStyleRule('font-size', '12px');
        expect(button).toHaveStyleRule('padding', '7px 12px');
        rerender(react_1.default.createElement(Button_1.Button, { size: 'medium' }, "BUTTON"));
        expect(button).toHaveStyleRule('font-size', '14px');
        expect(button).toHaveStyleRule('padding', '9.5px 18px');
        rerender(react_1.default.createElement(Button_1.Button, { size: 'large' }, "BUTTON"));
        expect(button).toHaveStyleRule('font-size', '16px');
        expect(button).toHaveStyleRule('padding', '12px 22px');
        rerender(react_1.default.createElement(Button_1.Button, { size: 'extraLarge' }, "BUTTON"));
        expect(button).toHaveStyleRule('font-size', '16px');
        expect(button).toHaveStyleRule('padding', '16px 22px');
    });
    it('should render correctly for "IconLeft" and "IconRight"', () => {
        const { getByRole, rerender } = (0, testing_library_1.render)(react_1.default.createElement(Button_1.Button, { IconLeft: pcln_icons_1.User }, "BUTTON"));
        const button = getByRole('button');
        expect(button).toHaveStyleRule('font-size', '14px');
        expect(button).toHaveStyleRule('padding', '8px 20px 8px 16px');
        rerender(react_1.default.createElement(Button_1.Button, { size: 'small', IconRight: pcln_icons_1.User }));
        expect(button).toHaveStyleRule('font-size', '12px');
        expect(button).toHaveStyleRule('padding', '7px 12px');
        rerender(react_1.default.createElement(Button_1.Button, { size: 'medium' }, "BUTTON"));
        expect(button).toHaveStyleRule('font-size', '14px');
        expect(button).toHaveStyleRule('padding', '9.5px 18px');
        rerender(react_1.default.createElement(Button_1.Button, { size: 'large' }, "BUTTON"));
        expect(button).toHaveStyleRule('font-size', '16px');
        expect(button).toHaveStyleRule('padding', '12px 22px');
        rerender(react_1.default.createElement(Button_1.Button, { size: 'extraLarge' }, "BUTTON"));
        expect(button).toHaveStyleRule('font-size', '16px');
        expect(button).toHaveStyleRule('padding', '16px 22px');
    });
    it('should render correctly for "width" prop', () => {
        const { getByRole, rerender } = (0, testing_library_1.render)(react_1.default.createElement(Button_1.Button, null, "BUTTON"));
        const button = getByRole('button');
        expect(button).toHaveStyleRule('width', undefined);
        rerender(react_1.default.createElement(Button_1.Button, { width: 1 }, "BUTTON"));
        expect(button).toHaveStyleRule('width', '100%');
        rerender(react_1.default.createElement(Button_1.Button, { width: 1 / 2 }, "BUTTON"));
        expect(button).toHaveStyleRule('width', '50%');
        rerender(react_1.default.createElement(Button_1.Button, { width: 100 }, "BUTTON"));
        expect(button).toHaveStyleRule('width', '100px');
        rerender(react_1.default.createElement(Button_1.Button, { width: '3em' }, "BUTTON"));
        expect(button).toHaveStyleRule('width', '3em');
    });
    it('should render correctly for "height" prop', () => {
        const { getByRole, rerender } = (0, testing_library_1.render)(react_1.default.createElement(Button_1.Button, null, "BUTTON"));
        const button = getByRole('button');
        expect(button).toHaveStyleRule('height', undefined);
        rerender(react_1.default.createElement(Button_1.Button, { height: 60 }, "BUTTON"));
        expect(button).toHaveStyleRule('height', '60px');
    });
    it('should render correctly for "title" prop', () => {
        const { getByTitle } = (0, testing_library_1.render)(react_1.default.createElement(Button_1.Button, { title: 'button title' }, "BUTTON"));
        expect(getByTitle('button title')).toHaveAttribute('aria-label', 'button title');
    });
    it('should forward the "aria-label" prop', () => {
        const label = 'i am an aria label';
        const { getByLabelText } = (0, testing_library_1.render)(react_1.default.createElement(Button_1.Button, { "aria-label": label }, "BUTTON"));
        expect(getByLabelText(label)).toHaveAttribute('aria-label', label);
    });
    it('should render correctly for "borderRadius" prop', () => {
        const { getByRole, rerender } = (0, testing_library_1.render)(react_1.default.createElement(Button_1.Button, { size: 'medium' }, "BUTTON"));
        const button = getByRole('button');
        expect(button).toHaveStyleRule('border-radius', theme_1.borderRadii['action-md']);
        rerender(react_1.default.createElement(Button_1.Button, { size: 'small', borderRadius: '' }, "BUTTON"));
        expect(button).toHaveStyleRule('border-radius', theme_1.borderRadii['action-sm']);
        rerender(react_1.default.createElement(Button_1.Button, { size: 'small', borderRadius: 'none' }, "BUTTON"));
        expect(button).toHaveStyleRule('border-radius', theme_1.borderRadii.none);
        rerender(react_1.default.createElement(Button_1.Button, { size: 'medium', borderRadius: 'sm' }, "BUTTON"));
        expect(button).toHaveStyleRule('border-radius', theme_1.borderRadii.sm);
        rerender(react_1.default.createElement(Button_1.Button, { size: 'large', borderRadius: 'md' }, "BUTTON"));
        expect(button).toHaveStyleRule('border-radius', theme_1.borderRadii.md);
        rerender(
        // @ts-ignore
        react_1.default.createElement(Button_1.Button, { size: 'large', borderRadius: 'NOT VALID' }, "BUTTON"));
        expect(button).toHaveStyleRule('border-radius', theme_1.borderRadii['action-lg']);
        rerender(react_1.default.createElement(Button_1.Button, { size: 'large', borderRadius: 'xl' }, "BUTTON"));
        expect(button).toHaveStyleRule('border-radius', theme_1.borderRadii.xl);
        rerender(
        // @ts-ignore
        react_1.default.createElement(Button_1.Button, { size: 'extraLarge', borderRadius: 'notValid' }, "BUTTON"));
        expect(button).toHaveStyleRule('border-radius', theme_1.borderRadii['action-xl']);
    });
    it('should render correctly for "boxShadowSize" prop', () => {
        const { getByRole, rerender } = (0, testing_library_1.render)(react_1.default.createElement(Button_1.Button, null, "BUTTON"));
        const button = getByRole('button');
        expect(button).toHaveStyleRule('box-shadow', undefined);
        Array.from(boxShadowAttrs_1.boxShadowSizeValues).forEach((size) => {
            // @ts-ignore
            rerender(react_1.default.createElement(Button_1.Button, { boxShadowSize: size }, "BUTTON"));
            expect(button).toHaveStyleRule('box-shadow', theme_1.shadows[size]);
        });
    });
    it('should render correctly for extraLarge size', () => {
        const { getByRole } = (0, testing_library_1.render)(react_1.default.createElement(Button_1.Button, { borderRadius: 'xl', size: 'extraLarge' }, "BUTTON"));
        const button = getByRole('button');
        expect(button).toHaveStyleRule('border-radius', '16px');
        expect(button).toHaveStyleRule('font-size', '16px');
        expect(button).toHaveStyleRule('padding', '16px 22px');
    });
    describe('variations', () => {
        describe('fill variation', () => {
            it('should render correctly', () => {
                const { getByRole } = (0, testing_library_1.render)(react_1.default.createElement(Button_1.Button, { variation: 'fill' }, "BUTTON"));
                const button = getByRole('button');
                expect(button).toHaveStyleRule('color', theme.palette.text.lightest);
                expect(button).toHaveStyleRule('background-color', theme.palette.primary.base);
                expect(button).toHaveStyleRule('color', theme.palette.text.lightest, {
                    modifier: ':hover',
                });
                expect(button).toHaveStyleRule('background-color', theme.palette.primary.dark, {
                    modifier: ':hover',
                });
                expect(button).toHaveStyleRule('outline', `0px solid ${theme.palette.primary.dark}`, {
                    modifier: ':focus-visible',
                });
                expect(button).toHaveStyleRule('box-shadow', `0 0 0 2px ${theme.palette.primary.dark}`, {
                    modifier: ':focus-visible',
                });
            });
            it('should render correctly when disabled', () => {
                const { getByRole } = (0, testing_library_1.render)(react_1.default.createElement(Button_1.Button, { variation: 'fill', disabled: true }, "BUTTON"));
                const button = getByRole('button');
                expect(button).toHaveStyleRule('color', theme.palette.text.base);
                expect(button).toHaveStyleRule('background-color', theme.palette.primary.light);
                expect(button).toHaveStyleRule('background-color', theme.palette.primary.light, {
                    modifier: ':hover',
                });
            });
        });
        describe('outline variation', () => {
            it('should render correctly', () => {
                const { getByRole } = (0, testing_library_1.render)(react_1.default.createElement(Button_1.Button, { variation: 'outline' }, "BUTTON"));
                const button = getByRole('button');
                expect(button).toHaveStyleRule('color', theme.palette.primary.base);
                expect(button).toHaveStyleRule('background-color', 'transparent');
                expect(button).toHaveStyleRule('background-color', 'transparent', {
                    modifier: ':hover',
                });
                expect(button).toHaveStyleRule('color', theme.palette.primary.dark, {
                    modifier: ':hover',
                });
                expect(button).toHaveStyleRule('box-shadow', `inset 0 0 0 2px ${theme.palette.primary.dark}`, {
                    modifier: ':hover',
                });
            });
            it('should render correctly when disabled', () => {
                const { getByRole } = (0, testing_library_1.render)(react_1.default.createElement(Button_1.Button, { variation: 'outline', disabled: true }, "BUTTON"));
                const button = getByRole('button');
                expect(button).toHaveStyleRule('color', theme.palette.primary.light);
                expect(button).toHaveStyleRule('background-color', 'transparent');
            });
        });
        describe('link variation', () => {
            it('should render correctly', () => {
                const { getByRole } = (0, testing_library_1.render)(react_1.default.createElement(Button_1.Button, { variation: 'link' }, "BUTTON"));
                const button = getByRole('button');
                expect(button).toHaveStyleRule('color', theme.palette.primary.base);
                expect(button).toHaveStyleRule('vertical-align', 'inherit');
                expect(button).toHaveStyleRule('-webkit-font-smoothing', 'inherit');
                expect(button).toHaveStyleRule('font-weight', '500');
                expect(button).toHaveStyleRule('line-height', '1.4');
                expect(button).toHaveStyleRule('padding', '0px');
                expect(button).toHaveStyleRule('color', theme.palette.primary.dark, {
                    modifier: ':hover',
                });
                expect(button).toHaveStyleRule('text-decoration', 'underline', {
                    modifier: ':hover',
                });
            });
            it('should render correctly when disabled', () => {
                const { getByRole } = (0, testing_library_1.render)(react_1.default.createElement(Button_1.Button, { variation: 'link', disabled: true }, "BUTTON"));
                const button = getByRole('button');
                expect(button).toHaveStyleRule('color', theme.palette.background.tone, {
                    modifier: ':disabled',
                });
                expect(button).toHaveStyleRule('background-color', theme.palette.background.base, {
                    modifier: ':disabled',
                });
                expect(button).toHaveStyleRule('background-color', 'transparent');
            });
        });
        describe('subtle variation', () => {
            it('should render correctly', () => {
                const { getByRole } = (0, testing_library_1.render)(react_1.default.createElement(Button_1.Button, { variation: 'subtle' }, "BUTTON"));
                const button = getByRole('button');
                expect(button).toHaveStyleRule('color', theme.palette.primary.base);
                expect(button).toHaveStyleRule('background-color', theme.palette.background.base);
                expect(button).toHaveStyleRule('vertical-align', 'middle');
                expect(button).toHaveStyleRule('-webkit-font-smoothing', 'antialiased');
                expect(button).toHaveStyleRule('font-weight', '700');
                expect(button).toHaveStyleRule('line-height', '1.5');
                expect(button).toHaveStyleRule('color', theme.palette.primary.dark, {
                    modifier: ':hover',
                });
                expect(button).toHaveStyleRule('background-color', theme.palette.background.tint, {
                    modifier: ':hover',
                });
                expect(button).toHaveStyleRule('outline', `0px solid ${theme.palette.primary.dark}`, {
                    modifier: ':focus-visible',
                });
                expect(button).toHaveStyleRule('box-shadow', `0 0 0 2px ${theme.palette.primary.dark}`, {
                    modifier: ':focus-visible',
                });
            });
            it('should render correctly when disabled', () => {
                const { getByRole } = (0, testing_library_1.render)(react_1.default.createElement(Button_1.Button, { variation: 'subtle', disabled: true }, "BUTTON"));
                const button = getByRole('button');
                expect(button).toHaveStyleRule('color', theme.palette.background.tone, {
                    modifier: ':disabled',
                });
                expect(button).toHaveStyleRule('background-color', theme.palette.background.base, {
                    modifier: ':disabled',
                });
            });
        });
        describe('white variation', () => {
            it('should render correctly', () => {
                const { getByRole } = (0, testing_library_1.render)(react_1.default.createElement(Button_1.Button, { variation: 'white' }, "BUTTON"));
                const button = getByRole('button');
                expect(button).toHaveStyleRule('background-color', theme.palette.background.lightest);
            });
        });
        describe('plain variation', () => {
            it('should render correctly', () => {
                const { getByRole } = (0, testing_library_1.render)(react_1.default.createElement(Button_1.Button, { variation: 'plain' }, "BUTTON"));
                const button = getByRole('button');
                expect(button).toHaveStyleRule('color', theme.palette.primary.base);
                expect(button).toHaveStyleRule('background-color', 'transparent');
                expect(button).toHaveStyleRule('vertical-align', 'middle');
                expect(button).toHaveStyleRule('-webkit-font-smoothing', 'antialiased');
                expect(button).toHaveStyleRule('font-weight', '700');
                expect(button).toHaveStyleRule('line-height', '1.5');
                expect(button).toHaveStyleRule('color', theme.palette.primary.dark, {
                    modifier: ':hover',
                });
                expect(button).toHaveStyleRule('background-color', theme.palette.background.base, {
                    modifier: ':hover',
                });
                expect(button).toHaveStyleRule('outline', `0px solid ${theme.palette.primary.dark}`, {
                    modifier: ':focus-visible',
                });
                expect(button).toHaveStyleRule('box-shadow', `0 0 0 2px ${theme.palette.primary.dark}`, {
                    modifier: ':focus-visible',
                });
            });
            it('should render correctly when disabled', () => {
                const { getByRole } = (0, testing_library_1.render)(react_1.default.createElement(Button_1.Button, { variation: 'plain', disabled: true }, "BUTTON"));
                const button = getByRole('button');
                expect(button).toHaveStyleRule('color', theme.palette.background.tone, {
                    modifier: ':disabled',
                });
                expect(button).toHaveStyleRule('background-color', theme.palette.background.base, {
                    modifier: ':disabled',
                });
            });
        });
        describe('lightFill variation', () => {
            it('should render correctly', () => {
                const { getByRole } = (0, testing_library_1.render)(react_1.default.createElement(Button_1.Button, { variation: 'lightFill', color: 'warning' }, "BUTTON"));
                const button = getByRole('button');
                expect(button).toHaveStyleRule('color', theme.palette.warning.base);
                expect(button).toHaveStyleRule('background-color', theme.palette.warning.light);
                expect(button).toHaveStyleRule('vertical-align', 'middle');
                expect(button).toHaveStyleRule('-webkit-font-smoothing', 'antialiased');
                expect(button).toHaveStyleRule('font-weight', '700');
                expect(button).toHaveStyleRule('line-height', '1.5');
                expect(button).toHaveStyleRule('color', theme.palette.warning.dark, {
                    modifier: ':hover',
                });
                expect(button).toHaveStyleRule('background-color', theme.palette.warning.light, {
                    modifier: ':hover',
                });
                expect(button).toHaveStyleRule('outline', `0px solid ${theme.palette.warning.dark}`, {
                    modifier: ':focus-visible',
                });
                expect(button).toHaveStyleRule('box-shadow', `0 0 0 2px ${theme.palette.warning.dark}`, {
                    modifier: ':focus-visible',
                });
            });
            it('should render correctly when disabled', () => {
                const { getByRole } = (0, testing_library_1.render)(react_1.default.createElement(Button_1.Button, { variation: 'lightFill', disabled: true }, "BUTTON"));
                const button = getByRole('button');
                expect(button).toHaveStyleRule('color', theme.palette.background.tone, {
                    modifier: ':disabled',
                });
                expect(button).toHaveStyleRule('background-color', theme.palette.background.base, {
                    modifier: ':disabled',
                });
            });
        });
        describe('input variation', () => {
            it('should render correctly', () => {
                const { getByRole } = (0, testing_library_1.render)(react_1.default.createElement(Button_1.Button, { variation: 'input' }, "BUTTON"));
                const button = getByRole('button');
                expect(button).toHaveStyleRule('color', theme.palette.text.base);
                expect(button).toHaveStyleRule('background-color', 'transparent');
                expect(button).toHaveStyleRule('border-color', theme.palette.border.base);
                expect(button).toHaveStyleRule('border-color', theme.palette.primary.base, {
                    modifier: ':focus',
                });
                expect(button).toHaveStyleRule('box-shadow', `0 0 0 2px ${theme.palette.primary.base}`, {
                    modifier: ':focus',
                });
            });
        });
    });
    // this test detects a current defect that will be fixed properly in DSv4
    it('should not lose base styles on "styled(Button)"', () => {
        const { getByRole } = (0, testing_library_1.render)(react_1.default.createElement(StyledButton, null, "BUTTON"));
        const button = getByRole('button');
        expect(button).toHaveStyleRule('background-color', theme.palette.primary.base);
        expect(button).toHaveStyleRule('color', theme.palette.text.lightest);
        expect(button).toHaveStyleRule('padding', '100px');
        expect(button).toHaveStyleRule('background-color', theme.palette.primary.dark, {
            modifier: ':hover',
        });
        expect(button).toHaveStyleRule('color', theme.palette.text.lightest, {
            modifier: ':hover',
        });
    });
});
//# sourceMappingURL=Button.spec.js.map