"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Checkbox = void 0;
const pcln_icons_1 = require("pcln-icons");
const react_1 = __importStar(require("react"));
const styled_components_1 = __importDefault(require("styled-components"));
const utils_1 = require("../utils/utils");
const CheckBoxWrapper = styled_components_1.default.div `
  display: inline-flex;
  align-items: center;
  position: relative;
  vertical-align: middle;
  padding: 2px;
  cursor: ${({ disabled }) => (disabled ? 'not-allowed' : 'pointer')};
  background-color: inherit;
  color: ${(props) => props.disabled ? (0, utils_1.getPaletteColor)('border.base')(props) : (0, utils_1.getPaletteColor)('border.dark')(props)};

  svg {
    border: 1px solid transparent;
    border-radius: 4px;
    padding: 2px;
  }

  svg[data-name='checked'] {
    display: none;
  }
  svg[data-name='indeterminate'] {
    display: none;
  }

  ~ span {
    cursor: ${({ disabled }) => (disabled ? 'not-allowed' : 'pointer')};
  }

  > input[data-indeterminate='true'] {
    & ~ svg[data-name='indeterminate'] {
      display: inline-block;
      color: ${(props) => props.disabled ? (0, utils_1.getPaletteColor)('border.base')(props) : (0, utils_1.getPaletteColor)('base')(props)};
    }
    &:hover ~ svg[data-name='indeterminate'] {
      color: ${(props) => props.disabled ? (0, utils_1.getPaletteColor)('border.base')(props) : (0, utils_1.getPaletteColor)('dark')(props)};
    }
    & ~ svg[data-name='empty'] {
      display: none;
    }
    & ~ svg[data-name='checked'] {
      display: none;
    }
  }

  > input:not([data-indeterminate='true']) {
    & ~ svg[data-name='empty'] {
      color: ${(props) => props.disabled ? (0, utils_1.getPaletteColor)('border.base') : (0, utils_1.getPaletteColor)(props.unselectedColor)};
    }
    &:focus-visible ~ svg {
      border: 1px solid ${(0, utils_1.getPaletteColor)('border.base')};
      background-color: ${(0, utils_1.getPaletteColor)('background.light')};
    }
  }

  > input:checked:not([data-indeterminate='true']) {
    & ~ svg[data-name='checked'] {
      display: inline-block;
      color: ${(props) => props.disabled ? (0, utils_1.getPaletteColor)('border.base')(props) : (0, utils_1.getPaletteColor)('base')(props)};
    }

    & ~ svg[data-name='empty'] {
      display: none;
    }

    &:focus-visible ~ svg {
      border: 1px solid ${(0, utils_1.getPaletteColor)('base')};
      background-color: ${(0, utils_1.getPaletteColor)('light')};
    }

    &:hover ~ svg[data-name='checked'] {
      color: ${(props) => props.disabled ? (0, utils_1.getPaletteColor)('border.base')(props) : (0, utils_1.getPaletteColor)('dark')(props)};
    }
  }

  > input:hover ~ svg[data-name='empty'] {
    color: ${(props) => props.disabled ? (0, utils_1.getPaletteColor)('border.base')(props) : (0, utils_1.getPaletteColor)('base')(props)};
  }

  ${(0, utils_1.applyVariations)('Checkbox')}
`;
const StyledInput = styled_components_1.default.input `
  appearance: none;
  opacity: 0;
  position: absolute;
  z-index: 0;
`;
/**
 * @public
 */
exports.Checkbox = react_1.default.forwardRef((props, ref) => {
    const { disabled, size, indeterminate, unselectedColor, onChange, defaultChecked } = props;
    const [showIndeterminate, setShowIndeterminate] = (0, react_1.useState)(indeterminate && !defaultChecked);
    function handleChange(e) {
        setShowIndeterminate(false);
        if (typeof onChange === 'function') {
            onChange(e);
        }
    }
    (0, react_1.useEffect)(() => {
        setShowIndeterminate(indeterminate);
    }, [indeterminate]);
    // Add 4px to Icon's height and width to account for size reduction caused by adding padding to SVG element
    const borderAdjustedSize = size + 4;
    return (react_1.default.createElement(CheckBoxWrapper, { color: props.color, disabled: disabled, unselectedColor: unselectedColor },
        react_1.default.createElement(StyledInput, { type: 'checkbox', ...props, onChange: handleChange, role: 'checkbox', "aria-checked": showIndeterminate ? 'mixed' : props.checked, "data-indeterminate": showIndeterminate, ref: ref }),
        react_1.default.createElement(pcln_icons_1.BoxChecked, { size: borderAdjustedSize, "data-name": 'checked' }),
        react_1.default.createElement(pcln_icons_1.BoxMinus, { size: borderAdjustedSize, "data-name": 'indeterminate' }),
        react_1.default.createElement(pcln_icons_1.BoxEmpty, { size: borderAdjustedSize, "data-name": 'empty' })));
});
exports.Checkbox.displayName = 'Checkbox';
exports.Checkbox.defaultProps = {
    size: 20,
    indeterminate: false,
    color: 'primary',
    unselectedColor: 'text.light',
};
//# sourceMappingURL=Checkbox.js.map