"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const testing_library_1 = require("../__test__/testing-library");
const Checkbox_1 = require("./Checkbox");
describe('Checkbox', () => {
    const onChange = jest.fn();
    test('renders without the theme passed specifically', () => {
        const { asFragment } = (0, testing_library_1.render)(react_1.default.createElement(Checkbox_1.Checkbox, { id: 'check-box', onChange: onChange }));
        expect(asFragment()).toMatchSnapshot();
    });
    test('renders checked when defaultChecked prop is passed as true', () => {
        const { getByRole } = (0, testing_library_1.render)(react_1.default.createElement(Checkbox_1.Checkbox, { id: 'check-box', defaultChecked: true, onChange: onChange }));
        const checkbox = getByRole('checkbox');
        expect(checkbox.checked).toBe(true);
    });
    test('renders disabled with disabled prop', () => {
        const { asFragment } = (0, testing_library_1.render)(react_1.default.createElement(Checkbox_1.Checkbox, { id: 'check-box', disabled: true, onChange: onChange }));
        expect(asFragment()).toMatchSnapshot();
    });
    test('renders disabled with defaultChecked', () => {
        const { asFragment } = (0, testing_library_1.render)(react_1.default.createElement(Checkbox_1.Checkbox, { id: 'check-box', disabled: true, defaultChecked: true, onChange: onChange }));
        expect(asFragment()).toMatchSnapshot();
    });
    test('calls onChange when clicked', () => {
        const { container } = (0, testing_library_1.render)(react_1.default.createElement(Checkbox_1.Checkbox, { id: 'check-box', onChange: onChange }));
        const checkbox = container.querySelector('[type=checkbox]');
        testing_library_1.fireEvent.click(checkbox);
        expect(onChange).toHaveBeenCalled();
    });
    it('renders an indeterminate checkbox that can be clicked to set checked to true', () => {
        const { getByRole } = (0, testing_library_1.render)(react_1.default.createElement(Checkbox_1.Checkbox, { id: 'check-box', indeterminate: true, onChange: onChange }));
        const checkbox = getByRole('checkbox');
        expect(checkbox.checked).toBe(false);
        // expect(checkbox.indeterminate).toBe(true)
        testing_library_1.fireEvent.click(checkbox);
        expect(checkbox.checked).toBe(true);
        // expect(checkbox.indeterminate).toBe(false)
    });
    it('renders an indeterminate checkbox that can be clicked to set checked to false', () => {
        const { getByRole } = (0, testing_library_1.render)(react_1.default.createElement(Checkbox_1.Checkbox, { id: 'check-box', indeterminate: true, defaultChecked: true, onChange: onChange }));
        const checkbox = getByRole('checkbox');
        expect(checkbox.checked).toBe(true);
        // expect(checkbox.indeterminate).toBe(true)
        testing_library_1.fireEvent.click(checkbox);
        expect(checkbox.checked).toBe(false);
        // expect(checkbox.indeterminate).toBe(false)
    });
    it('correctly passes in the ref so that the underlying input element can be modified by the parent component if needed', () => {
        const ref = react_1.default.createRef();
        const { getByRole } = (0, testing_library_1.render)(
        // @ts-ignore
        react_1.default.createElement(Checkbox_1.Checkbox, { id: 'check-box', ref: ref, indeterminate: true, defaultChecked: true, onChange: onChange }));
        const checkbox = getByRole('checkbox');
        // @ts-ignore
        expect(ref.current.id).toBe(checkbox.id);
    });
});
//# sourceMappingURL=Checkbox.spec.js.map