"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const testing_library_1 = require("../../__test__/testing-library");
const ButtonChip_1 = require("./ButtonChip");
const props = {
    id: 'testId',
    m: 2,
    expanded: false,
    disabled: false,
    onClick: jest.fn(),
};
describe('ButtonChip', () => {
    test('Default', () => {
        const { getByTestId } = (0, testing_library_1.render)(react_1.default.createElement(ButtonChip_1.ButtonChip, { ...props }));
        const buttonChip = getByTestId('testId');
        //onClick
        testing_library_1.fireEvent.click(buttonChip);
        expect(props.onClick).toHaveBeenCalled();
        //aria-expanded
        expect(buttonChip).toHaveAttribute('aria-expanded', 'false');
        //(not) disabled
        expect(getByTestId('testId')).not.toHaveAttribute('disabled');
        //style
        expect(buttonChip).toHaveStyleRule('margin', '8px');
    });
    test('Disabled', () => {
        const { getByTestId } = (0, testing_library_1.render)(react_1.default.createElement(ButtonChip_1.ButtonChip, { ...props, disabled: true }));
        expect(getByTestId('testId')).toHaveAttribute('disabled');
    });
    test('Expanded', () => {
        const { getByTestId } = (0, testing_library_1.render)(react_1.default.createElement(ButtonChip_1.ButtonChip, { ...props, expanded: true }));
        expect(getByTestId('testId')).toHaveAttribute('aria-expanded', 'true');
    });
});
//# sourceMappingURL=ButtonChip.spec.js.map