"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const pcln_icons_1 = require("pcln-icons");
const react_1 = __importDefault(require("react"));
const testing_library_1 = require("../../__test__/testing-library");
const ChipContent_1 = require("./ChipContent");
const props = {
    id: 'testId',
    disabled: false,
    selected: false,
    facet: '(06)',
    label: 'Chips are Delicious',
    bridgeLabel: 'Chips are amazing',
    Icon: pcln_icons_1.Departure,
    IconTitle: 'Departure',
    action: {
        Icon: pcln_icons_1.Broom,
        title: 'Sweep',
    },
    image: react_1.default.createElement("img", { src: 'https://www.priceline.com/sam/air/carrier_logos/airLogo_DL.png', alt: 'Delta', height: '24' }),
};
describe('ChipContent', () => {
    test('All Prop Options passed in', () => {
        const { getByText, getAllByTitle, getByAltText, getByTestId } = (0, testing_library_1.render)(react_1.default.createElement(ChipContent_1.ChipContent, { ...props }));
        //image
        expect(getByAltText('Delta'));
        //Icon
        expect(getAllByTitle('Departure')).toHaveLength(2);
        //label
        expect(getByText('Chips are Delicious'));
        //bridgeLabel
        expect(getAllByTitle('to')).toHaveLength(2);
        expect(getByText('Chips are amazing'));
        //action icon
        expect(getAllByTitle('Sweep')).toHaveLength(2);
        //facet
        expect(getByText('(06)'));
        //style
        expect(getByTestId('chipContentWrapper')).toHaveStyleRule('border', '1px solid #c0cad5');
        expect(getByTestId('chipContentWrapper')).toHaveStyleRule('background-color', '#fff');
        expect(getByTestId('chipContentWrapper')).toHaveStyleRule('cursor', 'pointer');
    });
    test('selected, sm', () => {
        const { getByTestId } = (0, testing_library_1.render)(react_1.default.createElement(ChipContent_1.ChipContent, { ...props, selected: true, size: 'sm' }));
        expect(getByTestId('chipContentWrapper')).toHaveStyleRule('border', '1px solid #0068ef');
        expect(getByTestId('chipContentWrapper')).toHaveStyleRule('cursor', 'pointer');
        expect(getByTestId('chipContentWrapper')).toHaveStyleRule('padding-left', '8px');
        expect(getByTestId('chipContentWrapper')).toHaveStyleRule('height', '32px');
    });
    test('disabled, md', () => {
        const { getByTestId } = (0, testing_library_1.render)(react_1.default.createElement(ChipContent_1.ChipContent, { ...props, disabled: true, size: 'md' }));
        expect(getByTestId('chipContentWrapper')).toHaveStyleRule('border', '1px solid transparent');
        expect(getByTestId('chipContentWrapper')).toHaveStyleRule('cursor', 'not-allowed');
        expect(getByTestId('chipContentWrapper')).toHaveStyleRule('padding-left', '16px');
        expect(getByTestId('chipContentWrapper')).toHaveStyleRule('height', '40px');
    });
    test('md, with topLabel', () => {
        const { getByTestId, getByText } = (0, testing_library_1.render)(react_1.default.createElement(ChipContent_1.ChipContent, { ...props, size: 'md', topLabel: 'I love chips' }));
        expect(getByTestId('chipContentWrapper')).toHaveStyleRule('height', '58px');
        expect(getByText('I love chips'));
    });
    test('Custom contents', () => {
        const { getByText } = (0, testing_library_1.render)(react_1.default.createElement(ChipContent_1.ChipContent, null, "HELLO"));
        //Child element
        expect(getByText('HELLO'));
    });
    test('No Icon and No image', () => {
        const { queryByAltText, queryByTitle } = (0, testing_library_1.render)(react_1.default.createElement(ChipContent_1.ChipContent, { ...props, BridgeIcon: pcln_icons_1.Broom, Icon: undefined, image: undefined }));
        expect(queryByAltText('Delta')).not.toBeInTheDocument();
        expect(queryByTitle('Departure')).not.toBeInTheDocument();
    });
    test('disabled and selected', () => {
        const { getByTestId } = (0, testing_library_1.render)(react_1.default.createElement(ChipContent_1.ChipContent, { ...props, disabled: true, selected: true }));
        expect(getByTestId('chipContentWrapper')).toHaveStyleRule('border', '1px solid #4f6f8f');
        expect(getByTestId('chipContentWrapper')).toHaveStyleRule('cursor', 'not-allowed');
    });
});
//# sourceMappingURL=ChipContent.spec.js.map