"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const testing_library_1 = require("../../__test__/testing-library");
const FilterChip_1 = require("./FilterChip");
const props = {
    id: 'testId',
    name: 'testFilterChipName',
    expanded: false,
    disabled: false,
    onClick: jest.fn(),
};
describe('FilterChip', () => {
    test('Default', () => {
        const { getByTestId } = (0, testing_library_1.render)(react_1.default.createElement(FilterChip_1.FilterChip, { ...props }));
        const filterChip = getByTestId('testId');
        //id
        expect(filterChip).toHaveAttribute('id', props.id);
        //name
        expect(filterChip).toHaveAttribute('name', props.name);
        //type
        expect(filterChip).toHaveAttribute('type', 'checkbox');
        //role
        expect(filterChip).toHaveAttribute('role', 'checkbox');
        //onClick
        testing_library_1.fireEvent.click(filterChip);
        expect(props.onClick).toHaveBeenCalled();
        //(not) disabled
        expect(filterChip).not.toHaveAttribute('disabled');
        //(not) checked
        expect(filterChip).not.toHaveAttribute('checked');
    });
    test('Disabled', () => {
        const { getByTestId } = (0, testing_library_1.render)(react_1.default.createElement(FilterChip_1.FilterChip, { ...props, disabled: true }));
        expect(getByTestId('testId')).toHaveAttribute('disabled');
    });
    test('Checked', () => {
        const { getByTestId } = (0, testing_library_1.render)(react_1.default.createElement(FilterChip_1.FilterChip, { ...props, selected: true }));
        expect(getByTestId('testId')).toHaveAttribute('checked');
    });
});
//# sourceMappingURL=FilterChip.spec.js.map