"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("@testing-library/react");
const react_2 = __importDefault(require("react"));
const Dialog_1 = require("./Dialog");
const triggerText = 'Open Dialog';
const contentText = 'Dialog Content';
describe('Dialog', () => {
    it('renders the trigger node', () => {
        (0, react_1.render)(react_2.default.createElement(Dialog_1.Dialog, { triggerNode: react_2.default.createElement("button", null, triggerText), ariaDescription: 'Description', ariaTitle: 'Title' }, contentText));
        const triggerNode = react_1.screen.getByText(triggerText);
        expect(triggerNode).toBeInTheDocument();
    });
    it('renders the dialog content when trigger is clicked', async () => {
        (0, react_1.render)(react_2.default.createElement(Dialog_1.Dialog, { triggerNode: react_2.default.createElement("button", null, triggerText), ariaDescription: 'Description', ariaTitle: 'Title' }, contentText));
        const triggerNode = react_1.screen.getByText(triggerText);
        triggerNode.click();
        await new Promise((resolve) => setTimeout(resolve, 1000));
        const contentNode = react_1.screen.getByText(contentText);
        expect(contentNode).toBeInTheDocument();
    });
    it('renders the dialog with footer content', async () => {
        (0, react_1.render)(react_2.default.createElement(Dialog_1.Dialog, { triggerNode: react_2.default.createElement("button", null, triggerText), ariaDescription: 'Description', ariaTitle: 'Title', footerContent: react_2.default.createElement("div", null, "Footer Content") }, contentText));
        const triggerNode = react_1.screen.getByText(triggerText);
        triggerNode.click();
        await (0, react_1.waitFor)(() => {
            expect(react_1.screen.getByText('Footer Content')).toBeInTheDocument();
        });
    });
    it.skip('calls onOpenChange when trigger is clicked', () => {
        const onOpenChange = jest.fn();
        (0, react_1.render)(react_2.default.createElement(Dialog_1.Dialog, { triggerNode: react_2.default.createElement("button", null, triggerText), ariaDescription: 'Description', ariaTitle: 'Title', onOpenChange: onOpenChange }, contentText));
        const triggerNode = react_1.screen.getByText(triggerText);
        triggerNode.click();
        expect(onOpenChange).toHaveBeenCalledWith(true);
    });
    it.skip('handles controlled state when open', () => {
        (0, react_1.render)(react_2.default.createElement(Dialog_1.Dialog, { triggerNode: react_2.default.createElement("button", null, triggerText), ariaDescription: 'Description', ariaTitle: 'Title', open: false }, contentText));
        const triggerNode = react_1.screen.getByText(triggerText);
        triggerNode.click();
        const contentNode = react_1.screen.queryByText(contentText);
        expect(contentNode).not.toBeVisible();
    });
});
//# sourceMappingURL=Dialog.spec.js.map