"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DialogContent = exports.DialogOverlay = exports.dialogSizes = void 0;
const Dialog = __importStar(require("@radix-ui/react-dialog"));
const react_visually_hidden_1 = require("@radix-ui/react-visually-hidden");
const theme_get_1 = __importDefault(require("@styled-system/theme-get"));
const framer_motion_1 = require("framer-motion");
const react_1 = __importDefault(require("react"));
const styled_components_1 = __importDefault(require("styled-components"));
const styled_system_1 = require("styled-system");
const CloseButton_1 = require("../CloseButton/CloseButton");
const Grid_1 = require("../Grid/Grid");
const Text_1 = require("../Text/Text");
const ThemeProvider_1 = require("../ThemeProvider/ThemeProvider");
const useScrollWithShadow_1 = require("../useScrollWithShadows/useScrollWithShadow");
const Box_1 = require("../Box/Box");
/** @public */
exports.dialogSizes = ['sm', 'md', 'lg', 'xl', 'full'];
const sizeStyles = {
    sm: { width: 'calc(min(400px, 100vw) - 2 * 16px)' },
    md: { width: 'calc(min(640px, 100vw) - 2 * 16px)' },
    lg: { width: 'calc(min(960px, 100vw) - 2 * 16px)' },
    xl: { width: 'calc(min(1280px, 100vw) - 2 * 16px)', height: 'calc(100% - 2 * 48px)' },
    full: { width: '100%', height: '100%' },
};
const scrimStyles = {
    dark: 'rgba(0, 24, 51, 0.75)',
    medium: 'rgba(0, 24, 51, 0.5)',
    light: 'rgba(0, 24, 51, 0.25)',
};
const enterTransition = { duration: 0.25, ease: 'easeOut' };
const exitTransition = { duration: 0.15, ease: 'easeIn' };
const animationStyles = {
    default: {
        initial: { opacity: 0, scale: 0.9, translateY: 64 },
        animate: { opacity: 1, scale: 1, translateY: 0, transition: enterTransition },
        exit: { opacity: 0, scale: 0.9, translateY: 32, transition: exitTransition },
    },
    sheet: {
        initial: { opacity: 0, translateY: '40%' },
        animate: { opacity: 1, translateY: 0, transition: enterTransition },
        exit: { opacity: 0, translateY: '60%', transition: exitTransition },
    },
    overlay: {
        initial: { opacity: 0, overflow: 'hidden' },
        animate: { opacity: 1, transitionEnd: { overflow: 'auto' }, transition: enterTransition },
        exit: { opacity: 0, overflow: 'hidden', transition: exitTransition },
    },
};
const FloatingCloseButton = (0, styled_components_1.default)(CloseButton_1.CloseButton) `
  position: absolute;
  top: ${(props) => (props.dialogSize === 'full' || props.fullWidth ? 8 : -12)}px;
  right: ${(props) => (props.dialogSize === 'full' || props.fullWidth ? 8 : -12)}px;
  z-index: ${(props) => (0, theme_get_1.default)('zIndices.absolute')(props)};
`;
const DialogOverlayWrapper = (0, styled_components_1.default)(framer_motion_1.motion.div) `
  ${styled_system_1.zIndex}
  position: fixed;
  inset: 0;
  display: grid;
  overflow-y: auto;
  place-items: ${(props) => (props.sheet ? 'end center' : 'center')};
  background-color: ${(props) => Object.keys(scrimStyles).includes(props.scrimColor) ? scrimStyles[props.scrimColor] : props.scrimColor};
`;
const DialogContentWrapper = (0, styled_components_1.default)(framer_motion_1.motion.div) `
  position: relative;
  cursor: initial;
  background-color: ${(props) => (0, theme_get_1.default)('palette.background.lightest')(props)};
  width: ${(props) => (props.fullWidth ? '100%' : sizeStyles[props.size]?.width)};
  height: ${(props) => props.sheet ? `calc(${sizeStyles[props.size]?.height} - 24px)` : sizeStyles[props.size]?.height};
  margin: ${(props) => props.sheet
    ? `${(0, theme_get_1.default)('space.3')(props)} 0 0 0`
    : props.size === 'full'
        ? '0'
        : `${(0, theme_get_1.default)('space.4')(props)}
         ${(0, theme_get_1.default)('space.3')(props)}
         ${(0, theme_get_1.default)('space.5')(props)}
         ${(0, theme_get_1.default)('space.3')(props)}`};
  border-radius: ${(props) => props.sheet
    ? `${(0, theme_get_1.default)(`borderRadii.${props.borderRadius}`)(props)} ${(0, theme_get_1.default)(`borderRadii.${props.borderRadius}`)(props)} 0 0`
    : props.size === 'full'
        ? 'none'
        : (0, theme_get_1.default)(`borderRadii.${props.borderRadius}`)(props)};
  box-shadow: ${(props) => (0, theme_get_1.default)('shadows.overlay-lg')(props)};
  ${(props) => props.hasFooterContent &&
    `
    overflow: ${props.sheet ? 'scroll' : 'visible'};
  `}
`;
const DialogInnerContentWrapper = styled_components_1.default.div `
  position: relative;
  display: grid;
  grid-template-columns: 1fr;
  grid-template-rows: auto 1fr auto;

  ${(props) => props.hasFooterContent && `height: 100%;`}

  ${styled_system_1.overflowX}
  ${styled_system_1.overflowY}
  border-radius: ${(props) => props.sheet
    ? `${(0, theme_get_1.default)(`borderRadii.${props.borderRadius}`)(props)} ${(0, theme_get_1.default)(`borderRadii.${props.borderRadius}`)(props)} 0 0`
    : props.size === 'full'
        ? 'none'
        : (0, theme_get_1.default)(`borderRadii.${props.borderRadius}`)(props)};
  border-top: ${(props) => props.hugColor && `4px solid ${(0, theme_get_1.default)('palette.' + props.hugColor)(props)}`};
`;
const DialogOverlay = ({ scrimColor, sheet, children, zIndex }) => {
    return (react_1.default.createElement(Dialog.Portal, { forceMount: true },
        react_1.default.createElement(ThemeProvider_1.ThemeProvider, null,
            react_1.default.createElement(Dialog.Overlay, { asChild: true, forceMount: true },
                react_1.default.createElement(DialogOverlayWrapper, { scrimColor: scrimColor, sheet: sheet, zIndex: zIndex, ...animationStyles.overlay }, children)))));
};
exports.DialogOverlay = DialogOverlay;
const SmoothTransitionBox = (0, styled_components_1.default)(Box_1.Box) `
  overflow: ${(props) => props.innerContentOverflow ?? 'auto'};
  transition: all 0.3s ease-in-out;
`;
const DialogContent = ({ ariaDescription, ariaTitle, borderRadius, children, footerContent, fullWidth, headerColorScheme = 'heading', headerContent, headerContentProps, headerIcon, headerShowCloseButton, hugColor, innerContentOverflow, overflowX, overflowY, scrimDismiss, sheet, showCloseButton, showScrollShadow, size, zIndex, onOpenChange, }) => {
    const headerSizeArray = [
        headerIcon ? 'heading5' : 'heading4', // xs
        headerIcon ? 'heading5' : 'heading4', // sm
        headerIcon ? 'heading5' : 'heading4', // md
        headerIcon ? 'heading5' : 'heading4', // lg
        headerIcon ? 'heading4' : 'heading3', // xl
        headerIcon ? 'heading4' : 'heading3', // xxl
    ];
    const { boxShadow, onScrollHandler } = (0, useScrollWithShadow_1.useScrollWithShadow)();
    return (react_1.default.createElement(Dialog.Content, { "aria-describedby": ariaDescription, onPointerDownOutside: (e) => {
            e.preventDefault();
            if (scrimDismiss)
                onOpenChange(false);
        }, onOpenAutoFocus: (e) => e.preventDefault(), asChild: true, forceMount: true },
        react_1.default.createElement(DialogContentWrapper, { size: size, sheet: sheet, fullWidth: fullWidth, borderRadius: borderRadius, zIndex: zIndex, hasFooterContent: footerContent, ...(sheet ? animationStyles.sheet : animationStyles.default) },
            showCloseButton && (react_1.default.createElement(Dialog.Close, { asChild: true },
                react_1.default.createElement(FloatingCloseButton, { dialogSize: size, fullWidth: fullWidth, variant: 'filled' }))),
            react_1.default.createElement(react_visually_hidden_1.VisuallyHidden, { asChild: true },
                react_1.default.createElement(Dialog.Title, null, ariaTitle)),
            react_1.default.createElement(DialogInnerContentWrapper, { overflowX: overflowX, overflowY: overflowY, sheet: sheet, hasFooterContent: footerContent, hugColor: hugColor, size: size, borderRadius: borderRadius },
                headerContent && (react_1.default.createElement(Grid_1.Grid, { px: [3, 3, 3, 3, '24px', '24px'], py: 3, autoFlow: 'column', templateColumns: 'auto 1fr', alignItems: 'center', colorScheme: headerColorScheme, ...headerContentProps },
                    react_1.default.createElement(Grid_1.Grid, { autoFlow: 'column', gap: '2' },
                        headerIcon,
                        react_1.default.createElement(Text_1.Text, { textStyle: size === 'sm' ? (headerIcon ? 'heading5' : 'heading4') : headerSizeArray }, headerContent)),
                    react_1.default.createElement(Grid_1.Grid, { justifySelf: 'end' }, headerShowCloseButton && react_1.default.createElement(CloseButton_1.CloseButton, { onClick: () => onOpenChange(false) })))),
                showScrollShadow ? (react_1.default.createElement(SmoothTransitionBox, { innerContentOverflow: innerContentOverflow, style: { boxShadow }, height: '100%', onScroll: onScrollHandler }, react_1.default.Children.map(children, (child) => react_1.default.cloneElement(child, {
                    onScroll: onScrollHandler,
                })))) : (react_1.default.createElement(Box_1.Box, { height: '100%', style: innerContentOverflow ? { overflowY: innerContentOverflow } : undefined }, children)),
                footerContent && (react_1.default.createElement(Box_1.Box, { boxShadow: showScrollShadow ? 'lg' : 'none', color: 'background.lightest' },
                    react_1.default.createElement(Grid_1.Grid, { px: [3, 3, 3, 3, '24px', '24px'], py: 3, autoFlow: 'column', templateColumns: '1fr', alignItems: 'center' }, footerContent)))))));
};
exports.DialogContent = DialogContent;
//# sourceMappingURL=Dialog.styled.js.map