"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const testing_library_1 = require("../__test__/testing-library");
const theme_1 = require("../theme/theme");
const Divider_1 = require("./Divider");
describe('Divider', () => {
    test('renders', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Divider_1.Divider, null)).toJSON();
        expect(json).toMatchSnapshot();
    });
    test('width prop sets width', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Divider_1.Divider, { width: 1 / 2 })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('width', '50%');
    });
    test('m prop sets margin', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Divider_1.Divider, { m: 2 })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('margin', theme_1.theme.space[2]);
    });
    test('borderColor prop sets borderColor', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Divider_1.Divider, { borderColor: 'blue' })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('border-color', theme_1.theme.colors.blue);
    });
    test('override default margin left and right', () => {
        (0, testing_library_1.render)(react_1.default.createElement(Divider_1.Divider, { mx: 2, "data-testid": 'divider' }));
        expect(testing_library_1.screen.getByTestId('divider')).toHaveStyleRule('margin-left', theme_1.theme.space[2]);
        expect(testing_library_1.screen.getByTestId('divider')).toHaveStyleRule('margin-right', theme_1.theme.space[2]);
    });
});
//# sourceMappingURL=Divider.spec.js.map