"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const testing_library_1 = require("../../__test__/testing-library");
const Section_1 = require("../Section/Section");
const TableOfContents_1 = require("./TableOfContents");
const testLinks = ['Test 1', 'Test 2', 'Test 3'];
describe('TableOfContents', () => {
    it('should render a list of links with correct text', () => {
        (0, testing_library_1.render)(react_1.default.createElement(TableOfContents_1.TableOfContents, { links: testLinks }));
        const listItems = testing_library_1.screen.getAllByRole('listitem');
        expect(listItems).toHaveLength(testLinks.length);
        listItems.forEach((item, index) => {
            expect(item).toHaveTextContent(testLinks[index]);
        });
    });
    it('should scroll items into view', () => {
        const scrollIntoViewMock = jest.fn();
        window.HTMLElement.prototype.scrollIntoView = scrollIntoViewMock;
        (0, testing_library_1.render)(react_1.default.createElement(react_1.default.Fragment, null,
            react_1.default.createElement(TableOfContents_1.TableOfContents, { links: [...testLinks, 'Dummy Link'] }),
            testLinks.map((link) => (react_1.default.createElement(Section_1.Section, { heading: link, key: link }, link)))));
        const listItems = testing_library_1.screen.getAllByRole('listitem');
        testing_library_1.fireEvent.click(listItems[0]);
        expect(scrollIntoViewMock).toBeCalledTimes(1);
        testing_library_1.fireEvent.click(listItems[listItems.length - 1]);
        expect(scrollIntoViewMock).toBeCalledTimes(1);
    });
});
//# sourceMappingURL=TableOfContents.test.js.map