"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const testing_library_1 = require("../__test__/testing-library");
const DotLoader_1 = require("./DotLoader");
describe('DotLoader', () => {
    it('renders a dot loader', () => {
        (0, testing_library_1.render)(react_1.default.createElement(DotLoader_1.DotLoader, { "data-testid": 'dot-loader' }));
        const container = testing_library_1.screen.getByTestId('dot-loader');
        const children = container.children;
        expect(children).toHaveLength(3);
        expect(children[0]).toHaveAttribute('color', 'primary');
        expect(children[0]).toHaveStyleRule('animation', expect.stringContaining('2s ease infinite'));
        expect(children[0]).toHaveStyleRule('animation-delay', '0s');
        expect(children[1]).toHaveAttribute('color', 'primary');
        expect(children[1]).toHaveStyleRule('animation', expect.stringContaining('2s ease infinite'));
        expect(children[1]).toHaveStyleRule('animation-delay', `${2 / 6}s`);
        expect(children[2]).toHaveStyleRule('animation-delay', `${4 / 6}s`);
    });
    it('renders a small and slow dot loader', () => {
        (0, testing_library_1.render)(react_1.default.createElement(DotLoader_1.DotLoader, { size: 'small', speed: 'slow', "data-testid": 'dot-loader' }));
        const container = testing_library_1.screen.getByTestId('dot-loader');
        const children = container.children;
        expect(children[0]).toHaveStyleRule('animation', 'eKaJJz 2.5s ease infinite');
        expect(children[1]).toHaveStyleRule('animation-delay', `${2.5 / 6}s`);
        expect(children[2]).toHaveStyleRule('animation-delay', `${5 / 6}s`);
    });
    it('renders a large and fast dot loader', () => {
        (0, testing_library_1.render)(react_1.default.createElement(DotLoader_1.DotLoader, { size: 'large', speed: 'fast', "data-testid": 'dot-loader' }));
        const container = testing_library_1.screen.getByTestId('dot-loader');
        const children = container.children;
        expect(children[0]).toHaveStyleRule('animation', 'eKaJJz 1s ease infinite');
        expect(children[1]).toHaveStyleRule('animation-delay', `${1 / 6}s`);
        expect(children[2]).toHaveStyleRule('animation-delay', `${2 / 6}s`);
    });
});
//# sourceMappingURL=DotLoader.spec.js.map