"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Drawer = void 0;
const react_1 = __importDefault(require("react"));
const Box_1 = require("../Box/Box");
const Flex_1 = require("../Flex/Flex");
const Text_1 = require("../Text/Text");
const Drawer_styled_1 = require("./Drawer.styled");
const pcln_icons_1 = require("pcln-icons");
const framer_motion_1 = require("framer-motion");
const useScrollWithShadow_1 = require("../useScrollWithShadows/useScrollWithShadow");
const Animate_1 = require("../Animate/Animate");
const enterAnimation = {
    top: { ...Animate_1.MotionVariants.slideInTop },
    bottom: { ...Animate_1.MotionVariants.slideInBottom },
    right: { ...Animate_1.MotionVariants.slideInRight },
    left: { ...Animate_1.MotionVariants.slideInLeft },
};
const dragToDismissAnimation = (onDragEnd) => {
    return {
        drag: 'y',
        dragConstraints: { top: 0, bottom: 0 },
        dragElastic: { top: 0, bottom: 0.3 },
        transition: { duration: 0.8, ease: [0.04, 0.62, 0.23, 0.98] },
        onDragEnd: (event, info) => {
            if (info.offset.y > 200) {
                onDragEnd();
            }
        },
    };
};
const Drawer = ({ children, heading, isCollapsed = false, isFloating = true, isMobile = false, isOpen = false, onClose, onCollapse, placement = 'right', ...props }) => {
    const { boxShadow, onScrollHandler } = (0, useScrollWithShadow_1.useScrollWithShadow)();
    return (react_1.default.createElement(framer_motion_1.AnimatePresence, null, isOpen && (react_1.default.createElement(Drawer_styled_1.DrawerWrapper, { placement: isMobile ? 'bottom' : placement, padding: isFloating ? '16px' : 0, maxHeight: isMobile ? ['290px', '400px', '480px', 'calc(100vh - 64px)'] : props.height ?? '100%', maxWidth: isMobile ? '100%' : ['400px', '600px', '800px', '100%'], width: isMobile ? '100%' : props.width, height: !isCollapsed && props.height ? props.height : 'fit-content' },
        react_1.default.createElement(Drawer_styled_1.DrawerRoot, { "data-testid": 'drawer', isCollapsed: isCollapsed, isFloating: isFloating, key: 'drawer', placement: isMobile ? 'bottom' : placement, ...enterAnimation[isMobile ? 'bottom' : placement], ...dragToDismissAnimation(onCollapse), height: '100%', width: '100%', overflow: 'hidden' },
            react_1.default.createElement(Flex_1.Flex, { flexDirection: 'column' },
                (heading || onClose || onCollapse) && (react_1.default.createElement(Flex_1.Flex, { flexDirection: 'column' },
                    react_1.default.createElement(Flex_1.Flex, { flexDirection: 'row', p: 3 },
                        typeof heading === 'string' ? (react_1.default.createElement(Text_1.Text, { width: '100%', textStyle: 'heading4' }, heading)) : (heading),
                        onClose || onCollapse ? (react_1.default.createElement(Flex_1.Flex, { flexDirection: 'row', ml: 'auto', style: { columnGap: '8px' } },
                            onCollapse && (react_1.default.createElement(framer_motion_1.motion.div, { animate: {
                                    rotate: isCollapsed ? 180 : 0,
                                    transition: { duration: 0.25 },
                                } },
                                react_1.default.createElement(Drawer_styled_1.HeaderButton, { "data-testid": 'drawerCollapse', onClick: onCollapse, icon: react_1.default.createElement(pcln_icons_1.ChevronDown, { title: 'Dismiss' }) }))),
                            onClose && (react_1.default.createElement(Drawer_styled_1.HeaderButton, { "data-testid": 'drawerClose', onClick: onClose, icon: react_1.default.createElement(pcln_icons_1.Close, { title: 'Close' }) })))) : null))),
                react_1.default.createElement(framer_motion_1.AnimatePresence, { initial: false }, !isCollapsed && (react_1.default.createElement(framer_motion_1.motion.div, { key: 'content', exit: { scaleY: 0, height: 0 },
                    animate: { scaleY: 1, height: 'auto' },
                    initial: { scaleY: 1, height: 'auto' } }, heading ? (react_1.default.createElement(Box_1.Box, { height: '100%', maxHeight: `calc(${props.height ?? '100vh'} - 100px)`, overflow: 'scroll', onScroll: onScrollHandler, style: {
                        boxShadow,
                    } },
                    react_1.default.createElement(Box_1.Box, { p: 3, height: '100%' }, children))) : (react_1.default.createElement(Box_1.Box, { p: 3, height: '100%' }, children)))))))))));
};
exports.Drawer = Drawer;
exports.Drawer.displayName = 'Drawer';
//# sourceMappingURL=Drawer.js.map