"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const testing_library_1 = require("../__test__/testing-library");
const Drawer_1 = require("./Drawer");
describe('Drawer', () => {
    test('renders Drawer with no heading', () => {
        const { queryByText } = (0, testing_library_1.render)(react_1.default.createElement(Drawer_1.Drawer, { isOpen: true, placement: 'right', onCollapse: jest.fn }));
        expect(queryByText('Drawer Heading')).toBeFalsy();
    });
    test('renders collapsed Drawer', () => {
        const { queryByText } = (0, testing_library_1.render)(react_1.default.createElement(Drawer_1.Drawer, { isOpen: true, isCollapsed: true, placement: 'right' }, "Drawer Content"));
        expect(queryByText('Drawer Content')).toBeFalsy();
    });
    test('renders mobile Drawer', () => {
        const { queryByText } = (0, testing_library_1.render)(react_1.default.createElement(Drawer_1.Drawer, { isOpen: true, isMobile: true, isCollapsed: true }, "Drawer Content"));
        expect(queryByText('Drawer Content')).toBeFalsy();
    });
    test('renders heading from string prop', () => {
        const { queryByText } = (0, testing_library_1.render)(react_1.default.createElement(Drawer_1.Drawer, { isOpen: true, isMobile: true, isCollapsed: true, heading: 'Default Heading' }, "Drawer Content"));
        expect(queryByText('Default Heading')).toBeTruthy();
    });
    test('renders Drawer with custom heading element', () => {
        const { getByText } = (0, testing_library_1.render)(react_1.default.createElement(Drawer_1.Drawer, { isOpen: true, placement: 'right', onClose: jest.fn, onCollapse: jest.fn, heading: react_1.default.createElement("div", null, "Custom Heading") }, "Content"));
        expect(getByText('Custom Heading')).toBeTruthy();
    });
});
//# sourceMappingURL=Drawer.spec.js.map