"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.HeaderButton = exports.HeadingWrapper = exports.DrawerRoot = exports.DrawerWrapper = void 0;
const styled_components_1 = __importDefault(require("styled-components"));
const Flex_1 = require("../Flex/Flex");
const theme_1 = require("../theme");
const framer_motion_1 = require("framer-motion");
const react_1 = __importDefault(require("react"));
const Absolute_1 = require("../Absolute/Absolute");
const utils_1 = require("../utils");
const Box_1 = require("../Box/Box");
const IconButton_1 = require("../IconButton/IconButton");
const Component = react_1.default.forwardRef((props, ref) => (react_1.default.createElement(Box_1.Box, { ...props, ref: ref })));
const AnimatedAbsolute = (0, framer_motion_1.motion)(Component);
const getBorderRadiusStyles = (placement, isFloating) => {
    const themeRadius = theme_1.theme.borderRadii['2xl'];
    if (isFloating) {
        return themeRadius;
    }
    switch (placement) {
        case 'top':
            return `0px 0px ${themeRadius} ${themeRadius}`;
        case 'right':
            return `${themeRadius} 0px 0px  ${themeRadius}`;
        case 'bottom':
            return `${themeRadius} ${themeRadius} 0px 0px`;
        case 'left':
            return `0px ${themeRadius} ${themeRadius} 0px`;
    }
};
const positions = {
    top: `top:0; left:0; right:0;`,
    right: `right: 0; bottom:0;`,
    bottom: `bottom:0; left:0; right:0;`,
    left: `left:0;bottom:0;`,
};
const getPlacementStyles = (placement) => placement ? `margin-inline:auto; margin-block:auto; ${positions[placement]};` : ``;
exports.DrawerWrapper = (0, styled_components_1.default)(Absolute_1.Absolute) `
  ${({ placement }) => `
    ${getPlacementStyles(placement)}
    `}
`;
exports.DrawerRoot = (0, styled_components_1.default)(AnimatedAbsolute) `
  background-color: ${(0, utils_1.getPaletteColor)('background.lightest')};
  ${({ theme, placement, isFloating }) => `box-shadow: ${theme.shadows['overlay-md']};
    border-radius: ${getBorderRadiusStyles(placement, isFloating)};
    `}
`;
exports.HeadingWrapper = (0, styled_components_1.default)(Flex_1.Flex) ``;
exports.HeaderButton = (0, styled_components_1.default)(IconButton_1.IconButton) `
  background-color: ${(0, utils_1.getPaletteColor)('background.lightest')};
  color: ${(0, utils_1.getPaletteColor)('text.dark')};
  padding: 0;

  &:hover {
    background-color: ${(0, utils_1.getPaletteColor)('background.light')};
    color: ${(0, utils_1.getPaletteColor)('text.dark')};
  }
`;
//# sourceMappingURL=Drawer.styled.js.map