"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Flag = void 0;
const theme_get_1 = __importDefault(require("@styled-system/theme-get"));
const react_1 = __importDefault(require("react"));
const styled_components_1 = __importDefault(require("styled-components"));
const Box_1 = require("../Box/Box");
const Flex_1 = require("../Flex/Flex");
const Hide_1 = require("../Hide/Hide");
const utils_1 = require("../utils/utils");
const capitalize = (str) => str.charAt(0).toUpperCase() + str.slice(1);
const shadowColor = (props) => {
    const darkColor = (0, utils_1.hasPaletteColor)(props)
        ? (0, utils_1.getPaletteColor)('dark')(props)
        : (0, theme_get_1.default)(`colors.dark${capitalize(props.color)}`)(props);
    return {
        backgroundImage: !darkColor
            ? `
        linear-gradient(45deg, transparent 50%, rgba(0, 0, 0, 0.5) 50%),
        linear-gradient(45deg, transparent 50%, ${props.color} 50%)
      `
            : `linear-gradient(45deg, transparent 50%, ${darkColor} 50%)`,
    };
};
const FlagShadow = (0, styled_components_1.default)(Box_1.Box) `
  width: 8px;
  height: 8px;
  align-self: flex-end;
  background-color: inherit;
  ${shadowColor};
  position: absolute;
  bottom: 0;
`;
const FlagRight = (0, styled_components_1.default)(Box_1.Box) `
  flex: none;
  background-color: ${(props) => (0, utils_1.getPaletteColor)('base')(props) || props.color};
  border-radius: 0 ${(0, theme_get_1.default)('radius')} ${(0, theme_get_1.default)('radius')} 0;
  /* for 32 x 8 triangle */
  transform: skew(-14deg);
  position: relative;
  z-index: 1;
`;
const flexAuto = (props) => props.flexAuto
    ? {
        flex: '1 1 auto',
    }
    : null;
const FlagBody = (0, styled_components_1.default)(Box_1.Box) `
  font-size: ${(0, theme_get_1.default)('fontSizes.0')}px;
  border-radius: 0 0 ${(0, theme_get_1.default)('radius')} 0;
  ${flexAuto} ${utils_1.color};
  z-index: 2;
`;
const RelativeHide = (0, styled_components_1.default)(Hide_1.Hide) `
  position: relative;
`;
const StyledFlex = (0, styled_components_1.default)(Flex_1.Flex) `
  ${(0, utils_1.applyVariations)('Flag')}
`;
/**
 * @public
 */
const Flag = ({ color, bg, children, pl, pr, py, width, ...props }) => (react_1.default.createElement(StyledFlex, { width: width, ...props, ml: [0, -2] },
    react_1.default.createElement(RelativeHide, { xs: true },
        react_1.default.createElement(FlagShadow, { width: '4px', mr: -2, mb: -2, color: (0, utils_1.hasPaletteColor)({ color, ...props }) ? color : bg })),
    react_1.default.createElement(FlagBody, { flexAuto: !!width, color: color, bg: (0, utils_1.hasPaletteColor)({ color, ...props }) ? false : bg, pl: pl, pr: pr, py: py }, children),
    react_1.default.createElement(FlagRight, { width: '18px', color: (0, utils_1.hasPaletteColor)({ color, ...props }) ? color : bg, ml: -2 })));
exports.Flag = Flag;
exports.Flag.defaultProps = {
    color: 'white',
    bg: 'green',
    pl: [1, 3],
    pr: null,
    py: [1, 2],
};
exports.Flag.displayName = 'Flag';
//# sourceMappingURL=Flag.js.map