"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CustomPositionUsingMargin = exports.MultiplePositions = exports.MultipleSamePosition = exports.HideUntilScroll = exports.DelayDisplay = exports.Default = void 0;
const react_1 = __importDefault(require("react"));
const addon_actions_1 = require("@storybook/addon-actions");
const testing_library_1 = require("@storybook/testing-library");
const jest_1 = require("@storybook/jest");
const FloatingActionButtonProvider_1 = require("./FloatingActionButtonProvider");
const pcln_icons_1 = require("pcln-icons");
const Box_1 = require("../Box/Box");
const Animate_args_1 = require("../Animate/Animate.args");
exports.default = {
    title: 'Core / FloatingActionButtonProvider',
    component: FloatingActionButtonProvider_1.FloatingActionButtonProvider,
    argTypes: {
        animationVariant: {
            name: 'animationVariant',
            options: Animate_args_1.animateArgs,
            control: 'select',
        },
        position: {
            name: 'position',
            options: ['topRight', 'centerRight', 'bottomRight'],
            control: 'select',
        },
    },
    args: {
        position: 'bottomRight',
        animationVariant: 'slideInBottom',
        floatingActionButtons: [
            {
                tooltip: 'Tooltip Text',
                onClick: (0, addon_actions_1.action)('Clicked FAB'),
                icon: pcln_icons_1.ArrowUp,
                key: 'up_arrow',
            },
        ],
    },
};
exports.Default = {
    render: (args) => (react_1.default.createElement(Box_1.Box, { height: '200px' },
        react_1.default.createElement(FloatingActionButtonProvider_1.FloatingActionButtonProvider, { ...args }))),
    play: async ({ args, canvasElement }) => {
        const canvas = (0, testing_library_1.within)(canvasElement);
        await (0, jest_1.expect)(canvas.getByRole('button')).toBeInTheDocument();
    },
};
exports.DelayDisplay = {
    render: (args) => (react_1.default.createElement(Box_1.Box, { height: '200px' },
        react_1.default.createElement(FloatingActionButtonProvider_1.FloatingActionButtonProvider, { ...args, delayDisplayMs: 2000 }))),
    play: async ({ args, canvasElement }) => {
        const canvas = (0, testing_library_1.within)(canvasElement);
        await (0, jest_1.expect)(canvas.queryByRole('button')).not.toBeInTheDocument();
        setTimeout(async () => {
            await (0, jest_1.expect)(canvas.queryByRole('button')).toBeInTheDocument();
        }, 2100);
    },
};
exports.HideUntilScroll = {
    render: (args) => (react_1.default.createElement(Box_1.Box, { height: '4000px' },
        react_1.default.createElement(Box_1.Box, null, "Scroll down to see FAB "),
        react_1.default.createElement(pcln_icons_1.ArrowDown, null),
        react_1.default.createElement(FloatingActionButtonProvider_1.FloatingActionButtonProvider, { ...args, hideUntilScrollPercent: 10 }))),
    play: async ({ args, canvasElement }) => {
        const canvas = (0, testing_library_1.within)(canvasElement);
        await (0, jest_1.expect)(canvas.queryByRole('button')).not.toBeInTheDocument();
        window.scrollTo({ top: 500 });
        setTimeout(async () => {
            await (0, jest_1.expect)(canvas.getByRole('button')).toBeInTheDocument();
        }, 2000);
    },
};
exports.MultipleSamePosition = {
    render: (args) => (react_1.default.createElement(Box_1.Box, { height: '400px' },
        react_1.default.createElement(FloatingActionButtonProvider_1.FloatingActionButtonProvider, { ...args, floatingActionButtons: [
                {
                    tooltip: 'Tooltip Text',
                    onClick: (0, addon_actions_1.action)('Clicked FAB'),
                    icon: pcln_icons_1.ArrowUp,
                    key: 'up_arrow',
                },
                {
                    tooltip: 'Tooltip Text',
                    onClick: (0, addon_actions_1.action)('Clicked FAB'),
                    icon: pcln_icons_1.ArrowDown,
                    mt: 2,
                    key: 'down_arrow',
                },
            ] }))),
};
exports.MultiplePositions = {
    render: (args) => (react_1.default.createElement(Box_1.Box, { height: '400px' },
        react_1.default.createElement(FloatingActionButtonProvider_1.FloatingActionButtonProvider, { ...args, position: 'topRight', animationVariant: 'slideInTop' }),
        react_1.default.createElement(FloatingActionButtonProvider_1.FloatingActionButtonProvider, { ...args, position: 'centerRight', animationVariant: 'slideInRight', delayDisplayMs: 300 }),
        react_1.default.createElement(FloatingActionButtonProvider_1.FloatingActionButtonProvider, { ...args, delayDisplayMs: 600 }))),
};
exports.CustomPositionUsingMargin = {
    render: (args) => (react_1.default.createElement(Box_1.Box, { height: '400px' },
        react_1.default.createElement(FloatingActionButtonProvider_1.FloatingActionButtonProvider, { ...args, position: 'topRight', animationVariant: 'slideInTop', mt: 6, mr: 6 }))),
};
//# sourceMappingURL=FloatingActionButtonProvider.stories.js.map