"use strict";
// @ts-nocheck
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FormField = void 0;
const react_1 = __importDefault(require("react"));
const styled_components_1 = __importDefault(require("styled-components"));
const Box_1 = require("../Box/Box");
const IconField_1 = require("../IconField/IconField");
const utils_1 = require("../utils/utils");
const DisableableBox = (0, styled_components_1.default)(Box_1.Box) `
  ${(props) => (props.disabled || props.readOnly) &&
    `
    background-color: ${(0, utils_1.getPaletteColor)('background.base')(props)};

    &&& * {
      background-color: transparent;
      color: ${(0, utils_1.getPaletteColor)('text.light')(props)};
      cursor: not-allowed;
    }
  `}
`;
const paddingTopWithLabel = {
    sm: '14px',
    md: '16px',
    lg: '20px',
    xl: '24px',
};
const paddingBottomWithLabel = {
    sm: '0px',
    md: '5px',
    lg: '8px',
    xl: '13px',
};
const paddingTopForLabel = {
    sm: '0px',
    md: '2px',
    lg: '6px',
    xl: '10px',
};
const inputPaddingTop = (size) => {
    return paddingTopWithLabel?.[size] ? paddingTopWithLabel[size] : '20px';
};
const inputPaddingBottom = (size) => {
    return paddingBottomWithLabel?.[size] ? paddingBottomWithLabel[size] : '8px';
};
const labelPaddingTop = (size) => {
    return paddingTopForLabel?.[size] ? paddingTopForLabel[size] : '6px';
};
/**
 * @public
 */
function FormField({ children, disabled, readOnly, ...props }) {
    let iconBefore = false;
    const childrenArray = react_1.default.Children.toArray(children);
    const [field] = childrenArray.filter((child) => child.type.isField);
    const [label] = childrenArray.filter((child) => child.type.isLabel);
    const valueNoLabel = !label && field && !!field.props.value;
    const showLabel = ((label && !label.props.autoHide) || (field && !!field.props.value)) && !valueNoLabel;
    const id = field && (field.props.id || field.props.name);
    const inputSize = field && (field.props.size || undefined);
    const styled = childrenArray.map((child, i, arr) => {
        if (child.type.isField && arr[i - 1] && arr[i - 1].type.isIcon) {
            iconBefore = true;
        }
        if (child === field) {
            return react_1.default.cloneElement(child, {
                id,
                disabled,
                readOnly,
                style: {
                    ...child.props.style,
                    transitionProperty: 'padding-top, padding-bottom',
                    transitionDuration: '.1s',
                    paddingTop: showLabel ? inputPaddingTop(inputSize) : undefined,
                    paddingBottom: showLabel ? inputPaddingBottom(inputSize) : undefined,
                },
            });
        }
        return child;
    });
    const ml = iconBefore ? '40px' : '12px';
    const styledLabel = label &&
        react_1.default.cloneElement(label, {
            htmlFor: label.props.htmlFor || id,
            fontSize: 10,
            ml,
            pt: labelPaddingTop(inputSize),
            mb: '-20px',
            style: {
                ...label.props.style,
                height: 20,
                transitionProperty: 'opacity',
                transitionDuration: '.1s',
                opacity: showLabel ? 1 : 0,
                pointerEvents: 'none',
                position: 'relative',
                width: `calc(100% - ${ml})`,
            },
        });
    return (react_1.default.createElement(DisableableBox, { ...props, borderRadius: 'lg', disabled: disabled, readOnly: readOnly },
        styledLabel,
        react_1.default.createElement(IconField_1.IconField, null, styled)));
}
exports.FormField = FormField;
FormField.displayName = 'FormField';
//# sourceMappingURL=FormField.js.map