"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const pcln_icons_1 = require("pcln-icons");
const react_1 = __importDefault(require("react"));
const Input_1 = require("../Input/Input");
const Label_1 = require("../Label/Label");
const Select_1 = require("../Select/Select");
const testing_library_1 = require("../__test__/testing-library");
const FormField_1 = require("./FormField");
afterEach(() => {
    // bust cache for propTypes
    FormField_1.FormField.displayName = 'FormField' + Math.random();
});
describe('FormField', () => {
    test('renders', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(FormField_1.FormField, null,
            react_1.default.createElement(Label_1.Label, null, "Email Address"),
            react_1.default.createElement(Input_1.Input, { id: 'email', name: 'email' }))).toJSON();
        expect(json).toMatchSnapshot();
    });
    test('renders with Icon', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(FormField_1.FormField, null,
            react_1.default.createElement(Label_1.Label, null, "Email Address"),
            react_1.default.createElement(pcln_icons_1.Email, null),
            react_1.default.createElement(Input_1.Input, { id: 'email', name: 'email' }))).toJSON();
        expect(json).toMatchSnapshot();
    });
    test('renders with Select ', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(FormField_1.FormField, null,
            react_1.default.createElement(Label_1.Label, null, "Pick Option"),
            react_1.default.createElement(Select_1.Select, null))).toJSON();
        expect(json).toMatchSnapshot();
    });
    test('renders with Select and Icon', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(FormField_1.FormField, null,
            react_1.default.createElement(Label_1.Label, null, "Pick Email Address"),
            react_1.default.createElement(pcln_icons_1.Email, null),
            react_1.default.createElement(Select_1.Select, null))).toJSON();
        expect(json).toMatchSnapshot();
    });
    test('renders with Label autoHide prop', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(FormField_1.FormField, null,
            react_1.default.createElement(Label_1.Label, { autoHide: true }, "Email"),
            react_1.default.createElement(pcln_icons_1.Email, null),
            react_1.default.createElement(Input_1.Input, { id: 'email', name: 'email' }))).toJSON();
        expect(json).toMatchSnapshot();
    });
    test('shows Label with autoHide prop and field value', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(FormField_1.FormField, null,
            react_1.default.createElement(Label_1.Label, { autoHide: true }, "Email"),
            react_1.default.createElement(pcln_icons_1.Email, null),
            react_1.default.createElement(Input_1.Input, { id: 'email', name: 'email', value: 'hello@example.com' }))).toJSON();
        const [label] = json.children;
        expect(label.props.style.opacity).toBe(1);
    });
    test('adds htmlFor prop to Label', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(FormField_1.FormField, null,
            react_1.default.createElement(Label_1.Label, null),
            react_1.default.createElement(Input_1.Input, { id: 'hello', name: 'hello' }))).toJSON();
        const [label] = json.children;
        expect(label.props.htmlFor).toBe('hello');
    });
    describe('disabled state', () => {
        it('renders input with icon - disabled', () => {
            const { asFragment } = (0, testing_library_1.render)(react_1.default.createElement(FormField_1.FormField, { disabled: true },
                react_1.default.createElement(Label_1.Label, null, "Email Address"),
                react_1.default.createElement(pcln_icons_1.Email, { "data-testid": 'email-icon' }),
                react_1.default.createElement(Input_1.Input, { id: 'email', name: 'email', placeholder: 'Email' })));
            expect(asFragment()).toMatchSnapshot();
        });
        it('renders select with icon - disabled', () => {
            const { asFragment } = (0, testing_library_1.render)(react_1.default.createElement(FormField_1.FormField, { disabled: true },
                react_1.default.createElement(Label_1.Label, null, "Pick Email Address"),
                react_1.default.createElement(pcln_icons_1.Email, null),
                react_1.default.createElement(Select_1.Select, { defaultValue: 'Premium Economy' },
                    react_1.default.createElement("option", null, "Premium Economy"))));
            expect(asFragment()).toMatchSnapshot();
        });
    });
});
//# sourceMappingURL=FormField.spec.js.map