"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.GenericBanner = void 0;
const react_1 = __importDefault(require("react"));
const styled_components_1 = __importDefault(require("styled-components"));
const Banner_1 = require("../Banner/Banner");
const Box_1 = require("../Box/Box");
const Button_1 = require("../Button/Button");
const Flex_1 = require("../Flex/Flex");
const Link_1 = require("../Link/Link");
const Relative_1 = require("../Relative/Relative");
const utils_1 = require("../utils/utils");
const BannerWithRadius = (0, styled_components_1.default)(Banner_1.Banner) `
  cursor: ${(props) => (props.onClick ? 'pointer' : 'cursor')};

  ${utils_1.colorSchemeCustomForeground}
`;
const WrapperLink = styled_components_1.default.a `
  z-index: 1;
  display: block;
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
`;
const CustomLink = (0, styled_components_1.default)(Link_1.Link) `
  display: inline-flex;
  z-index: 2;
`;
const CustomButton = (0, styled_components_1.default)(Button_1.Button) `
  z-index: 2;
  text-decoration: ${(props) => (props.buttonTextUnderline ? 'underline' : 'none')};
`;
/**
 * @public
 */
function GenericBanner({ alignItems, buttonClick, buttonSize, buttonVariation, ctaText, fontSize, heading, iconLeft, iconRight, imageLeft, justifyContent, linkVariation, linkColor, text, 
/* eslint-disable @typescript-eslint/naming-convention */
URLProps, ...props }) {
    function onClick(e) {
        e.stopPropagation();
        buttonClick();
    }
    return (react_1.default.createElement(Relative_1.Relative, null,
        URLProps && react_1.default.createElement(WrapperLink, { tabIndex: -1, "aria-hidden": 'true', ...URLProps }),
        react_1.default.createElement(BannerWithRadius, { ...props, onClick: URLProps ? null : buttonClick, iconUsesColorScheme: true, 
            // we need to unset Banner's color prop if colorScheme is provided so it doesn't render its own icon
            color: !props.colorScheme ? props.color : null },
            react_1.default.createElement(Flex_1.Flex, { alignItems: alignItems, justifyContent: justifyContent },
                !!iconLeft && iconLeft,
                !!imageLeft && imageLeft,
                react_1.default.createElement(Box_1.Box, { px: 2 },
                    !!heading &&
                        react_1.default.cloneElement(heading, {
                            fontSize: heading.props.fontSize || fontSize,
                        }),
                    !!text &&
                        react_1.default.cloneElement(text, {
                            fontSize,
                        }),
                    URLProps && ctaText && (react_1.default.createElement(CustomLink, { p: linkVariation === 'fill' || linkVariation === 'outline' ? 2 : null, color: linkColor, variation: linkVariation, fontSize: fontSize, ...URLProps }, react_1.default.cloneElement(ctaText, {
                        fontSize,
                        zIndex: 2,
                    }))),
                    buttonClick && typeof buttonClick === 'function' && ctaText && (react_1.default.createElement(CustomButton, { size: buttonSize, buttonTextUnderline: buttonVariation === 'link', variation: buttonVariation, onClick: onClick }, react_1.default.cloneElement(ctaText, {
                        fontSize,
                    })))),
                !!iconRight && iconRight))));
}
exports.GenericBanner = GenericBanner;
GenericBanner.defaultProps = {
    alignItems: 'center',
    buttonVariation: 'link',
    fontSize: [0, null, null, 1],
    justifyContent: 'center',
    linkColor: 'primary',
    linkVariation: 'link',
    borderRadius: '6px',
};
//# sourceMappingURL=GenericBanner.js.map