"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const pcln_icons_1 = require("pcln-icons");
const react_1 = __importDefault(require("react"));
const Image_1 = require("../Image/Image");
const Text_1 = require("../Text/Text");
const testing_library_1 = require("../__test__/testing-library");
const GenericBanner_1 = require("./GenericBanner");
const props = {
    p: 2,
    heading: (react_1.default.createElement(Text_1.Text.span, { fontWeight: 'bold', textColor: 'primary.base', mr: 1 }, "COVID-19")),
    text: (react_1.default.createElement(Text_1.Text.span, { textColor: 'primary.base', mr: 1 }, "Update: Your travel may be impacted. Please review this hotels important info.")),
    ctaText: (react_1.default.createElement(Text_1.Text.span, { textColor: 'primary.base', fontWeight: 'bold' }, "Read More")),
    imageLeft: react_1.default.createElement(Image_1.Image, { alt: 'ImageLeft' }),
    iconLeft: react_1.default.createElement(pcln_icons_1.Warning, null),
    iconRight: react_1.default.createElement(pcln_icons_1.Emoticon, null),
    color: 'caution.light',
};
const propsUpdatedHeading = {
    ...props,
    heading: (react_1.default.createElement(Text_1.Text.span, { fontWeight: 'bold', textColor: 'primary.base', mr: 1, fontSize: 4 }, "COVID-19")),
};
describe('GenericBanner', () => {
    test('renders', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(GenericBanner_1.GenericBanner, null)).toJSON();
        expect(json).toMatchSnapshot();
    });
    test('Renders as expected-onclick', () => {
        const buttonClick = jest.fn();
        const { getByText } = (0, testing_library_1.render)(react_1.default.createElement(GenericBanner_1.GenericBanner, { ...props, buttonClick: buttonClick }));
        const header = getByText('COVID-19');
        const text = getByText('Update: Your travel may be impacted. Please review this hotels important info.');
        expect(header).toBeTruthy();
        expect(text).toBeTruthy();
        const readMoreButton = getByText('Read More');
        expect(readMoreButton).toBeTruthy();
        testing_library_1.fireEvent.click(readMoreButton);
        expect(buttonClick).toHaveBeenCalled();
        expect(readMoreButton).toHaveStyleRule('font-size', '12px');
        expect(header).toHaveStyleRule('font-size', '12px');
        expect(text).toHaveStyleRule('font-size', '12px');
    });
    test('Renders as expected- url', () => {
        const { getByText, getByRole } = (0, testing_library_1.render)(react_1.default.createElement(GenericBanner_1.GenericBanner, { ...props, URLProps: {
                href: 'https://www.priceline.com',
                target: '_blank',
            } }));
        const header = getByText('COVID-19');
        const text = getByText('Update: Your travel may be impacted. Please review this hotels important info.');
        expect(getByRole('img')).toBeTruthy();
        expect(header).toBeTruthy();
        expect(text).toBeTruthy();
        const readMoreButton = getByText('Read More');
        expect(readMoreButton).toBeTruthy();
        testing_library_1.fireEvent.click(readMoreButton);
        expect(readMoreButton).toHaveStyleRule('font-size', '12px');
        expect(header).toHaveStyleRule('font-size', '12px');
        expect(text).toHaveStyleRule('font-size', '12px');
    });
    test('Renders as expected- with different heading size', () => {
        const { getByText, getByRole } = (0, testing_library_1.render)(react_1.default.createElement(GenericBanner_1.GenericBanner, { ...propsUpdatedHeading, URLProps: {
                href: 'https://www.priceline.com',
                target: '_blank',
            } }));
        const header = getByText('COVID-19');
        const text = getByText('Update: Your travel may be impacted. Please review this hotels important info.');
        expect(getByRole('img')).toBeTruthy();
        expect(header).toBeTruthy();
        expect(text).toBeTruthy();
        const readMoreButton = getByText('Read More');
        expect(readMoreButton).toBeTruthy();
        testing_library_1.fireEvent.click(readMoreButton);
        expect(readMoreButton).toHaveStyleRule('font-size', '12px');
        expect(header).toHaveStyleRule('font-size', '24px');
        expect(text).toHaveStyleRule('font-size', '12px');
    });
});
//# sourceMappingURL=GenericBanner.spec.js.map