"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ResponsiveLayout = exports.NestedGrids = exports.TemplateAreas = exports.Playground = void 0;
const addon_docs_1 = require("@storybook/addon-docs");
const addon_links_1 = require("@storybook/addon-links");
const react_1 = __importDefault(require("react"));
const Box_1 = require("../Box/Box");
const Hero_1 = require("../DocsUtils/Hero/Hero");
const RelatedComponent_1 = require("../DocsUtils/RelatedComponent/RelatedComponent");
const Section_1 = require("../DocsUtils/Section/Section");
const StoryHeading_1 = require("../DocsUtils/StoryHeading/StoryHeading");
const TableOfContents_1 = require("../DocsUtils/TableOfContents/TableOfContents");
const Flex_1 = require("../Flex/Flex");
const Grid_1 = require("../Grid/Grid");
const Text_1 = require("../Text/Text");
const ThemeProvider_1 = require("../ThemeProvider/ThemeProvider");
const GridItem = (props) => react_1.default.createElement(Grid_1.Grid, { p: 4, width: 1, placeItems: 'center', ...props });
exports.Playground = {
    render: () => (react_1.default.createElement(Grid_1.Grid, { templateColumns: ['1fr', '1fr 1fr', '1fr 1fr 1fr'], placeItems: 'center', gap: 2 },
        react_1.default.createElement(GridItem, { style: { background: '#00f8' } }, "A"),
        react_1.default.createElement(GridItem, { style: { background: '#0f08' } }, "B"),
        react_1.default.createElement(GridItem, { style: { background: '#0ff8' } }, "C"),
        react_1.default.createElement(GridItem, { style: { background: '#f008' } }, "D"),
        react_1.default.createElement(GridItem, { style: { background: '#f0f8' } }, "E"),
        react_1.default.createElement(GridItem, { style: { background: '#ff08' } }, "F"))),
};
exports.TemplateAreas = {
    render: () => (react_1.default.createElement(Grid_1.Grid, { templateAreas: `
        'header header' 
        'sidebar content'
        'footer footer'
      `, placeItems: 'center', minHeight: 'calc(100vh - 5rem)', templateRows: 'auto 1fr auto', templateColumns: '15em 1fr', gap: 2 },
        react_1.default.createElement(GridItem, { gridArea: 'header', style: { background: '#00f8' } }, "Header"),
        react_1.default.createElement(GridItem, { gridArea: 'sidebar', height: '100%', style: { background: '#0f08' } }, "Sidebar"),
        react_1.default.createElement(GridItem, { gridArea: 'content', height: '100%', style: { background: '#0ff8' } }, "Content"),
        react_1.default.createElement(GridItem, { gridArea: 'footer', mt: 'auto', style: { background: '#f008' } }, "Footer"))),
};
exports.NestedGrids = {
    render: () => (react_1.default.createElement(Grid_1.Grid, { templateColumns: '1fr 1fr', placeItems: 'center', gap: 2 },
        react_1.default.createElement(GridItem, { style: { background: '#00f8' } }, "A"),
        react_1.default.createElement(GridItem, { style: { background: '#0f08' } }, "B"),
        react_1.default.createElement(GridItem, { style: { background: '#0ff8' } }, "C"),
        react_1.default.createElement(Grid_1.Grid, { width: 1, templateColumns: '1fr 1fr 1fr', placeItems: 'center', gap: 2 },
            react_1.default.createElement(GridItem, { style: { background: '#f008' } }, "D"),
            react_1.default.createElement(GridItem, { style: { background: '#f0f8' } }, "E"),
            react_1.default.createElement(GridItem, { style: { background: '#ff08' } }, "F")))),
};
exports.ResponsiveLayout = {
    render: () => (react_1.default.createElement(Grid_1.Grid, { templateColumns: [
            '1fr',
            '1fr 1fr',
            '1fr 1fr 1fr',
            '1fr 1fr 1fr 1fr',
            '1fr 1fr 1fr 1fr 1fr',
            '1fr 1fr 1fr 1fr 1fr 1fr',
        ], placeItems: 'center', gap: 2 },
        react_1.default.createElement(GridItem, { style: { background: '#00f8' } }, "A"),
        react_1.default.createElement(GridItem, { style: { background: '#0f08' } }, "B"),
        react_1.default.createElement(GridItem, { style: { background: '#0ff8' } }, "C"),
        react_1.default.createElement(GridItem, { style: { background: '#f008' } }, "D"),
        react_1.default.createElement(GridItem, { style: { background: '#f0f8' } }, "E"),
        react_1.default.createElement(GridItem, { style: { background: '#ff08' } }, "F"))),
};
const meta = {
    title: 'Layout/Grid',
    component: Grid_1.Grid,
    parameters: {
        docs: {
            page: () => (react_1.default.createElement(ThemeProvider_1.ThemeProvider, null,
                react_1.default.createElement(Hero_1.Hero, { name: 'Grid', img: '' }, "Grids divide a web page into rows and columns and offer comprehensive features for controlling the sizing and positioning of grid items, including the ability to define grid areas, set grid gaps, and control the alignment and distribution of grid items"),
                react_1.default.createElement(TableOfContents_1.TableOfContents, { links: ['Overview', 'Props', 'Examples', 'Related Components'] }),
                react_1.default.createElement(Section_1.Section, { heading: 'Overview' },
                    react_1.default.createElement(Text_1.Text, { textStyle: 'paragraph' }, "Grid is based on the CSS Grid Layout Module, which provides a two-dimensional grid-based layout system, with rows and columns, making it easier to design web pages and components.")),
                react_1.default.createElement(Section_1.Section, { heading: 'Props' },
                    react_1.default.createElement(addon_docs_1.Primary, null),
                    react_1.default.createElement(addon_docs_1.ArgsTable, { story: addon_docs_1.PRIMARY_STORY })),
                react_1.default.createElement(Section_1.Section, { heading: 'Examples' },
                    react_1.default.createElement(StoryHeading_1.StoryHeading, { storyName: 'Template Areas', storyTitle: meta.title }),
                    react_1.default.createElement(Text_1.Text, { textStyle: 'paragraph' },
                        "Using the ",
                        react_1.default.createElement("code", null, "gridTemplateAreas"),
                        " prop, you can define grid areas and assign grid items to them. The grid areas are defined by using the ",
                        react_1.default.createElement("code", null, "grid-area"),
                        " property on the grid items. The ",
                        react_1.default.createElement("code", null, "grid-area"),
                        " property can be used to assign a name to a grid item, which can then be used as a value of the ",
                        react_1.default.createElement("code", null, "grid-template-areas"),
                        " property."),
                    react_1.default.createElement(StoryHeading_1.StoryHeading, { storyName: 'Nested Grids', storyTitle: meta.title }),
                    react_1.default.createElement(Text_1.Text, { textStyle: 'paragraph' }, "Grids can be nested inside other grids. This allows you to create more complex layouts."),
                    react_1.default.createElement(StoryHeading_1.StoryHeading, { storyName: 'Responsive Layout', storyTitle: meta.title }),
                    react_1.default.createElement(Text_1.Text, { textStyle: 'paragraph' },
                        "Grids can be responsive. You can define the number of columns for each breakpoint using the",
                        react_1.default.createElement("code", null, "templateColumns"),
                        " prop.")),
                react_1.default.createElement(Section_1.Section, { heading: 'Related Components' },
                    react_1.default.createElement(RelatedComponent_1.RelatedComponentContainer, null,
                        react_1.default.createElement(RelatedComponent_1.RelatedComponent, { name: 'Box', onClick: (0, addon_links_1.linkTo)('Core/Box') },
                            react_1.default.createElement(Box_1.Box, { width: '75%', height: '75%', bg: 'background.lightest' }, "Box")),
                        react_1.default.createElement(RelatedComponent_1.RelatedComponent, { name: 'Flex', onClick: (0, addon_links_1.linkTo)('Flex') },
                            react_1.default.createElement(Flex_1.Flex, { justifyContent: 'center', alignItems: 'center', width: '75%', height: '75%', bg: 'background.lightest' }, "Flex")))))),
        },
    },
};
exports.default = meta;
//# sourceMappingURL=Grid.stories.js.map