"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Hide = void 0;
const styled_components_1 = __importDefault(require("styled-components"));
const Box_1 = require("../Box/Box");
const Text_1 = require("../Text/Text");
const getMaxWidth = (em) => parseInt(em) - 0.01;
const breakpoints = (props) => ({
    xs: `@media screen and (max-width: ${getMaxWidth(props.theme.breakpoints[0])}em)`,
    sm: `@media screen and (min-width: ${props.theme.breakpoints[0]}) and (max-width: ${getMaxWidth(props.theme.breakpoints[1])}em)`,
    md: `@media screen and (min-width: ${props.theme.breakpoints[1]}) and (max-width: ${getMaxWidth(props.theme.breakpoints[2])}em)`,
    lg: `@media screen and (min-width: ${props.theme.breakpoints[2]}) and (max-width: ${getMaxWidth(props.theme.breakpoints[3])}em)`,
    xl: `@media screen and (min-width: ${props.theme.breakpoints[3]}) and (max-width: ${getMaxWidth(props.theme.breakpoints[4])}em)`,
    xxl: `@media screen and (min-width: ${props.theme.breakpoints[4]})`,
    print: `@media print`,
});
const hidden = (key) => (props) => props[key]
    ? {
        [breakpoints(props)[key]]: {
            display: 'none',
        },
    }
    : null;
/**
 * @public
 */
exports.Hide = (0, styled_components_1.default)(Box_1.Box) `
  ${hidden('xs')}
  ${hidden('sm')}
  ${hidden('md')}
  ${hidden('lg')}
  ${hidden('xl')}
  ${hidden('xxl')}
  ${hidden('print')};
`;
exports.Hide.displayName = 'Hide';
exports.Hide.text = (0, styled_components_1.default)(Text_1.Text) `
  display: inline;
  ${hidden('xs')}
  ${hidden('sm')}
  ${hidden('md')}
  ${hidden('lg')}
  ${hidden('xl')}
  ${hidden('xxl')}
  ${hidden('print')};
`;
//# sourceMappingURL=Hide.js.map