"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const pcln_icons_1 = require("pcln-icons");
const react_1 = __importDefault(require("react"));
const IconButton_1 = require("../IconButton/IconButton");
const Input_1 = require("../Input/Input");
const testing_library_1 = require("../__test__/testing-library");
const IconField_1 = require("./IconField");
describe('IconField', () => {
    it('renders', () => {
        (0, testing_library_1.render)(react_1.default.createElement(IconField_1.IconField, { "data-testid": 'icon-field' },
            react_1.default.createElement(pcln_icons_1.Calendar, { title: 'calendar' }),
            react_1.default.createElement(Input_1.Input, { id: 'test', placeholder: 'IconField' })));
        testing_library_1.screen.getByTestId('icon-field');
        testing_library_1.screen.getAllByTitle('calendar');
        testing_library_1.screen.getByPlaceholderText('IconField');
    });
    it('renders icon button', () => {
        (0, testing_library_1.render)(react_1.default.createElement(IconField_1.IconField, null,
            react_1.default.createElement(Input_1.Input, { id: 'test', placeholder: 'IconField' }),
            react_1.default.createElement(IconButton_1.IconButton, { id: 'test', icon: react_1.default.createElement(pcln_icons_1.Close, { title: 'close' }) })));
        testing_library_1.screen.getByPlaceholderText('IconField');
        testing_library_1.screen.getAllByTitle('close');
        testing_library_1.screen.getByRole('button');
    });
    it('renders icon, input and icon button together', () => {
        (0, testing_library_1.render)(react_1.default.createElement(IconField_1.IconField, null,
            react_1.default.createElement(pcln_icons_1.Calendar, { title: 'calendar' }),
            react_1.default.createElement(Input_1.Input, { id: 'test', placeholder: 'IconField' }),
            react_1.default.createElement(IconButton_1.IconButton, { id: 'test', icon: react_1.default.createElement(pcln_icons_1.Close, { title: 'close' }) })));
        testing_library_1.screen.getAllByTitle('calendar');
        testing_library_1.screen.getByPlaceholderText('IconField');
        testing_library_1.screen.getAllByTitle('close');
        testing_library_1.screen.getByRole('button');
    });
    it('does not render unknown children', () => {
        (0, testing_library_1.render)(react_1.default.createElement(IconField_1.IconField, { "data-testid": 'icon-field' },
            react_1.default.createElement("pre", null, "Does not render")));
        expect(testing_library_1.screen.queryByTestId('icon-field')).not.toBeInTheDocument();
    });
    it('does not add styles for no icons', () => {
        (0, testing_library_1.render)(react_1.default.createElement(IconField_1.IconField, null,
            react_1.default.createElement(Input_1.Input, { id: 'test', placeholder: 'IconField' })));
        const prefixIconWrapper = testing_library_1.screen.queryByTestId('icon-field-prefix-icons');
        const suffixIconWrapper = testing_library_1.screen.queryByTestId('icon-field-suffix-icons');
        const input = testing_library_1.screen.getByPlaceholderText('IconField');
        expect(prefixIconWrapper).not.toBeInTheDocument();
        expect(suffixIconWrapper).not.toBeInTheDocument();
        expect(input).not.toHaveStyleRule('padding-left');
        expect(input).not.toHaveStyleRule('padding-right');
    });
    it('adds styles for single icons', () => {
        (0, testing_library_1.render)(react_1.default.createElement(IconField_1.IconField, null,
            react_1.default.createElement(pcln_icons_1.Calendar, { title: 'calendar' }),
            react_1.default.createElement(Input_1.Input, { id: 'test', placeholder: 'IconField' }),
            react_1.default.createElement(pcln_icons_1.Close, { title: 'close' })));
        const calendarIcon = testing_library_1.screen.getAllByTitle('calendar')[0];
        const closeIcon = testing_library_1.screen.getAllByTitle('close')[0];
        const prefixIconWrapper = testing_library_1.screen.getByTestId('icon-field-prefix-icons');
        const suffixIconWrapper = testing_library_1.screen.getByTestId('icon-field-suffix-icons');
        const input = testing_library_1.screen.getByPlaceholderText('IconField');
        expect(calendarIcon).toHaveStyleRule('margin-left', '8px');
        expect(calendarIcon).toHaveStyleRule('margin-right', '8px');
        expect(closeIcon).toHaveStyleRule('margin-left', '8px');
        expect(closeIcon).toHaveStyleRule('margin-right', '8px');
        expect(prefixIconWrapper).toHaveStyleRule('margin-right', '-40px');
        expect(suffixIconWrapper).toHaveStyleRule('margin-left', '-40px');
        expect(input).toHaveStyleRule('padding-left', '40px');
        expect(input).toHaveStyleRule('padding-right', '40px');
    });
    it('adds styles for multiple icons', () => {
        (0, testing_library_1.render)(react_1.default.createElement(IconField_1.IconField, null,
            react_1.default.createElement(pcln_icons_1.User, { title: 'user' }),
            react_1.default.createElement(pcln_icons_1.Calendar, { title: 'calendar' }),
            react_1.default.createElement(Input_1.Input, { id: 'test', placeholder: 'IconField' }),
            react_1.default.createElement(pcln_icons_1.Visibility, { title: 'visibility' }),
            react_1.default.createElement(pcln_icons_1.Close, { title: 'close' })));
        const prefixIconWrapper = testing_library_1.screen.getByTestId('icon-field-prefix-icons');
        const suffixIconWrapper = testing_library_1.screen.getByTestId('icon-field-suffix-icons');
        const input = testing_library_1.screen.getByPlaceholderText('IconField');
        const calendarIcon = testing_library_1.screen.getAllByTitle('calendar')[0];
        const closeIcon = testing_library_1.screen.getAllByTitle('close')[0];
        expect(prefixIconWrapper).toHaveStyleRule('margin-right', '-80px');
        expect(suffixIconWrapper).toHaveStyleRule('margin-left', '-80px');
        expect(input).toHaveStyleRule('padding-left', '80px');
        expect(input).toHaveStyleRule('padding-right', '80px');
        expect(calendarIcon).toHaveStyleRule('margin-left', '0px');
        expect(calendarIcon).toHaveStyleRule('margin-right', '8px');
        expect(closeIcon).toHaveStyleRule('margin-left', '8px');
        expect(closeIcon).toHaveStyleRule('margin-right', '0px');
    });
});
//# sourceMappingURL=IconField.spec.js.map