"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const testing_library_1 = require("../__test__/testing-library");
const Label_1 = require("./Label");
describe('Label', () => {
    test('it renders', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Label_1.Label, null)).toJSON();
        expect(json).toMatchSnapshot();
    });
    test('Label hidden renders', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Label_1.Label, { hidden: true })).toJSON();
        expect(json).toMatchSnapshot();
    });
    test('Label nowrap renders', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Label_1.Label, { nowrap: true })).toJSON();
        expect(json).toMatchSnapshot();
    });
    test('Label width renders', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Label_1.Label, { width: 1 / 2, nowrap: true })).toJSON();
        expect(json).toMatchSnapshot();
    });
    test('Label clickable renders with cursor pointer', () => {
        const mockOnClick = jest.fn();
        (0, testing_library_1.render)(react_1.default.createElement(Label_1.Label, { onClick: mockOnClick }, "Clickable Label"));
        const label = testing_library_1.screen.getByText('Clickable Label');
        expect(label).toHaveStyleRule('cursor', 'pointer');
        expect(mockOnClick).toHaveBeenCalledTimes(0);
        testing_library_1.fireEvent.click(label);
        expect(mockOnClick).toHaveBeenCalledTimes(1);
    });
});
//# sourceMappingURL=Label.spec.js.map