"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Layout = exports.ALLOWED_GAP_VALUES = exports.ALLOWED_LAYOUT_VALUES = void 0;
const react_1 = __importStar(require("react"));
const styled_components_1 = __importDefault(require("styled-components"));
const styled_system_1 = require("styled-system");
const Box_1 = require("../Box/Box");
const Grid_1 = require("../Grid/Grid");
const theme_1 = require("../theme");
const getWidthsForVariation = (variation) => {
    return (variation &&
        variation
            .split('-')
            .map((width) => `${parseInt(width, 10) / 10}fr`)
            .join(' '));
};
/**
 * Returns an array of responsive arrays of numbers with same length as numChildren. Each value represents the
 * width of the corresponding child.
 * @param variation - variation string to determine how items are sized
 * @param numChildren - number of children
 * @returns
 */
const getGridTemplateColumns = (variation) => {
    if (Array.isArray(variation)) {
        return variation.map((v) => {
            return getWidthsForVariation(v);
        });
    }
    else {
        return getWidthsForVariation(variation);
    }
};
// After converting Layout from using Flex to Grid, we need to multiply
// the space values by 2 since we're using them for gap instead of padding on each child.
const spaceToGapValue = (idx) => `${theme_1.spaceValues[idx] * 2}px`;
// Map named sizes to responsive size values from theme
const gapValues = {
    sm: spaceToGapValue(1),
    md: spaceToGapValue(2),
    lg: spaceToGapValue(3),
    xl: spaceToGapValue(4),
};
/**
 * Returns an object containing responsive arrays of values for mx to apply to
 * the wrapper flex and px values to apply to the children.
 * @param gapProp - value passed in as gap prop
 * @returns
 */
const getGapValues = (gapProp, rowGapProp) => {
    let columnGap;
    let rowGap;
    if (Array.isArray(rowGapProp)) {
        rowGap = rowGapProp.map((gap) => gapValues[gap] || null);
    }
    else {
        rowGap = gapValues[rowGapProp];
    }
    if (Array.isArray(gapProp)) {
        columnGap = gapProp.map((gap) => gapValues[gap] || null);
    }
    else {
        columnGap = gapValues[gapProp];
    }
    return { columnGap, rowGap };
};
/**
 * @public
 */
exports.ALLOWED_LAYOUT_VALUES = [
    '50-50',
    '33-33-33',
    '33-66',
    '66-33',
    '25-25-25-25',
    '60-40',
    '40-60',
    '100',
];
/**
 * @public
 */
exports.ALLOWED_GAP_VALUES = ['sm', 'md', 'lg', 'xl'];
const ZIndexBox = (0, styled_components_1.default)(Box_1.Box) `
  ${styled_system_1.zIndex}
`;
/**
 * @public
 */
function Layout({ children, gap, rowGap, variation, stretchHeight, ...props }) {
    const [gapValues, setGapValues] = (0, react_1.useState)(getGapValues(gap, rowGap));
    const [gridTemplateColumns, setGridTemplateColumns] = (0, react_1.useState)(getGridTemplateColumns(variation));
    (0, react_1.useEffect)(() => {
        setGapValues(getGapValues(gap, rowGap));
    }, [gap, rowGap]);
    (0, react_1.useEffect)(() => {
        setGridTemplateColumns(getGridTemplateColumns(variation));
    }, [variation]);
    return (react_1.default.createElement(Grid_1.Grid, { ...props, "data-testid": 'layout-grid', width: 1, gridTemplateColumns: gridTemplateColumns, rowGap: gapValues.rowGap, columnGap: gapValues.columnGap }, react_1.default.Children.map(children, (child, idx) => child &&
        react_1.default.isValidElement(child) && (react_1.default.createElement(ZIndexBox, { "data-testid": `box-${idx}`, 
        // TS ignored because the type of child.props is unknown
        // @ts-ignore
        zIndex: child?.props?.zIndex }, react_1.default.cloneElement(child, {
        minHeight: stretchHeight ? '100%' : undefined,
    }))))));
}
exports.Layout = Layout;
Layout.displayName = 'Layout';
//# sourceMappingURL=Layout.js.map