"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const testing_library_1 = require("../__test__/testing-library");
const Link_1 = require("./Link");
describe('Link', () => {
    it('should render correctly with no props without throwing', () => {
        expect(() => {
            const { asFragment } = (0, testing_library_1.render)(react_1.default.createElement(Link_1.Link, null, "Dummy"));
            expect(asFragment()).toMatchSnapshot();
        }).not.toThrow();
    });
    it('should add rel="noopener" when target="_blank"', () => {
        const { asFragment } = (0, testing_library_1.render)(react_1.default.createElement(Link_1.Link, { target: '_blank' }, "Dummy"));
        expect(asFragment()).toMatchSnapshot();
        const link = testing_library_1.screen.getByText('Dummy');
        expect(link).toHaveAttribute('target', '_blank');
        expect(link).toHaveAttribute('rel', 'noopener');
    });
    it('should not add rel="noopener" when target is not "_blank"', () => {
        const { asFragment } = (0, testing_library_1.render)(react_1.default.createElement(Link_1.Link, null, "Dummy"));
        expect(asFragment()).toMatchSnapshot();
        const link = testing_library_1.screen.getByText('Dummy');
        expect(link).not.toHaveAttribute('target', '_blank');
        expect(link).not.toHaveAttribute('rel', 'noopener');
    });
    it('should be clickable when not disabled', () => {
        const mockOnClick = jest.fn();
        (0, testing_library_1.render)(react_1.default.createElement(Link_1.Link, { href: 'href', onClick: mockOnClick }, "Enabled"));
        const link = testing_library_1.screen.getByText('Enabled');
        expect(link).toHaveAttribute('href');
        expect(link).toHaveStyleRule('color', '#0068ef');
        expect(link).toHaveStyleRule('cursor', 'pointer');
        expect(link).toHaveStyleRule('text-decoration', 'underline', { modifier: ':hover' });
        expect(mockOnClick).toHaveBeenCalledTimes(0);
        testing_library_1.fireEvent.click(link);
        expect(mockOnClick).toHaveBeenCalledTimes(1);
    });
    it('should not be clickable when disabled', () => {
        const mockOnClick = jest.fn();
        (0, testing_library_1.render)(react_1.default.createElement(Link_1.Link, { disabled: true, href: 'href', onClick: mockOnClick }, "Disabled"));
        const link = testing_library_1.screen.getByText('Disabled');
        expect(link).not.toHaveAttribute('href');
        expect(link).toHaveStyleRule('color', '#4f6f8f');
        expect(link).toHaveStyleRule('cursor', 'default');
        expect(link).toHaveStyleRule('text-decoration', 'none', { modifier: ':hover' });
        expect(mockOnClick).toHaveBeenCalledTimes(0);
        testing_library_1.fireEvent.click(link);
        expect(mockOnClick).toHaveBeenCalledTimes(0);
    });
});
//# sourceMappingURL=Link.spec.js.map