"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const testing_library_1 = require("../__test__/testing-library");
const List_1 = require("./List");
describe('List', () => {
    it('renders ordered list', () => {
        (0, testing_library_1.render)(react_1.default.createElement(List_1.List.ol, { color: 'text.light', "data-testid": 'list' },
            react_1.default.createElement("li", null, "Example Text 1"),
            react_1.default.createElement("li", null, "Example Text 2"),
            react_1.default.createElement("li", null, "Example Text 3")));
        const list = testing_library_1.screen.getByTestId('list');
        expect(list).toHaveStyleRule('color', '#4f6f8f');
        testing_library_1.screen.getByText('Example Text 1');
        testing_library_1.screen.getByText('Example Text 2');
        testing_library_1.screen.getByText('Example Text 3');
    });
    it('renders unordered list', () => {
        (0, testing_library_1.render)(react_1.default.createElement(List_1.List.ul, { color: 'text.light', fontSize: 1, "data-testid": 'list' },
            react_1.default.createElement("li", null, "Example Text 1"),
            react_1.default.createElement("li", null, "Example Text 2"),
            react_1.default.createElement("li", null, "Example Text 3")));
        const list = testing_library_1.screen.getByTestId('list');
        expect(list).toHaveStyleRule('color', '#4f6f8f');
        expect(list).toHaveStyleRule('font-size', '14px');
        testing_library_1.screen.getByText('Example Text 1');
        testing_library_1.screen.getByText('Example Text 2');
        testing_library_1.screen.getByText('Example Text 3');
    });
    it('renders list with listStyles and indentation which is passed in props ', () => {
        (0, testing_library_1.render)(react_1.default.createElement(List_1.List.ul, { color: 'text.light', fontSize: 1, listStyle: 'upper-roman', indentSize: 'md', "data-testid": 'list' },
            react_1.default.createElement("li", null, "Example Text 1"),
            react_1.default.createElement("li", null, "Example Text 2"),
            react_1.default.createElement("li", null, "Example Text 3")));
        const list = testing_library_1.screen.getByTestId('list');
        expect(list).toHaveStyleRule('list-style-type', 'upper-roman');
        expect(list).toHaveStyleRule('margin-left', '32px');
    });
    it('should render list with default listStyles and indentation if right props are not passed ', () => {
        (0, testing_library_1.render)(
        // Ignoring TS error to test case when invalid listStyle is provided
        // @ts-ignore
        react_1.default.createElement(List_1.List.ul, { color: 'text.light', fontSize: 1, listStyle: 'roman', "data-testid": 'list' },
            react_1.default.createElement("li", null, "Example Text 1"),
            react_1.default.createElement("li", null, "Example Text 2"),
            react_1.default.createElement("li", null, "Example Text 3")));
        const list = testing_library_1.screen.getByTestId('list');
        expect(list).toHaveStyleRule('list-style-type', 'auto');
        expect(list).toHaveStyleRule('margin-left', '40px');
    });
});
//# sourceMappingURL=List.spec.js.map