"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PasswordInput = void 0;
const pcln_icons_1 = require("pcln-icons");
const react_1 = __importStar(require("react"));
const styled_components_1 = __importDefault(require("styled-components"));
const Badge_1 = require("../Badge/Badge");
const Flex_1 = require("../Flex/Flex");
const IconButton_1 = require("../IconButton/IconButton");
const IconField_1 = require("../IconField/IconField");
const Input_1 = require("../Input/Input");
const Label_1 = require("../Label/Label");
const ProgressBar_1 = require("../ProgressBar/ProgressBar");
const Text_1 = require("../Text/Text");
const NoWrapText = (0, styled_components_1.default)(Text_1.Text) `
  white-space: nowrap;
`;
const maxProgressBarLength = 4;
/**
 * @public
 */
function PasswordInput({ id, isValid, label, hasProgressBar, progressBarSteps, regexChecks, value, onChange, autoComplete, ...props }) {
    const [showPassword, setShowPassword] = (0, react_1.useState)(false);
    const [passedChecks, setPassedChecks] = (0, react_1.useState)([]);
    function changeVisibility() {
        return setShowPassword(!showPassword);
    }
    function handleChange(event) {
        const currentValue = event.target.value;
        const passedChecks = [];
        if (hasProgressBar) {
            regexChecks.forEach((element, index) => element.regex.test(currentValue) && passedChecks.push(index));
            setPassedChecks(passedChecks);
        }
        const lengthsMatch = !hasProgressBar || passedChecks.length === regexChecks.length;
        if (onChange) {
            onChange({ isValid: lengthsMatch, value: currentValue });
        }
    }
    const inputType = showPassword ? 'text' : 'password';
    const VisibilityIcon = showPassword ? pcln_icons_1.VisibilityOff : pcln_icons_1.Visibility;
    const strengthLevel = Math.max(Math.round((maxProgressBarLength / regexChecks.length) * passedChecks.length), 0);
    const currentStep = progressBarSteps[strengthLevel - 1];
    const showCheckIcon = isValid || (hasProgressBar && strengthLevel === maxProgressBarLength);
    return (react_1.default.createElement(Flex_1.Flex, { flexDirection: 'column', ...props },
        react_1.default.createElement(Label_1.Label, { htmlFor: id, fontSize: 0, mb: 2 }, label),
        react_1.default.createElement(IconField_1.IconField, null,
            react_1.default.createElement(Input_1.Input, { id: id, type: inputType, value: value, onChange: handleChange, "data-testid": 'input-field', autoComplete: autoComplete }),
            showCheckIcon && react_1.default.createElement(pcln_icons_1.Check, { color: 'secondary', "data-testid": 'check-mark-icon' }),
            react_1.default.createElement(IconButton_1.IconButton, { title: 'visibility-button', icon: react_1.default.createElement(VisibilityIcon, { color: 'text.light' }), onClick: changeVisibility })),
        hasProgressBar && (react_1.default.createElement(Flex_1.Flex, { flexDirection: 'column' },
            react_1.default.createElement(Flex_1.Flex, { alignItems: 'center', my: 2 },
                react_1.default.createElement(NoWrapText, { fontSize: 0, color: 'text.light', mr: 2 },
                    "Password Strength:",
                    ' '),
                currentStep && (react_1.default.createElement(Badge_1.Badge, { color: currentStep.color, size: 'small' }, currentStep.text))),
            react_1.default.createElement(ProgressBar_1.ProgressBar, { steps: progressBarSteps, currentStep: strengthLevel }),
            react_1.default.createElement(Flex_1.Flex, { flexDirection: ['column', null, 'row'], mt: 2, mb: [2, null, 0] },
                react_1.default.createElement(NoWrapText, { fontSize: 0, color: 'text.light', mr: 3 }, "Must contain:"),
                react_1.default.createElement(Flex_1.Flex, { flexWrap: 'wrap' }, regexChecks.map((check, index) => {
                    const didPass = passedChecks.findIndex((value) => index === value) !== -1;
                    const Icon = didPass ? pcln_icons_1.Success : pcln_icons_1.SuccessOutline;
                    const color = didPass ? 'success' : 'text.light';
                    return (react_1.default.createElement(Flex_1.Flex, { alignItems: 'center', mt: [2, null, 0], mb: [0, null, 2], key: 'regex-label-' + index },
                        react_1.default.createElement(Icon, { size: '16px', color: color, mr: 1, "data-testid": Icon === pcln_icons_1.Success ? 'check-icon-on' : 'check-icon-off' }),
                        react_1.default.createElement(NoWrapText, { fontSize: 0, color: color, mr: 3 }, check.label)));
                })))))));
}
exports.PasswordInput = PasswordInput;
PasswordInput.defaultProps = {
    hasProgressBar: false,
    progressBarSteps: [
        { color: 'warning', text: 'WEAK' },
        { color: 'caution', text: 'FAIR' },
        { color: 'primary', text: 'GOOD' },
        { color: 'success', text: 'STRONG' },
    ],
    progressBarDefaultStep: 1,
    regexChecks: [
        { label: '1 Uppercase Letter', regex: /(?=.*[A-Z])/ },
        { label: '1 Lowercase Letter', regex: /(?=.*[a-z])/ },
        { label: '1 Number', regex: /(?=.*[0-9])/ },
        { label: '1 Special Character', regex: /(?=.*[!@#$%^&*()])/ },
        { label: 'at least 12 Characters', regex: /.{12,}/ },
    ],
};
//# sourceMappingURL=PasswordInput.js.map