"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PlaceholderImage = void 0;
const react_1 = __importDefault(require("react"));
const styled_components_1 = __importDefault(require("styled-components"));
const Image_1 = require("../Image/Image");
const RandomImage = (0, styled_components_1.default)(Image_1.Image) `
  height: ${(props) => props.height}px;
  width: ${(props) => props.width}px;
`;
const determineSRC = (blur, chooseSrc, height, width) => {
    const imageURLs = [
        `http://placeimg.com/${width}/${height}/any`,
        `http://placekitten.com/${width}/${height}`,
        `https://picsum.photos/${width}/${height}`,
        `https://source.unsplash.com/${width}x${height}`,
        `https://www.fillmurray.com/${width}/${height}`,
    ];
    if (blur || chooseSrc) {
        return blur ? `https://picsum.photos/${width}/${height}?blur` : imageURLs[chooseSrc];
    }
    const randomNum = Math.floor(Math.random() * imageURLs.length);
    return imageURLs[randomNum];
};
/**
 * @public
 */
function PlaceholderImage(props) {
    const { alt, ariaHidden, blur, chooseSrc, className, height, width } = props;
    return (react_1.default.createElement(RandomImage, { alt: alt || 'Random image used for placeholder content', "aria-hidden": ariaHidden, blur: blur, className: className, height: height, src: determineSRC(blur, chooseSrc, height, width), width: width }));
}
exports.PlaceholderImage = PlaceholderImage;
PlaceholderImage.displayName = 'PlaceholderImage';
PlaceholderImage.defaultProps = {
    ariaHidden: true,
    blur: false,
    height: '500',
    width: '500',
};
//# sourceMappingURL=PlaceholderImage.js.map