"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const testing_library_1 = require("../__test__/testing-library");
const PlaceholderImage_1 = require("./PlaceholderImage");
describe('PlaceholderImage', () => {
    it('should use the default height and width when not specified', () => {
        const { getByAltText } = (0, testing_library_1.render)(react_1.default.createElement(PlaceholderImage_1.PlaceholderImage, null));
        const placeholderImage = getByAltText('Random image used for placeholder content');
        expect(placeholderImage).toHaveStyleRule('height', '500px');
        expect(placeholderImage).toHaveStyleRule('width', '500px');
    });
    it('should use provided height and width', () => {
        const { getByAltText } = (0, testing_library_1.render)(react_1.default.createElement(PlaceholderImage_1.PlaceholderImage, { height: '300', width: '600' }));
        const placeholderImage = getByAltText('Random image used for placeholder content');
        expect(placeholderImage).toHaveStyleRule('height', '300px');
        expect(placeholderImage).toHaveStyleRule('width', '600px');
    });
    it('should use a blurred image', () => {
        const { getByAltText } = (0, testing_library_1.render)(react_1.default.createElement(PlaceholderImage_1.PlaceholderImage, { blur: true }));
        const placeholderImage = getByAltText('Random image used for placeholder content');
        expect(placeholderImage).toHaveAttribute('src', 'https://picsum.photos/500/500?blur');
    });
    it('should allow the user to specify a placeholder service via chooseSrc', () => {
        const { getByAltText } = (0, testing_library_1.render)(react_1.default.createElement(PlaceholderImage_1.PlaceholderImage, { chooseSrc: '0' }));
        const placeholderImage = getByAltText('Random image used for placeholder content');
        expect(placeholderImage).toHaveAttribute('src', 'http://placeimg.com/500/500/any');
    });
    it('should apply the `alt` attribute as specified', () => {
        const { getByAltText } = (0, testing_library_1.render)(react_1.default.createElement(PlaceholderImage_1.PlaceholderImage, { alt: 'Test alt text here' }));
        getByAltText('Test alt text here');
    });
});
//# sourceMappingURL=PlaceholderImage.spec.js.map