"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const testing_library_1 = require("../__test__/testing-library");
const Popout_1 = require("./Popout");
const trigger = react_1.default.createElement("input", { "data-testid": 'trigger', "aria-label": 'trigger' });
const content = react_1.default.createElement("div", { "data-testId": 'content' }, "Content");
const delay = async (ms) => new Promise((resolve) => setTimeout(resolve, ms));
describe('Popout', () => {
    it('Renders the trigger', () => {
        const { getByTestId } = (0, testing_library_1.render)(react_1.default.createElement(Popout_1.Popout, { trigger: trigger }));
        expect(getByTestId('trigger')).toBeTruthy();
    });
    it('Handles opening and closing', async () => {
        const handler = jest.fn();
        const { getByTestId } = (0, testing_library_1.render)(react_1.default.createElement(Popout_1.Popout, { trigger: trigger, content: content, onOpen: handler, onClose: handler }));
        const triggerElement = getByTestId('trigger');
        testing_library_1.fireEvent.focusIn(triggerElement);
        await delay(100);
        expect(handler).toHaveBeenCalledTimes(1);
        const contentElement = getByTestId('content');
        testing_library_1.fireEvent.keyDown(contentElement, {
            key: 'Escape',
            code: 'Escape',
            keyCode: 27,
            charCode: 27,
        });
        await delay(100);
        expect(handler).toHaveBeenCalledTimes(2);
    });
    it('Handles losing focus', async () => {
        const handler = jest.fn();
        const { getByTestId } = (0, testing_library_1.render)(react_1.default.createElement(react_1.default.Fragment, null,
            react_1.default.createElement("input", { "data-testid": 'outside', "aria-label": 'outside' }),
            react_1.default.createElement(Popout_1.Popout, { trigger: trigger, content: content, onOpen: handler, onClose: handler })));
        const triggerElement = getByTestId('trigger');
        testing_library_1.fireEvent.focusIn(triggerElement);
        await delay(100);
        expect(handler).toHaveBeenCalledTimes(1);
        const outsideElement = getByTestId('outside');
        testing_library_1.fireEvent.focusIn(outsideElement);
        await delay(100);
        expect(handler).toHaveBeenCalledTimes(2);
    });
    it('Closes when the trigger ref is clicked', async () => {
        const handler = jest.fn();
        const triggerRef = react_1.default.createRef();
        const _trigger = react_1.default.cloneElement(trigger, { ref: triggerRef });
        const { getByTestId } = (0, testing_library_1.render)(react_1.default.createElement(Popout_1.Popout, { trigger: _trigger, triggerRef: triggerRef, content: content, onOpen: handler, onClose: handler, closeOnTriggerRefClick: true }));
        const triggerElement = getByTestId('trigger');
        testing_library_1.fireEvent.focusIn(triggerElement);
        await delay(100);
        expect(handler).toHaveBeenCalledTimes(1);
        testing_library_1.fireEvent.click(triggerRef.current);
        await delay(100);
        expect(handler).toHaveBeenCalledTimes(2);
    });
});
//# sourceMappingURL=Popout.spec.js.map