"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const testing_library_1 = require("../__test__/testing-library");
const ProgressBar_1 = require("./ProgressBar");
const testProps = [
    { color: 'warning' },
    { color: 'caution' },
    { color: 'primary' },
    { color: 'success' },
];
describe('ProgressBar', () => {
    it('Default progress bar (no colors)', () => {
        (0, testing_library_1.render)(react_1.default.createElement(ProgressBar_1.ProgressBar, { steps: testProps, currentStep: 0 }));
        const firstBar = testing_library_1.screen.getByTestId('test-id-0');
        const secondBar = testing_library_1.screen.getByTestId('test-id-1');
        const thirdBar = testing_library_1.screen.getByTestId('test-id-2');
        const fourthBar = testing_library_1.screen.getByTestId('test-id-3');
        expect(firstBar).toHaveStyleRule('background-color', '#f4f6f8');
        expect(secondBar).toHaveStyleRule('background-color', '#f4f6f8');
        expect(thirdBar).toHaveStyleRule('background-color', '#f4f6f8');
        expect(fourthBar).toHaveStyleRule('background-color', '#f4f6f8');
    });
    it('Basic progress bar with step level 3', () => {
        (0, testing_library_1.render)(react_1.default.createElement(ProgressBar_1.ProgressBar, { steps: testProps, currentStep: 3 }));
        const firstBar = testing_library_1.screen.getByTestId('test-id-0');
        const secondBar = testing_library_1.screen.getByTestId('test-id-1');
        const thirdBar = testing_library_1.screen.getByTestId('test-id-2');
        const fourthBar = testing_library_1.screen.getByTestId('test-id-3');
        expect(firstBar).toHaveStyleRule('background-color', '#0068ef');
        expect(secondBar).toHaveStyleRule('background-color', '#0068ef');
        expect(thirdBar).toHaveStyleRule('background-color', '#0068ef');
        expect(fourthBar).toHaveStyleRule('background-color', '#f4f6f8');
    });
    it('Basic progress bar with step level 4', () => {
        (0, testing_library_1.render)(react_1.default.createElement(ProgressBar_1.ProgressBar, { steps: testProps, currentStep: 4 }));
        const firstBar = testing_library_1.screen.getByTestId('test-id-0');
        const secondBar = testing_library_1.screen.getByTestId('test-id-1');
        const thirdBar = testing_library_1.screen.getByTestId('test-id-2');
        const fourthBar = testing_library_1.screen.getByTestId('test-id-3');
        expect(firstBar).toHaveStyleRule('background-color', '#0a0');
        expect(secondBar).toHaveStyleRule('background-color', '#0a0');
        expect(thirdBar).toHaveStyleRule('background-color', '#0a0');
        expect(fourthBar).toHaveStyleRule('background-color', '#0a0');
    });
});
//# sourceMappingURL=ProgressBar.spec.js.map