"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Radio = void 0;
const pcln_icons_1 = require("pcln-icons");
const react_1 = __importDefault(require("react"));
const styled_components_1 = __importDefault(require("styled-components"));
const utils_1 = require("../utils/utils");
const RadioWrap = styled_components_1.default.div `
  display: inline-block;
  color: ${(0, utils_1.getPaletteColor)('text.light')};
  cursor: ${(props) => (props.disabled ? `not-allowed` : `pointer`)};
  &:hover > svg {
    ${(props) => {
    if (props.checked && !props.disabled) {
        return `color: ${(0, utils_1.getPaletteColor)('dark')(props)} !important;`;
    }
    return props.disabled ? null : `color: ${(0, utils_1.getPaletteColor)('base')(props)};`;
}};
  }
  ${(0, utils_1.applyVariations)('Radio')}
`;
const RadioInput = styled_components_1.default.input `
  appearance: none;
  opacity: 0;
  position: absolute;
  z-index: 0;

  & ~ svg {
    border: 1px solid transparent;
    border-radius: 50%;
    padding: 2px;
  }

  &:focus {
    box-shadow: none;
    & ~ svg {
      border: 1px solid ${(0, utils_1.getPaletteColor)('border.base')};
      background-color: ${(0, utils_1.getPaletteColor)('background.light')};
    }
  }
  &:checked ~ svg {
    color: ${(0, utils_1.getPaletteColor)('base')};
  }
  &:disabled ~ svg {
    color: ${(0, utils_1.getPaletteColor)('border.base')};
    cursor: not-allowed;
  }
`;
const RadioCheckedIcon = (0, styled_components_1.default)(pcln_icons_1.RadioChecked) `
  vertical-align: middle;
`;
const RadioEmptyIcon = (0, styled_components_1.default)(pcln_icons_1.RadioEmpty) `
  vertical-align: middle;
`;
const RadioIcon = ({ checked, ...props }) => {
    return checked ? react_1.default.createElement(RadioCheckedIcon, { ...props }) : react_1.default.createElement(RadioEmptyIcon, { ...props });
};
/**
 * @public
 */
exports.Radio = react_1.default.forwardRef((props, ref) => {
    const { checked, disabled, size } = props;
    const borderAdjustedSize = size + 4;
    const dataNameHelper = (checked, disabled) => {
        if ((checked && disabled) || (!checked && disabled)) {
            return 'disabled';
        }
        if (checked && !disabled) {
            return 'checked';
        }
        return 'unchecked';
    };
    return (react_1.default.createElement(RadioWrap, { color: props.color, checked: checked, disabled: disabled, "data-name": dataNameHelper(checked, disabled) },
        react_1.default.createElement(RadioInput, { type: 'radio', ...props, ref: ref }),
        react_1.default.createElement(RadioIcon, { checked: checked, size: borderAdjustedSize })));
});
exports.Radio.displayName = 'Radio';
exports.Radio.defaultProps = {
    color: 'primary',
    size: 24,
};
//# sourceMappingURL=Radio.js.map