"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Colors = exports.FontWeight = exports.ForwardRefs = exports._MockForm = exports._3States = void 0;
const addon_actions_1 = require("@storybook/addon-actions");
const react_1 = __importDefault(require("react"));
const styled_components_1 = __importDefault(require("styled-components"));
const Button_1 = require("../Button/Button");
const Label_1 = require("../Label/Label");
const Radio_1 = require("../Radio/Radio");
const ForwardRefsDemo_1 = __importDefault(require("../storybook/utils/ForwardRefsDemo"));
const theme_1 = require("../theme/theme");
const utils_1 = require("../utils/utils");
const bold = (props) => (props.bold ? { fontWeight: props.theme.fontWeights.bold } : null);
const medium = (props) => (props.medium ? { fontWeight: props.theme.fontWeights.medium } : null);
const LabelText = styled_components_1.default.span `
  vertical-align: middle;
  margin-left: 8px;
  ${bold}
  ${medium}
`;
const RadioLabelDisabled = (0, styled_components_1.default)(Label_1.Label) `
  cursor: not-allowed;
  color: ${(0, utils_1.getPaletteColor)('border.base')};
`;
const RadioLabel = (0, styled_components_1.default)(Label_1.Label) `
  cursor: pointer;
  color: ${(0, utils_1.getPaletteColor)('text.light')};

  &:hover {
    div[data-name='unchecked'] {
      color: ${(0, utils_1.getPaletteColor)('primary.base')};
    }
    div[data-name='checked'] {
      > svg {
        color: ${(0, utils_1.getPaletteColor)('primary.dark')};
      }
    }
  }
`;
// @ts-ignore
class MockForm extends react_1.default.Component {
    setState;
    state;
    constructor(props) {
        super(props);
        this.state = {
            selection: 1,
            options: [0, 1, 2, 3],
            disabled: false,
        };
    }
    updateSelection = (event) => {
        this.setState({
            selection: Number(event.target.value),
        });
    };
    toggleDisabled = () => {
        this.setState((prevState) => ({
            disabled: !prevState.disabled,
        }));
    };
    render() {
        const { disabled, selection, options } = this.state;
        return (react_1.default.createElement("div", null,
            react_1.default.createElement("div", { onChange: this.updateSelection }, options.map((item, idx) => (react_1.default.createElement(Label_1.Label, { fontSize: '14px', key: idx },
                react_1.default.createElement(Radio_1.Radio, { checked: item === selection, name: 'mySelection', value: item, disabled: disabled }),
                react_1.default.createElement(LabelText, null, item))))),
            react_1.default.createElement(Button_1.Button, { mt: 3, onClick: this.toggleDisabled }, "Toggle disabled state")));
    }
}
exports.default = {
    title: 'Radio',
    component: Radio_1.Radio,
};
const _3States = () => (react_1.default.createElement("div", { onChange: (0, addon_actions_1.action)('changed') },
    react_1.default.createElement(RadioLabel, { fontSize: '14px' },
        react_1.default.createElement(Radio_1.Radio, { checked: true }),
        react_1.default.createElement(LabelText, null, "selected")),
    react_1.default.createElement(RadioLabel, { fontSize: '14px' },
        react_1.default.createElement(Radio_1.Radio, null),
        react_1.default.createElement(LabelText, null, "not selected")),
    react_1.default.createElement(RadioLabelDisabled, { fontSize: '14px' },
        react_1.default.createElement(Radio_1.Radio, { disabled: true }),
        react_1.default.createElement(LabelText, null, "disabled"))));
exports._3States = _3States;
// @ts-ignore
const _MockForm = () => react_1.default.createElement(MockForm, null);
exports._MockForm = _MockForm;
function ForwardRefs() {
    function refChild(dsRef) {
        function onClick() {
            return dsRef.current.focus();
        }
        return (react_1.default.createElement(react_1.default.Fragment, null,
            react_1.default.createElement(RadioLabel, { fontSize: '14px' },
                react_1.default.createElement(Radio_1.Radio, { checked: true }),
                react_1.default.createElement(LabelText, null, "selected")),
            react_1.default.createElement(Button_1.Button, { onClick: onClick, mt: 4 }, "Click to focus radio via ref")));
    }
    return react_1.default.createElement(ForwardRefsDemo_1.default, { refChild: refChild });
}
exports.ForwardRefs = ForwardRefs;
const FontWeight = () => (react_1.default.createElement("div", { onChange: (0, addon_actions_1.action)('changed') },
    react_1.default.createElement(RadioLabel, { fontSize: '14px' },
        react_1.default.createElement(Radio_1.Radio, { checked: true }),
        react_1.default.createElement(LabelText, { bold: true }, "font weight - bold")),
    react_1.default.createElement(RadioLabel, { fontSize: '14px' },
        react_1.default.createElement(Radio_1.Radio, { checked: true }),
        react_1.default.createElement(LabelText, { medium: true }, "font weight - medium"))));
exports.FontWeight = FontWeight;
const Colors = () => (react_1.default.createElement(react_1.default.Fragment, null, theme_1.paletteFamilyNames.map((color) => (react_1.default.createElement(RadioLabel, { fontSize: '14px', key: color },
    react_1.default.createElement(Radio_1.Radio, { checked: true, color: color }),
    react_1.default.createElement(LabelText, null, color))))));
exports.Colors = Colors;
//# sourceMappingURL=Radio.stories.js.map