"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.RadioCheckToggleCard = exports.RadioCheckToggleCardVPositions = exports.RadioCheckToggleCardHPositions = exports.RadioCheckToggleCardCardTypes = void 0;
const theme_get_1 = require("@styled-system/theme-get");
const pcln_icons_1 = require("pcln-icons");
const react_1 = __importDefault(require("react"));
const styled_components_1 = __importDefault(require("styled-components"));
const Box_1 = require("../Box/Box");
const Flex_1 = require("../Flex/Flex");
const Toggle_1 = require("../Toggle/Toggle");
const utils_1 = require("../utils/utils");
/**
 * @public
 */
exports.RadioCheckToggleCardCardTypes = ['radio', 'checkbox', 'toggle'];
/**
 * @public
 */
exports.RadioCheckToggleCardHPositions = ['left', 'right'];
/**
 * @public
 */
exports.RadioCheckToggleCardVPositions = ['top', 'center'];
const CombinedInput = styled_components_1.default.input `
  appearance: none;
  opacity: 0;
  position: absolute;
  z-index: 0;

  &:hover + div {
    border-color: ${(0, utils_1.getPaletteColor)('primary.base')};

    & svg {
      color: ${(0, utils_1.getPaletteColor)('primary.base')};
    }
  }

  &:focus-visible + div div.cardIcon > svg {
    border-color: ${(0, utils_1.getPaletteColor)('text.light')};
    box-shadow: inset 0 0 0 5px ${(0, utils_1.getPaletteColor)('background.light')};
  }

  &:active + div,
  &:checked:hover + div {
    border-color: ${(0, utils_1.getPaletteColor)('primary.dark')};

    & div.cardIcon > svg {
      color: ${(0, utils_1.getPaletteColor)('primary.dark')};
    }
  }

  &:checked + div {
    background-color: ${(0, utils_1.getPaletteColor)('primary.light')};
    border: 1px solid ${(0, utils_1.getPaletteColor)('primary.base')};

    & div.cardIcon > svg {
      color: ${(0, utils_1.getPaletteColor)('primary.base')};
    }
  }

  &:checked:focus-visible + div div.cardIcon > svg {
    border-color: ${(0, utils_1.getPaletteColor)('primary.dark')};
  }
`;
const RCTCardContainer = (0, styled_components_1.default)(Flex_1.Flex) `
  background-color: ${(0, utils_1.getPaletteColor)('background.lightest')};
  border: 1px solid transparent;
  border-radius: ${(0, theme_get_1.themeGet)('borderRadii.action-lg')};
  box-shadow: ${(0, theme_get_1.themeGet)('shadows.sm')};
  cursor: pointer;
  padding: ${(0, theme_get_1.themeGet)('space.3')};
`;
const CardHeader = (0, styled_components_1.default)(Flex_1.Flex) `
  min-width: 0;
  width: 100%;

  & + * {
    margin-top: ${(0, theme_get_1.themeGet)('space.3')};
  }
`;
const StyledTitle = (0, styled_components_1.default)(Box_1.Box) `
  font-weight: ${(props) => (props.isTitleBold ? '700' : '500')};
  font-size: ${(props) => (props.isTitleBold ? '16px' : '14px')};
  line-height: 24px;
`;
const CardContent = (0, styled_components_1.default)(Box_1.Box) `
  flex: 1;

  & > :first-child + * {
    margin-top: ${(0, theme_get_1.themeGet)('space.3')};
  }
`;
const CardIcon = (0, styled_components_1.default)(Box_1.Box) `
  line-height: 0px;
  margin: ${(props) => (props.hPosition === 'left' ? `0 16px 0 0` : `0 0 0 16px`)};

  & > svg {
    border: 1px solid transparent;
    border-radius: ${(props) => (props.cardType === 'checkbox' ? '4px' : '9999px')};
    color: ${(0, utils_1.getPaletteColor)('text.light')};
    padding: 2px;
  }
`;
const RadioIcon = ({ checked, ...props }) => {
    return checked ? react_1.default.createElement(pcln_icons_1.RadioChecked, { ...props }) : react_1.default.createElement(pcln_icons_1.RadioEmpty, { ...props });
};
const CheckboxIcon = ({ checked, ...props }) => {
    return checked ? react_1.default.createElement(pcln_icons_1.BoxChecked, { ...props }) : react_1.default.createElement(pcln_icons_1.BoxEmpty, { ...props });
};
const ToggleIcon = ({ checked, onChange, ...props }) => {
    const checkIcon = react_1.default.createElement(pcln_icons_1.Check, { size: '16' });
    return (react_1.default.createElement(Box_1.Box, { ...props },
        react_1.default.createElement(Toggle_1.Toggle, { height: 24, isOn: checked, icon: checkIcon, onToggle: onChange })));
};
const buttonIcon = (cardType) => {
    if (cardType === 'radio') {
        return RadioIcon;
    }
    else if (cardType === 'checkbox') {
        return CheckboxIcon;
    }
    else if (cardType === 'toggle') {
        return ToggleIcon;
    }
};
/**
 * @public
 */
function RadioCheckToggleCard(props) {
    const { children, cardType, hPosition, vPosition, isTakingFullHeightOfCard, title, isTitleBold, name, value, onChange, isSelected, } = props;
    const id = `${name}_${value}`;
    const ButtonIcon = buttonIcon(cardType);
    return (react_1.default.createElement("label", { htmlFor: id, "data-testId": 'rdt-card-label' },
        react_1.default.createElement(CombinedInput, { role: cardType === 'radio' ? 'radio' : 'checkbox', id: id, name: name, value: value, type: cardType === 'radio' ? 'radio' : 'checkbox', onChange: onChange, checked: isSelected }),
        react_1.default.createElement(RCTCardContainer, { flexDirection: 'column', "data-testId": 'rdt-card-main' },
            react_1.default.createElement(CardHeader, { alignItems: vPosition, flexDirection: hPosition === 'left' ? 'row-reverse' : 'row', "data-testId": 'rdt-card-header' },
                react_1.default.createElement(CardContent, null,
                    react_1.default.createElement(StyledTitle, { isTitleBold: isTitleBold, "data-testId": 'rdt-card-title' }, title),
                    isTakingFullHeightOfCard && children),
                react_1.default.createElement(CardIcon, { className: 'cardIcon', cardType: cardType, hPosition: hPosition },
                    react_1.default.createElement(ButtonIcon, { checked: isSelected, onChange: onChange, size: '24' }))),
            !isTakingFullHeightOfCard && children)));
}
exports.RadioCheckToggleCard = RadioCheckToggleCard;
RadioCheckToggleCard.displayName = 'RadioCheckToggleCard';
RadioCheckToggleCard.defaultProps = {
    cardType: 'radio',
    isTitleBold: false,
    hPosition: 'right',
    vPosition: 'top',
    isTakingFullHeightOfCard: false,
    onChange: () => { },
};
//# sourceMappingURL=RadioCheckToggleCard.js.map