"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const testing_library_1 = require("../__test__/testing-library");
const RatingBadge_1 = require("./RatingBadge");
const text = '123';
describe('RatingBadge', () => {
    let consoleError;
    beforeEach(() => {
        consoleError = console.error;
        console.error = jest.fn();
    });
    afterEach(() => (console.error = consoleError));
    test('renders', () => {
        const { asFragment } = (0, testing_library_1.render)(react_1.default.createElement(RatingBadge_1.RatingBadge, null, "5"));
        expect(asFragment()).toMatchSnapshot();
    });
    test('has correct background and text colors', () => {
        const color = 'secondary';
        const { getByText } = (0, testing_library_1.render)(react_1.default.createElement(RatingBadge_1.RatingBadge, { color: color }, text));
        const badge = getByText(text);
        // Need to check the computed styles because .toHaveStyleRule(..) doesn't evaluate the functions
        const computedStyles = window.getComputedStyle(badge);
        expect(computedStyles.color).toBe('rgb(255, 255, 255)');
        expect(computedStyles.backgroundColor).toBe('rgb(0, 170, 0)');
    });
    test('renders with bg and color', () => {
        const color = 'secondary';
        const bg = 'primary';
        const { getByText } = (0, testing_library_1.render)(react_1.default.createElement(RatingBadge_1.RatingBadge, { bg: bg, color: color }, text));
        const badge = getByText(text);
        const computedStyles = window.getComputedStyle(badge);
        expect(computedStyles.color).toBe('rgb(0, 170, 0)');
        expect(computedStyles.backgroundColor).toBe('rgb(0, 104, 239)');
    });
    test('renders bg and no color', () => {
        const bg = 'secondary';
        const { getByText } = (0, testing_library_1.render)(react_1.default.createElement(RatingBadge_1.RatingBadge, { bg: bg }, text));
        const badge = getByText(text);
        const computedStyles = window.getComputedStyle(badge);
        expect(computedStyles.backgroundColor).toBe('rgb(0, 170, 0)');
        expect(computedStyles.color).toBe('rgb(255, 255, 255)');
    });
    test('renders with no bg and color', () => {
        const color = 'secondary';
        const { getByText } = (0, testing_library_1.render)(react_1.default.createElement(RatingBadge_1.RatingBadge, { color: color }, text));
        const badge = getByText(text);
        const computedStyles = window.getComputedStyle(badge);
        expect(computedStyles.backgroundColor).toBe('rgb(0, 170, 0)');
        expect(computedStyles.color).toBe('rgb(255, 255, 255)');
    });
    test('renders default color with no props', () => {
        const { getByText } = (0, testing_library_1.render)(react_1.default.createElement(RatingBadge_1.RatingBadge, null, text));
        const badge = getByText(text);
        const computedStyles = window.getComputedStyle(badge);
        expect(computedStyles.color).toBe('rgb(255, 255, 255)');
        expect(computedStyles.backgroundColor).toBe('rgb(240, 111, 32)');
    });
});
//# sourceMappingURL=RatingBadge.spec.js.map