"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const testing_library_1 = require("../__test__/testing-library");
const theme_1 = require("../theme/theme");
const createTheme_1 = require("../utils/createTheme");
const utils_1 = require("../utils/utils");
const Select_1 = require("./Select");
describe('Select', () => {
    it('renders', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Select_1.Select, null)).toJSON();
        expect(json).toMatchSnapshot();
    });
    it('renders disabled', () => {
        const paletteTheme = (0, createTheme_1.createTheme)(theme_1.theme);
        (0, testing_library_1.render)(react_1.default.createElement(Select_1.Select, { "data-testId": 'disabled-select', defaultValue: 'Premium Economy', disabled: true },
            react_1.default.createElement("option", null, "Premium Economy")));
        const select = testing_library_1.screen.getByTestId('disabled-select');
        expect(select).toBeDisabled();
        expect(select).toHaveStyleRule('background-color', (0, utils_1.getPaletteColor)('background.light')({ theme: paletteTheme }), { modifier: ':disabled' });
        expect(select).toHaveStyleRule('color', (0, utils_1.getPaletteColor)('text.light')({ theme: paletteTheme }), {
            modifier: ':disabled',
        });
        expect(select).toHaveStyleRule('cursor', 'not-allowed', { modifier: ':disabled' });
        expect(select).toHaveStyleRule('opacity', '1', { modifier: ':disabled' });
    });
    describe('variations', () => {
        describe('subtle variation', () => {
            it('should render correctly', () => {
                const paletteTheme = (0, createTheme_1.createTheme)(theme_1.theme);
                (0, testing_library_1.render)(react_1.default.createElement(Select_1.Select, { "data-testId": 'select', defaultValue: 'Premium Economy', variation: 'subtle', size: 'lg' },
                    react_1.default.createElement("option", null, "Premium Economy")));
                const select = testing_library_1.screen.getByTestId('select');
                expect(select).toHaveStyleRule('background-color', (0, utils_1.getPaletteColor)('background.base')({ theme: paletteTheme }));
                expect(select).toHaveStyleRule('border-color', (0, utils_1.getPaletteColor)('background.base')({ theme: paletteTheme }));
                expect(select).toHaveStyleRule('color', (0, utils_1.getPaletteColor)('primary.base')({ theme: paletteTheme }));
                expect(select).toHaveStyleRule('font-weight', 'bold');
                expect(select).toHaveStyleRule('border-radius', '12px');
                expect(select).toHaveStyleRule('background-color', (0, utils_1.getPaletteColor)('background.tint')({ theme: paletteTheme }), {
                    modifier: ':hover',
                });
                expect(select).toHaveStyleRule('border-color', (0, utils_1.getPaletteColor)('background.tint')({ theme: paletteTheme }), {
                    modifier: ':hover',
                });
                expect(select).toHaveStyleRule('color', (0, utils_1.getPaletteColor)('primary.dark')({ theme: paletteTheme }), {
                    modifier: ':hover',
                });
                expect(select).toHaveStyleRule('outline', `0px solid ${(0, utils_1.getPaletteColor)('primary.dark')({ theme: paletteTheme })}`, {
                    modifier: ':focus-visible',
                });
                expect(select).toHaveStyleRule('box-shadow', `0 0 0 2px ${(0, utils_1.getPaletteColor)('primary.dark')({ theme: paletteTheme })}`, {
                    modifier: ':focus-visible',
                });
            });
            it('should render with round border in small or medium sizes', () => {
                (0, testing_library_1.render)(react_1.default.createElement(Select_1.Select, { "data-testId": 'select', defaultValue: 'Premium Economy', variation: 'subtle', size: 'md' },
                    react_1.default.createElement("option", null, "Premium Economy")));
                const select = testing_library_1.screen.getByTestId('select');
                expect(select).toHaveStyleRule('border-radius', '9999px');
            });
            it('should render correctly when disabled', () => {
                const paletteTheme = (0, createTheme_1.createTheme)(theme_1.theme);
                (0, testing_library_1.render)(react_1.default.createElement(Select_1.Select, { "data-testId": 'disabled-select', defaultValue: 'Premium Economy', disabled: true, variation: 'subtle' },
                    react_1.default.createElement("option", null, "Premium Economy")));
                const select = testing_library_1.screen.getByTestId('disabled-select');
                expect(select).toBeDisabled();
                expect(select).toHaveStyleRule('background-color', (0, utils_1.getPaletteColor)('background.light')({ theme: paletteTheme }), { modifier: ':disabled' });
                expect(select).toHaveStyleRule('color', (0, utils_1.getPaletteColor)('text.light')({ theme: paletteTheme }), {
                    modifier: ':disabled',
                });
                expect(select).toHaveStyleRule('cursor', 'not-allowed', { modifier: ':disabled' });
                expect(select).toHaveStyleRule('opacity', '1', { modifier: ':disabled' });
            });
        });
    });
});
//# sourceMappingURL=Select.spec.js.map