"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const Input_1 = require("../Input/Input");
const testing_library_1 = require("../__test__/testing-library");
const ShadowEffect_1 = require("./ShadowEffect");
describe.skip('ShadowEffect', () => {
    it('opens when clicked', () => {
        const mockOnOpen = jest.fn();
        const mockOnClick = jest.fn();
        (0, testing_library_1.render)(react_1.default.createElement(ShadowEffect_1.ShadowEffect, { onOpen: mockOnOpen, "data-testid": 'overlay' },
            react_1.default.createElement(Input_1.Input, { onClick: mockOnClick, id: 'input', "data-testid": 'input' })));
        expect(testing_library_1.screen.queryByTestId('overlay')).not.toBeInTheDocument();
        expect(mockOnOpen).toHaveBeenCalledTimes(0);
        expect(mockOnClick).toHaveBeenCalledTimes(0);
        testing_library_1.fireEvent.click(testing_library_1.screen.getByTestId('input'));
        expect(mockOnOpen).toHaveBeenCalledTimes(1);
        expect(mockOnClick).toHaveBeenCalledTimes(1);
        expect(testing_library_1.screen.queryByTestId('overlay')).toBeInTheDocument();
        expect(testing_library_1.screen.queryByTestId('overlay')).toHaveStyleRule('z-index', '550');
        expect(testing_library_1.screen.queryByTestId('input')).toHaveStyleRule('z-index', '600');
    });
    it('opens with custom z-index', () => {
        const mockOnOpen = jest.fn();
        const mockOnClick = jest.fn();
        (0, testing_library_1.render)(react_1.default.createElement(ShadowEffect_1.ShadowEffect, { zIndex: 5, onOpen: mockOnOpen, "data-testid": 'overlay' },
            react_1.default.createElement(Input_1.Input, { onClick: mockOnClick, id: 'input', "data-testid": 'input' })));
        expect(testing_library_1.screen.queryByTestId('input')).toHaveStyleRule('z-index', undefined);
        testing_library_1.fireEvent.click(testing_library_1.screen.getByTestId('input'));
        expect(testing_library_1.screen.queryByTestId('overlay')).toBeInTheDocument();
        expect(testing_library_1.screen.queryByTestId('overlay')).toHaveStyleRule('z-index', '5');
        expect(testing_library_1.screen.queryByTestId('input')).toHaveStyleRule('z-index', '5');
    });
    it('closes if overlay clicked', () => {
        const mockOnClose = jest.fn();
        (0, testing_library_1.render)(react_1.default.createElement(ShadowEffect_1.ShadowEffect, { onClose: mockOnClose, "data-testid": 'overlay' },
            react_1.default.createElement(Input_1.Input, { id: 'input', "data-testid": 'input' })));
        expect(testing_library_1.screen.queryByTestId('overlay')).not.toBeInTheDocument();
        testing_library_1.fireEvent.click(testing_library_1.screen.getByTestId('input'));
        expect(testing_library_1.screen.queryByTestId('overlay')).toBeInTheDocument();
        testing_library_1.fireEvent.click(testing_library_1.screen.getByTestId('overlay'));
        expect(testing_library_1.screen.queryByTestId('overlay')).not.toBeInTheDocument();
    });
    it('opens when focused', () => {
        const mockOnOpen = jest.fn();
        const mockOnFocus = jest.fn();
        (0, testing_library_1.render)(react_1.default.createElement(ShadowEffect_1.ShadowEffect, { shouldOpenOnFocus: true, onOpen: mockOnOpen, "data-testid": 'overlay' },
            react_1.default.createElement(Input_1.Input, { id: 'input', onFocus: mockOnFocus, "data-testid": 'input' })));
        expect(mockOnOpen).toHaveBeenCalledTimes(0);
        expect(mockOnFocus).toHaveBeenCalledTimes(0);
        expect(testing_library_1.screen.queryByTestId('overlay')).not.toBeInTheDocument();
        testing_library_1.screen.getByTestId('input').focus();
        expect(mockOnOpen).toHaveBeenCalledTimes(1);
        expect(mockOnFocus).toHaveBeenCalledTimes(1);
        expect(testing_library_1.screen.queryByTestId('overlay')).toBeInTheDocument();
    });
    it('does not open on focus if not set', () => {
        const mockOnOpen = jest.fn();
        const mockOnFocus = jest.fn();
        (0, testing_library_1.render)(react_1.default.createElement(ShadowEffect_1.ShadowEffect, { onOpen: mockOnOpen, "data-testid": 'overlay' },
            react_1.default.createElement(Input_1.Input, { onFocus: mockOnFocus, id: 'input', "data-testid": 'input' })));
        expect(mockOnOpen).toHaveBeenCalledTimes(0);
        expect(mockOnFocus).toHaveBeenCalledTimes(0);
        expect(testing_library_1.screen.queryByTestId('overlay')).not.toBeInTheDocument();
        testing_library_1.screen.getByTestId('input').focus();
        expect(mockOnOpen).toHaveBeenCalledTimes(0);
        expect(mockOnFocus).toHaveBeenCalledTimes(1);
        expect(testing_library_1.screen.queryByTestId('overlay')).not.toBeInTheDocument();
    });
    it('closes when blurred', () => {
        const mockOnClose = jest.fn();
        const mockOnBlur = jest.fn();
        (0, testing_library_1.render)(react_1.default.createElement(ShadowEffect_1.ShadowEffect, { shouldOpenOnFocus: true, shouldCloseOnBlur: true, onClose: mockOnClose, "data-testid": 'overlay' },
            react_1.default.createElement(Input_1.Input, { id: 'input', onBlur: mockOnBlur, "data-testid": 'input' })));
        expect(testing_library_1.screen.queryByTestId('overlay')).not.toBeInTheDocument();
        testing_library_1.screen.getByTestId('input').focus();
        expect(testing_library_1.screen.queryByTestId('overlay')).toBeInTheDocument();
        expect(mockOnClose).toHaveBeenCalledTimes(0);
        expect(mockOnBlur).toHaveBeenCalledTimes(0);
        testing_library_1.screen.getByTestId('input').blur();
        expect(mockOnClose).toHaveBeenCalledTimes(1);
        expect(mockOnBlur).toHaveBeenCalledTimes(1);
        expect(testing_library_1.screen.queryByTestId('overlay')).not.toBeInTheDocument();
    });
    it('does not close when blurred if not set', () => {
        const mockOnClose = jest.fn();
        const mockOnBlur = jest.fn();
        (0, testing_library_1.render)(react_1.default.createElement(ShadowEffect_1.ShadowEffect, { shouldOpenOnFocus: true, onClose: mockOnClose, "data-testid": 'overlay' },
            react_1.default.createElement(Input_1.Input, { id: 'input', onBlur: mockOnBlur, "data-testid": 'input' })));
        expect(testing_library_1.screen.queryByTestId('overlay')).not.toBeInTheDocument();
        testing_library_1.screen.getByTestId('input').focus();
        expect(testing_library_1.screen.queryByTestId('overlay')).toBeInTheDocument();
        expect(mockOnClose).toHaveBeenCalledTimes(0);
        expect(mockOnBlur).toHaveBeenCalledTimes(0);
        testing_library_1.screen.getByTestId('input').blur();
        expect(mockOnClose).toHaveBeenCalledTimes(0);
        expect(mockOnBlur).toHaveBeenCalledTimes(1);
        expect(testing_library_1.screen.queryByTestId('overlay')).toBeInTheDocument();
    });
    it('closes when escape is pressed', () => {
        const mockOnKeyDown = jest.fn();
        (0, testing_library_1.render)(react_1.default.createElement(ShadowEffect_1.ShadowEffect, { "data-testid": 'overlay' },
            react_1.default.createElement(Input_1.Input, { id: 'input', onKeyDown: mockOnKeyDown, "data-testid": 'input' })));
        expect(testing_library_1.screen.queryByTestId('overlay')).not.toBeInTheDocument();
        testing_library_1.fireEvent.click(testing_library_1.screen.getByTestId('input'));
        expect(testing_library_1.screen.queryByTestId('overlay')).toBeInTheDocument();
        expect(mockOnKeyDown).toHaveBeenCalledTimes(0);
        testing_library_1.fireEvent.keyDown(testing_library_1.screen.getByTestId('input'), { key: 'Escape' });
        expect(mockOnKeyDown).toHaveBeenCalledTimes(1);
        expect(testing_library_1.screen.queryByTestId('overlay')).not.toBeInTheDocument();
    });
    it('does not close for other key presses', () => {
        const mockOnKeyDown = jest.fn();
        (0, testing_library_1.render)(react_1.default.createElement(ShadowEffect_1.ShadowEffect, { "data-testid": 'overlay' },
            react_1.default.createElement(Input_1.Input, { id: 'input', onKeyDown: mockOnKeyDown, "data-testid": 'input' })));
        expect(testing_library_1.screen.queryByTestId('overlay')).not.toBeInTheDocument();
        testing_library_1.fireEvent.click(testing_library_1.screen.getByTestId('input'));
        expect(testing_library_1.screen.queryByTestId('overlay')).toBeInTheDocument();
        expect(mockOnKeyDown).toHaveBeenCalledTimes(0);
        testing_library_1.fireEvent.keyDown(testing_library_1.screen.getByTestId('input'), { key: 'Enter' });
        expect(mockOnKeyDown).toHaveBeenCalledTimes(1);
        expect(testing_library_1.screen.queryByTestId('overlay')).toBeInTheDocument();
    });
    it('errors if provided multiple children', () => {
        expect(() => {
            (0, testing_library_1.render)(react_1.default.createElement(ShadowEffect_1.ShadowEffect, null,
                react_1.default.createElement(Input_1.Input, { id: 'input' }),
                react_1.default.createElement(Input_1.Input, { id: 'input2' })));
        }).toThrow();
    });
});
//# sourceMappingURL=ShadowEffect.spec.js.map