"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const testing_library_1 = require("../__test__/testing-library");
const Shimmer_1 = require("./Shimmer");
describe('Shimmer', () => {
    test('should render correctly', () => {
        const { getByTestId } = (0, testing_library_1.render)(react_1.default.createElement(Shimmer_1.Shimmer, { height: '50px', width: '100px' }));
        const wrapper = getByTestId('Shimmer__Wrapper');
        const glare = getByTestId('Shimmer__Glare');
        expect(wrapper).toHaveStyleRule('background-color', '#EEEEEE');
        expect(wrapper).toHaveStyleRule('height', '50px');
        expect(wrapper).toHaveStyleRule('width', '100px');
        expect(glare).toHaveStyleRule('animation', expect.stringContaining('1.2s ease-in-out infinite'));
    });
    test('should render light variation correctly', () => {
        const { getByTestId } = (0, testing_library_1.render)(react_1.default.createElement(Shimmer_1.Shimmer, { height: '50px', width: '100px', variation: 'light' }));
        const wrapper = getByTestId('Shimmer__Wrapper');
        const glare = getByTestId('Shimmer__Glare');
        expect(wrapper).toHaveStyleRule('background-color', '#00000014');
        expect(glare).toHaveStyleRule('animation', expect.stringContaining('1.2s ease-in-out infinite'));
    });
    test('should render dark variation correctly', () => {
        const { getByTestId } = (0, testing_library_1.render)(react_1.default.createElement(Shimmer_1.Shimmer, { height: '50px', width: '100px', variation: 'dark' }));
        const wrapper = getByTestId('Shimmer__Wrapper');
        const glare = getByTestId('Shimmer__Glare');
        expect(wrapper).toHaveStyleRule('background-color', '#FFFFFF14');
        expect(wrapper).toHaveStyleRule('height', '50px');
        expect(wrapper).toHaveStyleRule('width', '100px');
        expect(glare).toHaveStyleRule('animation', expect.stringContaining('1.2s ease-in-out infinite'));
    });
});
//# sourceMappingURL=Shimmer.spec.js.map