"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const test_utils_1 = require("react-intersection-observer/test-utils");
const Box_1 = require("../Box/Box");
const testing_library_1 = require("../__test__/testing-library");
const SlideBox_1 = require("./SlideBox");
describe('SlideBox', () => {
    it('renders with layout', () => {
        const { getByTestId } = (0, testing_library_1.render)(react_1.default.createElement(SlideBox_1.SlideBox, { layout: '60-40', onSlideChange: () => { }, slideSpacing: 2, stretchHeight: true, arrowPosition: 'side' },
            react_1.default.createElement(Box_1.Box, null, "1"),
            react_1.default.createElement(Box_1.Box, null, "2"),
            react_1.default.createElement(Box_1.Box, null, "3")));
        (0, test_utils_1.mockAllIsIntersecting)(true);
        expect(getByTestId('slide1')).toHaveStyle(`width: ${(100 / 1.1).toString()}%;`);
    });
    it('renders with array visible slides', () => {
        const { getByTestId } = (0, testing_library_1.render)(react_1.default.createElement(SlideBox_1.SlideBox, { visibleSlides: [2, 3, 4], onSlideChange: () => { }, slideSpacing: 2, currentSlideOverride: 2, arrowPosition: 'side', overflowAllowancePxX: 20, overflowAllowancePxY: 40 },
            react_1.default.createElement(Box_1.Box, { key: 'testkey' }, "1"),
            react_1.default.createElement(Box_1.Box, null, "2"),
            react_1.default.createElement(Box_1.Box, null, "3")));
        (0, test_utils_1.mockAllIsIntersecting)(true);
        expect(getByTestId('slide1')).toHaveStyle(`width: 50%;`);
    });
    it('renders with int visible slides (small browser should default to 1.1 slides)', () => {
        const slideChange = jest.fn();
        const { getByTestId } = (0, testing_library_1.render)(react_1.default.createElement(SlideBox_1.SlideBox, { visibleSlides: 1, onSlideChange: slideChange, slideSpacing: 2, arrowPosition: 'bottom', overflowAllowancePxTop: 10 },
            react_1.default.createElement(Box_1.Box, null, "1"),
            react_1.default.createElement(Box_1.Box, null, "2"),
            react_1.default.createElement(Box_1.Box, null, "3")));
        (0, test_utils_1.mockIsIntersecting)(getByTestId('render-in-view-1'), true);
        expect(slideChange).toHaveBeenCalledTimes(1);
        expect(slideChange).toHaveBeenCalledWith(1);
        expect(getByTestId('slide1')).toHaveStyle(`width: ${(100 / 1.1).toString()}%;`);
    });
    it('renders with arrows on top', () => {
        const { getByTestId } = (0, testing_library_1.render)(react_1.default.createElement(SlideBox_1.SlideBox, { visibleSlides: 1, arrowButtonVariation: 'fill', arrowPosition: 'top' },
            react_1.default.createElement(Box_1.Box, null, "1"),
            react_1.default.createElement(Box_1.Box, null, "2"),
            react_1.default.createElement(Box_1.Box, null, "3")));
        getByTestId('top-arrows');
    });
    it('renders with no arrows default', () => {
        const { queryByTestId } = (0, testing_library_1.render)(react_1.default.createElement(SlideBox_1.SlideBox, { visibleSlides: 1 },
            react_1.default.createElement(Box_1.Box, null, "1"),
            react_1.default.createElement(Box_1.Box, null, "2"),
            react_1.default.createElement(Box_1.Box, null, "3")));
        expect(queryByTestId('top-arrows')).not.toBeInTheDocument();
        expect(queryByTestId('bottom-arrows')).not.toBeInTheDocument();
        expect(queryByTestId('side-left-arrow')).not.toBeInTheDocument();
        expect(queryByTestId('side-right-arrow')).not.toBeInTheDocument();
    });
});
//# sourceMappingURL=SlideBox.spec.js.map