"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const Button_1 = require("../Button/Button");
const testing_library_1 = require("../__test__/testing-library");
const useSlideBoxNav_1 = require("./useSlideBoxNav");
const getChildArray = () => {
    const childarray = [];
    for (let i = 0; i < 10; i++) {
        childarray.push(react_1.default.createElement("div", null,
            "d",
            i));
    }
    return childarray;
};
const props = {
    onSlideChange: jest.fn(),
    currentSlideOverride: 0,
    arrowSizeOverride: 'lg',
    arrowButtonVariation: 'white',
    arrowPosition: 'side',
    childArray: getChildArray(),
    slideScrollNum: 1,
    mobileSlideScrollNum: 1,
};
const Test = (testProps) => {
    const { setCurrentSlide, currentSlide, onSlideChangeWrapper, arrowProps, slideInView } = (0, useSlideBoxNav_1.useSlideBoxNav)(testProps);
    const { leftDisabled, rightDisabled, arrowButtonVariation, arrowPosition, size, leftArrowClick, rightArrowClick, } = arrowProps;
    const slideChange = () => {
        onSlideChangeWrapper(6, 3);
    };
    const slideChangeOutsideBounds = () => {
        onSlideChangeWrapper(-5, 3);
    };
    const slideChangeOutsideBoundsUpper = () => {
        onSlideChangeWrapper(99, 3);
    };
    return (react_1.default.createElement("div", null,
        react_1.default.createElement("div", { "data-testid": 'leftdisabled' }, leftDisabled ? 'true' : 'false'),
        react_1.default.createElement("div", { "data-testid": 'rightdisabled' }, rightDisabled ? 'true' : 'false'),
        react_1.default.createElement("div", { "data-testid": 'arrowButtonVariation' }, arrowButtonVariation),
        react_1.default.createElement("div", { "data-testid": 'arrowPosition' }, arrowPosition),
        react_1.default.createElement("div", { "data-testid": 'arrowSize' }, size),
        react_1.default.createElement("div", { "data-testid": 'currentslide' },
            "slide ",
            currentSlide),
        react_1.default.createElement("div", { "data-testid": 'slideInView' },
            "slide ",
            slideInView),
        react_1.default.createElement(Button_1.Button, { onClick: setCurrentSlide }, "Set Current Slide"),
        react_1.default.createElement(Button_1.Button, { onClick: leftArrowClick }, "Left Arrow Click"),
        react_1.default.createElement(Button_1.Button, { onClick: rightArrowClick }, "Right Arrow Click"),
        react_1.default.createElement(Button_1.Button, { onClick: slideChange }, "Slide Change Wrapper"),
        react_1.default.createElement(Button_1.Button, { onClick: slideChangeOutsideBounds }, "Slide Change Outside Bounds"),
        react_1.default.createElement(Button_1.Button, { onClick: slideChangeOutsideBoundsUpper }, "Slide Change Outside Bounds Upper")));
};
describe('useSlideBoxNav', () => {
    it('Basic functionality', () => {
        const { getByTestId, getByText } = (0, testing_library_1.render)(react_1.default.createElement(Test, { ...props }));
        expect(getByTestId('leftdisabled').innerHTML).toEqual('true');
        expect(getByTestId('rightdisabled').innerHTML).toEqual('false');
        expect(getByTestId('arrowButtonVariation').innerHTML).toEqual('white');
        expect(getByTestId('arrowPosition').innerHTML).toEqual('side');
        expect(getByTestId('arrowSize').innerHTML).toEqual('lg');
        expect(getByTestId('currentslide').innerHTML).toEqual('slide 0');
        //Right arrow click
        testing_library_1.fireEvent.click(getByText('Right Arrow Click'));
        expect(getByTestId('currentslide').innerHTML).toEqual('slide 1');
        //Left arrow click
        testing_library_1.fireEvent.click(getByText('Left Arrow Click'));
        expect(getByTestId('currentslide').innerHTML).toEqual('slide 0');
        //Slide Change (used in useEffect)
        testing_library_1.fireEvent.click(getByText('Slide Change Wrapper'));
        expect(getByTestId('slideInView').innerHTML).toEqual('slide 6');
        //Slide Change outside bounds
        testing_library_1.fireEvent.click(getByText('Slide Change Outside Bounds'));
        expect(getByTestId('slideInView').innerHTML).toEqual('slide 2');
        //Slide Change outside bounds (lower)
        testing_library_1.fireEvent.click(getByText('Slide Change Outside Bounds'));
        expect(getByTestId('slideInView').innerHTML).toEqual('slide 2');
        //Slide Change outside bounds (upper)
        testing_library_1.fireEvent.click(getByText('Slide Change Outside Bounds Upper'));
        expect(getByTestId('slideInView').innerHTML).toEqual('slide 9');
    });
});
describe('useSlideBoxNav', () => {
    beforeAll(() => {
        // @ts-ignore
        global.window.innerWidth = 800;
    });
    it('Edge cases', () => {
        const { getByText, getByTestId } = (0, testing_library_1.render)(react_1.default.createElement(Test, { ...props, onSlideChange: undefined, arrowSizeOverride: undefined }));
        //Slide Change (used in useEffect)
        testing_library_1.fireEvent.click(getByText('Slide Change Wrapper'));
        expect(getByTestId('slideInView').innerHTML).toEqual('slide 6');
        //Right arrow click
        testing_library_1.fireEvent.click(getByText('Right Arrow Click'));
        expect(getByTestId('currentslide').innerHTML).toEqual('slide 7');
        //Default arrow size to lg
        expect(getByTestId('arrowSize').innerHTML).toEqual('lg');
    });
    it('Uncovered prop cases', () => {
        const { getByTestId } = (0, testing_library_1.render)(react_1.default.createElement(Test, { ...props, arrowPosition: 'top', arrowSizeOverride: undefined }));
        //Default arrow size to sm when arrowPosition top
        expect(getByTestId('arrowSize').innerHTML).toEqual('sm');
    });
});
//# sourceMappingURL=TestUseSlideBoxNav.spec.js.map