"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const testing_library_1 = require("../__test__/testing-library");
const pcln_icons_1 = require("pcln-icons");
const Spinner_1 = require("./Spinner");
describe('Spinner', () => {
    it('renders a lonely spinner', () => {
        (0, testing_library_1.render)(react_1.default.createElement(Spinner_1.Spinner, { "data-testid": 'spinner' }));
        expect(testing_library_1.screen.getByTestId('spinner')).toHaveStyle('color: primary');
    });
    it('renders a lonely spinner with gradient', () => {
        (0, testing_library_1.render)(react_1.default.createElement(Spinner_1.Spinner, { "data-testid": 'spinner', useGradient: true }));
        expect(testing_library_1.screen.getByTestId('spinner')).toHaveStyle('color: primary');
    });
    it('renders with an icon', () => {
        (0, testing_library_1.render)(react_1.default.createElement(Spinner_1.Spinner, { "data-testid": 'spinner' },
            react_1.default.createElement(pcln_icons_1.Hotels, { "data-testid": 'icon' })));
        expect(testing_library_1.screen.getByTestId('spinner')).toHaveStyle('color: primary');
        expect(testing_library_1.screen.getByTestId('icon')).toHaveStyle('color: rgb(0, 104, 239)');
    });
    it('renders with multiple colors', () => {
        (0, testing_library_1.render)(react_1.default.createElement(Spinner_1.Spinner, { color: 'secondary', "data-testid": 'spinner' },
            react_1.default.createElement(pcln_icons_1.Hotels, { color: 'error', "data-testid": 'icon' })));
        expect(testing_library_1.screen.getByTestId('spinner')).toHaveStyle('color: secondary');
        expect(testing_library_1.screen.getByTestId('icon')).toHaveStyle('color: rgb(204, 0, 0)');
    });
    it('renders with multiple colors and gradient', () => {
        (0, testing_library_1.render)(react_1.default.createElement(Spinner_1.Spinner, { color: 'secondary', "data-testid": 'spinner', useGradient: true },
            react_1.default.createElement(pcln_icons_1.Hotels, { color: 'error', "data-testid": 'icon' })));
        expect(testing_library_1.screen.getByTestId('spinner')).toHaveStyle('color: secondary');
        expect(testing_library_1.screen.getByTestId('icon')).toHaveStyle('color: rgb(204, 0, 0)');
    });
});
//# sourceMappingURL=Spinner.spec.js.map