"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const Stamp_1 = require("../Stamp/Stamp");
const theme_1 = require("../theme/theme");
describe('Stamp', () => {
    let consoleError;
    beforeEach(() => {
        consoleError = console.error;
        console.error = jest.fn();
    });
    afterEach(() => (console.error = consoleError));
    test('renders', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Stamp_1.Stamp, null)).toJSON();
        expect(json).toMatchSnapshot();
    });
    test('renders small size', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Stamp_1.Stamp, { size: 'small' })).toJSON();
        expect(json).toMatchSnapshot();
    });
    test('renders medium fill', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Stamp_1.Stamp, { variation: 'fill' })).toJSON();
        expect(json).toMatchSnapshot();
    });
    test('renders small fill', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Stamp_1.Stamp, { size: 'small', variation: 'fill' })).toJSON();
        expect(json).toMatchSnapshot();
    });
    test('color gray sets text and icon color', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Stamp_1.Stamp, { color: 'gray' })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('color', theme_1.theme.colors.gray);
    });
    test('color blue sets text and icon color', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Stamp_1.Stamp, { color: 'blue' })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('color', theme_1.theme.colors.blue);
    });
    test('color green sets text and icon color', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Stamp_1.Stamp, { color: 'green' })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('color', theme_1.theme.colors.green);
    });
    test('color red sets text and icon color', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Stamp_1.Stamp, { color: 'red' })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('color', theme_1.theme.colors.red);
    });
    test('color orange sets text and icon color', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Stamp_1.Stamp, { color: 'orange' })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('color', theme_1.theme.colors.orange);
    });
    test('color purple sets text and icon color', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Stamp_1.Stamp, { color: 'purple' })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('color', theme_1.theme.colors.purple);
    });
    test('bg blue sets background color', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Stamp_1.Stamp, { bg: 'blue' })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('background-color', theme_1.theme.colors.blue);
    });
    test('borderColor green sets border color', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Stamp_1.Stamp, { borderColor: 'green' })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('border-color', theme_1.theme.colors.green);
    });
    test('has default borderGray border color', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Stamp_1.Stamp, null)).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('border-color', theme_1.theme.colors.borderGray);
    });
});
//# sourceMappingURL=Stamp.spec.js.map