"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const testing_library_1 = require("../__test__/testing-library");
const Step_1 = require("./Step");
describe('Step', () => {
    it('should render correctly with no props without throwing', () => {
        expect(() => {
            const { asFragment } = (0, testing_library_1.render)(react_1.default.createElement(Step_1.Step, null, "Step"));
            expect(asFragment()).toMatchSnapshot();
        }).not.toThrow();
    });
    it('should render an active step correctly', () => {
        const { asFragment, container, getByTestId } = (0, testing_library_1.render)(react_1.default.createElement(Step_1.Step, { active: true, "data-testid": 'Step' }, "Step"));
        expect(asFragment()).toMatchSnapshot();
        expect(getByTestId('Step')).toHaveStyleRule('cursor', 'default');
        expect(container.querySelector('svg')).not.toBeInTheDocument();
    });
    it('should render a completed step correctly', () => {
        const { asFragment, container, getByTestId } = (0, testing_library_1.render)(react_1.default.createElement(Step_1.Step, { completed: true, "data-testid": 'Step' }, "Step"));
        expect(asFragment()).toMatchSnapshot();
        expect(getByTestId('Step')).toHaveStyleRule('cursor', 'default');
        expect(container.querySelector('svg')).toBeInTheDocument();
    });
    it('should render a step that is "active" and "completed" correctly', () => {
        const { asFragment, container, getByTestId } = (0, testing_library_1.render)(react_1.default.createElement(Step_1.Step, { active: true, completed: true, "data-testid": 'Step' }, "Step"));
        expect(asFragment()).toMatchSnapshot();
        expect(getByTestId('Step')).toHaveStyleRule('cursor', 'default');
        expect(container.querySelector('svg')).toBeInTheDocument();
    });
    it('should handle onClick', () => {
        const handleClick = jest.fn();
        const { asFragment, getByTestId, getByText } = (0, testing_library_1.render)(react_1.default.createElement(Step_1.Step, { active: true, "data-testid": 'Step', onClick: handleClick }, "Step"));
        expect(asFragment()).toMatchSnapshot();
        expect(getByTestId('Step')).toHaveStyleRule('cursor', 'pointer');
        testing_library_1.fireEvent.click(getByText('Step'));
        expect(handleClick).toHaveBeenCalled();
    });
});
//# sourceMappingURL=Step.spec.js.map