"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const testing_library_1 = require("../__test__/testing-library");
const Swatch_1 = require("./Swatch");
const mockColors = ['red', 'green', 'blue'];
describe('Swatch', () => {
    it('should render correctly', () => {
        const { getByTestId } = (0, testing_library_1.render)(react_1.default.createElement(Swatch_1.Swatch, { colors: mockColors }));
        mockColors.map((color, idx) => {
            expect(getByTestId(`${idx}-${color}`)).toHaveStyle(`background-color: ${color}`);
            expect(getByTestId(`${idx}-${color}`)).toHaveStyle(`border: 1px solid #c0cad5}`);
        });
    });
    it('should call onClick callback with selected color value', () => {
        const mockOnClick = jest.fn();
        const { getByTestId } = (0, testing_library_1.render)(react_1.default.createElement(Swatch_1.Swatch, { colors: mockColors, onClick: mockOnClick }));
        mockColors.map((color, idx) => {
            expect(getByTestId(`${idx}-${color}`)).toHaveStyle('cursor: pointer');
            testing_library_1.fireEvent.click(getByTestId(`${idx}-${color}`));
            expect(mockOnClick).toHaveBeenLastCalledWith(color);
        });
    });
    it('does not crash when onClick callback is not provided', () => {
        const mockOnClick = jest.fn();
        const { getByTestId } = (0, testing_library_1.render)(react_1.default.createElement(Swatch_1.Swatch, { colors: mockColors }));
        mockColors.map((color, idx) => {
            expect(getByTestId(`${idx}-${color}`)).toHaveStyle('cursor: default');
            testing_library_1.fireEvent.click(getByTestId(`${idx}-${color}`));
            expect(mockOnClick).toHaveBeenCalledTimes(0);
        });
    });
});
//# sourceMappingURL=Swatch.spec.js.map