"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const testing_library_1 = require("../__test__/testing-library");
const testing_library_2 = require("@storybook/testing-library");
const Tab_1 = require("./Tab");
const pcln_icons_1 = require("pcln-icons");
describe('Tab', () => {
    const tabsData = [
        { id: 'tab1', text: 'Tab 1', children: react_1.default.createElement("div", null, "Tab 1 Content"), onTabSelect: () => { } },
        { id: 'tab2', text: 'Tab 2', children: react_1.default.createElement("div", null, "Tab 2 Content"), onTabSelect: () => { } },
    ];
    const tabsDataWithIcon = [
        { id: 'tab1', text: 'Tab 1', icon: pcln_icons_1.Departure, children: react_1.default.createElement("div", null, "Tab 1 Content"), onTabSelect: () => { } },
        { id: 'tab2', text: 'Tab 2', children: react_1.default.createElement("div", null, "Tab 2 Content"), onTabSelect: () => { } },
    ];
    it('renders tabs with correct text', () => {
        (0, testing_library_1.render)(react_1.default.createElement(Tab_1.Tab, { type: 'button', tabsData: tabsData }));
        expect(testing_library_1.screen.getByRole('tab', { name: 'Tab 1' })).toBeInTheDocument();
        expect(testing_library_1.screen.getByRole('tab', { name: 'Tab 2' })).toBeInTheDocument();
    });
    it('renders tab content based on active tab', async () => {
        (0, testing_library_1.render)(react_1.default.createElement(Tab_1.Tab, { type: 'button', tabsData: tabsData }));
        expect(testing_library_1.screen.getByRole('tab', { name: 'Tab 1' })).toBeInTheDocument();
        expect(testing_library_1.screen.getByText('Tab 1 Content')).toBeInTheDocument();
        expect(testing_library_1.screen.queryByText('Tab 2 Content')).not.toBeInTheDocument();
        await testing_library_2.userEvent.click(testing_library_1.screen.getByText('Tab 2'));
        expect(testing_library_1.screen.getByRole('tab', { name: 'Tab 2' })).toBeInTheDocument();
        expect(testing_library_1.screen.queryByText('Tab 1 Content')).not.toBeInTheDocument();
        expect(testing_library_1.screen.getByText('Tab 2 Content')).toBeInTheDocument();
    });
    it('renders tab content based on active tab with icon', async () => {
        (0, testing_library_1.render)(react_1.default.createElement(Tab_1.Tab, { type: 'button', tabsData: tabsDataWithIcon }));
        expect(testing_library_1.screen.getByRole('tab', { name: 'Tab 1' })).toBeInTheDocument();
        expect(testing_library_1.screen.getByText('Tab 1 Content')).toBeInTheDocument();
        expect(testing_library_1.screen.queryByText('Tab 2 Content')).not.toBeInTheDocument();
        await testing_library_2.userEvent.click(testing_library_1.screen.getByText('Tab 2'));
        expect(testing_library_1.screen.getByRole('tab', { name: 'Tab 2' })).toBeInTheDocument();
        expect(testing_library_1.screen.queryByText('Tab 1 Content')).not.toBeInTheDocument();
        expect(testing_library_1.screen.getByText('Tab 2 Content')).toBeInTheDocument();
    });
    it('renders tab content based on active tab in Chip Variation', async () => {
        (0, testing_library_1.render)(react_1.default.createElement(Tab_1.Tab, { type: 'chip', tabsData: tabsData }));
        expect(testing_library_1.screen.getByRole('radio', { name: 'Tab 1' })).toBeInTheDocument();
        expect(testing_library_1.screen.getByText('Tab 1 Content')).toBeInTheDocument();
        expect(testing_library_1.screen.queryByText('Tab 2 Content')).not.toBeInTheDocument();
        await testing_library_2.userEvent.click(testing_library_1.screen.getByText('Tab 2'));
        expect(testing_library_1.screen.getByRole('radio', { name: 'Tab 2' })).toBeInTheDocument();
        expect(testing_library_1.screen.queryByText('Tab 1 Content')).not.toBeInTheDocument();
        expect(testing_library_1.screen.getByText('Tab 2 Content')).toBeInTheDocument();
    });
    it('renders tab content based on active tab in Radio Variation', async () => {
        (0, testing_library_1.render)(react_1.default.createElement(Tab_1.Tab, { type: 'radio', tabsData: tabsData }));
        expect(testing_library_1.screen.getByRole('tab', { name: 'Tab 1' })).toBeInTheDocument();
        expect(testing_library_1.screen.getByText('Tab 1 Content')).toBeInTheDocument();
        expect(testing_library_1.screen.queryByText('Tab 2 Content')).not.toBeInTheDocument();
        await testing_library_2.userEvent.click(testing_library_1.screen.getByText('Tab 2'));
        expect(testing_library_1.screen.queryByText('Tab 1 Content')).not.toBeInTheDocument();
        expect(testing_library_1.screen.getByText('Tab 2 Content')).toBeInTheDocument();
    });
    it('renders tab content based on orientation', async () => {
        (0, testing_library_1.render)(react_1.default.createElement(Tab_1.Tab, { type: 'button', orientation: 'vertical', tabsData: tabsData }));
        expect(testing_library_1.screen.getByRole('tab', { name: 'Tab 1' })).toBeInTheDocument();
        await testing_library_2.userEvent.click(testing_library_1.screen.getByText('Tab 1'));
        expect(testing_library_1.screen.getByText('Tab 1 Content')).toBeInTheDocument();
        expect(testing_library_1.screen.queryByText('Tab 2 Content')).not.toBeInTheDocument();
        await testing_library_2.userEvent.click(testing_library_1.screen.getByText('Tab 2'));
        expect(testing_library_1.screen.queryByText('Tab 1 Content')).not.toBeInTheDocument();
        expect(testing_library_1.screen.getByText('Tab 2 Content')).toBeInTheDocument();
    });
});
//# sourceMappingURL=Tab.spec.js.map