"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const testing_library_1 = require("../__test__/testing-library");
const theme_1 = require("../theme/theme");
const Text_1 = require("./Text");
describe('Text', () => {
    test('renders', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Text_1.Text, null)).toJSON();
        expect(json).toMatchSnapshot();
    });
    test('textAlign prop sets text-align', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Text_1.Text, { textAlign: 'center' })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('text-align', 'center');
    });
    test('regular prop sets font-weight', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Text_1.Text, { regular: true })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('font-weight', theme_1.theme.regular.toString());
    });
    test('bold prop sets font-weight', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Text_1.Text, { bold: true })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('font-weight', theme_1.theme.bold.toString());
    });
    test('caps prop sets text-transform', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Text_1.Text, { caps: true })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('text-transform', 'uppercase');
    });
    test('fontSize prop sets font-size', () => {
        const f0 = rendererCreateWithTheme(react_1.default.createElement(Text_1.Text, { fontSize: 0 })).toJSON();
        const f1 = rendererCreateWithTheme(react_1.default.createElement(Text_1.Text, { fontSize: 1 })).toJSON();
        const f2 = rendererCreateWithTheme(react_1.default.createElement(Text_1.Text, { fontSize: 2 })).toJSON();
        const f3 = rendererCreateWithTheme(react_1.default.createElement(Text_1.Text, { fontSize: 3 })).toJSON();
        const f4 = rendererCreateWithTheme(react_1.default.createElement(Text_1.Text, { fontSize: 4 })).toJSON();
        const f5 = rendererCreateWithTheme(react_1.default.createElement(Text_1.Text, { fontSize: 5 })).toJSON();
        const f6 = rendererCreateWithTheme(react_1.default.createElement(Text_1.Text, { fontSize: 6 })).toJSON();
        expect(f0).toHaveStyleRule('font-size', theme_1.theme.fontSizes[0] + 'px');
        expect(f1).toHaveStyleRule('font-size', theme_1.theme.fontSizes[1] + 'px');
        expect(f2).toHaveStyleRule('font-size', theme_1.theme.fontSizes[2] + 'px');
        expect(f3).toHaveStyleRule('font-size', theme_1.theme.fontSizes[3] + 'px');
        expect(f4).toHaveStyleRule('font-size', theme_1.theme.fontSizes[4] + 'px');
        expect(f5).toHaveStyleRule('font-size', theme_1.theme.fontSizes[5] + 'px');
        expect(f6).toHaveStyleRule('font-size', theme_1.theme.fontSizes[6] + 'px');
    });
    test('mt prop sets margin-top', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Text_1.Text, { mt: 2 })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('margin-top', theme_1.theme.space[2]);
    });
    test('display and overflow', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Text_1.Text, { display: 'inline-block', overflow: 'none' })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('display', 'inline-block');
        expect(json).toHaveStyleRule('overflow', 'none');
    });
    test('height and width', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Text_1.Text, { height: 150, width: 200 })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('height', '150px');
        expect(json).toHaveStyleRule('width', '200px');
    });
    test('min/max values', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(Text_1.Text, { minHeight: 200, maxHeight: 400, minWidth: 200, maxWidth: 400 })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('min-height', '200px');
        expect(json).toHaveStyleRule('max-height', '400px');
        expect(json).toHaveStyleRule('min-width', '200px');
        expect(json).toHaveStyleRule('max-width', '400px');
    });
    test('fontStyle', () => {
        (0, testing_library_1.render)(react_1.default.createElement(Text_1.Text, { fontStyle: 'italic' }, "Italic Text"));
        expect(testing_library_1.screen.getByText('Italic Text')).toHaveStyleRule('font-style', 'italic');
    });
    test('textDecoration', () => {
        (0, testing_library_1.render)(react_1.default.createElement(Text_1.Text, { textDecoration: 'underline' }, "Underlined Text"));
        expect(testing_library_1.screen.getByText('Underlined Text')).toHaveStyleRule('text-decoration', 'underline');
    });
    test('textTransform', () => {
        (0, testing_library_1.render)(react_1.default.createElement(Text_1.Text, { textTransform: 'lowercase' }, "Lowercase Text"));
        expect(testing_library_1.screen.getByText('Lowercase Text')).toHaveStyleRule('text-transform', 'lowercase');
    });
});
//# sourceMappingURL=Text.spec.js.map