"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ColorSchemes = exports.ResponsiveTypographyVsFontSize = exports.Paragraph = exports.Span = exports.HideOnLgBreakpoints = exports.MinMaxHeight = exports.ReactiveColor = exports.Color = exports.Margin = exports.Strikethrough = exports.Italic = exports.Caps = exports.Bold = exports.Regular = exports.TextTransform = exports.TextDecoration = exports.TextAlign = exports.FontStyle = exports.FontSize = exports.TextStyleResponsive = exports.TextStyleGallery = exports.TextStyle = void 0;
const react_1 = __importDefault(require("react"));
const styled_components_1 = __importDefault(require("styled-components"));
const Box_1 = require("../Box/Box");
const Divider_1 = require("../Divider/Divider");
const args_1 = require("../storybook/args");
const typographyAttrs_1 = require("../utils/attrs/typographyAttrs");
const utils_1 = require("../utils/utils");
const Text_1 = require("./Text");
const Text_stories_args_1 = require("./Text.stories.args");
exports.default = {
    title: 'Typography / Text',
    component: Text_1.Text,
    args: Text_stories_args_1.defaultArgs,
    argTypes: Text_stories_args_1.argTypes,
    parameters: {
        docs: {
            description: {
                component: 'A low-level component for setting font-size, typographic styles, margin, and color',
            },
        },
    },
};
const Template = (args) => (react_1.default.createElement(Box_1.Box, null,
    react_1.default.createElement(Text_1.Text, { m: 3, ...args }, "Hello there."),
    react_1.default.createElement(Text_1.Text, { m: 3, ...args }, "The quick brown fox jumps over the lazy dog to discover new deals every day.")));
exports.TextStyle = Template.bind({});
const TextStyleGallery = () => (react_1.default.createElement(Box_1.Box, null, typographyAttrs_1.textStylesValues.map((textStyle) => (react_1.default.createElement(Box_1.Box, { mb: 5, key: textStyle },
    react_1.default.createElement(Text_1.Text, { textStyle: textStyle }, "The quick brown fox jumps over the lazy dog to discover new deals every day."),
    react_1.default.createElement(Text_1.Text, { my: 2, color: 'text.tint', textStyle: 'subheading5' }, textStyle))))));
exports.TextStyleGallery = TextStyleGallery;
exports.TextStyleResponsive = Template.bind({});
exports.TextStyleResponsive.args = {
    textStyle: ['heading6', 'heading5', 'heading4', 'heading3', 'heading2', 'heading1'],
};
const FontSize = () => (react_1.default.createElement("div", null,
    react_1.default.createElement(Text_1.Text, { fontSize: 6 }, "Hello 6"),
    react_1.default.createElement(Text_1.Text, { fontSize: 5 }, "Hello 5"),
    react_1.default.createElement(Text_1.Text, { fontSize: 4 }, "Hello 4"),
    react_1.default.createElement(Text_1.Text, { fontSize: 3 }, "Hello 3"),
    react_1.default.createElement(Text_1.Text, { fontSize: 2 }, "Hello 2"),
    react_1.default.createElement(Text_1.Text, { fontSize: 1 }, "Hello 1"),
    react_1.default.createElement(Text_1.Text, { fontSize: 0 }, "Hello 0")));
exports.FontSize = FontSize;
const FontStyle = () => (react_1.default.createElement("div", null,
    react_1.default.createElement(Text_1.Text, { fontStyle: 'italic' }, "Hello Italic"),
    react_1.default.createElement(Text_1.Text, { fontStyle: 'oblique' }, "Hello Oblique")));
exports.FontStyle = FontStyle;
const TextAlign = () => (react_1.default.createElement("div", null,
    react_1.default.createElement(Text_1.Text, { textAlign: 'left' }, "Hello Left"),
    react_1.default.createElement(Text_1.Text, { textAlign: 'center' }, "Hello Center"),
    react_1.default.createElement(Text_1.Text, { textAlign: 'right' }, "Hello Right")));
exports.TextAlign = TextAlign;
const TextDecoration = () => (react_1.default.createElement("div", null,
    react_1.default.createElement(Text_1.Text, { textDecoration: 'overline' }, "Hello Overline"),
    react_1.default.createElement(Text_1.Text, { textDecoration: 'line-through' }, "Hello Line-Through"),
    react_1.default.createElement(Text_1.Text, { textDecoration: 'underline' }, "Hello Underline")));
exports.TextDecoration = TextDecoration;
const TextTransform = () => (react_1.default.createElement("div", null,
    react_1.default.createElement(Text_1.Text, { textTransform: 'capitalize' }, "hello capitalize"),
    react_1.default.createElement(Text_1.Text, { textTransform: 'uppercase' }, "hello uppercase"),
    react_1.default.createElement(Text_1.Text, { textTransform: 'lowercase' }, "HELLO LOWERCASE"),
    react_1.default.createElement(Text_1.Text, { textTransform: 'none' }, "Hello none"),
    react_1.default.createElement(Text_1.Text, { textTransform: 'uppercase', textStyle: 'heading5' }, "hello uppercase heading5")));
exports.TextTransform = TextTransform;
const Regular = () => react_1.default.createElement(Text_1.Text, { regular: true }, "Hello Regular");
exports.Regular = Regular;
const Bold = () => react_1.default.createElement(Text_1.Text, { bold: true }, "Hello Bold");
exports.Bold = Bold;
const Caps = () => react_1.default.createElement(Text_1.Text, { caps: true }, "Hello Caps");
exports.Caps = Caps;
const Italic = () => react_1.default.createElement(Text_1.Text, { italic: true }, "Hello italic");
exports.Italic = Italic;
const Strikethrough = () => react_1.default.createElement(Text_1.Text.s, null, "Hello Strikethrough");
exports.Strikethrough = Strikethrough;
const Margin = () => (react_1.default.createElement(Text_1.Text, { mt: 4, mb: 2 }, "Hello Margin"));
exports.Margin = Margin;
const Color = () => (react_1.default.createElement("div", null,
    react_1.default.createElement(Text_1.Text, { color: 'blue' }, "Hello Blue"),
    react_1.default.createElement(Text_1.Text, { color: 'green' }, "Hello Green")));
exports.Color = Color;
const ReactiveText = (0, styled_components_1.default)(Text_1.Text) `
  color: ${(props) => (0, utils_1.getTextColorOn)(props.backgroundColor, props.lightColor, props.darkColor)(props)};
`;
const ReactiveColorTemplate = (args) => (react_1.default.createElement(react_1.default.Fragment, null,
    react_1.default.createElement(Text_1.Text, { mb: 2 },
        "Uses the ",
        react_1.default.createElement("code", null, "getTextColorOn"),
        " utility"),
    react_1.default.createElement(Box_1.Box, { color: args.backgroundColor, p: 2, width: 300 },
        react_1.default.createElement(ReactiveText, { ...args }, args.children)),
    react_1.default.createElement(Box_1.Box, { color: 'primary.light', p: 2, width: 300 },
        react_1.default.createElement(ReactiveText, { ...args, backgroundColor: 'background.lightest' }, args.children))));
exports.ReactiveColor = ReactiveColorTemplate.bind({});
exports.ReactiveColor.args = {
    children: 'Hello There',
    backgroundColor: 'primary.base',
    lightColor: 'text.lightest',
    darkColor: 'text.base',
};
const MinMaxHeight = () => (react_1.default.createElement("div", null,
    react_1.default.createElement(Text_1.Text, { color: 'blue', minHeight: 200, minWidth: 300, width: 1 }, "Hello Blue"),
    react_1.default.createElement(Text_1.Text, { color: 'green', maxHeight: 200, maxWidth: 300 }, "Hello Green")));
exports.MinMaxHeight = MinMaxHeight;
const HideOnLgBreakpoints = () => (react_1.default.createElement("div", null,
    react_1.default.createElement(Text_1.Text, { color: 'primary', display: [null, null, null, 'none'], fontSize: 4, width: 1 }, "Hidden text on larger screens"),
    react_1.default.createElement(Text_1.Text, { color: 'secondary', fontSize: 4, width: 1 }, "I am always show. But the text above, hides on larger screens.")));
exports.HideOnLgBreakpoints = HideOnLgBreakpoints;
const Span = () => (react_1.default.createElement(Text_1.Text, null,
    "Just some text ",
    react_1.default.createElement(Text_1.Text.span, { bold: true }, "Some span text"),
    " Just some more text"));
exports.Span = Span;
const Paragraph = () => (react_1.default.createElement(Text_1.Text.p, null, "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum."));
exports.Paragraph = Paragraph;
const ResponsiveTypographyVsFontSize = () => (react_1.default.createElement(react_1.default.Fragment, null,
    react_1.default.createElement(Text_1.Text, null, "Actual (heading):"),
    react_1.default.createElement(Text_1.Text, { textStyle: ['heading2', null, null, 'heading1'] }, "Words and stuff heading textStyle"),
    react_1.default.createElement(Text_1.Text, null, "Expected (heading):"),
    react_1.default.createElement(Text_1.Text, { bold: true, fontSize: ['5', null, null, '6'] }, "Words and stuff heading fontSize"),
    react_1.default.createElement(Divider_1.Divider, null),
    react_1.default.createElement(Text_1.Text, null, "Actual (subheading):"),
    react_1.default.createElement(Text_1.Text, { textStyle: ['subheading4', null, null, 'subheading3'] }, "Words and stuff subheading textStyle"),
    react_1.default.createElement(Text_1.Text, null, "Expected (subheading):"),
    react_1.default.createElement(Text_1.Text, { fontSize: ['3', null, null, '4'] }, "Words and stuff subheading")));
exports.ResponsiveTypographyVsFontSize = ResponsiveTypographyVsFontSize;
const ColorSchemesTemplate = () => {
    return (react_1.default.createElement(react_1.default.Fragment, null, args_1.colorSchemeNames.map((colorScheme) => (react_1.default.createElement(Text_1.Text, { m: 3, p: 3, colorScheme: colorScheme, key: colorScheme, textStyle: 'heading1' },
        react_1.default.createElement(Text_1.Text, null, colorScheme))))));
};
exports.ColorSchemes = ColorSchemesTemplate.bind({});
ColorSchemesTemplate.args = {};
//# sourceMappingURL=Text.stories.js.map