"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("@testing-library/react");
const react_2 = __importDefault(require("react"));
const Box_1 = require("../Box/Box");
const theme_1 = require("../theme/theme");
const ThemeProvider_1 = require("./ThemeProvider");
describe('ThemeProvider', () => {
    describe('ThemeProvider: ThemeProvider', () => {
        it('should render correctly without throwing', () => {
            expect(() => {
                const { asFragment } = (0, react_1.render)(react_2.default.createElement(ThemeProvider_1.ThemeProvider, null));
                expect(asFragment()).toMatchSnapshot();
            }).not.toThrow();
        });
        it('should handle the "customBreakpoints" prop', () => {
            expect(() => {
                const { asFragment, getByTestId } = (0, react_1.render)(react_2.default.createElement(ThemeProvider_1.ThemeProvider, { customBreakpoints: ['20em', '32em', '48em', '64em'] },
                    react_2.default.createElement(Box_1.Box, { width: [1, 1 / 2, 1 / 4], "data-testid": 'ResponsiveBox' })));
                expect(asFragment()).toMatchSnapshot();
                const ResponsiveBox = getByTestId('ResponsiveBox');
                expect(ResponsiveBox).toHaveStyleRule('width', '100%');
                expect(ResponsiveBox).toHaveStyleRule('width', '50%', {
                    media: 'screen and (min-width:20em)',
                });
                expect(ResponsiveBox).toHaveStyleRule('width', '25%', {
                    media: 'screen and (min-width:32em)',
                });
            }).not.toThrow();
        });
    });
    describe('ThemeProvider: Base', () => {
        it('should render correctly with a "font-family" rule', () => {
            expect(() => {
                const { asFragment, container } = (0, react_1.render)(react_2.default.createElement(ThemeProvider_1.ThemeProvider, null,
                    react_2.default.createElement(ThemeProvider_1.Base, null)));
                expect(asFragment()).toMatchSnapshot();
                expect(container.firstChild).toHaveStyleRule('font-family', theme_1.theme.font);
            }).not.toThrow();
        });
    });
});
//# sourceMappingURL=ThemeProvider.spec.js.map