"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
jest.useFakeTimers();
const pcln_icons_1 = require("pcln-icons");
const react_1 = __importDefault(require("react"));
const testing_library_1 = require("../__test__/testing-library");
const Toast_1 = require("./Toast");
describe('Toast', () => {
    it('renders a success toast that closes after 2 seconds', () => {
        const mockRemoveClick = jest.fn();
        (0, testing_library_1.render)(react_1.default.createElement(Toast_1.Toast, { id: 10, lifespan: 2000, color: 'success', onRemoveClick: mockRemoveClick }, "Success Message"));
        expect(testing_library_1.screen.getByText('Success Message')).toBeInTheDocument();
        expect(mockRemoveClick).toHaveBeenCalledTimes(0);
        jest.runAllTimers();
        expect(mockRemoveClick).toHaveBeenCalledTimes(1);
        expect(mockRemoveClick).toHaveBeenCalledWith(10);
    });
    it('renders an error toast that needs to be closed manually', () => {
        const mockRemoveClick = jest.fn();
        (0, testing_library_1.render)(react_1.default.createElement(Toast_1.Toast, { id: 10, color: 'error', onRemoveClick: mockRemoveClick }, "Error Message"));
        expect(testing_library_1.screen.getByText('Error Message')).toBeInTheDocument();
        expect(mockRemoveClick).toHaveBeenCalledTimes(0);
        jest.runAllTimers();
        expect(mockRemoveClick).toHaveBeenCalledTimes(0);
        testing_library_1.fireEvent.click(testing_library_1.screen.getByRole('button'));
        expect(mockRemoveClick).toHaveBeenCalledTimes(1);
        expect(mockRemoveClick).toHaveBeenCalledWith(10);
    });
    it('renders a default toast', () => {
        const mockRemoveClick = jest.fn();
        (0, testing_library_1.render)(react_1.default.createElement(Toast_1.Toast, { id: 10, lifespan: 2000, onRemoveClick: mockRemoveClick }, "Information Message"));
        expect(testing_library_1.screen.getByText('Information Message')).toBeInTheDocument();
    });
    it('renders a success border toast', () => {
        (0, testing_library_1.render)(react_1.default.createElement(Toast_1.Toast, { id: 10, color: 'success', icon: react_1.default.createElement(pcln_icons_1.Success, { "data-testid": 'success-icon' }), variation: 'border' }, "Success Border Message"));
        const toast = testing_library_1.screen.getByText('Success Border Message');
        expect(toast).toBeInTheDocument();
        expect(toast.parentNode.parentNode).toHaveStyleRule('background-color', '#ecf7ec');
        expect(toast.parentNode.parentNode).toHaveStyleRule('color', '#001833');
        expect(toast.parentNode.parentNode).toHaveStyleRule('border-left', '4px solid #0a0');
        const icon = testing_library_1.screen.getByTestId('success-icon');
        expect(icon).toBeInTheDocument();
        expect(icon).toHaveStyleRule('color', '#0a0');
    });
});
//# sourceMappingURL=Toast.spec.js.map