"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Toggle = void 0;
const react_1 = __importDefault(require("react"));
const styled_components_1 = __importDefault(require("styled-components"));
const Absolute_1 = require("../Absolute/Absolute");
const Box_1 = require("../Box/Box");
const utils_1 = require("../utils/utils");
const alphaColor = (color, props) => `${(0, utils_1.getPaletteColor)(color)(props)}4C`;
const AbsoluteInput = styled_components_1.default.input `
  position: absolute;
  z-index: 1;
  opacity: 0;
  width: 100%;
  height: 100%;
  top: 0;
  left: 0;
  margin: 0;
  cursor: ${(props) => (props.disabled ? 'not-allowed' : 'pointer')};
`;
const OutlineAbsolute = (0, styled_components_1.default)(Absolute_1.Absolute) `
  height: calc(100% + 8px);
  opacity: 0;
  background-color: ${(props) => alphaColor(props.isOn ? 'primary.base' : 'background.dark', props)};
`;
const CircleAbsolute = (0, styled_components_1.default)(Absolute_1.Absolute) `
  display: flex;
  justify-content: center;
  align-items: center;
  height: ${(props) => props.width};
  cursor: ${(props) => (props.disabled ? 'not-allowed' : 'pointer')};
  z-index: 2;
  transition: left 0.3s;
`;
const WrapperBox = (0, styled_components_1.default)(Box_1.Box) `
  position: relative;
  height: ${(props) => props.height}px;
  transition: background-color 0.15s ease 0s;
  min-width: ${(props) => props.width}px;

  ${AbsoluteInput}:focus-visible + ${OutlineAbsolute} {
    opacity: 1;
  }

  &:hover:not([disabled]) {
    background-color: ${(props) => `${(0, utils_1.getPaletteColor)(props.isOn ? 'primary.dark' : 'background.tone')(props)}`};
  }

  &:hover:not([disabled]) > #circle-handle {
    box-shadow: ${(props) => props.theme.shadows.xl};
  }
`;
/**
 * Toggle component
 *
 * @public
 */
function Toggle({ isOn, label, onToggle, disabled, height, icon, name, }) {
    const width = height * 1.875;
    const circleAbsoluteSize = height - 4;
    const leftToggleOnPosition = width - circleAbsoluteSize - 2;
    return (react_1.default.createElement(WrapperBox, { borderRadius: 'full', color: disabled ? 'background.light' : isOn ? 'primary.base' : 'background.dark', height: height, isOn: isOn, width: width, disabled: disabled, onClick: disabled ? null : onToggle },
        react_1.default.createElement(AbsoluteInput, { "aria-checked": isOn, "aria-label": label, checked: isOn, disabled: disabled, onChange: () => { }, p: 0, role: 'switch', tabIndex: '0', type: 'checkbox', name: name }),
        react_1.default.createElement(OutlineAbsolute, { borderRadius: 'full', isOn: isOn, left: '-4px', top: '-4px', width: 'calc(100% + 8px)' }),
        react_1.default.createElement(CircleAbsolute, { borderRadius: 'full', color: 'background.lightest', left: isOn ? leftToggleOnPosition : '2px', top: '2px', id: 'circle-handle' // added for testing purpose
            , width: `${circleAbsoluteSize}px`, boxShadowSize: 'sm', disabled: disabled, "data-testid": 'handle-div' }, icon)));
}
exports.Toggle = Toggle;
Toggle.displayName = 'Toggle';
Toggle.defaultProps = {
    isOn: false,
    height: 24,
};
//# sourceMappingURL=Toggle.js.map