"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const testing_library_1 = require("../__test__/testing-library");
const theme_1 = require("../theme/theme");
const createTheme_1 = require("../utils/createTheme");
const Toggle_1 = require("./Toggle");
const theme = (0, createTheme_1.createTheme)();
describe('Toggle', () => {
    test('renders correctly when off', () => {
        const { getByRole } = (0, testing_library_1.render)(react_1.default.createElement(Toggle_1.Toggle, { label: 'Total price toggle' }));
        const container = getByRole('switch').parentNode;
        expect(container).toHaveStyleRule('background-color', theme.palette.background.dark);
    });
    test('renders correctly when on', () => {
        const { getByRole } = (0, testing_library_1.render)(react_1.default.createElement(Toggle_1.Toggle, { isOn: true, label: 'Total price toggle' }));
        const container = getByRole('switch').parentNode;
        expect(container).toHaveStyleRule('background-color', theme.palette.primary.base);
    });
    test('renders correctly when disabled', () => {
        const { getByRole } = (0, testing_library_1.render)(react_1.default.createElement(Toggle_1.Toggle, { label: 'Total price toggle', disabled: true }));
        const container = getByRole('switch').parentNode;
        expect(container).toHaveStyleRule('background-color', theme.palette.background.light);
    });
    test('calls callback', () => {
        const cb = jest.fn();
        const { getByLabelText } = (0, testing_library_1.render)(react_1.default.createElement(Toggle_1.Toggle, { label: 'Total price toggle', onToggle: cb }));
        const input = getByLabelText('Total price toggle');
        testing_library_1.fireEvent.click(input);
        expect(cb).toHaveBeenCalled();
    });
    test('add boxshadow and bgColor when hover over the selected states', () => {
        const { getByTestId, getByRole } = (0, testing_library_1.render)(react_1.default.createElement(Toggle_1.Toggle, { label: 'Total price toggle', isOn: true }));
        const wrapper = getByRole('switch').parentNode;
        const circleHandle = getByTestId('handle-div');
        expect(wrapper).toHaveStyleRule('background-color', theme.palette.primary.base);
        expect(circleHandle).toHaveStyleRule('box-shadow', theme_1.theme.shadows.sm);
        // when it is hover
        expect(wrapper).toHaveStyleRule('background-color', theme.palette.primary.dark, {
            modifier: ':hover:not([disabled])',
        });
        expect(wrapper).toHaveStyleRule('box-shadow', theme_1.theme.shadows.xl, {
            modifier: ':hover:not([disabled]) > #circle-handle',
        });
    });
});
//# sourceMappingURL=Toggle.spec.js.map