"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const ToggleBadge_1 = require("../ToggleBadge/ToggleBadge");
const createTheme_1 = require("../utils/createTheme");
describe('ToggleBadge', () => {
    let consoleError;
    let theme;
    beforeEach(() => {
        consoleError = console.error;
        console.error = jest.fn();
        theme = (0, createTheme_1.createTheme)();
    });
    afterEach(() => (console.error = consoleError));
    test('selected ToggleBadge renders with default props', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(ToggleBadge_1.ToggleBadge, { selected: true })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('background-color', theme.colors.lightBlue);
        expect(json).toHaveStyleRule('color', theme.colors.blue);
    });
    test('unselected ToggleBadge renders with default props', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(ToggleBadge_1.ToggleBadge, null)).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('color', theme.colors.blue);
    });
    test('selected one with background-color and text color passed as props hover state', () => {
        const json = rendererCreateWithTheme(react_1.default.createElement(ToggleBadge_1.ToggleBadge, { selected: true, bg: 'secondary', color: 'error', fontSize: 1 })).toJSON();
        expect(json).toMatchSnapshot();
        expect(json).toHaveStyleRule('background-color', theme.palette.secondary.light);
        expect(json).toHaveStyleRule('color', theme.palette.error.base);
    });
});
//# sourceMappingURL=ToggleBadge.spec.js.map