"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ColorScheme = exports.Colors = exports.Palette = void 0;
const pcln_icons_1 = require("pcln-icons");
const react_1 = __importDefault(require("react"));
const styled_components_1 = require("styled-components");
const Box_1 = require("../Box/Box");
const Card_1 = require("../Card/Card");
const Flex_1 = require("../Flex/Flex");
const Text_1 = require("../Text/Text");
const createTheme_1 = require("../utils/createTheme");
const theme = (0, createTheme_1.createTheme)();
const blacklist = ['darkPurple'];
const keys = Object.keys(theme.colors).filter((key) => !blacklist.includes(key));
const next = keys.map((key) => ({ key, value: theme.colors[key] }));
const colorSchemeFamilies = [
    'Primary',
    'Secondary',
    'Neutral',
    'Success',
    'Warning',
    'Caution',
    'Highlight',
    'Promo',
    'Alert',
    'Heading',
];
const ColorCard = (props) => (react_1.default.createElement(Flex_1.Flex, { flexDirection: 'column', width: '100%' },
    react_1.default.createElement(Card_1.Card, { borderRadius: 'xl', bg: props.color || props.shade, height: '100px' }),
    react_1.default.createElement(Text_1.Text, { f: 0 }, props.shade),
    react_1.default.createElement(Text_1.Text, { as: 'pre', m: 0 }, props.hex)));
const ColorSchemeColumnCard = ({ title }) => {
    return (react_1.default.createElement(Card_1.Card, { height: '100px', width: '108px', borderRadius: 'xl' },
        react_1.default.createElement(Flex_1.Flex, { flexDirection: 'column', alignItems: 'center', justifyContent: 'center', height: '100%' },
            react_1.default.createElement(Text_1.Text, { mb: 2, fontSize: '14px' }, title),
            react_1.default.createElement(pcln_icons_1.ArrowDown, { size: '16px' }))));
};
const BackgroundForegroundCard = () => {
    return (react_1.default.createElement(Flex_1.Flex, { width: '100%', justifyContent: 'space-around', my: 2 },
        react_1.default.createElement(ColorSchemeColumnCard, { title: 'Background' }),
        react_1.default.createElement(ColorSchemeColumnCard, { title: 'Foreground' })));
};
exports.default = {
    title: 'Design / Color',
};
const Palette = () => (react_1.default.createElement(styled_components_1.ThemeConsumer, null, (theme) => {
    return (react_1.default.createElement("div", null,
        react_1.default.createElement(Box_1.Box, { p: 3 },
            react_1.default.createElement("h1", null, "Palette"),
            react_1.default.createElement("p", null, "The palette allows you to change the color of components."),
            react_1.default.createElement(Flex_1.Flex, { flexWrap: 'wrap' }, Object.keys(theme.palette).map((color) => {
                const shades = theme.palette[color];
                if (typeof shades === 'object') {
                    return (react_1.default.createElement("div", { style: { width: '100%' } },
                        react_1.default.createElement("h4", null, color),
                        react_1.default.createElement(Flex_1.Flex, { flexWrap: 'wrap' }, Object.keys(shades).map((shade) => {
                            const fullColor = `${color}.${shade}`;
                            return (react_1.default.createElement(Box_1.Box, { key: fullColor, p: 3, width: [1, 1 / 2, 1 / 3, 1 / 4, 1 / 7] },
                                react_1.default.createElement(ColorCard, { name: fullColor, color: fullColor, shade: shade, hex: shades[shade] })));
                        })),
                        react_1.default.createElement("hr", null)));
                }
                else {
                    const fullColor = `${color}.${shades}`;
                    return (react_1.default.createElement(Box_1.Box, { key: fullColor, p: 3, width: [1, 1 / 2, 1 / 3, 1 / 4, 1 / 5] },
                        react_1.default.createElement(ColorCard, { name: fullColor, color: fullColor })));
                }
            })))));
}));
exports.Palette = Palette;
const Colors = () => (react_1.default.createElement("div", null,
    react_1.default.createElement(Box_1.Box, { p: 3 },
        react_1.default.createElement("h1", null, "Colors")),
    react_1.default.createElement(Flex_1.Flex, { flexWrap: 'wrap' }, next.map((color) => (react_1.default.createElement(Box_1.Box, { key: color.key, p: 3, width: [1, 1 / 2, 1 / 3, 1 / 4, 1 / 5] },
        react_1.default.createElement(ColorCard, { name: color.key, shade: color.key, hex: color.value })))))));
exports.Colors = Colors;
const ColorScheme = () => (react_1.default.createElement(styled_components_1.ThemeConsumer, null, (theme) => {
    return (react_1.default.createElement("div", null,
        react_1.default.createElement(Box_1.Box, { p: 3 },
            react_1.default.createElement("h1", null, "Color Scheme"),
            react_1.default.createElement(Flex_1.Flex, { flexWrap: 'wrap' }, colorSchemeFamilies.map((colorSchemeFamily) => {
                return (react_1.default.createElement(Card_1.Card, { borderRadius: 'xl', m: 2, p: 3, key: colorSchemeFamily },
                    react_1.default.createElement(Flex_1.Flex, { flexDirection: 'column' },
                        react_1.default.createElement(Text_1.Text, { textStyle: 'heading3' }, colorSchemeFamily),
                        react_1.default.createElement(BackgroundForegroundCard, null),
                        Object.entries(theme.colorSchemes)
                            .filter((entry) => entry[0].includes(colorSchemeFamily.toLowerCase()))
                            .map((entry) => {
                            const [key, colorScheme] = entry;
                            return (react_1.default.createElement(Flex_1.Flex, { flexDirection: 'column', py: 3, key: key },
                                react_1.default.createElement(Text_1.Text, { fontWeight: 'bold', mb: 2 }, key),
                                react_1.default.createElement(Flex_1.Flex, null,
                                    react_1.default.createElement(Box_1.Box, { px: 3, width: '140px' },
                                        react_1.default.createElement(ColorCard, { color: colorScheme.background })),
                                    react_1.default.createElement(Box_1.Box, { px: 3, width: '140px' },
                                        react_1.default.createElement(ColorCard, { color: colorScheme.foreground })))));
                        }))));
            })))));
}));
exports.ColorScheme = ColorScheme;
//# sourceMappingURL=Colors.stories.js.map