"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createTheme = void 0;
const deepmerge_1 = __importDefault(require("deepmerge"));
const theme_1 = require("../theme/theme");
const createColorScheme_1 = require("./createColorScheme");
const createColorStyles_1 = require("./createColorStyles");
const createMediaQueries_1 = require("./createMediaQueries");
const createPalette_1 = require("./createPalette");
const createTextStyles_1 = require("./createTextStyles");
/**
 * Adds aliases to an array of keys
 *
 * @param arr - The array to add aliases to
 *
 * @public
 */
const addAliases = (arr) => {
    arr.forEach((val, key) => {
        arr[['sm', 'md', 'lg', 'xl', 'xxl'][key]] = val;
    });
    return arr;
};
/**
 * Create the theme
 * @param theme -             The theme to merge against the default
 * @param customBreakpoints - Custom breakpoints for the theme
 * @param existingTheme -     Existing theme passed from a parent provider (Undefined if it's most outer provider)
 *
 * @returns The generated theme
 *
 * @public
 */
const createTheme = (theme = {}, customBreakpoints = null, existingTheme = theme_1.theme) => {
    const finalMergedTheme = (0, deepmerge_1.default)(existingTheme, theme);
    const mediaQueries = customBreakpoints
        ? (0, createMediaQueries_1.createMediaQueries)(customBreakpoints)
        : finalMergedTheme.mediaQueries;
    const palette = (0, createPalette_1.createPalette)(finalMergedTheme);
    return {
        ...finalMergedTheme,
        contrastRatio: finalMergedTheme.contrastRatio || 2.6,
        breakpoints: addAliases(customBreakpoints || finalMergedTheme.breakpoints),
        mediaQueries: addAliases(mediaQueries),
        palette,
        colorSchemes: (0, createColorScheme_1.createColorScheme)({ palette }),
        colorStyles: (0, createColorStyles_1.createColorStyles)(finalMergedTheme),
        textStyles: (0, createTextStyles_1.createTextStyles)(finalMergedTheme),
    };
};
exports.createTheme = createTheme;
//# sourceMappingURL=createTheme.js.map