/* eslint-disable jsx-a11y/accessible-emoji */
import { expect } from '@storybook/jest';
import { userEvent, within } from '@storybook/testing-library';
import React, { useState } from 'react';
import { Box } from '../Box/Box';
import { Button } from '../Button/Button';
import { ChoiceChip } from '../Chip/ChoiceChip/ChoiceChip';
import { Flex } from '../Flex/Flex';
import { Image } from '../Image/Image';
import { Text } from '../Text/Text';
import { Animate, MotionVariants, TransitionVariants } from './Animate';
const meta = {
    component: Animate,
};
export default meta;
export const Playground = () => {
    const [motion, setMotion] = useState('expandDown');
    const [transition, setTransition] = useState('default');
    const [isRendered, setIsRendered] = useState(true);
    const rerender = () => {
        setIsRendered(false);
        setTimeout(() => setIsRendered(true));
    };
    const handleMotionChange = (variant) => {
        setMotion(variant);
        rerender();
    };
    const handleTransitionChange = (variant) => {
        setTransition(variant);
        rerender();
    };
    return (React.createElement(Flex, { flexDirection: 'column', maxWidth: 600 },
        React.createElement(Text, { fontSize: 5, bold: true }, "Motion Variants"),
        React.createElement(Flex, { flexWrap: 'wrap' }, Object.keys(MotionVariants).map((variant) => (React.createElement(ChoiceChip, { "data-testid": variant, selected: motion === variant, m: 2, key: variant, onClick: () => handleMotionChange(variant) }, variant)))),
        React.createElement(Text, { fontSize: 5, bold: true }, "Transition Variants"),
        React.createElement(Flex, { flexWrap: 'wrap' }, Object.keys(TransitionVariants).map((variant) => (React.createElement(ChoiceChip, { "data-testid": variant, selected: transition === variant, m: 2, key: variant, onClick: () => handleTransitionChange(variant) }, variant)))),
        isRendered && (React.createElement(Animate, { variant: motion, transition: transition },
            React.createElement(Flex, { "data-testid": 'playground-content', p: 5, bg: 'background.darkest', flexDirection: 'column', justifyContent: 'center', alignItems: 'center' },
                React.createElement(Text, { fontSize: 5, bold: true, color: 'text.lightest' }, "Hello \uD83D\uDC4B"),
                React.createElement(Text, { fontSize: 5, bold: true, color: 'text.lightest' }, "World \uD83C\uDF0E"))))));
};
const delay = (time) => new Promise((resolve) => setTimeout(resolve, time));
Playground.play = async ({ canvasElement }) => {
    const canvas = within(canvasElement);
    await userEvent.click(canvas.getByText('fadeIn'));
    await delay(1000);
    const playgroundContent = await canvas.getByTestId('playground-content');
    await expect(playgroundContent).toBeTruthy();
};
export const AnimatedListings = () => {
    const [isRendered, setIsRendered] = useState(true);
    const rerender = () => {
        setIsRendered(false);
        setTimeout(() => setIsRendered(true));
    };
    return (React.createElement(Box, null,
        React.createElement(Button, { onClick: rerender }, "Reset"),
        isRendered &&
            Array.from(Array(10).keys()).map((i) => (React.createElement(Animate, { key: i, variant: 'scaleFromTopLeft', override: { transition: { ...TransitionVariants.default, delay: 0.05 * i } } },
                React.createElement(Flex, { m: 2 },
                    React.createElement(Image, { src: `https://picsum.photos/id/${i + 50}/160/90`, alt: 'random' }),
                    React.createElement(Flex, { p: 2, bg: 'background.darkest', alignItems: 'center' },
                        React.createElement(Text, { color: 'text.lightest', fontSize: 3 }, "\uD83D\uDC48 Travel Here \uD83C\uDFE8 \u2708\uFE0F \uD83D\uDE99"))))))));
};
export const ComposedAnimations = () => {
    const [isRendered, setIsRendered] = useState(true);
    const rerender = () => {
        setIsRendered(false);
        setTimeout(() => setIsRendered(true));
    };
    return (React.createElement(Box, null,
        React.createElement(Flex, { width: 'fit-content' },
            React.createElement(Button, { m: 2, onClick: rerender }, "Reset")),
        isRendered && (React.createElement(Animate, { variant: 'scaleFromTopLeft' },
            React.createElement(Flex, { width: 'fit-content' },
                React.createElement(Animate, { variant: 'scaleOnHover' },
                    React.createElement(Button, { m: 2 }, "Hover Me")),
                React.createElement(Animate, { variant: 'scaleOnTap', transition: 'spring' },
                    React.createElement(Button, { m: 2 }, "Click Me")),
                React.createElement(Animate, { variant: 'scaleOnTap' },
                    React.createElement(Animate, { variant: 'scaleOnHover' },
                        React.createElement(Button, { m: 2 }, "I Do Both!"))))))));
};
export const SpinAnimation = () => {
    return (React.createElement(Flex, { width: 'fit-content' },
        React.createElement(Animate, { variant: 'spin' },
            React.createElement(Button, { m: 2 }, "Spin!"))));
};
//# sourceMappingURL=Animate.stories.js.map