import { Star } from 'pcln-icons';
import React from 'react';
import styled from 'styled-components';
import { Flex } from '../Flex/Flex';
import { Text } from '../Text/Text';
import { colorSchemeNames } from '../storybook/args';
import { Box } from './Box';
import { argTypes, defaultArgs } from './Box.stories.args';
export default {
    title: 'core / Box',
    component: Box,
    args: defaultArgs,
    argTypes,
    parameters: {
        docs: {
            description: {
                component: `A low-level layout component for setting color, display, height, margin, maxHeight, maxWidth, minHeight, minWidth, padding, size, textAlign, and width.`,
            },
        },
    },
};
const Template = (args) => (React.createElement(Box, { ...args },
    React.createElement(Text, { p: 3 }, "Hello!")));
export const _Box = Template.bind({});
export const DisplayAndSize = Template.bind({});
DisplayAndSize.storyName = 'Display and Size';
DisplayAndSize.args = {
    color: 'alert.base',
    display: ['none', null, 'block'],
    size: 250,
};
export const Padding = Template.bind({});
Padding.args = {
    p: 4,
    color: 'background.base',
};
export const Height = Template.bind({});
Height.args = {
    color: 'warning.base',
    height: ['250px', '350px', '450px', '550px'],
    width: ['150px', '250px', '350px', '450px'],
};
export const MaxAndMinValues = Template.bind({});
MaxAndMinValues.storyName = 'Min and Max Values';
MaxAndMinValues.args = {
    color: 'priceSecondary.base',
    maxHeight: ['300px', null, '400px', null, '500px'],
    maxWidth: ['300px', null, '400px', null, '500px'],
    minHeight: ['100px', null, '200px', null, '300px'],
    minWidth: ['300px', null, '200px', null, '100px'],
};
export const Margin = Template.bind({});
Margin.args = {
    m: 3,
    color: 'background.base',
};
export const Color = Template.bind({});
Color.args = {
    color: 'primary.base',
};
export const BoxShadow = Template.bind({});
BoxShadow.args = {
    boxShadowSize: 'overlay-lg',
};
export const Size = Template.bind({});
Size.args = {
    color: 'primary.base',
    size: 200,
};
const DimsChildren = () => React.createElement(Text, { color: 'text.lightest' }, "Box Dimensions");
export const Width = Template.bind({});
Width.args = {
    color: 'primary.base',
    width: 1 / 2,
    children: React.createElement(DimsChildren, null),
};
export const PixelWidth = Template.bind({});
PixelWidth.args = {
    color: 'primary.base',
    width: 256,
    children: React.createElement(DimsChildren, null),
};
export const VwWidth = Template.bind({});
VwWidth.storyName = 'Viewport Width unit';
VwWidth.args = {
    color: 'primary.base',
    width: '75vw',
    children: React.createElement(DimsChildren, null),
};
export const DirectionalPadding = () => (React.createElement(Box, { p: 3 },
    React.createElement(Box, { m: 1, pt: 3, color: 'white', bg: 'blue' }, "Padding Top"),
    React.createElement(Box, { m: 1, pr: 3, color: 'white', bg: 'blue' }, "Padding Right"),
    React.createElement(Box, { m: 1, pb: 3, color: 'white', bg: 'blue' }, "Padding Bottom"),
    React.createElement(Box, { m: 1, pl: 3, color: 'white', bg: 'blue' }, "Padding Left"),
    React.createElement(Box, { m: 1, px: 3, color: 'white', bg: 'blue' }, "Padding X-Axis"),
    React.createElement(Box, { m: 1, py: 3, color: 'white', bg: 'blue' }, "Padding Y-Axis")));
export const DirectionalMargin = () => (React.createElement(Box, { p: 3 },
    React.createElement(Box, { mt: 3, color: 'white', bg: 'blue' }, "Margin Top"),
    React.createElement(Box, { mr: 3, color: 'white', bg: 'blue' }, "Margin Right"),
    React.createElement(Box, { mb: 3, color: 'white', bg: 'blue' }, "Margin Bottom"),
    React.createElement(Box, { ml: 3, color: 'white', bg: 'blue' }, "Margin Left"),
    React.createElement(Box, { mx: 3, color: 'white', bg: 'blue' }, "Margin X-Axis"),
    React.createElement(Box, { my: 3, color: 'white', bg: 'blue' }, "Margin Y-Axis")));
export const Overflow = () => (React.createElement(Box, { p: 3 },
    React.createElement(Box, { overflow: 'hidden', maxHeight: '100px', maxWidth: '100px', mb: 3, color: 'background.darkest', bg: 'primary' }, "This is a box with hidden overflow. This is a box with hidden overflow."),
    React.createElement(Box, { overflow: 'clip', maxHeight: '100px', maxWidth: '100px', mb: 3, color: 'background.darkest', bg: 'primary' }, "This is a box with clip overflow. This is a box with clip overflow."),
    React.createElement(Box, { overflow: 'scroll', maxHeight: '100px', maxWidth: '100px', mb: 3, color: 'background.darkest', bg: 'primary' }, "This is a box with scroll overflow. This is a box with scroll overflow."),
    React.createElement(Box, { overflow: 'auto', maxHeight: '100px', maxWidth: '100px', mb: 3, color: 'background.darkest', bg: 'primary' }, "This is a box with auto overflow. This is a box with auto overflow."),
    React.createElement(Box, { overflow: 'visible', maxHeight: '100px', maxWidth: '100px', mb: 3, color: 'background.darkest', bg: 'primary' }, "This is a box with visible overflow. This is a box with visible overflow.")));
export const ThemeUserCaseColorText = () => (React.createElement(React.Fragment, null,
    React.createElement(Box, { p: 3 },
        React.createElement(Box, { mt: 3, color: 'text' }, "color=\"text\" w/o bg prop: retains the original \"text\" color from original color set as backward compatible: expected style w. \"text\" color and white background"),
        React.createElement(Box, { mt: 3, color: 'purple' }, "color=\"purple\" as none \"text\" color w/o bg prop")),
    React.createElement(Box, { p: 5 },
        React.createElement(Box, { mt: 3, color: 'text.lightest', bg: 'background.dark' }, "Theme 1: color=\"text.lightest\" value & bg=\"background.dark\""),
        React.createElement(Box, { mt: 3, color: 'text', bg: 'background.lightest' }, "Theme 2: color=\"text\" & bg=\"background.lightest\""))));
ThemeUserCaseColorText.storyName = 'Theme user case: color=text';
export const CustomColor = Template.bind({});
CustomColor.args = {
    color: 'magenta',
    bg: '#ebfa',
};
const ColorSchemeWithAttrs = styled(Box).attrs(() => ({
    colorScheme: 'cautionLight',
})) ``;
const ColorSchemesTemplate = () => {
    return (React.createElement(React.Fragment, null,
        colorSchemeNames.map((colorScheme) => (React.createElement(Box, { m: 3, p: 3, colorScheme: colorScheme, key: colorScheme },
            React.createElement(Flex, { flexDirection: 'column' },
                React.createElement(Text, { textStyle: 'heading1', mb: 2 }, colorScheme),
                React.createElement(Flex, { alignItems: 'center' },
                    React.createElement(Text, null, "Children inherit colors from the color scheme by default"),
                    React.createElement(Star, null)),
                React.createElement(Flex, { alignItems: 'center' },
                    React.createElement(Text, { color: 'text' }, "Custom text and icon colors override the color scheme"),
                    React.createElement(Star, { color: 'alert' })))))),
        React.createElement(ColorSchemeWithAttrs, { m: 3, p: 3 },
            React.createElement(Text, null, "Using attrs and colorScheme"))));
};
export const ColorSchemes = ColorSchemesTemplate.bind({});
ColorSchemesTemplate.args = {};
//# sourceMappingURL=Box.stories.js.map