import { ArgsTable, PRIMARY_STORY, Primary } from '@storybook/addon-docs';
import { linkTo } from '@storybook/addon-links';
import { Calendar, Check, ChevronDown, ChevronLeft, ChevronRight, Guests, Search, User } from 'pcln-icons';
import React from 'react';
import { Box } from '../Box/Box';
import { ButtonChip } from '../Chip/ButtonChip/ButtonChip';
import { CloseButton } from '../CloseButton/CloseButton';
import { DoDont } from '../DocsUtils/DoDont/DoDont';
import { DocTable } from '../DocsUtils/DocTable/DocTable';
import { Hero } from '../DocsUtils/Hero/Hero';
import { Note } from '../DocsUtils/Note/Note';
import { RelatedComponent, RelatedComponentContainer } from '../DocsUtils/RelatedComponent/RelatedComponent';
import { Section } from '../DocsUtils/Section/Section';
import { StoryHeading } from '../DocsUtils/StoryHeading/StoryHeading';
import { StoryStage } from '../DocsUtils/StoryStage/StoryStage';
import { TableOfContents } from '../DocsUtils/TableOfContents/TableOfContents';
import { Flex } from '../Flex/Flex';
import { Image } from '../Image/Image';
import { Label } from '../Label/Label';
import { Link } from '../Link/Link';
import { Text } from '../Text/Text';
import { ThemeProvider } from '../ThemeProvider/ThemeProvider';
import { colors, shadows } from '../storybook/args';
import { Button } from './Button';
import alignmentImage from './Button.Image.Alignment.png';
import groupsImage from './Button.Image.Groups.png';
import heroImage from './Button.Image.Hero.png';
import responsiveLayoutImage from './Button.Image.ResponsiveLayout.png';
import buttonStates from './Button.Image.States.png';
const sizeOptions = ['small', 'medium', 'large', 'extraLarge'];
export const Playground = {
    render: (args) => React.createElement(Button, { ...args }, "Button"),
    argTypes: {
        color: {
            control: 'select',
            options: colors,
            defaultValue: Button.defaultProps.color,
        },
        size: {
            control: 'select',
            options: sizeOptions,
            defaultValue: Button.defaultProps.size,
        },
        variation: {
            control: 'select',
            options: ['fill', 'input', 'lightFill', 'link', 'outline', 'plain', 'subtle', 'white'],
            defaultValue: Button.defaultProps.variation,
        },
        disabled: {
            defaultValue: false,
            type: 'boolean',
        },
        boxShadowSize: {
            control: 'select',
            options: shadows,
        },
    },
};
export const Size = {
    render: () => (React.createElement(StoryStage, null,
        React.createElement(Button, { size: 'small' }, "Small"),
        React.createElement(Button, { size: 'medium' }, "Medium"),
        React.createElement(Button, { size: 'large' }, "Large"),
        React.createElement(Button, { size: 'extraLarge' }, "Extra Large"))),
};
export const PrimaryVariations = {
    render: () => (React.createElement(StoryStage, null,
        React.createElement(Button, { width: 100, variation: 'fill' }, "Fill"),
        React.createElement(Button, { width: 100, variation: 'subtle' }, "Subtle"))),
};
export const TonalVariations = {
    render: () => (React.createElement(StoryStage, { borderRadius: 'md', bg: 'background.tint' },
        React.createElement(Button, { width: 100, variation: 'plain' }, "Plain"),
        React.createElement(Button, { width: 100, variation: 'white' }, "White"))),
};
export const LinkVariation = {
    render: () => (React.createElement(StoryStage, null,
        React.createElement(Button, { variation: 'link' }, "Enabled"),
        React.createElement(Button, { variation: 'link', disabled: true }, "Disabled"),
        React.createElement(Button, { variation: 'link' },
            React.createElement(Text, { fontWeight: 'bold' }, "Bold")))),
};
export const AdditionalVariations = {
    render: () => (React.createElement(StoryStage, null,
        React.createElement(Button, { variation: 'outline' }, "Outline"),
        React.createElement(Button, { variation: 'lightFill' }, "Light Fill"))),
};
export const Disabled = {
    render: () => (React.createElement(StoryStage, null,
        React.createElement(Button, { disabled: true }, "Continue"),
        React.createElement(Button, { disabled: true, variation: 'link' }, "Button"))),
};
export const SemanticStyles = {
    render: () => (React.createElement(StoryStage, null,
        React.createElement(Button, { color: 'primary' }, "Search Hotels"),
        React.createElement(Button, { color: 'primary', variation: 'subtle' }, "Search Hotels"),
        React.createElement(Button, { color: 'secondary' }, "Choose Room"),
        React.createElement(Button, { color: 'secondary', variation: 'subtle' }, "Choose Room"),
        React.createElement(Button, { color: 'secondary' }, "Secondary"),
        React.createElement(Button, { color: 'warning' }, "Cancel"),
        React.createElement(Button, { color: 'warning', variation: 'subtle' }, "Cancel"))),
};
export const IconButtons = {
    render: () => (React.createElement(React.Fragment, null, sizeOptions.map((size) => (React.createElement(StoryStage, { key: size },
        React.createElement(Button, { size: size, IconLeft: User }, "Sign In"),
        React.createElement(Button, { size: size, IconRight: Calendar }, "Select Dates"),
        React.createElement(Button, { size: size, IconLeft: Search, IconRight: Check }, "Bookends"),
        React.createElement(Button, { size: size, IconLeft: ChevronLeft }),
        React.createElement(Button, { size: size, IconLeft: ChevronRight }),
        React.createElement(Button, { size: size, IconLeft: User }),
        React.createElement(Button, { size: size, variation: 'link', IconLeft: User }, "Link Button Text")))))),
};
export const InputVariation = {
    render: () => (React.createElement(StoryStage, null,
        React.createElement(Button, { size: 'large', variation: 'input', borderRadius: 'lg', py: 0 },
            React.createElement(Flex, { width: '100%', justifyContent: 'flex-start', alignItems: 'center', height: '54px' },
                React.createElement(Calendar, { mr: 2, color: 'primary.base' }),
                React.createElement(Flex, { flexDirection: 'column' },
                    React.createElement(Label, { as: 'div' }, "Check-in - Check-out"),
                    React.createElement(Text, null, "09/21/2023 \u2013 09/22/2023")))),
        React.createElement(Button, { size: 'large', variation: 'input', borderRadius: 'lg' },
            React.createElement(Flex, { width: '100%', justifyContent: 'flex-start', height: '100%', alignItems: 'center' },
                React.createElement(Calendar, { mr: 2, color: 'primary.base' }),
                React.createElement(Flex, { flexDirection: 'column' },
                    React.createElement(Text, { color: 'text.light' }, "mm/dd/yyyy - mm/dd/yyyy")))),
        React.createElement(Button, { size: 'large', variation: 'input', borderRadius: 'lg' },
            React.createElement(Flex, { width: '100%', justifyContent: 'space-between', height: '100%', alignItems: 'center' },
                React.createElement(Flex, { alignItems: 'center' },
                    React.createElement(Guests, { mr: 2, color: 'primary.base' }),
                    React.createElement(Flex, { flexDirection: 'column' },
                        React.createElement(Text, { color: 'text.light' }, "Select travelers"))),
                React.createElement(ChevronDown, { color: 'primary.base' }))))),
};
export const FlexProps = {
    render: () => (React.createElement(StoryStage, null,
        React.createElement(Button, { width: 200, variation: 'fill', flexProps: { justifyContent: 'left' } }, "Left Justify"),
        React.createElement(Button, { width: 200, variation: 'fill', flexProps: { justifyContent: 'right' } }, "Right Justify"))),
};
const meta = {
    title: 'Actions/Button',
    component: Button,
    parameters: {
        design: {
            type: 'figma',
            url: 'https://www.figma.com/file/1lLCo0ZnO1RyMDEbnnS0by/Web-Design-System?type=design&node-id=131-21304&t=wTmhDg2MwlPA9PGf-4',
        },
        docs: {
            page: () => (React.createElement(ThemeProvider, null,
                React.createElement(Hero, { name: 'Button', img: heroImage }, "Buttons allow users to trigger an action or event with a single click. For example, you can use a button for allowing the functionality of submitting a form, opening a dialog, canceling an action, or performing a delete operation."),
                React.createElement(TableOfContents, { links: [
                        'Overview',
                        'Props',
                        'Examples & Variations',
                        'States',
                        'Theming',
                        'Usage',
                        `Do's and Don'ts`,
                        'Related Components',
                    ] }),
                React.createElement(Section, { heading: 'Overview' },
                    React.createElement(Text, { textStyle: 'paragraph' }, "Buttons allow users to trigger an action or event with a single click. For example, you can use a button for allowing the functionality of submitting a form, opening a dialog, canceling an action, or performing a delete operation.")),
                React.createElement(Section, { heading: 'Props' },
                    React.createElement(Primary, null),
                    React.createElement(ArgsTable, { story: PRIMARY_STORY })),
                React.createElement(Section, { heading: 'Examples & Variations' },
                    React.createElement(Text, { textStyle: 'paragraph' }, "Each button variation and property has set functions that provide patterns and signals to the user their function and the desired actions on a per page and per component basis. Because of this it is very important that the different variants are implemented consistently across products, so that they message the correct actions."),
                    React.createElement(StoryHeading, { storyName: 'Size', storyTitle: meta.title }),
                    React.createElement(Text, { textStyle: 'paragraph' }, "Our design system supports a default button size as well as a extraLarge, large and small size. If a large or small button is desired, set the size property to either extraLarge, large or small. These sizes allow for hierarchy, emphasis, larger/smaller touch targets, and flexibility."),
                    React.createElement(DocTable, { columns: [
                            { field: 'size', heading: 'Size' },
                            { field: 'useCase', heading: 'Use Case' },
                        ], data: [
                            {
                                size: 'Small',
                                useCase: 'Use when there is not enough space for the default and in responsive patterns on mobile breakpoints.',
                            },
                            { size: 'Medium (default)', useCase: 'This is the most commonly used button size.' },
                            { size: 'Large', useCase: 'Use when buttons are paired with input fields.' },
                            {
                                size: 'Extra Large',
                                useCase: 'Use on search forms and marketing and promotion hero modules.',
                            },
                        ] }),
                    React.createElement(StoryHeading, { storyName: 'Primary Variations', storyTitle: meta.title }),
                    React.createElement(Text, { textStyle: 'paragraph' }, "Our core button variations use fill and subtle properties. These variations make up the majority of our button styles outside of the conversion funnel."),
                    React.createElement(DocTable, { columns: [
                            { field: 'variation', heading: 'Variation' },
                            { field: 'useCase', heading: 'Use Case' },
                        ], data: [
                            {
                                variation: 'Fill',
                                useCase: 'The filled button is used for high emphasis, the primary, most important, or most common actions on a screen. The filled button’s contrasting surface color makes it the most prominent button.',
                            },
                            {
                                variation: 'Subtle',
                                useCase: 'Subtle button are best used for supporting actions of medium emphasis. Secondary buttons are also suited for prodiving clear actions on screens with multiple button with various levels of emphasis or to provide low-level emphasis over UI elements, and text links or buttons.',
                            },
                        ] }),
                    React.createElement(StoryHeading, { storyName: 'Tonal Variations', storyTitle: meta.title }),
                    React.createElement(Text, { textStyle: 'paragraph' }, "In addition to Fill and Subtle, Plain and White variations can be used on their own to reduce emphasis, provide contrast, or paired with primary buttons for supporting actions."),
                    React.createElement(DocTable, { columns: [
                            { field: 'variation', heading: 'Variation' },
                            { field: 'useCase', heading: 'Use Case' },
                        ], data: [
                            {
                                variation: 'Plain',
                                useCase: 'Plain button variation has a transparent background but has the same height and width poperties as the fill button.',
                            },
                            {
                                variation: 'White',
                                useCase: 'White buttons are used over images and in place of fill and subtle buttons when color contrast is needed.',
                            },
                        ] }),
                    React.createElement(StoryHeading, { storyName: 'Text Buttons', storyTitle: meta.title }),
                    React.createElement(Text, { textStyle: 'paragraph' }, "Text buttons have less visual prominence, so should be used for secondary actions or low emphasis actions. Used when aligning with 16px, 14px, and 12px body copy."),
                    React.createElement(StoryHeading, { storyName: 'Additional Variations', storyTitle: meta.title }),
                    React.createElement(Text, { textStyle: 'paragraph' }, "Although rarely used on Priceline, we understand these are popular variations used in interface design.")),
                React.createElement(Section, { heading: 'States' },
                    React.createElement(Text, { textStyle: 'paragraph' }, "States are visual representations used to communicate the status of a component or interactive element."),
                    React.createElement(Flex, { my: 4, borderRadius: 'xl', bg: 'primary.light' },
                        React.createElement(Image, { src: buttonStates })),
                    React.createElement(StoryHeading, { storyName: 'Disabled', storyTitle: meta.title }),
                    React.createElement(Text, { textStyle: 'paragraph' }, "Disabled or inactive buttons are often \u201Cgreyed out\u201D, and used to communicate to the user that some kind of task needs to be completed by them before they can proceed. Components can inherit a disabled state, such as form fields, list items, cards, chips, and buttons."),
                    React.createElement(Note, null, "Not all users know that an interactive design element can have disabled state. If you show an element but don't allow people to interact with it, they then have to interpret why they can't. Not everyone will be able to do this, for this reason and other issues try to avoid disabling buttons or actions.")),
                React.createElement(Section, { heading: 'Theming' },
                    React.createElement(StoryHeading, { storyName: 'Semantic Styles', storyTitle: meta.title }),
                    React.createElement(Text, { textStyle: 'paragraph' }, "Semantic styles combine variation props and colors from our semantic palette, which defines colors based on how they are used. Each and every semantic color points to a color from the palette.")),
                React.createElement(Section, { heading: 'Usage' },
                    React.createElement(Text, { textStyle: 'subheading3', my: 4 }, "Responsive Layout"),
                    React.createElement(Text.p, { textStyle: 'paragraph' }, "When scaling layouts for large screen devices, buttons can adapt their visual presentation, alignment, and arrangement to fit different contexts and user needs."),
                    React.createElement(Text.p, { textStyle: 'paragraph' }, "The size and placement of buttons can change as parent containers, such as cards, adapt for larger screens."),
                    React.createElement(Box, { p: 3, my: 3, borderRadius: 'xl', bg: 'primary.light' },
                        React.createElement(Image, { src: responsiveLayoutImage })),
                    React.createElement(Text, { textStyle: 'subheading3', my: 4 }, "Alignment"),
                    React.createElement(Text.p, { textStyle: 'paragraph' }, "Alignment indicates whether the button aligns left, right or full width in a window, page, container, or component. What makes buttons different than most components is that their alignment can be independent, aligned with content, fit and fill containers."),
                    React.createElement(Text.p, { textStyle: 'paragraph' }, "As a general rule actions follow a similar rule as text, aligning to the left side on pages and components. When users are progressing through a series of steps or action required modals, the primary action traditionally sits at the bottom right. Buttons within components such as notifications, search fields, and data tables are also right-aligned. However there are times when the button In some cases a button group may span the entire width of a window or container."),
                    React.createElement(Text.p, { textStyle: 'paragraph' }, "Typical nested button locations include:"),
                    React.createElement(Box, { p: 3, my: 3, borderRadius: 'xl', bg: 'primary.light' },
                        React.createElement(Image, { src: alignmentImage })),
                    React.createElement(Text, { textStyle: 'subheading3', my: 4 }, "Button Groups"),
                    React.createElement(Text.p, { textStyle: 'paragraph' }, "Button Groups Button groups are a design pattern used when presenting users with multiple call to actions with hierarchical emphasis or of equal value. Understanding the correct combinations of hierarchy and size when displaying groups of buttons helps to prevent the user from feeling overwhelm and confuse."),
                    React.createElement(Text.p, { textStyle: 'paragraph' }, "As a general rule button groups should be limited to only medium, small, and text buttons."),
                    React.createElement(Box, { p: 3, my: 3, borderRadius: 'xl', bg: 'primary.light' },
                        React.createElement(Image, { src: groupsImage }))),
                React.createElement(Section, { heading: `Do's and Don'ts` },
                    React.createElement(DoDont, { doExample: React.createElement(Button, null, "Search Hotels"), doText: 'use 1 or 2 words, no longer than 4 words, with fewer than 20 characters including spaces.', dontExample: React.createElement(Button, null, "Start Saving!"), dontText: 'use punctuation marks such as periods or exclamation points.' }),
                    React.createElement(DoDont, { doExample: React.createElement(Button, null, "Go"), doText: 'allow a buttons width to use default settings to dynamically set to fit its label text.', dontExample: React.createElement(Button, { width: 100, style: { whiteSpace: 'nowrap' } }, "Search Hotels"), dontText: 'make the width of the button narrower than its label text.' }),
                    React.createElement(DoDont, { doExample: React.createElement(Button, { width: '100%' }, "Search Rental Cars"), doText: 'allow a buttons to fill the width of a responsive layout, container, and component.', dontExample: React.createElement(Button, { width: 150 }, "Search Rental Cars"), dontText: 'make the width of the button narrower than its label text.' }),
                    React.createElement(Text, { py: 3, textStyle: 'subheading3' }, "Do's and Don't For Button Groups"),
                    React.createElement(DoDont, { doExample: React.createElement(Box, { style: { display: 'grid', gridTemplateColumns: '1fr 1fr', gap: '.5rem' } },
                            React.createElement(Button, { variation: 'subtle' }, "Visit Help Center"),
                            React.createElement(Button, null, "Sign In")), doText: 'use min widths when available to allow the primary action to display at the same width as the secondary action.', dontExample: React.createElement(Box, null,
                            React.createElement(Button, { variation: 'subtle', mr: 2 }, "Visit Help Center"),
                            React.createElement(Button, null, "Sign In")), dontText: 'your secondary action should be short and not much longer than the primary action. This is especially important when space does not allow for each action to display at the same width.' }),
                    React.createElement(DoDont, { doExample: React.createElement(Flex, { width: '100%', flexDirection: 'column', style: { gap: '.5rem' } },
                            React.createElement(Button, { variation: 'subtle' }, "Add Rental Car"),
                            React.createElement(Button, null, "Continue to Checkout")), dontExample: React.createElement(Box, { textAlign: 'center' },
                            React.createElement(Button, null, "Add Rental Car"),
                            React.createElement("br", null),
                            React.createElement(Button, { variation: 'link' }, "No thanks, I don't need a rental car")) }),
                    React.createElement(DoDont, { doExample: React.createElement(Flex, { style: { gap: 8 } },
                            React.createElement(Button, { variation: 'lightFill' }, "Cancel"),
                            React.createElement(Button, { variation: 'lightFill', color: 'warning' }, "Delete")), dontExample: React.createElement(Flex, { style: { gap: 8 } },
                            React.createElement(Button, { width: 200, borderRadius: 'lg', variation: 'lightFill' }, "Add Flight"),
                            React.createElement(Button, { width: 200, borderRadius: 'lg' }, "Search Hotels")) }),
                    React.createElement(DoDont, { doExample: React.createElement(Flex, { style: { gap: 8 } },
                            React.createElement(Button, { variation: 'lightFill' }, "Yes"),
                            React.createElement(Button, { variation: 'lightFill', color: 'warning' }, "No")), dontExample: React.createElement(Flex, { style: { gap: 8 } },
                            React.createElement(Button, { color: 'secondary' }, "Yes"),
                            React.createElement(Button, { variation: 'lightFill', color: 'warning' }, "No")) })),
                React.createElement(Section, { heading: 'Related Components' },
                    React.createElement(RelatedComponentContainer, null,
                        React.createElement(RelatedComponent, { name: 'ButtonChip', onClick: linkTo('core-chip-ButtonChip') },
                            React.createElement(ButtonChip, null, "Button Chip")),
                        React.createElement(RelatedComponent, { name: 'Link', onClick: linkTo('Link') },
                            React.createElement(Link, null, "Link")),
                        React.createElement(RelatedComponent, { name: 'CloseButton', onClick: linkTo('CloseButton') },
                            React.createElement(CloseButton, null)))))),
        },
    },
};
export default meta;
//# sourceMappingURL=Button.stories.js.map