import { ArgsTable, Canvas, PRIMARY_STORY, Primary } from '@storybook/addon-docs';
import React from 'react';
import styled from 'styled-components';
import { Button } from '../Button/Button';
import { Hero } from '../DocsUtils/Hero/Hero';
import { Note } from '../DocsUtils/Note/Note';
import { Section } from '../DocsUtils/Section/Section';
import { StoryHeading } from '../DocsUtils/StoryHeading/StoryHeading';
import { TableOfContents } from '../DocsUtils/TableOfContents/TableOfContents';
import { Flex } from '../Flex/Flex';
import { Image } from '../Image/Image';
import { Text } from '../Text/Text';
import { ThemeProvider } from '../ThemeProvider/ThemeProvider';
import { Card } from './Card';
import heroImage from './Card.Image.Hero.png';
import cardWithLinks from './Card.Image.Links.png';
import cardStates from './Card.Image.States.png';
import * as CardStories from './Card.stories';
import { argTypes } from './Card.stories.args';
export const Playground = {
    render: (args) => (React.createElement(Card, { ...args, m: 4, p: 4, width: 1 / 2 }, "Card")),
    argTypes,
};
export const ShowcaseCard = () => (React.createElement(React.Fragment, null,
    React.createElement(Flex, { height: '120px' },
        React.createElement(Card, { as: 'button', width: '100%', bg: 'white', borderWidth: 0, boxShadowSize: 'sm', borderRadius: 'xl', display: 'inline-flex', p: 3, m: 2 }, "sm"),
        React.createElement(Card, { as: 'button', width: '100%', bg: 'white', borderWidth: 0, boxShadowSize: 'sm', borderRadius: 'xl', display: 'inline-flex', p: 3, m: 2 }, "sm"),
        React.createElement(Card, { as: 'button', width: '100%', bg: 'white', borderWidth: 0, boxShadowSize: 'sm', borderRadius: 'xl', display: 'inline-flex', p: 3, m: 2 }, "sm")),
    React.createElement(Flex, { height: '200px' },
        React.createElement(Card, { as: 'button', width: '100%', bg: 'white', borderWidth: 0, boxShadowSize: 'md', borderRadius: 'xl', display: 'inline-flex', p: 3, m: 2 }, "md"),
        React.createElement(Card, { as: 'button', width: '100%', bg: 'white', borderWidth: 0, boxShadowSize: 'md', borderRadius: 'xl', display: 'inline-flex', p: 3, m: 2 }, "md")),
    React.createElement(Flex, { height: '200px' },
        React.createElement(Card, { as: 'button', width: '100%', bg: 'background.base', borderWidth: 0, borderRadius: 'xl', display: 'inline-flex', p: 3, m: 2 }, "flat"),
        React.createElement(Card, { as: 'button', width: '100%', bg: 'background.base', borderWidth: 0, borderRadius: 'xl', display: 'inline-flex', p: 3, m: 2 }, "flat"),
        React.createElement(Card, { as: 'button', width: '100%', bg: 'background.base', borderWidth: 0, borderRadius: 'xl', display: 'inline-flex', p: 3, m: 2 }, "flat"))));
const StyledCard = styled(Card) `
  font-family: inherit;
  &:hover {
    cursor: pointer;
    box-shadow: ${({ theme }) => theme.shadows.xl};
  }
`;
export const CardHousingButton = () => (React.createElement(Flex, null,
    React.createElement(StyledCard, { boxShadowSize: 'sm', m: 2, p: 3, height: '160px', width: '240px', bg: 'white', borderRadius: 'xl', borderWidth: 0 },
        React.createElement(Text, { textStyle: 'paragraph', mb: '68px' }, "text"),
        React.createElement(Button, { width: '100%' }, "My action is the same")),
    React.createElement(StyledCard, { boxShadowSize: 'sm', m: 2, p: 3, height: '160px', width: '240px', bg: 'white', borderRadius: 'xl', borderWidth: 0 },
        React.createElement(Text, { textStyle: 'paragraph', mb: '20px' }, "text"),
        React.createElement(Button, { width: '100%', mb: 2, variation: 'lightFill' }, "My action is different"),
        React.createElement(Button, { width: '100%' }, "My action is the same")),
    React.createElement(Card, { boxShadowSize: 'sm', m: 2, p: 3, height: '160px', width: '240px', bg: 'white', borderRadius: 'xl', borderWidth: 0 },
        React.createElement(Text, { textStyle: 'paragraph', mb: '20px' }, "text"),
        React.createElement(Button, { width: '100%', mb: 2, variation: 'lightFill' }, "My action is different"),
        React.createElement(Button, { width: '100%' }, "My action is the same"))));
const meta = {
    title: 'Card',
    component: Card,
    parameters: {
        docs: {
            page: () => (React.createElement(ThemeProvider, null,
                React.createElement(Hero, { name: 'Card', img: heroImage }, "Cards allow developers to house related elements. Cards are actionable Box components that come in elevated, filled, or outlined. Contents inside card can include inputs, buttons, toggles, or general actionable text."),
                React.createElement(TableOfContents, { links: [
                        'Overview',
                        'Props',
                        'Support for focus and hover states',
                        'States',
                        'Accessibility Guidelines',
                    ] }),
                React.createElement(Section, { heading: 'Overview' },
                    React.createElement(Text, { textStyle: 'paragraph' }, "Each Card should contain content of the same subject. For example, one card should house one hotel or one ad. Use Cards to bring user's attention to clickable elements such as the Card itself.")),
                React.createElement(Section, { heading: 'Props' },
                    React.createElement(Primary, null),
                    React.createElement(ArgsTable, { story: PRIMARY_STORY })),
                React.createElement(Section, { heading: 'Variatons' },
                    React.createElement(StoryHeading, { storyName: 'Support for focus and hover states', storyTitle: meta.title }),
                    React.createElement(Text, { textStyle: 'paragraph' }, "The easiest way to make a card focusable and have a hover state is by passing the prop as = button. This renders the Card on the DOM as html native element button. Try this in the playground above or look at the examples below. In the example below you can easily tab between each Card!"),
                    React.createElement(Canvas, { of: CardStories.ShowcaseCard }),
                    React.createElement(StoryHeading, { storyName: 'States', storyTitle: meta.title }),
                    React.createElement(Flex, { my: 4, borderRadius: 'xl', bg: 'primary.light' },
                        React.createElement(Image, { src: cardStates }))),
                React.createElement(Section, { heading: 'Accessibility Guidelines' },
                    React.createElement(StoryHeading, { storyName: 'Support for using Button or Link inside a Card', storyTitle: meta.title }),
                    React.createElement(Text, { mb: 4, textStyle: 'paragraph' }, "When a Card has an anchor tag or link, the card does not have a focus state only the children."),
                    React.createElement(Flex, { my: 4, borderRadius: 'xl', bg: 'primary.light' },
                        React.createElement(Image, { src: cardWithLinks })),
                    React.createElement(Note, null, "Adding a nested action with the same behavior of the parent card is fully accessible. However, adding an action with a different action will be accessible if implemented correctly, it is recommended you avoid doing so. This could add strain on users as they may not be sure of the expected outcome when clicking anywhere else on the parent card."),
                    React.createElement(Canvas, { of: CardStories.CardHousingButton })))),
        },
    },
};
export default meta;
//# sourceMappingURL=Card.stories.js.map