import { userEvent, within } from '@storybook/testing-library';
import { Discount } from 'pcln-icons';
import React, { useState } from 'react';
import { Box } from '../Box/Box';
import { Breadcrumbs } from '../Breadcrumbs/Breadcrumbs';
import { Button } from '../Button/Button';
import { Grid } from '../Grid/Grid';
import { Text } from '../Text/Text';
import { Dialog } from './Dialog';
import { argTypes, defaultArgs } from './Dialog.stories.args';
import { Flex } from '../Flex/Flex';
import { Tooltip } from '../Tooltip/Tooltip';
const exampleHeaderProps = {
    headerContent: 'Hello World',
    headerIcon: React.createElement(Discount, null),
    headerShowCloseButton: true,
};
const exampleFooterProps = {
    footerContent: React.createElement(Button, { borderRadius: 'lg' }, "Done"),
};
export const Playground = {
    render: (args) => (React.createElement(Box, { height: '1000px' },
        React.createElement(Dialog, { ...args, headerIcon: args.headerIcon && exampleHeaderProps.headerIcon }))),
    play: async ({ args, canvasElement }) => {
        const canvas = within(canvasElement);
        const openButton = canvas.getByText('Open Dialog');
        await userEvent.click(openButton);
    },
};
export const WithHug = {
    ...Playground,
    args: {
        hugColor: 'primary.base',
    },
};
export const WithHeaderText = {
    ...Playground,
    args: {
        showCloseButton: false,
        ...exampleHeaderProps,
    },
};
export const WithHeaderContent = {
    ...Playground,
    args: {
        showCloseButton: false,
        headerContent: (React.createElement(Text, { textStyle: 'paragraph' },
            React.createElement(Breadcrumbs, null,
                React.createElement(Breadcrumbs.Link, { href: 'javascript:void(0)', label: 'Home' }),
                React.createElement(Breadcrumbs.Link, { href: 'javascript:void(0)', label: 'Flights' }),
                React.createElement(Breadcrumbs.Link, { href: 'javascript:void(0)', label: 'Settings' })))),
        headerColorScheme: 'neutralDarkOnLightest',
        headerShowCloseButton: true,
    },
};
export const WithHeaderContentProps = {
    ...Playground,
    args: {
        headerContent: (React.createElement(Flex, { justifyContent: 'space-between' },
            React.createElement(Box, { width: 40 }),
            React.createElement(Text, { textStyle: 'paragraph' },
                React.createElement(Breadcrumbs, null,
                    React.createElement(Breadcrumbs.Link, { href: 'javascript:void(0)', label: 'Home' }),
                    React.createElement(Breadcrumbs.Link, { href: 'javascript:void(0)', label: 'Flights' }),
                    React.createElement(Breadcrumbs.Link, { href: 'javascript:void(0)', label: 'Settings' }))),
            React.createElement(Box, { width: 40 }))),
        headerContentProps: { px: 2, py: 2, templateColumns: '1fr' },
        headerColorScheme: 'neutralDarkOnLightest',
    },
};
export const WithTooltip = {
    ...Playground,
    args: {
        children: (React.createElement(Box, { width: 400, p: 2, my: 2, height: 200 },
            React.createElement(Tooltip, { bottom: true, center: true, color: 'primary' }, "top center tooltip")))
    }
};
const ExampleImage = () => (React.createElement("img", { src: 'https://s1.pclncdn.com/design-assets/hero/beach.jpg?opto&optimize=medium&auto=jpg&width=600&height=450&fit=crop', alt: 'an example', style: { width: '100%', display: 'block' } }));
export const FullWidthImage = {
    ...Playground,
    args: {
        children: (React.createElement(React.Fragment, null,
            React.createElement(ExampleImage, null),
            React.createElement(Grid, { p: 24, gap: 3 },
                React.createElement(Text, { textStyle: 'heading1' }, "Dialog Heading"),
                React.createElement(Text, { textStyle: 'paragraph' }, "Lorem ipsum dolor sit, amet consectetur adipisicing elit. Totam possimus quia voluptatem minima voluptatum dolor rem cumque odio ab accusantium deleniti vero voluptas odit numquam fugit non eveniet, sunt natus!")))),
    },
};
const ExampleOverflowingContent = (props) => (React.createElement(Grid, { p: 24, gap: 5, ...props }, [...Array(5).keys()].map((i) => (React.createElement(React.Fragment, null,
    React.createElement(Text, { textStyle: 'heading4' },
        i + 1,
        ". Lorem ipsum, dolor sit amet consectetur adipisicing elit. Ex quas voluptas, vel id doloribus delectus deleniti minus eius ullam vero dolorum laboriosam dolor cupiditate sequi quia itaque corrupti quaerat hic!"),
    React.createElement(ExampleImage, null))))));
const ExampleOverflowingAbsolute = (props) => {
    const [showText, setShowText] = React.useState(false);
    return (React.createElement(Box, null,
        React.createElement(Grid, { p: 24, gap: 5, ...props },
            React.createElement(Button, { onClick: () => setShowText(!showText) }, "Show text overflow")),
        showText && (React.createElement(Text, { style: { overflow: 'visible', position: 'absolute' } }, "Lorem ipsum, dolor sit amet consectetur adipisicing elit. Ex quas voluptas, vel id doloribus delectus deleniti minus eius ullam vero dolorum laboriosam dolor cupiditate sequi quia itaque corrupti quaerat hic! Lorem ipsum, dolor sit amet consectetur adipisicing elit. Ex quas voluptas, vel id doloribus delectus deleniti minus eius ullam vero dolorum laboriosam dolor cupiditate sequi quia itaque corrupti quaerat hic!"))));
};
export const OverflowModal = {
    ...Playground,
    args: {
        children: React.createElement(ExampleOverflowingContent, { overflow: 'auto' }),
    },
};
export const OverflowOutsideContainer = {
    ...Playground,
    args: {
        children: React.createElement(ExampleOverflowingAbsolute, { overflow: 'visible' }),
        overflowX: 'visible',
        overflowY: 'visible',
    },
};
export const OverflowContent = {
    ...Playground,
    args: {
        children: React.createElement(ExampleOverflowingContent, { overflow: 'auto', maxHeight: 'calc(100vh - 2 * 96px)' }),
        showScrollShadow: true,
    },
};
export const StickyHeader = {
    ...Playground,
    args: {
        children: React.createElement(ExampleOverflowingContent, { overflow: 'auto', maxHeight: 500 }),
        ...exampleHeaderProps,
        headerShowCloseButton: false,
        showScrollShadow: true,
    },
};
export const StickyFooter = {
    ...Playground,
    args: {
        children: React.createElement(ExampleOverflowingContent, { overflow: 'auto', maxHeight: 500 }),
        ...exampleHeaderProps,
        ...exampleFooterProps,
        headerShowCloseButton: false,
        showScrollShadow: true,
    },
};
export const ScrimColors = {
    render: (args) => {
        const [scrimColor, setScrimColor] = useState('dark');
        return (React.createElement(Dialog, { ...args, headerIcon: args.headerIcon && exampleHeaderProps.headerIcon, scrimColor: scrimColor },
            React.createElement(Grid, { p: 4, gap: 4 },
                React.createElement(Text, { textStyle: 'heading3', textAlign: 'center' }, "Set Scrim Color:"),
                React.createElement(Grid, { gap: 4, templateColumns: '1fr 1fr' },
                    React.createElement(Button, { onClick: () => setScrimColor('dark') }, "Dark"),
                    React.createElement(Button, { onClick: () => setScrimColor('medium') }, "Medium"),
                    React.createElement(Button, { onClick: () => setScrimColor('light') }, "Light"),
                    React.createElement(Button, { onClick: () => setScrimColor('rgba(0, 0, 0, 0.5)') }, "rgba(0, 0, 0, 0.5)")))));
    },
};
// export const WithShadowOnScroll: DialogStory = {
//   ...Playground,
//   args: {
//     children: (
//       <ExampleOverflowingContent
//         overflow='auto'
//         maxHeight={500}
//         background={`
//           linear-gradient(#ffffff 33%, rgba(255,255,255, 0)),
//           linear-gradient(rgba(255,255,255, 0), #ffffff 66%) 0 100%,
//           radial-gradient(farthest-side at 50% 0, rgba(40,40,40, 0.5), rgba(0,0,0,0)),
//           radial-gradient(farthest-side at 50% 100%, rgba(40,40,40, 0.5), rgba(0,0,0,0)) 0 100%,
//           linear-gradient(rgba(0,0,0,.15), rgba(0,0,0,.15))
//         `}
//         backgroundRepeat='no-repeat'
//         backgroundSize='100% 40px, 100% 40px, 100% 16px, 100% 16px, 100% 1px'
//         style={{ backgroundAttachment: 'local, local, scroll, scroll, scroll' }}
//       />
//     ),
//     ...exampleHeaderProps,
//     headerShowCloseButton: false,
//   },
// }
export const SheetMode = {
    ...Playground,
    args: {
        sheet: true,
        size: 'full',
    },
};
export const SheetWithHeaderAndFooter = {
    ...Playground,
    args: {
        children: React.createElement(ExampleOverflowingContent, null),
        ...SheetMode.args,
        ...exampleHeaderProps,
        ...exampleFooterProps,
        showScrollShadow: true,
    },
};
export const Controlled = {
    render: (args) => {
        const [open, setOpen] = useState(false);
        return (React.createElement(Dialog, { ...args, triggerNode: React.createElement(Button, { onClick: () => setOpen(true) },
                "Click to open. Modal is ",
                open ? 'open' : 'closed'), open: open, onOpenChange: setOpen, ...exampleHeaderProps },
            React.createElement(Grid, { p: 3, gap: 3 },
                React.createElement(Box, null, "Dialog Content"),
                React.createElement(Grid, { placeItems: 'end', autoFlow: 'column' },
                    React.createElement(Button, { onClick: () => setOpen(false) }, "Close")))));
    },
};
const meta = {
    title: 'Overlays/Dialog',
    component: Dialog,
    args: defaultArgs,
    argTypes: argTypes,
};
export default meta;
//# sourceMappingURL=Dialog.stories.js.map