import { Email as EmailIcon } from 'pcln-icons';
import React from 'react';
import { Input } from '../Input/Input';
import { Label } from '../Label/Label';
import { Select } from '../Select/Select';
import { render } from '../__test__/testing-library';
import { FormField } from './FormField';
afterEach(() => {
    // bust cache for propTypes
    FormField.displayName = 'FormField' + Math.random();
});
describe('FormField', () => {
    test('renders', () => {
        const json = rendererCreateWithTheme(React.createElement(FormField, null,
            React.createElement(Label, null, "Email Address"),
            React.createElement(Input, { id: 'email', name: 'email' }))).toJSON();
        expect(json).toMatchSnapshot();
    });
    test('renders with Icon', () => {
        const json = rendererCreateWithTheme(React.createElement(FormField, null,
            React.createElement(Label, null, "Email Address"),
            React.createElement(EmailIcon, null),
            React.createElement(Input, { id: 'email', name: 'email' }))).toJSON();
        expect(json).toMatchSnapshot();
    });
    test('renders with Select ', () => {
        const json = rendererCreateWithTheme(React.createElement(FormField, null,
            React.createElement(Label, null, "Pick Option"),
            React.createElement(Select, null))).toJSON();
        expect(json).toMatchSnapshot();
    });
    test('renders with Select and Icon', () => {
        const json = rendererCreateWithTheme(React.createElement(FormField, null,
            React.createElement(Label, null, "Pick Email Address"),
            React.createElement(EmailIcon, null),
            React.createElement(Select, null))).toJSON();
        expect(json).toMatchSnapshot();
    });
    test('renders with Label autoHide prop', () => {
        const json = rendererCreateWithTheme(React.createElement(FormField, null,
            React.createElement(Label, { autoHide: true }, "Email"),
            React.createElement(EmailIcon, null),
            React.createElement(Input, { id: 'email', name: 'email' }))).toJSON();
        expect(json).toMatchSnapshot();
    });
    test('shows Label with autoHide prop and field value', () => {
        const json = rendererCreateWithTheme(React.createElement(FormField, null,
            React.createElement(Label, { autoHide: true }, "Email"),
            React.createElement(EmailIcon, null),
            React.createElement(Input, { id: 'email', name: 'email', value: 'hello@example.com' }))).toJSON();
        const [label] = json.children;
        expect(label.props.style.opacity).toBe(1);
    });
    test('adds htmlFor prop to Label', () => {
        const json = rendererCreateWithTheme(React.createElement(FormField, null,
            React.createElement(Label, null),
            React.createElement(Input, { id: 'hello', name: 'hello' }))).toJSON();
        const [label] = json.children;
        expect(label.props.htmlFor).toBe('hello');
    });
    describe('disabled state', () => {
        it('renders input with icon - disabled', () => {
            const { asFragment } = render(React.createElement(FormField, { disabled: true },
                React.createElement(Label, null, "Email Address"),
                React.createElement(EmailIcon, { "data-testid": 'email-icon' }),
                React.createElement(Input, { id: 'email', name: 'email', placeholder: 'Email' })));
            expect(asFragment()).toMatchSnapshot();
        });
        it('renders select with icon - disabled', () => {
            const { asFragment } = render(React.createElement(FormField, { disabled: true },
                React.createElement(Label, null, "Pick Email Address"),
                React.createElement(EmailIcon, null),
                React.createElement(Select, { defaultValue: 'Premium Economy' },
                    React.createElement("option", null, "Premium Economy"))));
            expect(asFragment()).toMatchSnapshot();
        });
    });
});
//# sourceMappingURL=FormField.spec.js.map