import React, { useState } from 'react';
import { Box } from '../Box/Box';
import { Flex } from '../Flex/Flex';
import { Input } from '../Input/Input';
import { Label } from '../Label/Label';
import { Select } from '../Select/Select';
import { Tooltip } from '../Tooltip/Tooltip';
import { FormField } from './FormField';
import { Check as CheckIcon, Email as EmailIcon, Pin as PinIcon, Success as SuccessIcon, Warning as WarningIcon, } from 'pcln-icons';
export default {
    title: 'FormField',
    component: FormField,
    args: {
        disabled: false,
        readOnly: false,
    },
};
const Template = (args) => (React.createElement(FormField, { ...args },
    React.createElement(Label, { htmlFor: 'demo' }, "Email Address"),
    React.createElement(EmailIcon, { color: 'primary' }),
    React.createElement(Input, { type: 'email', id: 'email', name: 'email', defaultValue: 'hello@example.com' })));
export const _FormField = Template.bind({});
export const DisabledInputFormField = Template.bind({});
DisabledInputFormField.args = { disabled: true };
export const ReadOnlyInputFormField = Template.bind({});
ReadOnlyInputFormField.args = { readOnly: true };
export const DynamicLabel = () => (React.createElement(Flex, null,
    React.createElement(Box, { px: 2, width: 1 / 3 },
        React.createElement(FormField, null,
            React.createElement(Label, { autoHide: true, htmlFor: 'dynamic-label-without-a-value' }, "No value"),
            React.createElement(Input, { id: 'dynamic-label-without-a-value', name: 'dynamic-label-without-a-value', placeholder: 'Without a value' }))),
    React.createElement(Box, { px: 2, width: 1 / 3 },
        React.createElement(FormField, null,
            React.createElement(Label, { autoHide: true, htmlFor: 'dynamic-label-with-a-value' }, "With value"),
            React.createElement(Input, { id: 'dynamic-label-with-a-value', name: 'dynamic-label-with-a-value', value: 'hello@example.com' }))),
    React.createElement(Box, { px: 2, width: 1 / 3 },
        React.createElement(FormField, null,
            React.createElement(Input, { id: 'dynamic-label-without-a-label', name: 'dynamic-label-without-a-label', value: 'Value without label' })))));
export const DynamicLabelWithValue = () => (React.createElement(FormField, null,
    React.createElement(Label, { htmlFor: 'dynamic-label-email' }, "Email Address"),
    React.createElement(Input, { id: 'dynamic-label-email', name: 'dynamic-label-email', placeholder: 'hello@example.com', value: 'hello@example.com' })));
export const IconToTheRight = () => (React.createElement(FormField, null,
    React.createElement(Label, { htmlFor: 'dynamic-label-email-icon-right' }, "Email Address"),
    React.createElement(Input, { id: 'dynamic-label-email-icon-right', name: 'dynamic-label-email-icon-right', placeholder: 'hello@example.com', value: 'hello@example.com' }),
    React.createElement(CheckIcon, { color: 'secondary' })));
export const WithSelect = () => (React.createElement(FormField, null,
    React.createElement(Label, { htmlFor: 'dynamic-label-state-select' }, "State"),
    React.createElement(PinIcon, { color: 'primary' }),
    React.createElement(Select, { id: 'dynamic-label-state-select', name: 'dynamic-label-state-select' },
        React.createElement("option", null, "New York"),
        React.createElement("option", null, "New Jersey"))));
export const WithDisabledSelect = () => (React.createElement(FormField, { disabled: true },
    React.createElement(Label, { htmlFor: 'dynamic-label-state-select' }, "State"),
    React.createElement(PinIcon, { color: 'primary' }),
    React.createElement(Select, { id: 'dynamic-label-state-select', name: 'dynamic-label-state-select' },
        React.createElement("option", null, "New York"),
        React.createElement("option", null, "New Jersey"))));
export const WithReadOnlySelect = () => (React.createElement(FormField, { readOnly: true },
    React.createElement(Label, { htmlFor: 'dynamic-label-state-select' }, "State"),
    React.createElement(PinIcon, { color: 'primary' }),
    React.createElement(Select, { id: 'dynamic-label-state-select', name: 'dynamic-label-state-select', defaultValue: 'New York' },
        React.createElement("option", null, "New York"),
        React.createElement("option", null, "New Jersey"))));
export const WithSuccessfulValidation = () => (React.createElement(FormField, null,
    React.createElement(Label, { htmlFor: 'valid' }, "Email Address"),
    React.createElement(Input, { id: 'valid', name: 'valid', placeholder: 'hello@example.com', color: 'success' }),
    React.createElement(SuccessIcon, { color: 'success' })));
export const WithErrorTooltip = () => (React.createElement(Box, null,
    React.createElement(FormField, null,
        React.createElement(Label, { htmlFor: 'error-tooltip' }, "Email Address"),
        React.createElement(Input, { id: 'error-tooltip', name: 'error-tooltip', placeholder: 'hello@example.com', "aria-describedby": 'demo-error', color: 'error' }),
        React.createElement(WarningIcon, { color: 'error' })),
    React.createElement(Tooltip, { id: 'demo-error', right: true, color: 'error' }, "Email address is required")));
const validateEmailFormat = (email) => {
    // eslint-disable-next-line @rushstack/security/no-unsafe-regexp
    const reg = new RegExp([
        '^(([^<>()[\\]\\\\.,;:\\s@"]+(\\.[^<>()[\\]\\\\.,;:\\s@"]+)*)',
        '|(".+"))@((\\[[0-9]{1,3}\\.[0-9]{1,3}\\.[0-9]{1,3}\\.[0-9]{1,3}\\])|(([a-zA-Z\\-0-9]+\\.)',
        '+[a-zA-Z]{2,}))$',
    ].join(''));
    return reg.test(email);
};
export const Usage = () => {
    const [email, setEmail] = useState('');
    const [isValidEmail, setIsValidEmail] = useState(false);
    const [isFocused, SetIsFocused] = useState(true);
    // update email address
    const updateInput = (e) => {
        const value = e.target.value;
        setEmail(value);
    };
    // handle when focus leave the field
    const handleBlur = (e) => {
        const value = e.target.value;
        setIsValidEmail(validateEmailFormat(value));
        SetIsFocused(false);
    };
    // handle when field is on focus
    const handleFocus = (e) => {
        SetIsFocused(true);
    };
    return (React.createElement(Box, null,
        React.createElement(FormField, null,
            React.createElement(Label, { autoHide: true, htmlFor: 'dynamic-label-usage' }, "Email Address"),
            React.createElement(Input, { id: 'dynamic-label-usage', name: 'dynamic-label-usage', onChange: updateInput, onBlur: handleBlur, value: email, onFocus: handleFocus, color: isFocused ? '' : isValidEmail ? 'success' : 'error', placeholder: 'Email Address' }),
            isFocused ? null : isValidEmail ? React.createElement(SuccessIcon, { color: 'success' }) : React.createElement(WarningIcon, { color: 'error' })),
        !isFocused && !isValidEmail ? (React.createElement(Tooltip, { id: 'demo-error', right: true, color: 'error' }, "Email address is required")) : null));
};
//# sourceMappingURL=FormField.stories.js.map