import { Star } from 'pcln-icons';
import React from 'react';
import { Card } from '../Card/Card';
import { Hide } from '../Hide/Hide';
import { Text } from '../Text/Text';
import { Hug } from './Hug';
import { colorSchemeNames } from '../storybook/args';
import { HugContentText, argTypes, defaultArgs, iconMap } from './Hug.stories.args';
const ChildrenCardInside = () => (React.createElement(Card, { p: 3, color: 'warning.light' }, "I'm a card within a hug!"));
const ChildrenCardInsideCard = () => (React.createElement(Card, { p: 3, color: 'background.light' },
    React.createElement(Card, { p: 3, color: 'background.dark' }, "I'm a card within a card within a hug!")));
const ResponsiveText = () => (React.createElement(Text.span, null,
    "Today's best deal! You save ",
    React.createElement(Text.span, { fontWeight: 'bold' }, "$300"),
    React.createElement(Hide, { as: 'span', xs: true },
        ' ',
        "for your party of 2"),
    ".\u00A0"));
export default {
    title: 'core / Hug',
    component: Hug,
    args: defaultArgs,
    argTypes,
    parameters: {
        docs: {
            description: {
                component: `Use the Hug component to surround another component with a border and a banner on top.`,
            },
        },
    },
};
const Template = ({ icon, ...rest }) => {
    const SelectedIcon = (icon && iconMap[icon]) || null;
    if (icon && SelectedIcon) {
        rest.icon = React.createElement(SelectedIcon, null);
    }
    return React.createElement(Hug, { ...rest });
};
export const _Hug = Template.bind({});
_Hug.args = {
    children: React.createElement(ChildrenCardInside, null),
};
_Hug.storyName = 'With a card inside';
export const WithAnIcon = Template.bind({});
WithAnIcon.args = {
    children: React.createElement(ChildrenCardInside, null),
    icon: 'ThumbsUp',
};
WithAnIcon.storyName = 'With an icon';
export const CardInACard = Template.bind({});
CardInACard.args = {
    children: React.createElement(ChildrenCardInsideCard, null),
};
CardInACard.storyName = 'With a card in a card';
export const PlainText = Template.bind({});
PlainText.args = {
    text: 'I am some plain text!',
    children: React.createElement(ChildrenCardInside, null),
};
export const ArrayOfText = Template.bind({});
ArrayOfText.args = {
    text: [React.createElement(HugContentText, { key: 1 }), React.createElement(HugContentText, { key: 2 })],
    children: React.createElement(ChildrenCardInside, null),
};
ArrayOfText.storyName = 'With an array of text nodes';
export const Responsive = Template.bind({});
Responsive.args = {
    text: React.createElement(ResponsiveText, null),
    children: React.createElement(ChildrenCardInside, null),
    p: 2,
    fontSize: [0, 1],
};
Responsive.storyName = 'With a responsive Hug';
Responsive.parameters = {
    viewport: { defaultViewport: 'designSystem_xs' },
};
export const ColorScheme = () => {
    return colorSchemeNames.map((colorScheme) => (React.createElement(Hug, { text: React.createElement(Text, null, colorScheme), icon: React.createElement(Star, null), colorScheme: colorScheme, key: colorScheme, my: '3', boxShadowSize: 'xl' },
        React.createElement(Card, { borderRadius: 'xl', p: 3, color: 'background.lightest' },
            React.createElement(Text, null, "I'm a card within a card within a hug!")))));
};
export const ColorSchemeWithCustomHeaderTextAndIconColors = () => {
    return (React.createElement(Hug, { text: React.createElement(Text, { color: 'error.base' }, "Custom Header Color"), icon: React.createElement(Star, { color: 'promoPrimary.base' }), colorScheme: 'primaryLight', my: '3', boxShadowSize: 'xl' },
        React.createElement(Card, { borderRadius: 'xl', p: 3, color: 'background.lightest' },
            React.createElement(Text, null, "I'm a card within a card within a hug!"))));
};
//# sourceMappingURL=Hug.stories.js.map