import React from 'react';
import { Box } from '../Box/Box';
import { Button } from '../Button/Button';
import { Divider } from '../Divider/Divider';
import { Label } from '../Label/Label';
import ForwardRefDemo from '../storybook/utils/ForwardRefsDemo';
import { Input } from './Input';
import { argTypes } from './Input.stories.args';
export default {
    title: 'Input',
    component: Input,
    parameters: {
        docs: {
            description: {
                component: 'Simple styled input component that accepts a color and whether or not to show an error container.',
            },
        },
    },
    argTypes,
};
const Template = (args) => React.createElement(Input, { my: 3, ...args });
export const InputComponent = Template.bind({});
export const Disabled = () => React.createElement(Input, { disabled: true, value: 'Disabled Input' });
export const ReadOnly = () => React.createElement(Input, { readOnly: true, value: 'Readonly Input' });
export const Colors = () => (React.createElement(Box, { width: 400 },
    React.createElement(Input, { mb: 3, id: 'input-colors-1', placeholder: 'No color' }),
    React.createElement(Input, { mb: 3, id: 'input-colors-2', color: 'primary', placeholder: 'Primary' }),
    React.createElement(Input, { mb: 3, id: 'input-colors-3', color: 'secondary', placeholder: 'Secondary' }),
    React.createElement(Input, { mb: 3, id: 'input-colors-4', color: 'warning', placeholder: 'Warning' }),
    React.createElement(Input, { mb: 3, id: 'input-colors-5', color: 'alert', placeholder: 'Alert' }),
    React.createElement(Input, { mb: 3, id: 'input-colors-6', color: 'caution', placeholder: 'Caution' })));
export const WithExternalLabel = () => (React.createElement(Box, { width: 400 },
    React.createElement(Label, { fontSize: 4, htmlFor: 'sample-input' }, "Label!"),
    React.createElement(Input, { id: 'sample-input-1', placeholder: 'Click the label' })));
export const WithHelperText = () => (React.createElement(Box, { width: 400 },
    React.createElement(Box, null,
        React.createElement(Label, { fontSize: 4, htmlFor: 'sample-input-2' }, "Same color as Input"),
        React.createElement(Input, { id: 'sample-input-2', placeholder: 'Click the label', color: 'error.base', helperText: React.createElement(Input.HelperText, null, "No soup for you!") })),
    React.createElement(Divider, null),
    React.createElement(Box, null,
        React.createElement(Label, { fontSize: 4, htmlFor: 'sample-input-3' }, "Override color for helper text"),
        React.createElement(Input, { id: 'sample-input-3', placeholder: 'Click the label', color: 'error.base', helperText: React.createElement(Input.HelperText, { color: 'secondary.base' }, "No soup for you!") }))));
export const WithLabel = () => (React.createElement(Box, { width: 400 },
    React.createElement(Label, null,
        "Label Text",
        React.createElement(Input, { id: 'input-with-label', placeholder: 'Click the label', mt: 1 }))));
export function ForwardsRefs() {
    function refChild(dsRef) {
        function onClick() {
            return dsRef.current.focus();
        }
        return (React.createElement(React.Fragment, null,
            React.createElement(Input, { ref: dsRef, placeholder: 'Priceline!' }),
            React.createElement(Button, { onClick: onClick, mt: 3 }, "Click to focus the input via ref")));
    }
    return React.createElement(ForwardRefDemo, { refChild: refChild });
}
//# sourceMappingURL=Input.stories.js.map