import styled from 'styled-components';
import { compose, fontSize, fontWeight, letterSpacing, lineHeight, space, textStyle, width, } from 'styled-system';
import { typographyAttrs } from '../utils/attrs/typographyAttrs';
import { applyVariations, getPaletteColor } from '../utils/utils';
const nowrap = (props) => props.nowrap
    ? {
        whiteSpace: 'nowrap',
    }
    : null;
const accessiblyHide = (props) => props.hidden
    ? {
        position: 'absolute',
        width: '1px',
        height: '1px',
        clip: 'rect(1px, 1px, 1px, 1px)',
    }
    : null;
/**
 * @public
 */
export const Label = styled.label.attrs((props) => ({
    ...typographyAttrs(props),
    ...props,
})) `
  display: block;
  width: 100%;
  margin: 0;
  z-index: 1;
  color: ${getPaletteColor('base')};
  ${(props) => (props.bg ? `background-color: ${getPaletteColor(props.bg, 'base')(props)};` : '')}
  ${(props) => (props.onClick ? 'cursor: pointer;' : '')}

  ${applyVariations('Label')}

  ${nowrap}
  ${accessiblyHide}

  ${(props) => compose(fontSize, fontWeight, lineHeight, letterSpacing, space, textStyle, width)(props)}
`;
Label.defaultProps = {
    color: 'text.light',
    textStyle: 'label',
};
Label.displayName = 'Label';
Label.isLabel = true;
//# sourceMappingURL=Label.js.map