import React from 'react';
import { fireEvent, render, screen } from '../__test__/testing-library';
import { Label } from './Label';
describe('Label', () => {
    test('it renders', () => {
        const json = rendererCreateWithTheme(React.createElement(Label, null)).toJSON();
        expect(json).toMatchSnapshot();
    });
    test('Label hidden renders', () => {
        const json = rendererCreateWithTheme(React.createElement(Label, { hidden: true })).toJSON();
        expect(json).toMatchSnapshot();
    });
    test('Label nowrap renders', () => {
        const json = rendererCreateWithTheme(React.createElement(Label, { nowrap: true })).toJSON();
        expect(json).toMatchSnapshot();
    });
    test('Label width renders', () => {
        const json = rendererCreateWithTheme(React.createElement(Label, { width: 1 / 2, nowrap: true })).toJSON();
        expect(json).toMatchSnapshot();
    });
    test('Label clickable renders with cursor pointer', () => {
        const mockOnClick = jest.fn();
        render(React.createElement(Label, { onClick: mockOnClick }, "Clickable Label"));
        const label = screen.getByText('Clickable Label');
        expect(label).toHaveStyleRule('cursor', 'pointer');
        expect(mockOnClick).toHaveBeenCalledTimes(0);
        fireEvent.click(label);
        expect(mockOnClick).toHaveBeenCalledTimes(1);
    });
});
//# sourceMappingURL=Label.spec.js.map