import { Information as InformationIcon, Pin as PinIcon, Search as SearchIcon } from 'pcln-icons';
import React, { useEffect, useRef, useState } from 'react';
import styled from 'styled-components';
import { Box } from '../Box/Box';
import { Button } from '../Button/Button';
import { Flex } from '../Flex/Flex';
import { FormField } from '../FormField/FormField';
import { Input } from '../Input/Input';
import { Label } from '../Label/Label';
import { Popout } from '../Popout/Popout';
import { Text } from '../Text/Text';
import { getPaletteColor } from '../utils/utils';
export default {
    component: Popout,
};
const states = [
    'Alabama',
    'Alaska',
    'Arizona',
    'Arkansas',
    'California',
    'Colorado',
    'Connecticut',
    'Delaware',
    'Florida',
    'Georgia',
    'Hawaii',
    'Idaho',
    'Illinois',
    'Indiana',
    'Iowa',
    'Kansas',
    'Kentucky',
    'Louisiana',
    'Maine',
    'Maryland',
    'Massachusetts',
    'Michigan',
    'Minnesota',
    'Mississippi',
    'Missouri',
    'Montana',
    'Nebraska',
    'Nevada',
    'New Hampshire',
    'New Jersey',
    'New Mexico',
    'New York',
    'North Carolina',
    'North Dakota',
    'Ohio',
    'Oklahoma',
    'Oregon',
    'Pennsylvania',
    'Rhode Island',
    'South Carolina',
    'South Dakota',
    'Tennessee',
    'Texas',
    'Utah',
    'Vermont',
    'Virginia',
    'Washington',
    'West Virginia',
    'Wisconsin',
    'Wyoming',
];
const PclnSearchItem = styled(Flex) `
  cursor: pointer;
  white-space: nowrap;
  &:hover,
  &:focus {
    background-color: ${getPaletteColor('primary.base')};
    color: white;
  }
`;
const Wrapper = ({ children }) => React.createElement(Box, { m: 5 }, children);
export const Basic = () => {
    const triggerRef = useRef(null);
    const [value, setValue] = useState('');
    const trigger = (React.createElement("input", { "aria-label": 'x', ref: triggerRef, value: value, onChange: (e) => setValue(e.target.value) }));
    const content = value && React.createElement("h1", null, value);
    return (React.createElement(Wrapper, null,
        React.createElement(Popout, { trigger: trigger, triggerRef: triggerRef, content: content })));
};
export const IconPopout = () => {
    const triggerRef = useRef(null);
    const trigger = (React.createElement(Box, { width: 'fit-content', ref: triggerRef },
        React.createElement(InformationIcon, { color: 'primary', style: { cursor: 'pointer' } })));
    const content = React.createElement("h1", null, "This is some important information");
    return (React.createElement(Wrapper, null,
        React.createElement(Popout, { trigger: trigger, triggerRef: triggerRef, content: content, closeOnTriggerRefClick: true })));
};
export const FormFieldExample = () => {
    const triggerRef = useRef(null);
    const [search, setSearch] = useState('');
    const [results, setResults] = useState([]);
    useEffect(() => {
        setResults(search ? states.filter((x) => x.toLowerCase().startsWith(search.toLowerCase())) : []);
    }, [search]);
    const trigger = (React.createElement(FormField, null,
        React.createElement(Label, { autoHide: true, htmlFor: 'pclnInput' }, "Where To?"),
        React.createElement(SearchIcon, { color: 'primary', size: 24 }),
        React.createElement(Input, { id: 'pclnInput', name: 'pclnInput', value: search, placeholder: 'Where to?', onChange: (e) => setSearch(e.target.value), ref: triggerRef })));
    const content = results.length > 0 && (React.createElement(Flex, { flexDirection: 'column', mt: 2, style: { maxHeight: 300, overflow: 'auto', gap: 8 } }, results.map((x) => (React.createElement(PclnSearchItem, { tabIndex: 0, alignItems: 'center', borderRadius: 'xl', key: x, p: 2, onClick: () => setSearch(x) },
        React.createElement(PinIcon, { size: 24, mr: 2 }),
        React.createElement(Text, null, x))))));
    return (React.createElement(Wrapper, null,
        React.createElement(Popout, { trigger: trigger, triggerRef: triggerRef, content: content })));
};
export const TabFocusing = () => {
    const arr = Array(3).fill('');
    const [value, setValue] = useState('');
    const triggerRefs = arr.map((_) => useRef(null));
    const content = value && React.createElement("h1", null, value);
    const Popouts = arr.map((_, i) => (React.createElement(Popout, { key: i, trigger: React.createElement("input", { ref: triggerRefs[i], "aria-label": 'x', value: value, onChange: (e) => setValue(e.target.value) }), content: content, triggerRef: triggerRefs[i] })));
    return (React.createElement(Wrapper, null,
        React.createElement(Flex, { flexDirection: 'column', width: 'fit-content', style: { gap: 16 } },
            React.createElement(Button, null, "This is just to trap focus"),
            Popouts,
            React.createElement(Button, null, "This is just to trap focus"))));
};
//# sourceMappingURL=Popout.stories.js.map