import { action } from '@storybook/addon-actions';
import React from 'react';
import styled from 'styled-components';
import { Button } from '../Button/Button';
import { Label } from '../Label/Label';
import { Radio } from '../Radio/Radio';
import ForwardRefDemo from '../storybook/utils/ForwardRefsDemo';
import { paletteFamilyNames } from '../theme/theme';
import { getPaletteColor } from '../utils/utils';
const bold = (props) => (props.bold ? { fontWeight: props.theme.fontWeights.bold } : null);
const medium = (props) => (props.medium ? { fontWeight: props.theme.fontWeights.medium } : null);
const LabelText = styled.span `
  vertical-align: middle;
  margin-left: 8px;
  ${bold}
  ${medium}
`;
const RadioLabelDisabled = styled(Label) `
  cursor: not-allowed;
  color: ${getPaletteColor('border.base')};
`;
const RadioLabel = styled(Label) `
  cursor: pointer;
  color: ${getPaletteColor('text.light')};

  &:hover {
    div[data-name='unchecked'] {
      color: ${getPaletteColor('primary.base')};
    }
    div[data-name='checked'] {
      > svg {
        color: ${getPaletteColor('primary.dark')};
      }
    }
  }
`;
// @ts-ignore
class MockForm extends React.Component {
    setState;
    state;
    constructor(props) {
        super(props);
        this.state = {
            selection: 1,
            options: [0, 1, 2, 3],
            disabled: false,
        };
    }
    updateSelection = (event) => {
        this.setState({
            selection: Number(event.target.value),
        });
    };
    toggleDisabled = () => {
        this.setState((prevState) => ({
            disabled: !prevState.disabled,
        }));
    };
    render() {
        const { disabled, selection, options } = this.state;
        return (React.createElement("div", null,
            React.createElement("div", { onChange: this.updateSelection }, options.map((item, idx) => (React.createElement(Label, { fontSize: '14px', key: idx },
                React.createElement(Radio, { checked: item === selection, name: 'mySelection', value: item, disabled: disabled }),
                React.createElement(LabelText, null, item))))),
            React.createElement(Button, { mt: 3, onClick: this.toggleDisabled }, "Toggle disabled state")));
    }
}
export default {
    title: 'Radio',
    component: Radio,
};
export const _3States = () => (React.createElement("div", { onChange: action('changed') },
    React.createElement(RadioLabel, { fontSize: '14px' },
        React.createElement(Radio, { checked: true }),
        React.createElement(LabelText, null, "selected")),
    React.createElement(RadioLabel, { fontSize: '14px' },
        React.createElement(Radio, null),
        React.createElement(LabelText, null, "not selected")),
    React.createElement(RadioLabelDisabled, { fontSize: '14px' },
        React.createElement(Radio, { disabled: true }),
        React.createElement(LabelText, null, "disabled"))));
// @ts-ignore
export const _MockForm = () => React.createElement(MockForm, null);
export function ForwardRefs() {
    function refChild(dsRef) {
        function onClick() {
            return dsRef.current.focus();
        }
        return (React.createElement(React.Fragment, null,
            React.createElement(RadioLabel, { fontSize: '14px' },
                React.createElement(Radio, { checked: true }),
                React.createElement(LabelText, null, "selected")),
            React.createElement(Button, { onClick: onClick, mt: 4 }, "Click to focus radio via ref")));
    }
    return React.createElement(ForwardRefDemo, { refChild: refChild });
}
export const FontWeight = () => (React.createElement("div", { onChange: action('changed') },
    React.createElement(RadioLabel, { fontSize: '14px' },
        React.createElement(Radio, { checked: true }),
        React.createElement(LabelText, { bold: true }, "font weight - bold")),
    React.createElement(RadioLabel, { fontSize: '14px' },
        React.createElement(Radio, { checked: true }),
        React.createElement(LabelText, { medium: true }, "font weight - medium"))));
export const Colors = () => (React.createElement(React.Fragment, null, paletteFamilyNames.map((color) => (React.createElement(RadioLabel, { fontSize: '14px', key: color },
    React.createElement(Radio, { checked: true, color: color }),
    React.createElement(LabelText, null, color))))));
//# sourceMappingURL=Radio.stories.js.map