import React from 'react';
import { fireEvent, render } from '../__test__/testing-library';
import { Step } from './Step';
describe('Step', () => {
    it('should render correctly with no props without throwing', () => {
        expect(() => {
            const { asFragment } = render(React.createElement(Step, null, "Step"));
            expect(asFragment()).toMatchSnapshot();
        }).not.toThrow();
    });
    it('should render an active step correctly', () => {
        const { asFragment, container, getByTestId } = render(React.createElement(Step, { active: true, "data-testid": 'Step' }, "Step"));
        expect(asFragment()).toMatchSnapshot();
        expect(getByTestId('Step')).toHaveStyleRule('cursor', 'default');
        expect(container.querySelector('svg')).not.toBeInTheDocument();
    });
    it('should render a completed step correctly', () => {
        const { asFragment, container, getByTestId } = render(React.createElement(Step, { completed: true, "data-testid": 'Step' }, "Step"));
        expect(asFragment()).toMatchSnapshot();
        expect(getByTestId('Step')).toHaveStyleRule('cursor', 'default');
        expect(container.querySelector('svg')).toBeInTheDocument();
    });
    it('should render a step that is "active" and "completed" correctly', () => {
        const { asFragment, container, getByTestId } = render(React.createElement(Step, { active: true, completed: true, "data-testid": 'Step' }, "Step"));
        expect(asFragment()).toMatchSnapshot();
        expect(getByTestId('Step')).toHaveStyleRule('cursor', 'default');
        expect(container.querySelector('svg')).toBeInTheDocument();
    });
    it('should handle onClick', () => {
        const handleClick = jest.fn();
        const { asFragment, getByTestId, getByText } = render(React.createElement(Step, { active: true, "data-testid": 'Step', onClick: handleClick }, "Step"));
        expect(asFragment()).toMatchSnapshot();
        expect(getByTestId('Step')).toHaveStyleRule('cursor', 'pointer');
        fireEvent.click(getByText('Step'));
        expect(handleClick).toHaveBeenCalled();
    });
});
//# sourceMappingURL=Step.spec.js.map