import { Bus, Check } from 'pcln-icons';
import React from 'react';
import styled from 'styled-components';
import { Box } from '../Box/Box';
import { Flex } from '../Flex/Flex';
import { FormField } from '../FormField/FormField';
import { Input } from '../Input/Input';
import { Label } from '../Label/Label';
import { colorSchemeNames } from '../storybook/args';
import { Tooltip } from './Tooltip';
import { argTypes } from './Tooltip.stories.args';
const FlexColumn = styled(Flex) `
  flex-direction: column;
`;
export default {
    title: 'Tooltip',
    component: Tooltip,
    argTypes,
};
const Template = (args) => React.createElement(Tooltip, { ...args }, "I am a tooltip!");
export const TooltipComponent = Template.bind({});
TooltipComponent.args = { color: 'primary' };
export const WithoutAnchors = () => (React.createElement(Box, { mt: 5, width: 500 },
    React.createElement(Tooltip, { color: 'primary', top: true, left: true }, "left tooltip"),
    React.createElement(Tooltip, { color: 'primary', top: true, center: true }, "centered tooltip"),
    React.createElement(Tooltip, { color: 'error', top: true, right: true }, "right tooltip"),
    React.createElement("br", null),
    React.createElement(Tooltip, { bottom: true, left: true }, "left tooltip"),
    React.createElement(Tooltip, { bottom: true, center: true }, "centered tooltip"),
    React.createElement(Tooltip, { bottom: true, right: true }, "right tooltip")));
export const WithAnchors = () => (React.createElement(FlexColumn, { justifyContent: 'space-between', wrap: 'wrap' },
    React.createElement(Box, { width: 300, p: 2, my: 2 },
        React.createElement(Tooltip, { top: true, left: true, color: 'primary' }, "top left tooltip"),
        React.createElement("div", null, "some text")),
    React.createElement(Box, { width: '300px', p: 2, mb: 5 },
        React.createElement("div", null, "some text"),
        React.createElement(Tooltip, { bottom: true, left: true, color: 'error' }, "bottom left tooltip")),
    React.createElement(Box, { width: '300px', p: 2, mb: 55 },
        React.createElement(FormField, null,
            React.createElement(Label, null, "Email Address"),
            React.createElement(Input, { defaultValue: 'albus.dumbledore@priceline.com', id: 'form-field-3', placeholder: 'example@test.com' }),
            React.createElement(Check, { color: 'primary' })),
        React.createElement(Tooltip, { bottom: true, left: true, color: 'primary' }, "bottom left tooltip")),
    React.createElement(Box, { width: '300px', p: 2, mb: 5 },
        React.createElement(FormField, null,
            React.createElement(Label, null, "Email Address"),
            React.createElement(Input, { defaultValue: 'albus.dumbledore@priceline.com', id: 'form-field-4', placeholder: 'example@test.com' }),
            React.createElement(Check, { color: 'primary' })),
        React.createElement(Tooltip, { bottom: true, center: true, color: 'primary' }, "bottom center tooltip")),
    React.createElement(Box, { width: '300px', p: 2, mb: '80px' },
        React.createElement(FormField, null,
            React.createElement(Label, null, "Email Address"),
            React.createElement(Input, { defaultValue: 'albus.dumbledore@priceline.com', id: 'form-field-5', placeholder: 'example@test.com' }),
            React.createElement(Check, { color: 'error' })),
        React.createElement(Tooltip, { bottom: true, right: true, color: 'error' }, "Email Address Invalid")),
    React.createElement(Box, { width: '300px', p: 2, mb: 5 },
        React.createElement(Tooltip, { top: true, left: true, color: 'primary' }, "top left tooltip"),
        React.createElement(FormField, null,
            React.createElement(Label, null, "Email Address"),
            React.createElement(Input, { defaultValue: 'albus.dumbledore@priceline.com', id: 'form-field-6', placeholder: 'example@test.com' }),
            React.createElement(Check, { color: 'primary' }))),
    React.createElement(Box, { width: '300px', p: 2, mb: 5 },
        React.createElement(Tooltip, { top: true, center: true, color: 'primary' }, "top center tooltip"),
        React.createElement(FormField, null,
            React.createElement(Label, null, "Email Address"),
            React.createElement(Input, { defaultValue: 'albus.dumbledore@priceline.com', id: 'form-field-7', placeholder: 'example@test.com' }),
            React.createElement(Check, { color: 'primary' }))),
    React.createElement(Box, { width: '300px', p: 2 },
        React.createElement(Tooltip, { top: true, right: true, color: 'primary' }, "top right tooltip"),
        React.createElement(FormField, null,
            React.createElement(Label, null, "Email Address"),
            React.createElement(Input, { defaultValue: 'albus.dumbledore@priceline.com', id: 'form-field-8', placeholder: 'example@test.com' }),
            React.createElement(Check, { color: 'primary' })))));
const ColorSchemesTemplate = () => {
    return (React.createElement(React.Fragment, null, colorSchemeNames.map((colorScheme) => (React.createElement(Box, { mb: '70px', key: colorScheme },
        React.createElement(Tooltip, { top: true, right: true, colorScheme: colorScheme },
            React.createElement(Flex, { alignItems: 'center' },
                React.createElement(Bus, { mr: 2 }),
                colorScheme)),
        React.createElement(FormField, null,
            React.createElement(Label, null, "Email Address"),
            React.createElement(Input, { defaultValue: 'albus.dumbledore@priceline.com', id: 'form-field-7', placeholder: 'example@test.com' }),
            React.createElement(Check, { color: 'primary' })))))));
};
export const ColorSchemes = ColorSchemesTemplate.bind({});
ColorSchemesTemplate.args = {};
//# sourceMappingURL=Tooltip.stories.js.map