import { ArrowDown } from 'pcln-icons';
import React from 'react';
import { ThemeConsumer } from 'styled-components';
import { Box } from '../Box/Box';
import { Card } from '../Card/Card';
import { Flex } from '../Flex/Flex';
import { Text } from '../Text/Text';
import { createTheme } from '../utils/createTheme';
const theme = createTheme();
const blacklist = ['darkPurple'];
const keys = Object.keys(theme.colors).filter((key) => !blacklist.includes(key));
const next = keys.map((key) => ({ key, value: theme.colors[key] }));
const colorSchemeFamilies = [
    'Primary',
    'Secondary',
    'Neutral',
    'Success',
    'Warning',
    'Caution',
    'Highlight',
    'Promo',
    'Alert',
    'Heading',
];
const ColorCard = (props) => (React.createElement(Flex, { flexDirection: 'column', width: '100%' },
    React.createElement(Card, { borderRadius: 'xl', bg: props.color || props.shade, height: '100px' }),
    React.createElement(Text, { f: 0 }, props.shade),
    React.createElement(Text, { as: 'pre', m: 0 }, props.hex)));
const ColorSchemeColumnCard = ({ title }) => {
    return (React.createElement(Card, { height: '100px', width: '108px', borderRadius: 'xl' },
        React.createElement(Flex, { flexDirection: 'column', alignItems: 'center', justifyContent: 'center', height: '100%' },
            React.createElement(Text, { mb: 2, fontSize: '14px' }, title),
            React.createElement(ArrowDown, { size: '16px' }))));
};
const BackgroundForegroundCard = () => {
    return (React.createElement(Flex, { width: '100%', justifyContent: 'space-around', my: 2 },
        React.createElement(ColorSchemeColumnCard, { title: 'Background' }),
        React.createElement(ColorSchemeColumnCard, { title: 'Foreground' })));
};
export default {
    title: 'Design / Color',
};
export const Palette = () => (React.createElement(ThemeConsumer, null, (theme) => {
    return (React.createElement("div", null,
        React.createElement(Box, { p: 3 },
            React.createElement("h1", null, "Palette"),
            React.createElement("p", null, "The palette allows you to change the color of components."),
            React.createElement(Flex, { flexWrap: 'wrap' }, Object.keys(theme.palette).map((color) => {
                const shades = theme.palette[color];
                if (typeof shades === 'object') {
                    return (React.createElement("div", { style: { width: '100%' } },
                        React.createElement("h4", null, color),
                        React.createElement(Flex, { flexWrap: 'wrap' }, Object.keys(shades).map((shade) => {
                            const fullColor = `${color}.${shade}`;
                            return (React.createElement(Box, { key: fullColor, p: 3, width: [1, 1 / 2, 1 / 3, 1 / 4, 1 / 7] },
                                React.createElement(ColorCard, { name: fullColor, color: fullColor, shade: shade, hex: shades[shade] })));
                        })),
                        React.createElement("hr", null)));
                }
                else {
                    const fullColor = `${color}.${shades}`;
                    return (React.createElement(Box, { key: fullColor, p: 3, width: [1, 1 / 2, 1 / 3, 1 / 4, 1 / 5] },
                        React.createElement(ColorCard, { name: fullColor, color: fullColor })));
                }
            })))));
}));
export const Colors = () => (React.createElement("div", null,
    React.createElement(Box, { p: 3 },
        React.createElement("h1", null, "Colors")),
    React.createElement(Flex, { flexWrap: 'wrap' }, next.map((color) => (React.createElement(Box, { key: color.key, p: 3, width: [1, 1 / 2, 1 / 3, 1 / 4, 1 / 5] },
        React.createElement(ColorCard, { name: color.key, shade: color.key, hex: color.value })))))));
export const ColorScheme = () => (React.createElement(ThemeConsumer, null, (theme) => {
    return (React.createElement("div", null,
        React.createElement(Box, { p: 3 },
            React.createElement("h1", null, "Color Scheme"),
            React.createElement(Flex, { flexWrap: 'wrap' }, colorSchemeFamilies.map((colorSchemeFamily) => {
                return (React.createElement(Card, { borderRadius: 'xl', m: 2, p: 3, key: colorSchemeFamily },
                    React.createElement(Flex, { flexDirection: 'column' },
                        React.createElement(Text, { textStyle: 'heading3' }, colorSchemeFamily),
                        React.createElement(BackgroundForegroundCard, null),
                        Object.entries(theme.colorSchemes)
                            .filter((entry) => entry[0].includes(colorSchemeFamily.toLowerCase()))
                            .map((entry) => {
                            const [key, colorScheme] = entry;
                            return (React.createElement(Flex, { flexDirection: 'column', py: 3, key: key },
                                React.createElement(Text, { fontWeight: 'bold', mb: 2 }, key),
                                React.createElement(Flex, null,
                                    React.createElement(Box, { px: 3, width: '140px' },
                                        React.createElement(ColorCard, { color: colorScheme.background })),
                                    React.createElement(Box, { px: 3, width: '140px' },
                                        React.createElement(ColorCard, { color: colorScheme.foreground })))));
                        }))));
            })))));
}));
//# sourceMappingURL=Colors.stories.js.map