/// <reference types="react" />
import { BackgroundProps, BorderProps, ColorProps, FlexboxProps, GridProps, LayoutProps, PositionProps, ShadowProps, SpaceProps, TypographyProps } from 'styled-system';
import { colors } from './colors';
/**
 * @public
 */
export { colors };
/**
 * @public
 */
export declare const breakpoints: string[];
/**
 * @public
 */
export declare const mediaQueries: any;
/**
 * @public
 */
export declare const spaceValues: number[];
export declare const space: string[];
/**
 * @public
 */
export declare const font = "'Montserrat','Helvetica Neue',Helvetica,Arial,sans-serif";
/**
 * @public
 */
export declare const fontSizes: number[];
/**
 * @public
 */
export declare const medium = 500;
/**
 * @public
 */
export declare const bold = 700;
/**
 * @public
 */
export declare const regular = 500;
/**
 * styled-system's `fontWeight` function can hook into the `fontWeights` object
 *
 * @public
 */
export declare const fontWeights: {
    medium: number;
    bold: number;
    regular: number;
};
/**
 * @public
 */
export declare const lineHeights: {
    standard: number;
    display: number;
};
/**
 * @public
 */
export declare const typography: {
    title1: {
        fontWeight: number;
        fontSize: string;
        lineHeight: string;
    };
    title2: {
        fontWeight: number;
        fontSize: string;
        lineHeight: string;
    };
    title3: {
        fontWeight: number;
        fontSize: string;
        lineHeight: string;
    };
    heading1: {
        fontWeight: number;
        fontSize: string;
        lineHeight: string;
    };
    heading2: {
        fontWeight: number;
        fontSize: string;
        lineHeight: string;
    };
    heading3: {
        fontWeight: number;
        fontSize: string;
        lineHeight: string;
    };
    heading4: {
        fontWeight: number;
        fontSize: string;
        lineHeight: string;
    };
    heading5: {
        fontWeight: number;
        fontSize: string;
        lineHeight: string;
    };
    heading6: {
        fontWeight: number;
        fontSize: string;
        lineHeight: string;
    };
    article: {
        fontWeight: number;
        fontSize: string;
        lineHeight: string;
        letterSpacing: string;
    };
    paragraph: {
        fontWeight: number;
        fontSize: string;
        lineHeight: string;
        letterSpacing: string;
    };
    caption: {
        fontWeight: number;
        fontSize: string;
        lineHeight: string;
        letterSpacing: string;
    };
    overline: {
        fontWeight: number;
        fontSize: string;
        lineHeight: string;
        letterSpacing: string;
    };
    disclaimer: {
        fontWeight: number;
        fontSize: string;
        lineHeight: string;
        letterSpacing: string;
    };
    highlight: {
        fontWeight: number;
        fontSize: string;
        lineHeight: string;
        letterSpacing: string;
        textTransform: string;
        caps: boolean;
    };
    highlightBold: {
        fontWeight: number;
        fontSize: string;
        lineHeight: string;
        letterSpacing: string;
        textTransform: string;
        caps: boolean;
    };
    subtitle1: {
        fontWeight: number;
        fontSize: string;
        lineHeight: string;
    };
    subheading1: {
        fontWeight: number;
        fontSize: string;
        lineHeight: string;
    };
    subheading2: {
        fontWeight: number;
        fontSize: string;
        lineHeight: string;
    };
    subheading3: {
        fontWeight: number;
        fontSize: string;
        lineHeight: string;
    };
    subheading4: {
        fontWeight: number;
        fontSize: string;
        lineHeight: string;
    };
    subheading5: {
        fontWeight: number;
        fontSize: string;
        lineHeight: string;
    };
    subheading6: {
        fontWeight: number;
        fontSize: string;
        lineHeight: string;
    };
    articleBold: {
        fontWeight: number;
        fontSize: string;
        lineHeight: string;
        letterSpacing: string;
    };
    paragraphBold: {
        fontWeight: number;
        fontSize: string;
        lineHeight: string;
        letterSpacing: string;
    };
    paragraph2: {
        fontWeight: number;
        fontSize: string;
        lineHeight: string;
        letterSpacing: string;
    };
    paragraph2Bold: {
        fontWeight: number;
        fontSize: string;
        lineHeight: string;
        letterSpacing: string;
    };
    captionBold: {
        fontWeight: number;
        fontSize: string;
        lineHeight: string;
        letterSpacing: string;
    };
    overlineMedium: {
        fontWeight: number;
        fontSize: string;
        lineHeight: string;
        letterSpacing: string;
    };
    disclaimerBold: {
        fontWeight: number;
        fontSize: string;
        lineHeight: string;
        letterSpacing: string;
    };
    label: {
        fontWeight: number;
        fontSize: string;
        lineHeight: number;
        letterSpacing: string;
    };
};
/**
 * @public
 */
export type ZIndexStrings = 'auto' | 'absolute' | 'dropdown' | 'sticky' | 'fixed' | 'overlay' | 'onOverlay' | 'offCanvas' | 'modal' | 'popover' | 'tooltip';
/**
 * @public
 */
export type ZIndex = number | ZIndexStrings;
/**
 * @public
 */
export type ZIndices = Record<ZIndexStrings, string | number>;
/**
 * @public
 */
export declare const zIndices: ZIndices;
/**
 * styled-system's `borderRadius` function can hook into the `radii` object/array
 * @public
 */
export declare const radii: number[];
/**
 * @public
 */
export declare const radius = "2px";
/**
 * @public
 */
export declare const baseBorderRadii: {
    none: string;
    xsm: string;
    sm: string;
    md: string;
    lg: string;
    xl: string;
    '2xl': string;
    '3xl': string;
    full: string;
};
/**
 * @public
 */
export declare const actionBorderRadii: {
    'action-sm': string;
    'action-md': string;
    'action-lg': string;
    'action-xl': string;
};
/**
 * @public
 */
export declare const borderRadii: {
    'action-sm': string;
    'action-md': string;
    'action-lg': string;
    'action-xl': string;
    none: string;
    xsm: string;
    sm: string;
    md: string;
    lg: string;
    xl: string;
    '2xl': string;
    '3xl': string;
    full: string;
};
/**
 * @public
 */
export type BorderRadius = keyof typeof borderRadii;
/**
 * @public
 */
export declare const maxContainerWidth = "1280px";
/**
 * @public
 */
export declare const shadows: {
    sm: string;
    md: string;
    lg: string;
    xl: string;
    '2xl': string;
    'overlay-md': string;
    'overlay-lg': string;
    'overlay-xl': string;
};
/**
 * @public
 */
export type BoxShadowSize = keyof typeof shadows;
/**
 * @public
 */
export declare const textShadows: {
    sm: string;
    md: string;
};
/**
 * @public
 */
export declare const duration: {
    fast: string;
    normal: string;
    slow: string;
    slowest: string;
    'duration-100': string;
    'duration-200': string;
    'duration-250': string;
    'duration-300': string;
    'duration-450': string;
};
/**
 * @public
 */
export declare const timingFunctions: {
    easeInOut: string;
    easeOut: string;
    easeIn: string;
    'standard-productive': string;
    'entrance-productive': string;
    'exit-productive': string;
    'standard-expressive': string;
    'entrance-expressive': string;
    'exit-expressive': string;
};
/**
 * @public
 */
export declare const textStyles: any;
/**
 * @public
 */
export declare const colorStyles: any;
/**
 * @public
 */
export declare const theme: any;
/**
 * @public
 */
export type TextStyle = {
    fontWeight: number;
    fontSize: string;
    lineHeight: string;
};
/**
 * @public
 */
export declare const paletteFamilyVariations: readonly ["lightest", "light", "tint", "base", "heading", "tone", "dark", "shade", "darkest"];
/**
 * @public
 */
export type PaletteFamily = {
    lightest?: string;
    light?: string;
    tint?: string;
    base: string;
    heading?: string;
    tone?: string;
    dark?: string;
    shade?: string;
    darkest?: string;
};
/**
 * @public
 */
export declare const paletteFamilyNames: readonly ["primary", "secondary", "text", "highlight", "success", "error", "warning", "alert", "caution", "notify", "pricePrimary", "priceSecondary", "strike", "promoPrimary", "promoSecondary", "border", "background"];
/**
 * @public
 */
export type PaletteFamilyVariation = (typeof paletteFamilyVariations)[number];
/**
 * @public
 */
export type PaletteFamilyName = (typeof paletteFamilyNames)[number];
/**
 * @public
 */
export type PaletteFamilies = Record<PaletteFamilyName, PaletteFamily>;
/**
 * @public
 */
export type PaletteColorPaletteFamily = Array<keyof PaletteFamilies>[number];
/**
 * @public
 */
export type PaletteColorPaletteFamilyOption = Array<keyof PaletteFamily>[number];
/**
 * @public
 */
export type PaletteColor = `${PaletteColorPaletteFamily}.${PaletteColorPaletteFamilyOption}`;
/**
 * @public
 */
export declare const paletteColors: string[];
/**
 * @public
 */
export type ColorStyle = {
    color: string;
    backgroundColor: string;
};
/**
 * @public
 */
export declare const colorStyleNames: readonly ["whiteOnText", "whiteOnGray", "textOnLightGray", "whiteOnBlue", "blueOnLightBlue", "whiteOnGreen", "greenOnLightGreen", "whiteOnRed", "redOnLightRed", "textOnOrange", "whiteOnPurple", "purpleOnLightPurple", "textOnWhite", "grayOnWhite", "blueOnWhite", "greenOnWhite", "redOnWhite", "purpleOnWhite", "whiteOnDarkOrange", "info", "success", "warning", "danger"];
/**
 * @public
 */
export type ColorStyleName = (typeof colorStyleNames)[number];
/**
 * @public
 */
export type ColorStyles = Record<ColorStyleName, ColorStyle>;
/**
 * @public
 */
export type ColorScheme = {
    foreground: string;
    background: string;
    backgroundName: PaletteColor;
};
/**
 * @public
 */
export declare const colorSchemeNames: readonly ["primary", "primaryLight", "primaryLightest", "primaryDark", "primaryShade", "primaryDarkOnLight", "secondary", "secondaryLight", "secondaryLightest", "secondaryDark", "secondaryDarkOnLight", "neutral", "neutralLight", "neutralLightest", "neutralDark", "neutralDarkOnLight", "neutralDarkOnLightest", "success", "successLight", "successLightest", "successDark", "successDarkOnLight", "warning", "warningLight", "warningLightest", "cautionLight", "highlightLight", "promo", "promoLight", "promoLightest", "promoDark", "promoDarkOnLight", "alert", "alertLight", "alertLightest", "alertDarkOnLight", "heading", "headingBase", "headingLight", "headingOnPrimaryLight"];
/**
 * @public
 */
export type ColorSchemeName = (typeof colorSchemeNames)[number];
/**
 * @public
 */
export type ColorSchemes = Record<ColorSchemeName, ColorScheme>;
/**
 * @public
 */
export type ColorName = keyof typeof colors;
/**
 * @public
 */
export type ColorProp = ColorName | PaletteFamilyName | PaletteColor;
/**
 * @public
 */
export type DesignSystemTheme = {
    space: string[];
    colors: Record<string, string>;
    componentStyles: Record<string, Record<string, Record<string, Record<string, unknown>>>>;
    mediaQueries: string[];
    breakpoints: string[];
    palette: PaletteFamilies;
    colorStyles: ColorStyles;
    textStyles: TextStyle[];
    contrastRatio: number;
    colorSchemes: ColorSchemes;
    zIndices: ZIndices;
};
/**
 * @public
 */
export interface IStyledSystemProps extends BackgroundProps, BorderProps, ColorProps, FlexboxProps, GridProps, LayoutProps, PositionProps, ShadowProps, SpaceProps, TypographyProps {
    style?: React.CSSProperties;
}
/**
 * @public
 */
export declare const ComposedStyleFns: import("styled-system").styleFn;
//# sourceMappingURL=theme.d.ts.map